@@ -47,9 +47,6 @@ module.exports = {
         //
         // http://eslint.org/docs/rules/index.html#possible-errors
 
-        // disallow dangling commas
-        'comma-dangle': [2, 'never'],
-
         // disallow assignment in conditional expressions
         'no-cond-assign': [2, 'except-parens'],
 
@@ -104,9 +101,6 @@ module.exports = {
         // disallow irregular whitespace outside of strings and comments
         'no-irregular-whitespace': 2,
 
-        // disallow negation of the left operand of an in expression
-        'no-negated-in-lhs': 2,
-
         // disallow the use of object properties of the global object (Math and JSON) as functions
         'no-obj-calls': 2,
 
@@ -119,6 +113,9 @@ module.exports = {
         // disallow sparse arrays
         'no-sparse-arrays': 2,
 
+        // disallow template literal placeholder syntax in regular strings
+        'no-template-curly-in-string': 2,
+
         // Avoid code that looks like two expressions but is actually one
         'no-unexpected-multiline': 2,
 
@@ -128,6 +125,9 @@ module.exports = {
         // disallow control flow statements in finally blocks
         'no-unsafe-finally': 2,
 
+        // disallow negating the left operand of relational operators
+        'no-unsafe-negation': 2,
+
         // disallow comparisons with the value NaN
         'use-isnan': 2,
 
@@ -154,6 +154,9 @@ module.exports = {
         // treat var statements as if they were block scoped
         'block-scoped-var': 2,
 
+        // enforce that class methods utilize this
+        'class-methods-use-this': 2,
+
         // specify the maximum cyclomatic complexity allowed in a program
         'complexity': [0, 11],
 
@@ -220,6 +223,9 @@ module.exports = {
         // disallow the use of leading or trailing decimal points in numeric literals
         'no-floating-decimal': 2,
 
+        // disallow assignment to native objects or read-only global variables
+        'no-global-assign': 2,
+
         // disallow the type conversions with shorter notations
         'no-implicit-coercion': 0,
 
@@ -253,9 +259,6 @@ module.exports = {
         // disallow use of multiline strings
         'no-multi-str': 2,
 
-        // disallow reassignments of native objects
-        'no-native-reassign': 2,
-
         // disallow use of new operator when not part of the assignment or comparison
         'no-new': 2,
 
@@ -268,8 +271,7 @@ module.exports = {
         // disallow use of (old style) octal literals
         'no-octal': 2,
 
-        // disallow use of octal escape sequences in string literals, such as
-        // var foo = 'Copyright \251';
+        // disallow use of octal escape sequences in string literals
         'no-octal-escape': 2,
 
         // disallow reassignment of function parameters
@@ -281,6 +283,9 @@ module.exports = {
         // disallow declaring the same variable more then once
         'no-redeclare': 2,
 
+        // disallow certain object properties
+        'no-restricted-properties': [2/*, { 'object': '', 'property': '' }*/],
+
         // disallow use of assignment in return statement
         'no-return-assign': [2, 'except-parens'],
 
@@ -300,7 +305,7 @@ module.exports = {
         'no-throw-literal': 2,
 
         // disallow unmodified conditions of loops
-        'no-unmodified-loop-condition': 0, // disabled temporarily: https://github.com/eslint/eslint/issues/6280
+        'no-unmodified-loop-condition': 0, // disabled: https://github.com/eslint/eslint/issues/6280
 
         // disallow usage of expressions in statement position
         'no-unused-expressions': 2,
@@ -317,6 +322,10 @@ module.exports = {
         // disallow unnecessary escape characters
         'no-useless-escape': 2,
 
+        // disallow redundant return statements
+        // TODO: disabled due to https://github.com/eslint/eslint/issues/7477
+        'no-useless-return': 0,
+
         // disallow use of void operator
         'no-void': 2,
 
@@ -407,6 +416,9 @@ module.exports = {
         // require camel case names
         'camelcase': 0,
 
+        // disallow dangling commas
+        'comma-dangle': [2, 'never'],
+
         // enforce spacing before and after comma
         'comma-spacing': [2, { before: false, after: true }],
 
@@ -422,6 +434,9 @@ module.exports = {
         // enforce newline at the end of file, with no multiple empty lines
         'eol-last': 2,
 
+        // require or disallow spacing between function identifiers and their invocations
+        'func-call-spacing': [2, 'never'],
+
         // require function expressions to have a name
         'func-names': 0,
 
@@ -429,7 +444,7 @@ module.exports = {
         'func-style': 0,
 
         // disallow specified identifiers
-        'id-blacklist': 2,
+        'id-blacklist': [2/*, ''*/],
 
         // this option enforces minimum and maximum identifier lengths (variable names, property names etc.)
         'id-length': 0,
@@ -455,12 +470,18 @@ module.exports = {
         // enforces empty lines around comments
         'lines-around-comment': 0,
 
+        // require or disallow newlines around directives
+        'lines-around-directive': 2,
+
         // specify the maximum depth that blocks can be nested
         'max-depth': 0,
 
         // specify the maximum length of a line in your program
         'max-len': 0,
 
+        // enforce a maximum file length
+        'max-lines': 0,
+
         // specify the maximum depth callbacks can be nested
         'max-nested-callbacks': 0,
 
@@ -473,6 +494,9 @@ module.exports = {
         // enforce a maximum number of statements allowed per line
         'max-statements-per-line': 0,
 
+        // enforce or disallow newlines between operands of ternary expressions
+        'multiline-ternary': 0,
+
         // require a capital letter for constructors
         'new-cap': [2, { capIsNew: true, newIsCap: true, properties: true, capIsNewExceptions: ['$.Deferred', 'Baton'] }],
 
@@ -503,6 +527,19 @@ module.exports = {
         // disallow if as the only statement in an else block
         'no-lonely-if': 0,
 
+        // disallow mixes of different operators
+        'no-mixed-operators': [2, {
+            'groups': [
+                // allow to mix arithmethic operators
+                //['+', '-', '*', '/', '%', '**'],
+                ['&', '|', '^', '~', '<<', '>>', '>>>'],
+                ['==', '!=', '===', '!==', '>', '>=', '<', '<='],
+                ['&&', '||'],
+                ['in', 'instanceof']
+            ],
+            'allowSamePrecedence': true
+        }],
+
         // disallow mixed spaces and tabs for indentation
         'no-mixed-spaces-and-tabs': 2,
 
@@ -524,8 +561,8 @@ module.exports = {
         // disallow use of certain syntax in code
         'no-restricted-syntax': 0,
 
-        // disallow space between function identifier and application
-        'no-spaced-func': 2,
+        // disallow tabs in file
+        'no-tabs': 2,
 
         // disallow the use of ternary operators
         'no-ternary': 0,
@@ -542,6 +579,9 @@ module.exports = {
         // disallow whitespace before properties
         'no-whitespace-before-property': 2,
 
+        // enforce consistent line breaks inside braces
+        'object-curly-newline': 0,
+
         // require or disallow padding inside curly braces
         'object-curly-spacing': [2, 'always', { objectsInObjects: true, arraysInObjects: true }],
 
@@ -578,6 +618,9 @@ module.exports = {
         // enforce spacing before and after semicolons
         'semi-spacing': [2, { before: false, after: true }],
 
+        // require object keys to be sorted
+        'sort-keys': 0,
+
         // sort variables within the same declaration block
         'sort-vars': 0,
 
