@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -28,9 +29,10 @@ define('io.ox/office/baseframework/app/baseapplication', [
     'io.ox/office/baseframework/utils/apptooltipmixin',
     'io.ox/office/baseframework/app/applicationlauncher',
     'io.ox/office/baseframework/app/appobjectmixin',
+    'io.ox/office/tk/utils/deferredutils',
     'settings!io.ox/office',
     'gettext!io.ox/office/baseframework/main'
-], function (Notifications, SessionRestore, MailApi, Utils, IO, DriveUtils, BaseObject, TimerMixin, BaseLabels, ErrorCode, ErrorMessages, AppTooltipMixin, ApplicationLauncher, AppObjectMixin, Settings, gt) {
+], function (Notifications, SessionRestore, MailApi, Utils, IO, DriveUtils, BaseObject, TimerMixin, BaseLabels, ErrorCode, ErrorMessages, AppTooltipMixin, ApplicationLauncher, AppObjectMixin, DeferredUtils, Settings, gt) {
 
     'use strict';
 
@@ -163,6 +165,12 @@ define('io.ox/office/baseframework/app/baseapplication', [
         // file descriptor of the document edited by this application
         var file = Utils.getObjectOption(launchOptions, 'file', null);
 
+        // the file is encrypted with OX Guard
+        var fileIsGuardEncrypted = Utils.hasProperty(launchOptions, 'auth_code');
+
+        // the full path to the document edited by this application
+        var path = [];
+
         // callback to flush the document before accessing its source
         var initFileHandler = Utils.getFunctionOption(initOptions, 'initFileHandler');
 
@@ -175,14 +183,13 @@ define('io.ox/office/baseframework/app/baseapplication', [
         // all registered quit handlers
         var quitHandlers = [];
 
-        // a deferred object representing the initialization state (pending: early application construction, resolved: regular application runtime)
-        var initDef = $.Deferred();
+        var initDef = baseContext.createDeferredObject({ infoString: 'BaseApplication: initialization', app: self });
 
         // a deferred object representing the import state (pending: before import, resolved/rejected: import already started)
-        var importStartDef = $.Deferred();
+        var importStartDef = baseContext.createDeferredObject({ infoString: 'BaseApplication: importStartDef', app: self });
 
         // a deferred object representing the import state (pending: importing, resolved/rejected: import finished with state)
-        var importFinishDef = $.Deferred();
+        var importFinishDef = baseContext.createDeferredObject({ infoString: 'BaseApplication: importFinishDef', app: self });
 
         // time stamp when the application launcher has started
         var launchStartTime = 0;
@@ -312,7 +319,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
             // open pop-up window early to prevent browser pop-up blockers (bug 28251)
             if (convert) {
                 popupWindow = blankshield.open('about:blank', '_blank');
-                window.focus();
+                Utils.setFocus(window);
 
                 // browser plug-ins may still prevent opening pop-up windows
                 if (!popupWindow) { return reject('popupblocker'); }
@@ -362,7 +369,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
                 // download file into the pop-up window, show/focus it
                 if (popupWindow) {
                     popupWindow.location = downloadURL;
-                    popupWindow.focus();
+                    Utils.setFocus(popupWindow);
                     return;
                 }
 
@@ -380,9 +387,14 @@ define('io.ox/office/baseframework/app/baseapplication', [
                 });
             }
 
+            //workaround for unreproducable Bug 48895
+            var busyTimeoutPromise = self.createAbortablePromise(DeferredUtils.createDeferred(self, 'BaseApplication.download() timeout'), function () {
+                docView.leaveBusy();
+            }, 15000);
+
             // leave busy mode after download
             downloadPromise.always(function () {
-                docView.leaveBusy();
+                busyTimeoutPromise.abort();
             });
 
             return downloadPromise;
@@ -491,29 +503,30 @@ define('io.ox/office/baseframework/app/baseapplication', [
                     compose.app.model.attachFiles([_.extend(attachment, { group: 'file' })]);
                 });
             }
-            var attach = _.clone(file);
 
-            // delete version number, that preview of the attached file is "current version"
-            // Bug 45775
-            delete attach.version;
+            // Bug 48214, Bug 45775
+            // update file data, that preview of the attached file is "current version"
+            DriveUtils.propagateChangeFile(file).done(function (updatedFile) {
+                var attach = _.clone(updatedFile);
 
-            if (attach.source && attach.source === 'mail') {
+                if (attach.source && attach.source === 'mail') {
 
-                // bug 32760: special handling, if file is an attachment, e.g. of a mail or task
-                // TODO: propably deprecated
-                MailApi.get({ id: attach.id, folder_id: attach.folder_id }).done(function (mail) {
-                    return reply(mail, mail.attachments[1]);
-                });
+                    // bug 32760: special handling, if file is an attachment, e.g. of a mail or task
+                    // TODO: probably deprecated
+                    MailApi.get({ id: attach.id, folder_id: attach.folder_id }).done(function (mail) {
+                        return reply(mail, mail.attachments[1]);
+                    });
 
-            } else if (_.isObject(attach.origin) && attach.origin.source === 'mail') {
+                } else if (_.isObject(attach.origin) && attach.origin.source === 'mail') {
 
-                // 34300: mail attachments copied to Drive
-                MailApi.get({ id: attach.origin.id, folder_id: attach.origin.folder_id }).done(function (mail) {
-                    return reply(mail, attach);
-                });
-            } else {
-                return ox.registry.call('mail-compose', 'compose', { infostore_ids: [attach] });
-            }
+                    // 34300: mail attachments copied to Drive
+                    MailApi.get({ id: attach.origin.id, folder_id: attach.origin.folder_id }).done(function (mail) {
+                        return reply(mail, attach);
+                    });
+                } else {
+                    return ox.registry.call('mail-compose', 'compose', { infostore_ids: [attach] });
+                }
+            });
         }
 
         /**
@@ -522,7 +535,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
         function handleMailCompositionForPDFAttachment() {
             // open mail compose
             var
-                promisedAttachmentData = (self.canConvertTo('pdf-mail-attachment') && self.convertTo('pdf-mail-attachment')) || $.when({
+                promisedAttachmentData = (self.canConvertTo('pdf-attachment') && self.convertTo('pdf-attachment')) || $.when({
                     id:         '',
                     filename:   ''
                 });
@@ -568,34 +581,29 @@ define('io.ox/office/baseframework/app/baseapplication', [
          */
         function handleMailCompositionForInlineHTML() {
             // open mail compose
-            var
-                promisedDocument = (self.canConvertTo('inline-html-document') && self.convertTo('inline-html-document')) || $.when({
-                    title:   '',
+            var promisedDocument = self.canConvertTo('inline-html') && self.convertTo('inline-html');
+            if (!promisedDocument) {
+                promisedDocument = $.when({
+                    title: '',
                     content: ''
-                }),
-                messageFormat = 'alternative'; //  messageFormat = MailSettings.get('messageFormat'); // HOTFIX due to module removal
+                });
+            }
 
             return promisedDocument.then(function (document) {
-                var
-                    options = {
-                        subject: document.title,
-                        attachments: {
-                            html: [{ content: document.content }]
-                        }
-                        //  gets assigned explicitly only in case a user has
-                        //  a 'plain text' mail message format preference
-                        //
-                        //  editorMode: 'html',
-                        //  preferredEditorMode: 'html'
-                    };
-                if (messageFormat === 'text') {
-                    options.editorMode = options.preferredEditorMode = 'html';
-                }
+                // changes for Bug 48812 & Bug 49615
+                var options = {
+                    preferredEditorMode: 'alternative',
+                    editorMode: 'html',
+                    subject: document.title,
+                    attachments: {
+                        html: [{ content: document.content }]
+                    }
+                };
+
                 return ox.registry.call('mail-compose', 'compose', options);
 
             }).fail(function (msg) {
-                var
-                    message = Utils.getStringOption(msg, 'text', null);
+                var message = Utils.getStringOption(msg, 'text', null);
                 if (message) {
                     handleMailCompositionFailure(message);
                 }
@@ -1034,6 +1042,27 @@ define('io.ox/office/baseframework/app/baseapplication', [
             return _.isString(fileName) ? Utils.getFileExtension(fileName) : null;
         };
 
+        /**
+         * Returns the full path to the document edited by this application.
+         *
+         * @returns {Array<String>}
+         *  The current file path, as array of strings with the titles of all
+         *  path components.
+         */
+        this.getFilePath = function () {
+            return _.pluck(path, 'title');
+        };
+
+         /**
+         * Returns whether the currently loaded document is encrypted.
+         *
+         * @returns {Boolean}
+         *  Whether the currently loaded document is encrypted.
+         */
+        this.isDocumentEncrypted = function () {
+            return fileIsGuardEncrypted;
+        };
+
         // server requests ----------------------------------------------------
 
         /**
@@ -1110,22 +1139,22 @@ define('io.ox/office/baseframework/app/baseapplication', [
          */
         this.createImageNode = function (url, options) {
 
-            var // the resulting deferred object
-                def = $.Deferred(),
-                // the image node
-                imgNode = $('<img>', { src: url }),
-                // the duration of the failure timeout
-                timeout = Utils.getIntegerOption(options, 'timeout', 10000, 0),
-                // the resulting promise
-                promise = this.createAbortablePromise(def, _.noop, timeout),
-                // the event handlers for the image node
-                handlers = {
-                    load: function () { def.resolve(imgNode); },
-                    error: function () { def.reject(); }
-                };
+            // the resulting deferred object
+            var def = DeferredUtils.createDeferred(self, 'BaseApplication: createImageNode');
+            // the image node
+            var imgNode = $('<img>');
+            // the duration of the failure timeout
+            var timeout = Utils.getIntegerOption(options, 'timeout', 10000, 0);
+            // the resulting promise
+            var promise = this.createAbortablePromise(def, _.noop, timeout);
+            // the event handlers for the image node
+            var handlers = {
+                load: function () { def.resolve(imgNode); },
+                error: function () { def.reject(); }
+            };
 
             // wait that the image is loaded
-            imgNode.one(handlers);
+            imgNode.one(handlers).attr('src', url);
             return promise.always(function () { imgNode.off(handlers); });
         };
 
@@ -1407,12 +1436,6 @@ define('io.ox/office/baseframework/app/baseapplication', [
                 // the Promise with the result of the flush callback handler
                 flushPromise = (this.isImportSucceeded() && this.hasFileDescriptor()) ? $.when(flushHandler.call(this, 'email')) : $.Deferred().reject();
 
-            /*
-            flushPromise = flushPromise.then(function () {
-                return DriveUtils.propagateChangeFile(self.getFileDescriptor());
-            });
-            */
-
             return flushPromise.then(handleMailComposition, handleMailCompositionFailure);
         };
 
@@ -1445,7 +1468,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
                 var origQuitMethod = this.quit;
 
                 // create the result deferred (rejecting means resume application)
-                currentQuitDef = $.Deferred();
+                currentQuitDef = DeferredUtils.createDeferred(self, 'BaseApplication: quit');
 
                 // rejected: resume to running state of application
                 currentQuitDef.fail(function () {
@@ -1529,18 +1552,25 @@ define('io.ox/office/baseframework/app/baseapplication', [
             return this.getConverter(type).call(this);
         };
 
+        this.flushDocument = function (reason) {
+            return $.when(flushHandler.call(self, reason));
+        };
+
         // initialization -----------------------------------------------------
 
         // register application in global cache for type detection
         runningAppMap[this.cid] = this;
 
         // provide the API provided by a real BaseObject instance
-        this.createAbortablePromise = baseContext.createAbortablePromise.bind(baseContext);
         this.registerDestructor = baseContext.registerDestructor.bind(baseContext);
+        this.createAbortablePromise = baseContext.createAbortablePromise.bind(baseContext);
+        this.createResolvedPromise = baseContext.createResolvedPromise.bind(baseContext);
+        this.createRejectedPromise = baseContext.createRejectedPromise.bind(baseContext);
+        this.createDeferredObject = baseContext.createDeferredObject.bind(baseContext);
+        this.waitForEvent = baseContext.waitForEvent.bind(baseContext);
         this.waitForSuccess = baseContext.waitForSuccess.bind(baseContext);
         this.waitForFailure = baseContext.waitForFailure.bind(baseContext);
         this.waitForAny = baseContext.waitForAny.bind(baseContext);
-        this.waitForEvent = baseContext.waitForEvent.bind(baseContext);
 
         // add mix-in classes (need a complete application instance)
         TimerMixin.call(this);
@@ -1609,9 +1639,21 @@ define('io.ox/office/baseframework/app/baseapplication', [
 
                 // call the import handler
                 initGuiPromise = initGuiPromise.then(function () {
-                    return importHandler.call(self).always(function () {
+
+                    // resolve the full file path while the document is being loading (never fail, fall-back to empty array)
+                    var filePathPromise = (file && file.folder_id) ? DriveUtils.getPath(file.folder_id) : $.when([]);
+                    filePathPromise = filePathPromise.then(null, $.when.bind($, []));
+
+                    // invoke the import callback handler
+                    var importPromise = $.when(importHandler.call(self), filePathPromise).always(function () {
                         logLaunchDuration('document import', 'documentImported');
                     });
+
+                    // store the resulting file path, and return the result of the import handler
+                    return importPromise.then(function (importResult, filePath) {
+                        path = filePath || [];
+                        return importResult;
+                    });
                 });
 
                 // makes the view visible after import
@@ -1621,7 +1663,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
                     if (!self || self.isInQuit()) { return result; }
 
                     // the Deferred object used to forward the original state and result
-                    var def = $.Deferred();
+                    var def = DeferredUtils.createDeferred(self, 'BaseApplication: showAfterImport');
 
                     // make the view visible
                     docView.showAfterImport(!resolved).always(function () {
@@ -1646,7 +1688,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
 
                     // set app auto-close timeout, if specified
                     if (_.isNumber(autoCloseDelay)) {
-                        self.executeDelayed(function () { self.quit('autoclose'); }, autoCloseDelay);
+                        self.executeDelayed(function () { self.quit('autoclose'); }, { delay: autoCloseDelay, infoString: 'BaseApplication: initGuiPromise', app: self });
                     }
                     importFinishDef.resolve(result);
                 });
@@ -1719,7 +1761,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
 
                     // run all initialization callbacks registered in the MVC constructors
                     initDef.resolve();
-                });
+                }, { infoString: 'BaseApplication: init MVC instances', app: self });
             });
 
             // early exit if file descriptor cannot be resolved
@@ -1801,7 +1843,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
                     } else {
                         appWindow.one('show', initializeGui);
                     }
-                }, undefined, 'BaseApplication: GUI preparation');
+                }, { infoString: 'BaseApplication: GUI preparation', app: self });
             });
         }.call(this));
 
