@@ -6,18 +6,15 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/baseframework/app/basecontroller', [
 
-    'io.ox/core/capabilities',
-
-    'io.ox/office/tk/config',
     'io.ox/office/tk/utils',
-
     'io.ox/office/tk/keycodes',
     'io.ox/office/tk/dialogs',
 
@@ -29,9 +26,10 @@ define('io.ox/office/baseframework/app/basecontroller', [
     'io.ox/office/tk/object/triggerobject',
     'io.ox/office/tk/object/timermixin',
 
+    'io.ox/office/baseframework/utils/baseconfig',
     'io.ox/office/baseframework/app/appobjectmixin'
 
-], function (Capabilities, Config, Utils, KeyCodes, Dialogs, DriveUtils, ShareUtils, DOMConsole, BaseObject, TriggerObject, TimerMixin, AppObjectMixin) {
+], function (Utils, KeyCodes, Dialogs, DriveUtils, ShareUtils, DOMConsole, BaseObject, TriggerObject, TimerMixin, Config, AppObjectMixin) {
 
     'use strict';
 
@@ -52,10 +50,6 @@ define('io.ox/office/baseframework/app/basecontroller', [
      *  The current value (the result of the getter callback) of the controller
      *  item.
      *
-     * @property {Boolean} dirty
-     *  Whether the item has been set to dirty state. A dirty item will always
-     *  be updated, regardless if it has been changed since the last update.
-     *
      * @property {Array<ItemState>} parentStates
      *  The item states of all parent items of the controller item, in order of
      *  the parent keys registered for the item. If the item does not contain
@@ -76,7 +70,6 @@ define('io.ox/office/baseframework/app/basecontroller', [
         this.key = key;
         this.enabled = false;
         this.value = undefined;
-        this.dirty = false;
 
         // parent states and values
         this.parentStates = parentStates;
@@ -124,7 +117,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
      *      The delay for the debounced Controller.update() method, in
      *      milliseconds. Must not be less than 50.
      */
-    function BaseController(app, docModel, docView, initOptions) {
+    var BaseController = TriggerObject.extend({ constructor: function (app, docModel, docView, initOptions) {
 
         // self reference
         var self = this;
@@ -144,8 +137,6 @@ define('io.ox/office/baseframework/app/basecontroller', [
         // cached item states, mapped by item keys
         var stateCache = {};
 
-        var controllerUpdatePromise = $.when();
-
         // cached states of all controller items as notified the last time
         var notifiedStateCache = {};
 
@@ -158,6 +149,9 @@ define('io.ox/office/baseframework/app/basecontroller', [
         // shortcut definitions for 'keypress', mapped by char code (for performance)
         var charShortcuts = {};
 
+        // the internal deferred object representing the current update cycle
+        var updateDeferred = null;
+
         // class Item ---------------------------------------------------------
 
         var Item = BaseObject.extend({ constructor: function (key, definition) {
@@ -172,10 +166,14 @@ define('io.ox/office/baseframework/app/basecontroller', [
             var setHandler = Utils.getFunctionOption(definition, 'set');
             // whether an asynchronous setter is cancelable
             var cancelable = Utils.getBooleanOption(definition, 'cancel', false);
+            // whether an asynchronous setter does not block the controller
+            var nonblocking = Utils.getBooleanOption(definition, 'nonblocking', false);
             // behavior for returning browser focus to application
             var itemPreserveFocus = Utils.getBooleanOption(definition, 'preserveFocus', false);
             // custom focus target node or callback handler
             var itemFocusTarget = Utils.getOption(definition, 'focusTarget');
+            // alwaysDirty if true, always refresh without checking for changed value
+            var alwaysDirty = Utils.getBooleanOption(definition, 'alwaysDirty');
 
             BaseObject.call(this);
 
@@ -227,10 +225,6 @@ define('io.ox/office/baseframework/app/basecontroller', [
                 // resolve and store the enabled state
                 itemState.enabled = itemState.parentsEnabled && (enableHandler.apply(this, itemState.parentValues) === true);
 
-                // copy dirty flag from previous state cache
-                var oldItemState = notifiedStateCache[key];
-                itemState.dirty = !oldItemState || oldItemState.dirty || itemState.parentStates.some(function (parent) { return parent.dirty; });
-
                 // return the state descriptor
                 return itemState;
             };
@@ -275,6 +269,13 @@ define('io.ox/office/baseframework/app/basecontroller', [
                 return this.getState().value;
             };
 
+            /**
+             * Returns true if always refresh without checking for changed value
+             */
+            this.isAlwaysDirty = function () {
+                return alwaysDirty;
+            };
+
             /**
              * Executes the setter function of this item (passing in the new
              * value), and moves the browser focus back to the application
@@ -297,22 +298,19 @@ define('io.ox/office/baseframework/app/basecontroller', [
              */
             this.execute = function (value, options) {
 
-                var // the current state and value of the item
-                    state = this.getState(),
-                    // the resulting promise
-                    promise = null,
-                    // whether the setter runs asynchronous code
-                    pending = false,
-                    // focus options after executing the item
-                    focusOptions = _.extend({}, options);
+                // the current state and value of the item
+                var state = this.getState();
+                // the resulting promise
+                var promise = null;
+                // whether the setter runs asynchronous code
+                var pending = false;
+                // focus options after executing the item
+                var focusOptions = _.extend({}, options);
 
                 // final processing after the set handler has finished
                 function finalize() {
-
-                    // bug 40673: mark the item in the state cache as dirty, to force updating
-                    // the item with the effective value as returned then by its getter
-                    var oldState = notifiedStateCache[key];
-                    if (oldState) { oldState.dirty = true; }
+                    // reverted workarounds for Bug 37174, Bug 40673 and Bug 40787
+                    // as fix for Bug 47566
 
                     // update the controller items
                     self.update();
@@ -344,7 +342,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
 
                     // show busy screen if setter is running asynchronously
                     // (but not for modal dialogs which have their own blocker overlay)
-                    pending = promise.state() === 'pending';
+                    pending = !nonblocking && (promise.state() === 'pending');
                     if (pending && !Dialogs.isModalDialogOpen()) {
                         var showCancel = cancelable && _.isFunction(promise.abort);
                         docView.enterBusy({ cancelHandler: showCancel ? function () { promise.abort(); } : null });
@@ -359,7 +357,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
                     this.waitForAny(promise, function () {
                         if (pending) {
                             // execute in a timeout, needed for dialogs which are closed *after* resolve/reject
-                            self.executeDelayed(function () { self.grabFocus(focusOptions); }, undefined, 'BaseController: grabFocus');
+                            self.executeDelayed(function () { self.grabFocus(focusOptions); }, { infoString: 'BaseController: grabFocus', app: app });
                         } else {
                             self.grabFocus(focusOptions);
                         }
@@ -405,6 +403,17 @@ define('io.ox/office/baseframework/app/basecontroller', [
 
         // private methods ----------------------------------------------------
 
+        /**
+         * Creates a new deferred object representing the next update cycle.
+         */
+        function createUpdateDeferred() {
+
+            // pending deferred object represents the current controller update cycle
+            if (!updateDeferred || (updateDeferred.state() !== 'pending')) {
+                updateDeferred = self.createDeferredObject({ infoString: 'BaseController: createUpdateDeferred', app: app });
+            }
+        }
+
         /**
          * Handles 'keydown' and 'keypress' events and calls the setter of this
          * item, if it contains a matching keyboard shortcut definition.
@@ -564,12 +573,16 @@ define('io.ox/office/baseframework/app/basecontroller', [
          *      that the setter executes asynchronous code. In this case, the
          *      application window will be blocked and a busy indicator will be
          *      shown while the setter is running.
+         *  @param {Boolean} [definition.nonblocking=false]
+         *      If set to true, the promise returned by the setter function
+         *      will be ignored. The busy blocker screen will NOT be shown.
          *  @param {Boolean} [definition.cancel=false]
          *      If set to true, and if the setter function of the item has
          *      returned a pending abortable promise, the busy blocker screen
          *      will show a Cancel button that will abort that promise. It is
          *      up to the implementation of the setter function to react
-         *      properly on aborting the promise.
+         *      properly on aborting the promise. This option will be ignored,
+         *      if the option 'nonblocking' is set to true.
          *  @param {Object|Array} [definition.shortcut]
          *      One or multiple keyboard shortcut definitions. If the window
          *      root node of the application receives a 'keydown' or 'keypress'
@@ -675,8 +688,8 @@ define('io.ox/office/baseframework/app/basecontroller', [
             if (_.isObject(definition.shortcut)) {
                 _.getArray(definition.shortcut).forEach(function (shortcut) {
 
-                    var keyCode = Utils.getOption(shortcut, 'keyCode'),
-                        charCode = Utils.getOption(shortcut, 'charCode');
+                    var keyCode = Utils.getOption(shortcut, 'keyCode');
+                    var charCode = Utils.getOption(shortcut, 'charCode');
 
                     if (_.isString(keyCode)) {
                         keyCode = KeyCodes[keyCode] || 0;
@@ -715,21 +728,37 @@ define('io.ox/office/baseframework/app/basecontroller', [
             return this;
         };
 
+        /**
+         * Returns a promise that represents the current update cycle.
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that represents the current update cycle. If the promise
+         *  is pending, the update cycle is not finished yet. The promise is
+         *  (or will be) resolved with the states of all changed controller
+         *  items, as passed with the 'change:items' event triggered by this
+         *  instance.
+         */
+        this.getUpdatePromise = function () {
+            return updateDeferred.promise();
+        };
+
         /**
          * Refreshes the states and values of all registered items, and
          * triggers a 'change:items' event.
          *
-         * @returns {BaseController}
-         *  A reference to this controller.
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved after the controller has updated
+         *  all registered items. The promise will be resolved with the states
+         *  of all changed controller items, as passed with the 'change:items'
+         *  event triggered by this instance.
          */
         this.update = (function () {
 
             // clear the entire cache state on every call of the update() method
             function invalidateStates() {
                 stateCache = {};
-                if (controllerUpdatePromise.state() !== 'pending') {
-                    controllerUpdatePromise = $.Deferred();
-                }
+                createUpdateDeferred();
+                return this.getUpdatePromise();
             }
 
             // after a delay, collect all item states, and notify change listeners
@@ -753,10 +782,22 @@ define('io.ox/office/baseframework/app/basecontroller', [
                     _.invoke(items, 'getState');
                 }
 
+                /* test code for performance issues
+                _.any(items, function (item, key) {
+                    var now = _.now();
+                    item.getState();
+                    var time = _.now() - now;
+                    if (time > 1) {
+                        Utils.warn('BaseController updateState', key, (_.now() - now));
+                    }
+                });
+                */
+
                 // reduce to the properties that differ from previous state
                 var changedStates = _.omit(stateCache, function (state, key) {
                     var prevState = notifiedStateCache[key];
-                    return prevState && !state.dirty && (prevState.enabled === state.enabled) && _.isEqual(prevState.value, state.value);
+
+                    return prevState && (prevState.enabled === state.enabled) && !items[key].isAlwaysDirty() && _.isEqual(prevState.value, state.value);
                 });
 
                 // store the current cache for next update() call
@@ -771,10 +812,10 @@ define('io.ox/office/baseframework/app/basecontroller', [
                     });
                 }
 
-                controllerUpdatePromise.resolve();
+                updateDeferred.resolve(changedStates);
             }
 
-            return self.createDebouncedMethod(invalidateStates, updateStates, { delay: updateDelay, infoString: 'BaseController: update' });
+            return self.createDebouncedMethod(invalidateStates, updateStates, { delay: updateDelay, infoString: 'BaseController: update', app: app });
         }());
 
         /**
@@ -903,7 +944,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
             if (_.isObject(focusTarget) && _.isFunction(focusTarget.grabFocus) && _.isFunction(focusTarget.isVisible) && focusTarget.isVisible()) {
                 focusTarget.grabFocus(options);
             } else if (((focusTarget instanceof $) || (focusTarget instanceof HTMLElement)) && $(focusTarget).is(':visible')) {
-                $(focusTarget).focus();
+                Utils.setFocus($(focusTarget));
             } else {
                 docView.grabFocus(options);
             }
@@ -911,15 +952,14 @@ define('io.ox/office/baseframework/app/basecontroller', [
             return this;
         };
 
-        this.getControllerUpdatePromise = function () {
-            return controllerUpdatePromise;
-        };
-
         // initialization -----------------------------------------------------
 
         // dummy item singleton, used e.g. for undefined parent items
         dummyItem = new Item('\x00');
 
+        // create the initial update promise
+        createUpdateDeferred();
+
         // register all controller items
         this.registerDefinitions({
 
@@ -941,7 +981,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
 
             'app/share': {
                 parent: ['app/imported', 'app/bundled'],
-                enable: function () { return DriveUtils.isShareable(app.getFileDescriptor()); }
+                enable: function () { return DriveUtils.isShareable(app.getFileDescriptor()) && !app.isDocumentEncrypted(); }
             },
 
             // all supported operation systems have a file system where user can save in, but not on IOS
@@ -952,12 +992,14 @@ define('io.ox/office/baseframework/app/basecontroller', [
             // download the document: enabled in read-only mode, disabled during import
             'document/download': {
                 parent: ['app/imported', 'system/filesystem'],
+                enable: function () { return !app.isDocumentEncrypted(); },
                 set: function () { return app.download(); }
             },
 
             // print the document (download as PDF): enabled in read-only mode, disabled during import
             'document/print': {
                 parent: 'app/imported',
+                enable: function () { return !app.isDocumentEncrypted(); },
                 set: function () { return app.print(); },
                 shortcut: { keyCode: 'P', ctrlOrMeta: true }
             },
@@ -965,7 +1007,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
             // compose new mail with this document as attachment
             'document/sendmail': {
                 parent: ['app/imported', 'app/bundled'],
-                enable: function () { return (Capabilities.has('webmail') && !DriveUtils.isGuest()); },
+                enable: function () { return Config.MAIL_AVAILABLE && !DriveUtils.isGuest() && !app.isDocumentEncrypted(); },
                 set: function () { return app.sendMail(); }
             },
 
@@ -984,21 +1026,24 @@ define('io.ox/office/baseframework/app/basecontroller', [
             },
 
             'document/sendmail/menu': {
-                parent: 'app/share',
-                enable: function () { return (Capabilities.has('webmail') && !DriveUtils.isGuest()); }
+                parent: 'app/valid',
+                enable: function () { return Config.MAIL_AVAILABLE && !DriveUtils.isGuest(); }
             },
 
             'document/share': {
-                parent: 'app/share'
+                parent: 'app/share',
+                enable: function () { return ShareUtils.isSharingSupported(); }
             },
 
             'document/share/getlink': {
                 parent: 'document/share',
+                enable: function () { return ShareUtils.canShareLink(); },
                 set: function () { return ShareUtils.shareLink(app.getFileDescriptor());  }
             },
 
             'document/share/inviteuser': {
                 parent: 'document/share',
+                enable: function () { return ShareUtils.canInviteUser(); },
                 set: function () { return ShareUtils.inviteUser(app.getFileDescriptor()); }
             },
 
@@ -1032,11 +1077,10 @@ define('io.ox/office/baseframework/app/basecontroller', [
             items = dummyItem = stateCache = keyShortcuts = charShortcuts = null;
         });
 
-    } // class BaseController
+    } }); // class BaseController
 
     // exports ================================================================
 
-    // derive this class from class TriggerObject
-    return TriggerObject.extend({ constructor: BaseController });
+    return BaseController;
 
 });
