@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -28,7 +29,27 @@ define('io.ox/office/baseframework/app/extensionregistry', [
     // the extension suffix for files with an internal error
     var INTERNAL_ERROR_SUFFIX = '_ox';
 
-    // file extension configuration
+    // File extension configuration
+    //
+    // Each extension configuration entry supports the following properties:
+    // - {String} [format]
+    //      The file format used by the server-side filter component to load
+    //      and save the contents of the document. If omitted, documents with
+    //      the current file extension cannot be edited. The following file
+    //      formats are supported:
+    //      - 'ooxml': Office Open XML (Microsoft Office)
+    //      - 'odf' OpenDocument Format (OpenOffice/LibreOffice)
+    // - {String} [template]
+    //      The file extension of the template file used to create a new
+    //      document with the current file extension. If omitted, there is no
+    //      template file extension available for the current file format (i.e.
+    //      it is not possible to create a template for the edited document).
+    // - {Boolean} [macros=false]
+    //      If set to true, the document may contain scripting macros.
+    // - {Boolean} [convert=false]
+    //      If set to true, the server needs to convert the original file to
+    //      the file format specified with the property 'format'.
+    //
     var FILE_EXTENSION_CONFIGURATION = {
 
         text: {
@@ -36,14 +57,10 @@ define('io.ox/office/baseframework/app/extensionregistry', [
             requires: 'text',
             editable: !_.browser.Android || Utils.supportedChromeVersionOnAndroidForText(),
             extensions: {
-                docx: { format: 'ooxml' },
-                docm: { format: 'ooxml', macros: true },
-                dotx: { format: 'ooxml', template: true },
-                dotm: { format: 'ooxml', template: true, macros: true },
-                odt:  { format: 'odf', macros: true },
-                ott:  { format: 'odf', template: true, macros: true },
-                doc:  { format: 'ooxml', macros: true, convert: true },
-                dot:  { format: 'ooxml', template: true, templateLocked: true, macros: true, convert: true },
+                docx: { format: 'ooxml', template: 'dotx' },
+                docm: { format: 'ooxml', template: 'dotm', macros: true },
+                doc:  { format: 'ooxml', template: 'dot', macros: true, convert: true },
+                odt:  { format: 'odf', template: 'ott',  macros: true },
                 rtf:  { format: 'ooxml', convert: true }
             }
         },
@@ -53,17 +70,13 @@ define('io.ox/office/baseframework/app/extensionregistry', [
             requires: 'spreadsheet',
             editable: true,
             extensions: {
-                xlsx: { format: 'ooxml' },
-                xlsm: { format: 'ooxml', macros: true },
-                xltx: { format: 'ooxml', template: true },
-                xltm: { format: 'ooxml', template: true, macros: true },
-                xlam: { macros: true }, // add-in
-                xls:  { format: 'ooxml', macros: true, convert: true },
-                xlt:  { format: 'ooxml', template: true, templateLocked: true, macros: true, convert: true },
-                xla:  { macros: true }, // add-in
+                xlsx: { format: 'ooxml', template: 'xltx' },
+                xlsm: { format: 'ooxml', template: 'xltm', macros: true },
                 xlsb: { format: 'ooxml', macros: true, convert: true },
-                ods:  { format: 'odf', macros: true }, //spreadsheet
-                ots:  { format: 'odf', template: true, macros: true } //spreadsheet
+                xlam: { macros: true }, // add-in
+                xls:  { format: 'ooxml', template: 'xlt', macros: true, convert: true },
+                xla:  { macros: true }, // add-in
+                ods:  { format: 'odf', template: 'ots', macros: true }
             }
         },
 
@@ -72,53 +85,22 @@ define('io.ox/office/baseframework/app/extensionregistry', [
             requires: 'presentation',
             editable: !_.browser.Android || Utils.supportedChromeVersionOnAndroidForText(),
             extensions: {
-                pptx: { format: 'ooxml' },
-                pptm: { format: 'ooxml', macros: true },
-                potx: { format: 'ooxml', template: true },
-                potm: { format: 'ooxml', template: true, macros: true },
+                pptx: { format: 'ooxml', template: 'potx' },
+                pptm: { format: 'ooxml', template: 'potm', macros: true },
                 ppsx: {}, // slide show
                 ppsm: { macros: true }, // slide show
                 ppam: { macros: true }, // add-in
-                odp:  { format: 'odf', macros: true },
-                otp:  { format: 'odf', template: true, macros: true },
-                ppt:  { format: 'ooxml', macros: true, convert: true },
-                pot:  { format: 'ooxml', template: true, templateLocked: true, macros: true, convert: true },
+                // disabled for US DOCS-618, no direct odf support, and no doc-converter support
+                // odp:  { format: 'odf', template: 'otp', macros: true },
+                ppt:  { format: 'ooxml', template: 'pot', macros: true, convert: true },
                 pps:  { format: 'ooxml', macros: true, convert: true }, // slide show
                 ppa:  { format: 'ooxml', macros: true, convert: true } // add-in
             }
-        },
-
-        preview: {
-            extensions: {
-                pdf:  {},
-                odg:  { format: 'odf', macros: true }, // drawing
-                otg:  { format: 'odf', template: true, macros: true }, // drawing
-                odi:  { format: 'odf' }, // image
-                oti:  { format: 'odf', template: true }, // image
-                odc:  { format: 'odf' }, // chart
-                otc:  { format: 'odf', template: true }, // chart
-                odf:  { format: 'odf' }, // formula
-                otf:  { format: 'odf', template: true }, // formula
-                odm:  { format: 'odf' } // global text document
-            }
         }
     };
 
     // extension to template extension map
-    var EXT_TO_TEMPLATE_EXT_MAP = {
-        docx: 'dotx',
-        docm: 'dotx',
-        dotm: 'dotx',
-        xlsx: 'xltx',
-        xlsm: 'xltx',
-        xltm: 'xltx',
-        pptx: 'potx',
-        pptm: 'potx',
-        potm: 'potx',
-        odt: 'ott',
-        ods: 'ots',
-        odp: 'otp'
-    };
+    var TEMPLATE_EXT_MAP = {};
 
     // all application configurations, mapped by application identifier
     var applicationMap = {};
@@ -126,8 +108,24 @@ define('io.ox/office/baseframework/app/extensionregistry', [
     // all configurations, mapped by lower-case extension
     var fileExtensionMap = {};
 
-    // whether OX Preview is available at all
-    var previewAvailable = Capabilities.has('document_preview');
+    // can we edit guard protected documents?
+    var editGuardDocs = Capabilities.has('guard-docs');
+
+    // private global functions ===============================================
+
+    function registerFileExtension(extension, settings) {
+
+        if (extension in fileExtensionMap) {
+            Utils.warn('ExtensionRegistry: extension "' + extension + '" already registered');
+        }
+
+        fileExtensionMap[extension] = settings;
+
+        // add extension with internal error suffix (native only)
+        if (settings.native) {
+            fileExtensionMap[extension + INTERNAL_ERROR_SUFFIX] = settings;
+        }
+    }
 
     // static class ExtensionRegistry =========================================
 
@@ -165,13 +163,16 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      *  registered for the extension of the passed file name. If omitted, the
      *  edit application module name for the extension will be ignored.
      *
+     *  @param {Boolean} ignoreGuardExt
+     *  Ignore/skip the Guard extension
+     *
      * @returns {Object|Null}
      *  The file extension settings; or null, if the extension is not known.
      */
-    ExtensionRegistry.getExtensionSettings = function (fileName, editModule) {
+    ExtensionRegistry.getExtensionSettings = function (fileName, editModule, ignoreGuardExt) {
 
         // the lower-case extension of the passed file name
-        var extension = Utils.getFileExtension(fileName);
+        var extension = Utils.getFileExtension(fileName, ignoreGuardExt);
         // the extension settings object
         var extensionSettings = (extension in fileExtensionMap) ? fileExtensionMap[extension] : null;
         // the module name of the edit application for the extension
@@ -193,30 +194,12 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      *  - 'text': A text document.
      *  - 'spreadsheet': A spreadsheet document.
      *  - 'presentation': A presentation document.
-     *  - 'preview': Another viewable document that is not part of the
-     *      preceding file categories.
      */
     ExtensionRegistry.getFileCategory = function (fileName) {
         var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName);
         return Utils.getStringOption(extensionSettings, 'type', '');
     };
 
-    /**
-     * Returns all extensions that can be viewed with OX Preview, as array.
-     *
-     * @returns {Array<String>}
-     *  All extensions supported by OX Preview.
-     */
-    ExtensionRegistry.getViewableExtensions = function () {
-        var extensions = [];
-        _.each(fileExtensionMap, function (settings, extension) {
-            if (settings.viewable) {
-                extensions.push(extension);
-            }
-        });
-        return extensions;
-    };
-
     /**
      * Returns an array containing all file extensions that can be edited.
      *
@@ -233,21 +216,6 @@ define('io.ox/office/baseframework/app/extensionregistry', [
         return extensions;
     };
 
-    /**
-     * Returns whether the file with the passed name is viewable by the OX
-     * Preview application.
-     *
-     * @param {String} fileName
-     *  The file name (case-insensitive).
-     *
-     * @returns {Boolean}
-     *  Whether the specified file is viewable by the OX Preview application.
-     */
-    ExtensionRegistry.isViewable = function (fileName) {
-        var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName);
-        return Utils.getBooleanOption(extensionSettings, 'viewable', false);
-    };
-
     /**
      * Returns the module name of the edit application that is able to modify
      * the file with the passed file name.
@@ -261,7 +229,7 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      *  file extension.
      */
     ExtensionRegistry.getEditModule = function (fileName) {
-        var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName);
+        var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName, null, editGuardDocs);
         return Utils.getStringOption(extensionSettings, 'module', null);
     };
 
@@ -282,7 +250,7 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      *  applications.
      */
     ExtensionRegistry.isEditable = function (fileName, editModule) {
-        var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName, editModule);
+        var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName, editModule, editGuardDocs);
         return Utils.getBooleanOption(extensionSettings, 'editable', false);
     };
 
@@ -303,7 +271,7 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      *  Documents edit applications.
      */
     ExtensionRegistry.isNative = function (fileName, editModule) {
-        var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName, editModule);
+        var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName, editModule, editGuardDocs);
         return Utils.getBooleanOption(extensionSettings, 'editable', false) && Utils.getBooleanOption(extensionSettings, 'native', false);
     };
 
@@ -349,7 +317,7 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      *  - An empty string for all other file names.
      */
     ExtensionRegistry.getFileFormat = function (fileName, editModule) {
-        var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName, editModule);
+        var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName, editModule, true);
         return Utils.getStringOption(extensionSettings, 'format', '');
     };
 
@@ -373,23 +341,19 @@ define('io.ox/office/baseframework/app/extensionregistry', [
     };
 
     /**
-     * Returns whether the file with the passed name is a locked template file.
-     * (is used for binary templates)
+     * Provides the template file extension for a given file name.
      *
      * @param {String} fileName
      *  The file name (case-insensitive).
      *
-     * @param {String} [editModule]
-     *  If specified, must match the module name of the edit application
-     *  registered for the extension of the passed file name. If omitted, the
-     *  edit application module name for the extension will be ignored.
-     *
-     * @returns {Boolean}
-     *  Whether the specified file is a locked document template file.
+     * @returns {String|Null}
+     *  The template extension for the file name; or null if the format cannot
+     *  be written to a template format. If the passed file name refers to a
+     *  template file by itself, its own extension will be returned.
      */
-    ExtensionRegistry.isTemplateLocked = function (fileName, editModule) {
-        var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName, editModule);
-        return Utils.getBooleanOption(extensionSettings, 'templateLocked', false);
+    ExtensionRegistry.getTemplateExtension = function (fileName) {
+        var extension = Utils.getFileExtension(fileName);
+        return TEMPLATE_EXT_MAP[extension] || null;
     };
 
     /**
@@ -411,6 +375,21 @@ define('io.ox/office/baseframework/app/extensionregistry', [
         return Utils.getBooleanOption(extensionSettings, 'macros', false);
     };
 
+    /**
+     * Returns whether the file with the passed name contains the 'internal
+     * error' extension suffix.
+     *
+     * @param {String} fileName
+     *  The file name (case-insensitive).
+     *
+     * @returns {Boolean}
+     *  Whether the file with the passed name contains the 'internal error'
+     *  extension suffix.
+     */
+    ExtensionRegistry.isGuardEncrypted = function (fileName) {
+        return Utils.isGuardEncrypted(fileName);
+    };
+
     /**
      * Returns whether the file with the passed name contains the 'internal
      * error' extension suffix.
@@ -424,7 +403,7 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      */
     ExtensionRegistry.isError = function (fileName) {
         var extension = Utils.getFileExtension(fileName);
-        return extension.indexOf(INTERNAL_ERROR_SUFFIX, extension.length - INTERNAL_ERROR_SUFFIX.length) >= 0;
+        return extension.substr(-INTERNAL_ERROR_SUFFIX.length) === INTERNAL_ERROR_SUFFIX;
     };
 
     /**
@@ -442,22 +421,6 @@ define('io.ox/office/baseframework/app/extensionregistry', [
         return ExtensionRegistry.isError(fileName) ? fileName : (fileName + INTERNAL_ERROR_SUFFIX);
     };
 
-    /**
-     * Provides the pre-defined template extension for a given file name.
-     *
-     * @param {String} fileName
-     *  The file name (case-insensitive).
-     *
-     * @returns {String|Null}
-     *  The template extension for the file name; or null if the format cannot
-     *  be written to a template format.
-     */
-    ExtensionRegistry.getTemplateExtensionForFileName = function (fileName) {
-        var extension = Utils.getFileExtension(fileName);
-        extension = EXT_TO_TEMPLATE_EXT_MAP[extension];
-        return _.isString(extension) ? extension : null;
-    };
-
     // static initialization ==================================================
 
     // process the configuration of all modules
@@ -472,7 +435,7 @@ define('io.ox/office/baseframework/app/extensionregistry', [
         // whether the edit module is available at all
         var editAvailable = editable && _.isString(requires) && Capabilities.has(requires) && _.isString(module);
 
-        // application configuration antry
+        // application configuration entry
         applicationMap[documentType] = { editable: editAvailable };
 
         // process all extensions registered for the module
@@ -482,27 +445,25 @@ define('io.ox/office/baseframework/app/extensionregistry', [
             var format = Utils.getStringOption(extensionSettings, 'format', '');
             // whether the file extension is supported natively
             var native = !Utils.getBooleanOption(extensionSettings, 'convert', false);
-
-            if (extension in fileExtensionMap) {
-                Utils.warn('ExtensionRegistry(): extension "' + extension + '" already registered');
-            }
+            // the file extension of template files
+            var template = Utils.getStringOption(extensionSettings, 'template', null);
 
             // initialize all properties of the current extension
-            var fileExtension = _.extend({
-                type: documentType,
-                viewable: previewAvailable,
-                editable: editAvailable && Utils.getBooleanOption(EDITABLE_FILE_FORMATS, format, false),
+            registerFileExtension(extension, extensionSettings = {
                 module: module,
-                native: native
-            }, extensionSettings);
+                type: documentType,
+                format: format,
+                template: false,
+                editable: editAvailable && Utils.getBooleanOption(EDITABLE_FILE_FORMATS, format, false),
+                native: native,
+                macros: Utils.getBooleanOption(extensionSettings, 'macros', false)
+            });
 
-            fileExtensionMap[extension] = fileExtension;
-
-            // initialize all properties of the current extension with internal error
-            // suffix (native only) - these files are not viewable in OX Preview
-            if (native) {
-                fileExtension = _.extend({}, fileExtension, { viewable: false });
-                fileExtensionMap[extension + INTERNAL_ERROR_SUFFIX] = fileExtension;
+            // register the template extension, store the template file extension for the
+            // original extension, AND for the template extension
+            if (template) {
+                registerFileExtension(template, _.extend({}, extensionSettings, { template: true }));
+                TEMPLATE_EXT_MAP[extension] = TEMPLATE_EXT_MAP[template] = template;
             }
         });
     });
