@@ -5,7 +5,9 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ *
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -28,16 +30,111 @@ define('io.ox/office/baseframework/app/guidedtour', [
     // whether a tour is currently running, for fail-safety
     var isTourRunning = false;
 
-    // class StepMixin ========================================================
+    // mix-in class ApplicationMixin ==========================================
+
+    /**
+     * Mix-in class for tour classes to add convenience methods for accessing
+     * the components of an application instance.
+     *
+     * @constructor
+     */
+    function ApplicationMixin() {
+
+        // public methods -----------------------------------------------------
+
+        /**
+         * Convenience method to get the application that is currently active.
+         *
+         * @returns {ox.ui.App|Null}
+         *  The application that is currently active, if available. Note that
+         *  the returned application may not be a Document application (i.e. an
+         *  instance of BaseApplication).
+         */
+        this.getApp = ox.ui.App.getCurrentApp;
+
+        /**
+         * Convenience method to get the document model of the Documents
+         * application that is currently active.
+         *
+         * @returns {BaseModel|Null}
+         *  The document model of the Documents application that is currently
+         *  active, if available.
+         */
+        this.getDocModel = function () {
+            var app = this.getApp();
+            return BaseApplication.isInstance(app) ? app.getModel() : null;
+        };
+
+        /**
+         * Convenience method to get the document view of the Documents
+         * application that is currently active.
+         *
+         * @returns {BaseView|Null}
+         *  The document view of the Documents application that is currently
+         *  active, if available.
+         */
+        this.getDocView = function () {
+            var app = this.getApp();
+            return BaseApplication.isInstance(app) ? app.getView() : null;
+        };
+
+        /**
+         * Convenience method to get the document controller of the Documents
+         * application that is currently active.
+         *
+         * @returns {BaseController|Null}
+         *  The document controller of the Documents application that is
+         *  currently active, if available.
+         */
+        this.getDocController = function () {
+            var app = this.getApp();
+            return BaseApplication.isInstance(app) ? app.getController() : null;
+        };
+
+        /**
+         * Convenience method to execute a controller item of the Documents
+         * application that is currently active. Does nothing, if the active
+         * application is not a Documents application (i.e. not an instance of
+         * BaseApplication).
+         *
+         * @attention
+         *  The method invokes the controller item immediately. It is intended
+         *  to be used in an event handler, NOT when defining this tour step.
+         *
+         * @param {String} key
+         *  The key of the controller item to be executed.
+         *
+         * @param {Any} [value]
+         *  The new value of the item.
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved or rejected according to the result
+         *  of the item setter function. See BaseController.executeItem() for
+         *  more details.
+         */
+        this.executeItem = function (key, value) {
+            var controller = this.getDocController();
+            return controller ? controller.executeItem(key, value) : $.Deferred().reject();
+        };
+
+    } // class ApplicationMixin
+
+    // mix-in class StepMixin =================================================
 
     /**
      * Mix-in class for a tour step of instances of GuidedTour. Provided to add
      * some convenience and special behavior to generic AppSuite tours.
      *
      * @constructor
+     *
+     * @extends ApplicationMixin
      */
     function StepMixin() {
 
+        // base constructors --------------------------------------------------
+
+        ApplicationMixin.call(this);
+
         // public methods -----------------------------------------------------
 
         /**
@@ -289,81 +386,6 @@ define('io.ox/office/baseframework/app/guidedtour', [
             return this;
         };
 
-        /**
-         * Convenience method to get the application that is currently active.
-         *
-         * @returns {ox.ui.App|Null}
-         *  The application that is currently active, if available. Note that
-         *  the returned application may not be a Document application (i.e. an
-         *  instance of BaseApplication).
-         */
-        this.getApp = ox.ui.App.getCurrentApp;
-
-        /**
-         * Convenience method to get the document model of the Documents
-         * application that is currently active.
-         *
-         * @returns {BaseModel|Null}
-         *  The document model of the Documents application that is currently
-         *  active, if available.
-         */
-        this.getDocModel = function () {
-            var app = this.getApp();
-            return BaseApplication.isInstance(app) ? app.getModel() : null;
-        };
-
-        /**
-         * Convenience method to get the document view of the Documents
-         * application that is currently active.
-         *
-         * @returns {BaseView|Null}
-         *  The document view of the Documents application that is currently
-         *  active, if available.
-         */
-        this.getDocView = function () {
-            var app = this.getApp();
-            return BaseApplication.isInstance(app) ? app.getView() : null;
-        };
-
-        /**
-         * Convenience method to get the document controller of the Documents
-         * application that is currently active.
-         *
-         * @returns {BaseController|Null}
-         *  The document controller of the Documents application that is
-         *  currently active, if available.
-         */
-        this.getDocController = function () {
-            var app = this.getApp();
-            return BaseApplication.isInstance(app) ? app.getController() : null;
-        };
-
-        /**
-         * Convenience method to execute a controller item of the Documents
-         * application that is currently active. Does nothing, if the active
-         * application is not a Documents application (i.e. not an instance of
-         * BaseApplication).
-         *
-         * @attention
-         *  The method invokes the controller item immediately. It is intended
-         *  to be used in an event handler, NOT when defining this tour step.
-         *
-         * @param {String} key
-         *  The key of the controller item to be executed.
-         *
-         * @param {Any} [value]
-         *  The new value of the item.
-         *
-         * @returns {jQuery.Promise}
-         *  A promise that will be resolved or rejected according to the result
-         *  of the item setter function. See BaseController.executeItem() for
-         *  more details.
-         */
-        this.executeItem = function (key, value) {
-            var controller = this.getDocController();
-            return controller ? controller.executeItem(key, value) : $.Deferred().reject();
-        };
-
     } // class StepMixin
 
     // class GuidedTour =======================================================
@@ -375,12 +397,14 @@ define('io.ox/office/baseframework/app/guidedtour', [
      * @constructor
      *
      * @extends Wizard
+     * @extends ApplicationMixin
      */
     var GuidedTour = _.makeExtendable(Wizard).extend({ constructor: function () {
 
         // base constructor ---------------------------------------------------
 
         Wizard.call(this);
+        ApplicationMixin.call(this);
 
         // public methods -----------------------------------------------------
 
@@ -406,16 +430,6 @@ define('io.ox/office/baseframework/app/guidedtour', [
             return step;
         });
 
-        /**
-         * Convenience method to get the application that is currently active.
-         *
-         * @returns {ox.ui.App|Null}
-         *  The application that is currently active, if available. Note that
-         *  the returned application may not be a Document application (i.e. an
-         *  instance of BaseApplication).
-         */
-        this.getApp = ox.ui.App.getCurrentApp;
-
         // initialization -----------------------------------------------------
 
         // when closing the tour, move browser focus into Documents applications
@@ -451,7 +465,7 @@ define('io.ox/office/baseframework/app/guidedtour', [
      *  The CSS selector for the root node of the specified control group.
      */
     GuidedTour.getGroupSelector = function (selector, key) {
-        return selector + ' .group[data-key="' + key + '"]';
+        return selector + ' .group[data-key="' + key + '"]:visible';
     };
 
     /**
