@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  */
@@ -109,6 +110,7 @@ define('io.ox/office/baseframework/utils/apptooltipmixin', [
                 mouseEnter({ currentTarget: node[0] });
 
                 menu.one('popup:hide', function () {
+                    mouseLeave();
                     Forms.disableToolTip(node);
                 });
             });
