@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Carsten Driesner <carsten.driesner@open-xchange.com>
  */
@@ -135,7 +136,7 @@ define('io.ox/office/baseframework/utils/infomessages', [
                     infoMessage.message =
                         //#. %1$s is the file name of the copied document
                         //#, c-format
-                        gt('The document was saved as a template "%1$s" in in folder "%2$s".', gt.noI18n(contextData), gt.noI18n(contextData2));
+                        gt('The document was saved as a template "%1$s" in folder "%2$s".', gt.noI18n(contextData), gt.noI18n(contextData2));
                     break;
                 case 'INFO_DOC_SAVED_IN_FOLDER':
                     contextData = Utils.getStringOption(options, 'fullFileName', null);
