@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -65,7 +66,8 @@ define('io.ox/office/baseframework/view/basecontrols', [
             visibleKey:      'document/share',
             icon:            'fa-user-plus',
             classes:         'link-style',
-            tooltip:         tooltip
+            tooltip:         tooltip,
+            dropDownVersion: { label: tooltip }
         });
 
         // private functions --------------------------------------------------
