@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -265,7 +266,7 @@ define('io.ox/office/baseframework/view/baseview', [
                 }
             }
 
-            return self.createDebouncedMethod(registerRefresh, executeRefresh);
+            return self.createDebouncedMethod(registerRefresh, executeRefresh, { infoString: 'BaseView paneResizeHandler()', app: app });
         }());
 
         /**
@@ -306,8 +307,8 @@ define('io.ox/office/baseframework/view/baseview', [
 
                 // append the mark-up for a static hyperlink to the alert message
                 if (linkUrl) {
-                    linkLabel = linkLabel ? Utils.escapeHTML(linkLabel) : _.noI18n(linkUrl);
-                    messageNode.append('<div><a href="' + linkUrl + '" target="_blank" tabindex="0">' + linkLabel + '</a></div>');
+                    linkLabel = Utils.escapeHTML(linkLabel || _.noI18n(linkUrl));
+                    messageNode.append('<div><a href="' + linkUrl + '" target="_blank" rel="noopener" tabindex="0">' + linkLabel + '</a></div>');
                 }
 
                 // extended message text for better support
@@ -321,7 +322,7 @@ define('io.ox/office/baseframework/view/baseview', [
                 // the key of the controller item for an action link
                 var actionKey = Utils.getStringOption(actionOptions, 'itemKey');
                 // do not insert an action link, if the controller item is missing or disabled
-                if (!actionKey || !app.getController().isItemEnabled(actionKey)) { return; }
+                if (!actionKey || !self.isControllerItemEnabled(actionKey)) { return; }
 
                 // the icon class for the link
                 var actionIcon = Utils.getStringOption(actionOptions, 'icon');
@@ -349,7 +350,7 @@ define('io.ox/office/baseframework/view/baseview', [
             self.listenTo(yellNode, 'notification:removed', function (event) {
                 // bug 33735: only if focus is inside the alert box (e.g. after mouse click)
                 if (Forms.containsFocus(event.currentTarget)) {
-                    self.executeDelayed(function () { self.grabFocus(); });
+                    self.executeDelayed(function () { self.grabFocus(); }, { infoString: 'BaseView.showNotification', app: app });
                 }
             });
         }
@@ -387,7 +388,11 @@ define('io.ox/office/baseframework/view/baseview', [
             if (tempNode.children().length > 0) {
                 winBodyNode.append(tempNode.children());
                 // restore invalidated tabindex attribute for browser focus tab chain
-                if (!self.isBusy()) { restoreTabIndexes(); }
+                if (!self.isBusy()) {
+                    restoreTabIndexes();
+                    // bug #49359 - due to the detached DOM calling idle() didn't remove the disabled attributes from input and textarea elements, so call it again after the DOM is attached.
+                    self.leaveBusy();
+                }
             }
 
             // do not update GUI and grab focus while document is still being imported
@@ -396,7 +401,7 @@ define('io.ox/office/baseframework/view/baseview', [
                     refreshPaneLayout();
                     app.getController().update();
                     self.grabFocus({ afterImport: true });
-                }, undefined, 'BaseView: windowShowHandler');
+                }, { infoString: 'BaseView: windowShowHandler', app: app });
             }
         }
 
@@ -508,6 +513,10 @@ define('io.ox/office/baseframework/view/baseview', [
          * Moves the browser focus into the application pane. Calls the
          * handler function passed to the constructor of this instance.
          *
+         * @param {Object} [options]
+         *  Optional parameters that will be passed to the grab focus handler
+         *  function.
+         *
          * @returns {BaseView}
          *  A reference to this instance.
          */
@@ -517,11 +526,11 @@ define('io.ox/office/baseframework/view/baseview', [
                 if (dialogNode.length > 0) {
                     Forms.grabFocus(dialogNode);
                 } else if (this.isBusy()) {
-                    appWindow.nodes.blocker.focus();
+                    Utils.setFocus(appWindow.nodes.blocker);
                 } else if (_.isFunction(grabFocusHandler)) {
                     grabFocusHandler.call(this, options);
                 } else if (contentFocusable) {
-                    contentRootNode.focus();
+                    Utils.setFocus(contentRootNode);
                 } else {
                     Forms.grabFocus(this.getAppPaneNode());
                 }
@@ -646,7 +655,7 @@ define('io.ox/office/baseframework/view/baseview', [
                 // focus handler that prevents focusing document contents during busy mode
                 function changeFocusHandler(event, focusNode) {
                     if (focusNode && Utils.containsNode(winBodyNode, focusNode) && !Utils.containsNode(blockerNode, focusNode, { allowEqual: true })) {
-                        ((cancelButton && cancelButton.is(':visible')) ? cancelButton : blockerNode).focus();
+                        Utils.setFocus(((cancelButton && cancelButton.is(':visible')) ? cancelButton : blockerNode));
                     }
                 }
 
@@ -667,7 +676,7 @@ define('io.ox/office/baseframework/view/baseview', [
                 }
 
                 // bug 38770: grab focus to prevent modifications of document
-                blockerNode.attr('tabindex', 1).focus();
+                Utils.setFocus(blockerNode.attr('tabindex', 1));
                 invalidateTabIndexes();
                 self.listenTo(Utils, 'change:focus', changeFocusHandler);
 
@@ -693,7 +702,7 @@ define('io.ox/office/baseframework/view/baseview', [
                     blockerNode.css('opacity', 0);
                     blockerFadeTimer = self.repeatDelayed(function (index) {
                         blockerNode.css('opacity', (index + 1) / 10);
-                    }, { delay: delay, repeatDelay: 50, cycles: 10 }, 'BaseApp: blockerFadeTimer');
+                    }, { delay: delay, repeatDelay: 50, cycles: 10, infoString: 'BaseApp: blockerFadeTimer', app: app });
                     // defer showing the warning box until blocker is visible
                     warningDelay += delay + 500;
                 }
@@ -719,10 +728,10 @@ define('io.ox/office/baseframework/view/baseview', [
                     blockerWarningTimer = self.executeDelayed(function () {
                         warningNode.show();
                         if (cancelButton) {
-                            cancelButton.focus();
+                            Utils.setFocus(cancelButton);
                             blockerNode.removeAttr('tabindex');
                         }
-                    }, warningDelay);
+                    }, { delay: warningDelay, infoString: 'BaseView: blockerWarningTimer', app: app });
                 }
             }, options);
 
@@ -764,7 +773,7 @@ define('io.ox/office/baseframework/view/baseview', [
                 }
             }
 
-            return self.createDebouncedMethod(registerProgress, showProgress, { delay: 500, maxDelay: 500 });
+            return self.createDebouncedMethod(registerProgress, showProgress, { delay: 500, maxDelay: 500, infoString: 'BaseView updateBusyProgress()', app: app });
         }());
 
         /**
@@ -806,7 +815,7 @@ define('io.ox/office/baseframework/view/baseview', [
          *      An optional headline shown above the message text.
          *  @param {String} yellOptions.message
          *      The message text shown in the alert banner.
-         *  @param {Number} []yellOptions.duration]
+         *  @param {Number} [yellOptions.duration]
          *      The time to show the alert banner, in milliseconds; or -1 to
          *      show a permanent alert. Default duration is dependent on the
          *      alert type: permanent for error alerts, and specific durations
@@ -853,6 +862,51 @@ define('io.ox/office/baseframework/view/baseview', [
             return this;
         };
 
+        /**
+         * Hides the alert banner currently shown, and clears the cached
+         * settings for an alert banner to be shown in the future when this
+         * application becomes visible.
+         *
+         * @returns {BaseView}
+         *  A reference to this instance.
+         */
+        this.hideYell = function () {
+            Notifications.yell.close();
+            pendingYellOptions = null;
+            return this;
+        };
+
+        /**
+         * A shortcut to receive the enabled state of the specified controller
+         * item that directly invokes the method BaseController.isItemEnabled()
+         * of the application controller owning this view instance.
+         *
+         * @param {String} key
+         *  The key of the item.
+         *
+         * @returns {Boolean}
+         *  Whether the specified item exists and is enabled.
+         */
+        this.isControllerItemEnabled = function (key) {
+            return app.getController().isItemEnabled(key);
+        };
+
+        /**
+         * A shortcut to receive the value of the specified controller item
+         * that directly invokes the method BaseController.getItemValue() of
+         * the application controller owning this view instance.
+         *
+         * @param {String} key
+         *  The key of the item.
+         *
+         * @returns {Any}
+         *  The current value of the item; or undefined, if the item does not
+         *  exist.
+         */
+        this.getControllerItemValue = function (key) {
+            return app.getController().getItemValue(key);
+        };
+
         /**
          * A shortcut to execute the specified controller item that directly
          * invokes the method BaseController.executeItem() of the application
@@ -1106,7 +1160,7 @@ define('io.ox/office/baseframework/view/baseview', [
         (function () {
 
             var // all CSS classes (always add the application name)
-                windowNodeClasses = 'io-ox-office-main ' + app.getName().replace(/[.\/]/g, '-') + '-main',
+                windowNodeClasses = 'io-ox-office-main ' + app.getName().replace(/[./]/g, '-') + '-main',
                 // additional CSS classes from options
                 classes = Utils.getStringOption(initOptions, 'classes');
 
