@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -238,7 +239,7 @@ define('io.ox/office/baseframework/view/component', [
                 var options = { triggerLayout: triggerLayout };
                 triggerLayout = false;
                 updateNodeSize(options);
-            });
+            }, { infoString: 'Component groupResizeHandler()', app: app });
         }());
 
         /**
@@ -325,7 +326,7 @@ define('io.ox/office/baseframework/view/component', [
         /**
          * Debounced version of the method updateAllGroups().
          */
-        var updateAllGroupsDebounced = this.createDebouncedMethod(_.noop, function () { self.updateAllGroups(); }, { delay: 50 });
+        var updateAllGroupsDebounced = this.createDebouncedMethod(_.noop, function () { self.updateAllGroups(); }, { delay: 50, infoString: 'Component updateAllGroupsDebounced()', app: app });
 
         /**
          * Handler for changed controller items. Updates the state and value of
