@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -44,14 +45,14 @@ define('io.ox/office/baseframework/view/control/dynamiclabel', [
      */
     function DynamicLabel(initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // resolves the value to a display string, or a caption options object
-            captionResolver = Utils.getFunctionOption(initOptions, 'captionResolver'),
+        // resolves the value to a display string, or a caption options object
+        var captionResolver = Utils.getFunctionOption(initOptions, 'captionResolver');
 
-            // whether to set the caption as tool-tip
-            setToolTip = Utils.getOption(initOptions, 'setToolTip', false);
+        // whether to set the caption as tool-tip
+        var setToolTip = Utils.getOption(initOptions, 'setToolTip', false);
 
         // base constructor ---------------------------------------------------
 
@@ -63,7 +64,7 @@ define('io.ox/office/baseframework/view/control/dynamiclabel', [
          * Updates the label text.
          */
         function updateHandler(value) {
-            var label = _.isFunction(captionResolver) ? captionResolver.call(self, value) : value;
+            var label = captionResolver ? captionResolver.call(self, value) : value;
             if (_.isObject(label)) {
                 self.setCaption(label);
             } else {
