@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -15,13 +16,12 @@ define('io.ox/office/baseframework/view/pane', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/keycodes',
     'io.ox/office/tk/forms',
-    'io.ox/office/tk/config',
     'io.ox/office/tk/utils/tracking',
     'io.ox/office/tk/object/triggerobject',
     'io.ox/office/tk/object/timermixin',
     'io.ox/office/baseframework/app/appobjectmixin',
     'io.ox/office/baseframework/view/viewobjectmixin'
-], function (Utils, KeyCodes, Forms, Config, Tracking, TriggerObject, TimerMixin, AppObjectMixin, ViewObjectMixin) {
+], function (Utils, KeyCodes, Forms, Tracking, TriggerObject, TimerMixin, AppObjectMixin, ViewObjectMixin) {
 
     'use strict';
 
@@ -122,13 +122,15 @@ define('io.ox/office/baseframework/view/pane', [
             isResizeTriggering = false,
 
             // whether a 'pane:layout' event is currently triggering (prevent recursion)
-            isLayoutTriggering = false;
+            isLayoutTriggering = false,
+
+            app = docView.getApp();
 
         // base constructors --------------------------------------------------
 
         TriggerObject.call(this);
         TimerMixin.call(this);
-        AppObjectMixin.call(this, docView.getApp());
+        AppObjectMixin.call(this, app);
         ViewObjectMixin.call(this, docView);
 
         // private methods ----------------------------------------------------
@@ -230,7 +232,7 @@ define('io.ox/office/baseframework/view/pane', [
                 var options = { triggerLayout: triggerLayout };
                 triggerLayout = false;
                 updateNodeSize(options);
-            });
+            }, { infoString: 'Pane componentResizeHandler()', app: app });
         }());
 
         /**
