@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -120,7 +121,7 @@ define('io.ox/office/baseframework/view/popup/contextmenu', [
             }
 
             if (delay) {
-                self.executeDelayed(executeShow, delay);
+                self.executeDelayed(executeShow, { delay: delay, infoString: 'showContextMenu', app: docView.getApp() });
             } else {
                 executeShow();
             }
@@ -332,6 +333,14 @@ define('io.ox/office/baseframework/view/popup/contextmenu', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
+            sourceNode.off({
+                mousedown: mouseDownHandler,
+                mouseup: mouseUpHandler,
+                keydown: keyDownHandler,
+                keyup: keyUpHandler,
+                'documents:contextmenu': contextMenuHandler
+            }, selector);
+
             docView = sourceNode = initOptions = self = null;
         });
 
