@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Michael Nimz <michael.nimz@open-xchange.com>
  */
@@ -56,7 +57,7 @@ define('io.ox/office/baseframework/view/popup/layermenu', [
             titleNode = $('<div class="title-label">').text(titleLabel),
 
             // the close button element
-            closeButton = $('<a class="closer" tabindex="1">' + Forms.createIconMarkup('fa-times') + '</a>'),
+            closeButton = $('<a class="closer" tabindex="0">' + Forms.createIconMarkup('fa-times') + '</a>'),
 
             // the container node for this pop-up node
             rootContainerNode = $(Utils.getOption(initOptions, 'rootContainerNode', window.document.body)),
@@ -120,7 +121,7 @@ define('io.ox/office/baseframework/view/popup/layermenu', [
 
         // initialization -----------------------------------------------------
 
-        this.getNode().addClass('layer-menu').attr('id', this.getUid());
+        this.getNode().addClass('layer-menu').addClass('f6-target').attr('id', this.getUid());
 
         // event handlers for the pop-up menu
         this.on('popup:beforehide', popupBeforeHideHandler);
