@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -165,11 +166,11 @@ define('io.ox/office/baseframework/view/toolpane', [
             rootNode.addClass('tool-pane hidden-contents');
 
             // removes the CSS marker class that hides the pane contents during import
-            function showPaneContents() {
+            var showPaneContents = _.once(function () {
                 self.executeDelayed(function () {
                     rootNode.removeClass('hidden-contents');
-                }, 1500);
-            }
+                }, { delay: 1500, infoString: 'ToolPane: showPaneContents', app: docView.getApp() });
+            });
 
             // show pane contents after import, and during import in preview state
             this.waitForImport(showPaneContents);
