@@ -6,14 +6,15 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/drawinglayer/model/drawingcollection', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/simplemap',
+    'io.ox/office/tk/container/simplemap',
     'io.ox/office/tk/object/triggerobject',
     'io.ox/office/tk/object/timermixin',
     'io.ox/office/drawinglayer/model/drawingmodel'
