@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -32,7 +33,7 @@ define('io.ox/office/drawinglayer/model/drawingmodel', [
      * @param {EditModel} docModel
      *  The document model containing this drawing object.
      *
-     * @param {String} type
+     * @param {String} drawingType
      *  The type of this drawing object.
      *
      * @param {Object} [initAttributes]
@@ -47,7 +48,7 @@ define('io.ox/office/drawinglayer/model/drawingmodel', [
      *      supported by all drawing objects will be registered implicitly, and
      *      does not have to be added here.
      */
-    function DrawingModel(docModel, type, initAttributes, initOptions) {
+    function DrawingModel(docModel, drawingType, initAttributes, initOptions) {
 
         // base constructors --------------------------------------------------
 
@@ -73,14 +74,14 @@ define('io.ox/office/drawinglayer/model/drawingmodel', [
         // public methods -----------------------------------------------------
 
         /**
-         * Returns the type of this drawing model, as specified by the
+         * Returns the type of this drawing model, as specified by the document
          * operation that has created the drawing model.
          *
          * @returns {String}
          *  The type of this drawing model.
          */
         this.getType = function () {
-            return type;
+            return drawingType;
         };
 
         /**
@@ -108,6 +109,28 @@ define('io.ox/office/drawinglayer/model/drawingmodel', [
             return null;
         };
 
+        /**
+         * Returns whether this drawing model is set to the specified type, or
+         * contains an embedded drawing collection with at least one drawing
+         * model of that type (e.g. in group objects).
+         *
+         * @param {String} type
+         *  The drawing model type to be checked.
+         *
+         * @returns {Boolean}
+         *  Whether this drawing model has the specified type, or contains an
+         *  embedded drawing model of that type.
+         */
+        this.isOrContainsType = function (type) {
+
+            // first check the own type
+            if (drawingType === type) { return true; }
+
+            // check whether an embedded drawing model exists
+            var collection = this.getCollection();
+            return !!collection && (collection.getModelCount({ deep: true, type: type }) > 0);
+        };
+
         // initialization -----------------------------------------------------
 
         // destroy all class members on destruction
