@@ -6,17 +6,23 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
 
 define('io.ox/office/drawinglayer/model/drawingstylecollection', [
+
     'io.ox/office/tk/utils',
+
     'io.ox/office/editframework/utils/color',
+    'io.ox/office/editframework/utils/gradient',
+
     'io.ox/office/editframework/model/stylecollection'
-], function (Utils, Color, StyleCollection) {
+
+], function (Utils, Color, Gradient, StyleCollection) {
 
     'use strict';
 
@@ -88,22 +94,39 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
 
         /**
          *  Type of the fill. Supported values are:
-         *  - 'none': Not filled (transparent).
+         *  - 'none': not filled (transparent).
          *  - 'auto': specific default fill, dependent on context.
          *  - 'solid': single fill color ('color' attribute).
+         *  - 'gradient': color gradient.
+         *  - 'pattern': monochrome pattern.
          *  - 'bitmap': background image.
          */
         type: { def: 'none' },
 
         /**
-         * Fill color (used for fill type 'solid').
+         * Fill color (used for fill type 'solid', 'gradient', and 'pattern').
          */
         color: { def: Color.AUTO },
 
         /**
-         * Image URL (used for fill type 'bitmap')
+         * Second fill color (used for fill type 'gradient' or 'pattern').
          */
-        imageUrl: { def: '' }
+        backgroundColor: { def: Color.AUTO },
+
+        /**
+         * Gradient descriptor object (used for fill type 'gradient').
+         */
+        gradient: { def: Gradient.LINEAR },
+
+        /**
+         * Pattern type (used for fill type 'pattern').
+         */
+        pattern: { def: 'none' },
+
+        /**
+         * Bitmap descriptor object (used for fill type 'bitmap').
+         */
+        bitmap: { def: { imageUrl: '', transparency: 0 } }
     };
 
     // definitions for drawing outline attributes -----------------------------
@@ -124,7 +147,61 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
         /**
          * Width of the outline, in 1/100 of millimeters.
          */
-        width: { def: 1 }
+        width: { def: 1 },
+
+        /**
+         * Specifies the head end type. Supported values are:
+         * - 'none': No head end is drawn..
+         * - 'triangle': A head end is drawn using triangle style.
+         * - 'stealth': A head end is drawn using stealth style.
+         * - 'diamond': A head end is drawn using diamond style.
+         * - 'oval': A head end is drawn using oval style.
+         * - 'arrow': A head end is drawn using arrow style.
+         */
+        headEndType: { def: 'none' },
+
+        /**
+         * Specifies the head end length. Supported values are:
+         * - 'small': A small length head end is drawn.
+         * - 'medium': A medium length head end is drawn.
+         * - 'large': A large length head end is drawn.
+         */
+        headEndLength: { def: 'medium' },
+
+        /**
+         * Specifies the head end width. Supported values are:
+         * - 'small': A small width head end is drawn.
+         * - 'medium': A medium width head end is drawn.
+         * - 'large': A large width head end is drawn.
+         */
+        headEndWidth: { def: 'medium' },
+
+        /**
+         * Specifies the tail end type. Supported values are:
+         * - 'none': No tail end is drawn..
+         * - 'triangle': A tail end is drawn using triangle style.
+         * - 'stealth': A tail end is drawn using stealth style.
+         * - 'diamond': A tail end is drawn using diamond style.
+         * - 'oval': A tail end is drawn using oval style.
+         * - 'arrow': A tail end is drawn using arrow style.
+         */
+        tailEndType: { def: 'none' },
+
+        /**
+         * Specifies the tail end length. Supported values are:
+         * - 'small': A small length tail end is drawn.
+         * - 'medium': A medium length tail end is drawn.
+         * - 'large': A large length tail end is drawn.
+         */
+        tailEndLength: { def: 'medium' },
+
+        /**
+         * Specifies the tail end width. Supported values are:
+         * - 'small': A small width tail end is drawn.
+         * - 'medium': A medium width tail end is drawn.
+         * - 'large': A large width tail end is drawn.
+         */
+        tailEndWidth: { def: 'medium' }
     });
 
     // definitions for linked text attributes ---------------------------------
@@ -256,7 +333,11 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
         /**
          * disables autoResizeHeight & autoResizeText
          */
-        noAutoResize:   { def: false }
+        noAutoResize:   { def: false },
+       /**
+        * Specifies the text orientation
+        */
+        vert: { def: 'horz' }
     };
 
     // definitions for geometry attributes --------------------------------
@@ -279,6 +360,22 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
         textRect: { def: {} }
     };
 
+    // definitions for connector attributes --------------------------------
+
+    var CONNECTOR_ATTRIBUTE_DEFINITIONS = {
+
+        /**
+         * Connector attributes defines the shape the connector is connected to
+         */
+        startId: { def: '' },
+
+        startIndex: { def: 0 },
+
+        endId: { def: '' },
+
+        endIndex: { def: 0 }
+    };
+
     // definitions for common chart attributes --------------------------------
 
     var CHART_ATTRIBUTE_DEFINITIONS = {
@@ -404,6 +501,7 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
             .registerAttributeDefinitions('line', LINE_ATTRIBUTE_DEFINITIONS)
             .registerAttributeDefinitions('text', TEXT_ATTRIBUTE_DEFINITIONS)
             .registerAttributeDefinitions('image', IMAGE_ATTRIBUTE_DEFINITIONS)
+            .registerAttributeDefinitions('connector', CONNECTOR_ATTRIBUTE_DEFINITIONS)
             .registerAttributeDefinitions('shape', SHAPE_ATTRIBUTE_DEFINITIONS)
             .registerAttributeDefinitions('chart', CHART_ATTRIBUTE_DEFINITIONS)
             .registerAttributeDefinitions('series', CHART_SERIES_ATTRIBUTE_DEFINITIONS)
