@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  */
@@ -33,7 +34,7 @@ define('io.ox/office/drawinglayer/view/chartformatter', [
         // private methods ----------------------------------------------------
 
         function isAnyDateTime(format, value) {
-            if (format && format.isAnyDateTime() && !isNaN(value)) {
+            if (format && format.isAnyDateTime() && isFinite(value)) {
                 return true;
             }
         }
@@ -50,7 +51,6 @@ define('io.ox/office/drawinglayer/view/chartformatter', [
         }
 
         function handleData(info, source, dataPoint, nullAsZero) {
-
             var realNr = source.value;
             var display = source.display;
             var format = source.format;
@@ -66,24 +66,24 @@ define('io.ox/office/drawinglayer/view/chartformatter', [
             var res = null;
             if (info.date) {
                 res = realNr;
-                info.max = Math.max(info.max, res);
+                info.max = Math.max(info.max, Math.abs(realNr));
                 label = display;
 
-            } else if (realNr === undefined || realNr === null || isNaN(realNr)) {
+            } else if (realNr === undefined || realNr === null || !isFinite(realNr)) {
                 info.unclean = true;
                 res = nullAsZero ? 0 : undefined;
                 label = display;
             } else if (info.format) {
-                info.max = Math.max(info.max, realNr);
+                info.max = Math.max(info.max, Math.abs(realNr));
                 res = realNr;
                 label = docModel.getNumberFormatter().formatValue(info.format, realNr);
             } else {
-                info.max = Math.max(info.max, realNr);
+                info.max = Math.max(info.max, Math.abs(realNr));
                 res = realNr;
                 label = docModel.getNumberFormatter().formatStandardNumber(realNr, 12);
             }
 
-            dataPoint[info.label] = sanitize(label);
+            dataPoint[info.label] = label;
             dataPoint[info.type] = res;
         }
 
@@ -113,10 +113,6 @@ define('io.ox/office/drawinglayer/view/chartformatter', [
             }
         }
 
-        function sanitize(text) {
-            return Utils.parseAndSanitizeHTML(text).text();
-        }
-
         // public methods -----------------------------------------------------
 
         this.format = function () {
@@ -176,9 +172,9 @@ define('io.ox/office/drawinglayer/view/chartformatter', [
 
                     //ugly part against double formatting!!!
                     if (dataPoint.nameSource) {
-                        dataPoint[x.label] = sanitize(dataPoint.nameSource.display);
+                        dataPoint[x.label] = dataPoint.nameSource.display;
                     } else {
-                        dataPoint[x.label] = sanitize(String(dataPoint[x.type]));
+                        dataPoint[x.label] = String(dataPoint[x.type]);
                     }
 
                     if (dataPoint.label) { dataPoint.legendLabel = dataPoint.label; }
@@ -199,8 +195,6 @@ define('io.ox/office/drawinglayer/view/chartformatter', [
                     dataPoint.legendText = dataPoint.legendLabel;
                 });
 
-                dataSeries.toolTipContent = '{label}: {name}';
-
                 if (xyChart && x.unclean) {
                     _.each(dataPoints, function (dataPoint, n) {
                         dataPoint.x = n + 1;
@@ -258,7 +252,7 @@ define('io.ox/office/drawinglayer/view/chartformatter', [
             // build series title
             if (titles) { dataSeries.nameHolder = titles[0]; }
             if (!seriesIndex) {
-                if (dataSeries.nameHolder) {
+                if (dataSeries.nameHolder && data.series.length === 1) {
                     chartModel.setMainName(dataSeries.nameHolder.display);
                 } else {
                     chartModel.setMainName(null);
