@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  */
@@ -100,19 +101,24 @@ define('io.ox/office/drawinglayer/view/chartstyleutil', [
         return BACKGROUNDTRANSFORMATION;
     };
 
-    function getCorrectLineColor(docModel, chartModel) {
+    ChartStyleUtil.isAuto = function (color) {
+        return color.type === 'auto' || color.value === 'phClr';
+    };
+
+    function getLineColorForAuto(docModel, chartModel) {
         var attrs = chartModel.getMergedAttributeSet(true);
         var bg = attrs.fill.color;
-        if (Color.parseJSON(bg).isAuto()) {
+
+        if (ChartStyleUtil.isAuto(bg)) {
             chartModel.updateBackgroundColor();
             attrs = chartModel.getMergedAttributeSet(true);
             bg = attrs.fill.color;
+            if (!_.isString(bg.fallbackValue)) {
+                bg.fallbackValue = colorDesc.hex;
+            }
         }
         var colorDesc = docModel.resolveColor(Color.parseJSON(bg), 'line');
-        if (!_.isString(bg.fallbackValue)) {
-            bg.fallbackValue = colorDesc.hex;
-        }
-        return { type: 'preset', value: colorDesc.dark ? 'white' : 'black' };
+        return colorDesc.dark ? 'white' : 'black';
     }
 
     /**
@@ -135,11 +141,26 @@ define('io.ox/office/drawinglayer/view/chartstyleutil', [
             usePrefix = 'font';
         }
 
-        target[usePrefix + 'Color'] = docModel.getCssColor(character.color, getCorrectLineColor(docModel, chartModel));
-        target[usePrefix + 'Family'] = docModel.getCssFontFamily(character.fontName);
-        target[usePrefix + 'Size'] = docView.getZoomFactor() * Utils.convertLength(character.fontSize, 'pt', 'px');
-        target[usePrefix + 'Weight'] = character.bold ? 'bold' : 'normal';
-        target[usePrefix + 'Style'] = character.italic ? 'italic' : 'normal';
+        var cssColor = null;
+        var color = character.color;
+        if (ChartStyleUtil.isAuto(color)) {
+            cssColor = getLineColorForAuto(docModel, chartModel);
+        } else {
+            cssColor = docModel.getCssColor(color);
+        }
+
+        var targetJSON = target[usePrefix] || {};
+        target[usePrefix] = targetJSON;
+
+        targetJSON.Color  = cssColor;
+        targetJSON.Family = docModel.getCssFontFamily(character.fontName);
+        targetJSON.Size   = docView.getZoomFactor() * Utils.convertLength(character.fontSize, 'pt', 'px');
+        targetJSON.Weight = character.bold ? 'bold' : 'normal';
+        targetJSON.Style  = character.italic ? 'italic' : 'normal';
+
+        _.each(targetJSON, function (entry, key) {
+            target[usePrefix + key] = entry;
+        });
     };
 
     /**
@@ -158,12 +179,27 @@ define('io.ox/office/drawinglayer/view/chartstyleutil', [
         var w = line.width ? line.width * (72 / 2540) : 1;
         var usePrefix = prefix;
 
+        var targetJSON = target[usePrefix] || {};
+        target[usePrefix] = targetJSON;
+
         if (line.type === 'none') {
-            target[usePrefix + 'Color'] = 'transparent';
+            targetJSON.Color = 'transparent';
         } else {
-            target[usePrefix + 'Color'] = docModel.getCssColor(line.color, getCorrectLineColor(docModel, chartModel));
-            target[usePrefix + 'Thickness'] = Math.max(1, Math.round(docView.getZoomFactor() * w));
+            var cssColor = null;
+            var color = line.color;
+            if (ChartStyleUtil.isAuto(color)) {
+                cssColor = getLineColorForAuto(docModel, chartModel);
+            } else {
+                cssColor = docModel.getCssColor(color);
+            }
+
+            targetJSON.Color     = cssColor;
+            targetJSON.Thickness = Math.max(1, Math.round(docView.getZoomFactor() * w));
         }
+
+        _.each(targetJSON, function (entry, key) {
+            target[usePrefix + key] = entry;
+        });
     };
 
     // exports ================================================================
