@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
@@ -104,7 +105,7 @@ define('io.ox/office/drawinglayer/view/control/chartcolorsetpicker', [
             _.each(CHART_COLOR_SETS, function (colorSet, index) {
                 self.createOptionButton('cs' + index, { tooltip: colorSet.name, colorSet: colorSet });
             });
-        }, { delay: 500 });
+        }, { delay: 500, infoString: 'ChartColorSetPicker: initializeColorTable', app: docView.getApp() });
 
         // initialization -----------------------------------------------------
 
