@@ -6,19 +6,30 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/editframework/app/editcontroller', [
-    'io.ox/core/capabilities',
+    'io.ox/office/tk/utils',
     'io.ox/office/baseframework/app/basecontroller',
     'io.ox/office/editframework/utils/editconfig'
-], function (Capabilities, BaseController, Config) {
+], function (Utils, BaseController, Config) {
 
     'use strict';
 
+    // default search configuration
+    var DEFAULT_SEARCH_SETTINGS = {
+        // current search query
+        query: '',
+        // whether 'query' is a regular expression
+        regexp: false,
+        // the replacement string
+        replace: ''
+    };
+
     // class EditController ===================================================
 
     /**
@@ -38,19 +49,100 @@ define('io.ox/office/editframework/app/editcontroller', [
      * @param {EditView} docView
      *  The document view created by the passed application.
      *
+     * @param {Function} searchHandler
+     *  A callback function that will implement searching for a specific query
+     *  string entered in the search/replace tool bar. Receives the following
+     *  parameters:
+     *  (1) {String} command
+     *      The search/replace command to be executed. Will be one of the
+     *      following commands:
+     *      - 'search:start'
+     *          Start a new search/replace session. Will be sent after entering
+     *          some text in the query input field, or changing any search
+     *          options which influence the matching document contents.
+     *      - 'search:prev'
+     *          Search for the previous occurrence of the current query string.
+     *      - 'search:next'
+     *          Search for the next occurrence of the current query string.
+     *      - 'search:end'
+     *          Finish the current search/replace session, remove all feedback
+     *          for search/replace in the user interface. Will be sent after
+     *          closing the search pane.
+     *      - 'replace:next'
+     *          Replace the next occurrence of the current query string with
+     *          the replacement text.
+     *      - 'replace:all'
+     *          Replace all occurrences of the current query string with the
+     *          replacement text.
+     *  (2) {Object} settings
+     *      The current search settings. The object contains the following
+     *      properties:
+     *      - {String} query
+     *          The search query string.
+     *      - {Boolean} regexp
+     *          Whether the query string shall be interpreted as regular
+     *          expression, instead of a literal search string.
+     *      - {String} replace
+     *          The string containing the replacement text for the matches.
+     *  The function may return a promise, if the search action involves
+     *  asynchronous operations. The view will be locked until the promise has
+     *  been resolved or rejected. The promise may be rejected with an error
+     *  code string which may result in an alert message box shown in the user
+     *  interface. Alternatively, the function may return an explicit error
+     *  code string synchronously (without using a promise). The function will
+     *  be called in the context of this view instance.
+     *
      * @param {Object} [initOptions]
      *  Optional parameters. Supports all options supported by the base class
      *  BaseController.
      */
-    function EditController(app, docModel, docView, initOptions) {
+    function EditController(app, docModel, docView, searchHandler, initOptions) {
 
         // self reference
         var self = this;
 
+        // the current search configuration
+        var searchSettings = _.clone(DEFAULT_SEARCH_SETTINGS);
+
         // base constructor ---------------------------------------------------
 
         BaseController.call(this, app, docModel, docView, initOptions);
 
+        // private methods ----------------------------------------------------
+
+        /**
+         * Invokes the search/replace handler passed to the constructor of this
+         * instance.
+         *
+         * @param {String} command
+         *  The search/replace command to be executed.
+         *
+         * @param {Object} [newSettings]
+         *  New properties for the search configuration object. Will be
+         *  inserted into the configuration before invoking the search handler.
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved when the search handler has
+         *  finished the specified operation, or that will be rejected on any
+         *  error.
+         */
+        function executeSearch(command, newSettings) {
+
+            // change the specified configuration properties
+            _.extend(searchSettings, newSettings);
+
+            // invoke the search handler
+            var result = searchHandler.call(this, command, _.clone(searchSettings));
+
+            // convert error code (non-empty strings) to rejected promise
+            var promise = (_.isString(result) && result) ? $.Deferred().reject(result) : $.when(result);
+
+            // TODO: show alert messages for generic errors
+            promise.fail(function (result) { Utils.error('executeSearch failed', result); });
+
+            return promise;
+        }
+
         // initialization -----------------------------------------------------
 
         // register all controller items
@@ -85,7 +177,7 @@ define('io.ox/office/editframework/app/editcontroller', [
             // dummy item for the 'Save in Drive' drop-down menu
             'view/saveas/menu': {
                 parent: 'app/valid',
-                enable: function () { return !app.getLaunchOption('disableSaveAs'); }
+                enable: function () { return (!app.getLaunchOption('disableSaveAs')) && (!app.isDocumentEncrypted()); }
             },
 
             'view/searchgroup': {
@@ -127,13 +219,18 @@ define('io.ox/office/editframework/app/editcontroller', [
                 enable: function () { return docModel.getEditMode(); }
             },
 
+            'document/readonly': {
+                parent: 'app/valid',
+                enable: function () { return !docModel.getEditMode(); }
+            },
+
             'document/fullname': {
                 get: function () { return app.getFullFileName(); }
             },
 
             'document/rename': {
                 parent: ['document/editable', 'app/bundled'],
-                enable: function () { return !Config.RENAME_DISABLED; },
+                enable: function () { return !Config.RENAME_DISABLED && (!app.isDocumentEncrypted() || !app.doesRenameNeedReload()); },
                 get: function () { return app.getShortFileName(); },
                 set: function (fileName) { return app.rename(fileName); }
             },
@@ -175,14 +272,16 @@ define('io.ox/office/editframework/app/editcontroller', [
             'document/exportaspdf/dialog': {
               //parent: 'document/saveas/dialog',
                 parent: 'app/valid',
-                enable: function () { return Capabilities.has('document_preview'); },
+                enable: function () { return Config.CONVERTER_AVAILABLE; },
                 set: function (type) { return docView.showSaveAsDialog(type); }
             },
 
             'document/autosave': {
-                parent: 'app/valid',
+                parent: ['document/editable'],
                 get: function () { return app.isAutoSaveEnabled(); },
-                set: function (state) { app.toggleAutoSave(state); }
+                set: function (state) { return app.toggleAutoSave(state); },
+                // auto save button must be always fresh
+                alwaysDirty: true
             },
 
             'document/users': {
@@ -192,49 +291,53 @@ define('io.ox/office/editframework/app/editcontroller', [
                 set: function (state) { docView.toggleCollaboratorPopup(state); }
             },
 
-            // base item for search/replace, returns the search configuration object
+            // base item for search/replace
             'document/search': {
                 // enabled in read-only mode
-                parent: 'app/valid',
-                get: function () { return docView.getSearchSettings(); }
+                parent: 'app/valid'
             },
 
             'document/search/text': {
                 parent: 'document/search',
-                get: function (settings) { return settings.query; },
+                get: function () { return searchSettings.query; },
                 set: function (text, evt) {
                     // workaround for Bug 46401: 'custom' sourceType is triggered on blur on the textfield
                     if (evt && evt.changeEvent && evt.changeEvent.sourceType === 'custom') {
-                        return docView.changeSearchSettings({ query: text });
+                        searchSettings.query = text;
                     } else {
-                        return docView.executeSearchOperation('search:start', { query: text });
+                        return executeSearch('search:start', { query: text });
                     }
                 }
             },
 
             'document/search/regexp': {
                 parent: 'document/search',
-                get: function (settings) { return settings.regexp; },
-                set: function (state) { return docView.executeSearchOperation('search:start', { regexp: state }); }
+                get: function () { return searchSettings.regexp; },
+                set: function (state) { return executeSearch('search:start', { regexp: state }); }
             },
 
             'document/search/start': {
                 parent: 'document/search',
-                set: function () { return docView.executeSearchOperation('search:start'); }
+                set: function () { return executeSearch('search:start'); }
             },
 
             'document/search/prev': {
                 parent: 'document/search',
-                set: function () { return docView.executeSearchOperation('search:prev'); },
+                set: function () { return executeSearch('search:prev'); },
                 shortcut: [{ keyCode: 'G', ctrlOrMeta: true, shift: true }, { keyCode: 'F3', shift: true }]
             },
 
             'document/search/next': {
                 parent: 'document/search',
-                set: function () { return docView.executeSearchOperation('search:next'); },
+                set: function () { return executeSearch('search:next'); },
                 shortcut: [{ keyCode: 'G', ctrlOrMeta: true }, { keyCode: 'F3' }]
             },
 
+            'document/search/end': {
+                parent: 'document/search',
+                set: function () { return executeSearch('search:end', { query: '', replace: '' }); }
+            },
+
             'document/search/close': {
                 parent: 'document/search',
                 set: function () { return docView.getSearchGroup().hide(); }
@@ -247,18 +350,18 @@ define('io.ox/office/editframework/app/editcontroller', [
 
             'document/replace/text': {
                 parent: 'document/replace',
-                get: function (settings) { return settings.replace; },
-                set: function (text) { docView.changeSearchSettings({ replace: text }); }
+                get: function () { return searchSettings.replace; },
+                set: function (text) { searchSettings.replace = text; }
             },
 
             'document/replace/next': {
                 parent: 'document/replace',
-                set: function () { return docView.executeSearchOperation('replace:next'); }
+                set: function () { return executeSearch('replace:next'); }
             },
 
             'document/replace/all': {
                 parent: 'document/replace',
-                set: function () { return docView.executeSearchOperation('replace:all'); }
+                set: function () { return executeSearch('replace:all'); }
             }
         });
 
