@@ -5,7 +5,9 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ *
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -20,8 +22,9 @@ define('io.ox/office/editframework/app/fileactions', [
     'io.ox/office/tk/io',
     'io.ox/office/baseframework/app/extensionregistry',
     'io.ox/office/baseframework/app/applicationlauncher',
+    'io.ox/office/tk/utils/deferredutils',
     'gettext!io.ox/office/editframework/actions'
-], function (ext, links, DriveUtils, Utils, IO, ExtensionRegistry, ApplicationLauncher, gt) {
+], function (ext, links, DriveUtils, Utils, IO, ExtensionRegistry, ApplicationLauncher, DeferredUtils, gt) {
 
     'use strict';
 
@@ -29,23 +32,45 @@ define('io.ox/office/editframework/app/fileactions', [
 
     /**
      * Returns whether the files in the folder described by the passed baton
-     * object are considered to be editable. The trash folder for example will
-     * be treated as read-only folder.
+     * object are considered to be editable.
+     * The trash folder for example will be treated as read-only folder.
      *
      * @param {Object} baton
      *  The baton object providing access to a folder.
      *
-     * @returns {Boolean|jQuery.Promise}
-     *  A Boolean value specifying whether the folder is considered editable,
-     *  or a Promise that will resolve with a Boolean value, if the folder data
-     *  in the baton object is not available yet.
+     * @returns {jQuery.Promise}
+     *  A Promise that will resolve with a Boolean value,
+     *  specifying whether the folder is considered editable.
      */
     function isEditableFolder(baton) {
         // no baton.data, no trash folder (e.g. main portal)
         if (!baton.data.id) { return $.when(true); }
 
         return DriveUtils.getTrashState(baton.data.folder_id).then(function (state) {
-            return !state;
+            return $.when(!state);
+        });
+    }
+
+    /**
+     * Returns whether the files in the folder described by the passed baton
+     * object are considered to be editable and the current version.
+     *
+     * @param {Object} baton
+     *  The baton object providing access to a folder.
+     *
+     * @returns {jQuery.Promise}
+     *  A Promise that will resolve with a Boolean value,
+     *  specifying whether the folder is considered editable and
+     *  the file represents the current version.
+     */
+    function isEditableFolderAndCurrentVersion(baton) {
+
+        // check if file is editable
+        var promise = isEditableFolder(baton);
+
+        // check if file is the current version
+        return promise.then(function (canEdit) {
+            return canEdit && DriveUtils.getCurrentFileVersionState(baton.data, { cache: true });
         });
     }
 
@@ -86,7 +111,7 @@ define('io.ox/office/editframework/app/fileactions', [
             if (e.collection.has('modify')) {
                 return true;
             }
-            if (e.baton.models.length) {
+            if (e.baton.models && e.baton.models.length) {
                 return e.baton.models[0].hasWritePermissions();
             }
         }
@@ -221,7 +246,7 @@ define('io.ox/office/editframework/app/fileactions', [
                 if (filename && hasWritePermissions(e) && ExtensionRegistry.isEditable(filename, MODULE_NAME) && !ExtensionRegistry.isTemplate(filename, MODULE_NAME) && ExtensionRegistry.isNative(filename, MODULE_NAME)) {
                     // prefetch application source code
                     IO.prefetchModuleSource(MODULE_NAME);
-                    return isEditableFolder(e.baton);
+                    return isEditableFolderAndCurrentVersion(e.baton);
                 }
                 return $.when(false);
             },
@@ -243,7 +268,7 @@ define('io.ox/office/editframework/app/fileactions', [
 
                 var filename = e.context.filename;
                 if (filename && e.collection.has('one', 'read') && !ExtensionRegistry.isError(filename) && ExtensionRegistry.isTemplate(filename, MODULE_NAME)) {
-                    return isEditableFolder(e.baton);
+                    return isEditableFolderAndCurrentVersion(e.baton);
                 }
                 return $.when(false);
             },
@@ -299,23 +324,23 @@ define('io.ox/office/editframework/app/fileactions', [
                 // guest -> no my files -> no edit-as-new button!
                 var filename = e.context.filename;
                 if (!filename || DriveUtils.isGuest()) { return false; }
-                return e.collection.has('one', 'read') && !ExtensionRegistry.isError(filename) && !ExtensionRegistry.isTemplate(filename, MODULE_NAME) && ExtensionRegistry.isEditable(filename, MODULE_NAME);
+                return e.collection.has('one', 'read') && !ExtensionRegistry.isError(filename) && !ExtensionRegistry.isGuardEncrypted(filename) && !ExtensionRegistry.isTemplate(filename, MODULE_NAME) && ExtensionRegistry.isEditable(filename, MODULE_NAME);
             };
 
             var isNormalEditAsNew = function (e) {
                 var filename = e.context.filename;
-                return !!filename && hasWritePermissions(e) && ExtensionRegistry.isNative(filename, MODULE_NAME);
+                return !!filename && !ExtensionRegistry.isGuardEncrypted(filename) && hasWritePermissions(e) && ExtensionRegistry.isNative(filename, MODULE_NAME);
             };
 
             editAsNew('-edit-asnew', function (e) {
                 if (isExtraEditAsNew(e) && isNormalEditAsNew(e)) {
-                    return isEditableFolder(e.baton);
+                    return isEditableFolderAndCurrentVersion(e.baton);
                 }
             });
 
             editAsNew('-edit-asnew-hi', function (e) {
                 if (isExtraEditAsNew(e) && !isNormalEditAsNew(e)) {
-                    return isEditableFolder(e.baton);
+                    return isEditableFolderAndCurrentVersion(e.baton);
                 }
             });
 
@@ -324,8 +349,9 @@ define('io.ox/office/editframework/app/fileactions', [
             new links.Action(ACTION_POINT + '-edit-template', {
                 requires: function (e) {
                     var filename = e.context.filename;
-                    if (filename && hasWritePermissions(e) && !ExtensionRegistry.isError(filename) && ExtensionRegistry.isTemplate(filename, MODULE_NAME) && !ExtensionRegistry.isTemplateLocked(filename, MODULE_NAME) && ExtensionRegistry.isEditable(filename, MODULE_NAME)) {
-                        return isEditableFolder(e.baton);
+                    // template files cannot be edited directly, if they would need to be converted to another file format
+                    if (filename && hasWritePermissions(e) && ExtensionRegistry.isTemplate(filename, MODULE_NAME) && ExtensionRegistry.isNative(filename, MODULE_NAME)) {
+                        return isEditableFolderAndCurrentVersion(e.baton);
                     }
                     return $.when(false);
                 },
@@ -374,18 +400,22 @@ define('io.ox/office/editframework/app/fileactions', [
 
             // define links for document actions in the OX Viewer toolbar.
             ext.point('io.ox/core/viewer/toolbar/links/drive').extend(new links.Link(link));
+            ext.point('io.ox/core/viewer/toolbar/links/guardDrive').extend(new links.Link(link));
 
+            // define links for document actions in the OX Drive toolbar.
             ext.point('io.ox/files/classic-toolbar/links').extend(new links.Link(link));
 
+            // define links for document actions in the OX Viewer version drop-down.
+            ext.point('io.ox/files/versions/links/inline').extend(new links.Link(link));
         }
 
         //      id                  label                       prio    prioMobile    index     ref                 section
-        extend('-edit',            gt('Edit'),                 'hi',   'lo',         150,      '-edit',            'edit');
-        extend('-newfromtemplate', gt('New from template'),    'hi',   'lo',         150,      '-new-fromtemplate');
-        extend('-edittemplate',    gt('Edit template'),        'lo',   'lo',         'first',  '-edit-template',   'edit');
+        extend('-edit',            gt('Edit'),                 'hi',   'lo',          150,      '-edit',            'edit');
+        extend('-newfromtemplate', gt('New from template'),    'hi',   'lo',          150,      '-new-fromtemplate');
+        extend('-edittemplate',    gt('Edit template'),        'lo',   'lo',          160,      '-edit-template',   'edit');
 
-        extend('-editasnew',       gt('Edit as new'),          'lo',   'lo',         'first',  '-edit-asnew',     'edit');
-        extend('-editasnewhi',     gt('Edit as new'),          'hi',   'lo',         150,      '-edit-asnew-hi',  'edit');
+        extend('-editasnew',       gt('Edit as new'),          'lo',   'lo',          160,      '-edit-asnew',      'edit');
+        extend('-editasnewhi',     gt('Edit as new'),          'hi',   'lo',          150,      '-edit-asnew-hi',   'edit');
 
         if (!Utils.IOS) {
             overwriteExtPointForRunningApp('io.ox/files/actions/download', MODULE_NAME, '/download', 50, function (app) {
