@@ -5,7 +5,9 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ *
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Oliver Specht <oliver.specht@open-xchange.com>
  */
@@ -69,18 +71,31 @@ define('io.ox/office/editframework/app/mailactions', [
             capabilities: 'infostore',
             requires: function (e) {
 
-                // Fix for 46557: e.context can be an object or array dependent on the context
-                // Show operations for attachments or show all attachments in a list with operations
-                var // whether the "edit" link should be shown for the attachment
-                    isEditable = e.collection.has('one') && ((_.isArray(e.context)) ? ExtensionRegistry.isEditable(e.context[0].filename, MODULE_NAME) : ExtensionRegistry.isEditable(e.context.filename, MODULE_NAME));
+                if (!e.collection.has('one')) {
+                    return false;
+                }
+
+                var filename = null;
+                if (_.isArray(e.context)) {
+                    // Fix for 46557: e.context can be an object or array dependent on the context
+                    // Show operations for attachments or show all attachments in a list with operations
+                    filename = e.context[0].filename;
+                } else {
+                    filename = e.context.filename;
+                }
+
+                // whether the "edit" link should be shown for the attachment
+                var editable = ExtensionRegistry.isEditable(filename, MODULE_NAME);
+                if (!editable) {
+                    return false;
+                }
 
                 // prefetch application source code
-                if (isEditable) { IO.prefetchModuleSource(MODULE_NAME); }
-                return isEditable;
+                IO.prefetchModuleSource(MODULE_NAME);
+                return true;
             },
             multiple: function (list) {
                 MailApi.saveAttachments(list, DriveUtils.getStandardDocumentsFolderId()).done(function (result) {
-
                     if (result && result[0] && result[0].error) {
                         Utils.error('MailApi.saveAttachments makes an error', result[0]);
                         require(['io.ox/office/baseframework/utils/errormessages']).done(function (ErrorMessages) {
@@ -89,10 +104,10 @@ define('io.ox/office/editframework/app/mailactions', [
                         return;
                     }
 
-                    var // the baton data of the created Drive file returned by the mail API
-                        baton = result[0],
-                        // the file descriptor passed to the OX Documents application launcher
-                        file = _.clone(baton.data);
+                    // the baton data of the created Drive file returned by the mail API
+                    var baton = result[0];
+                    // the file descriptor passed to the OX Documents application launcher
+                    var file = _.clone(baton.data);
 
                     // Bug 40376 add the origin property to the file descriptor
                     file.source = 'drive';
