@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Kai Ahrens <kai.ahrens@open-xchange.com>
  * @author Carsten Driesner <carsten.driesner@open-xchange.com>
@@ -22,8 +23,9 @@ define('io.ox/office/editframework/app/rtconnection', [
     'io.ox/office/tk/utils/logger',
     'io.ox/office/tk/object/triggerobject',
     'io.ox/office/tk/object/timermixin',
-    'io.ox/office/editframework/utils/editconfig'
-], function (Events, UUID, SessionRestore, RTGroups, Utils, Logger, TriggerObject, TimerMixin, Config) {
+    'io.ox/office/editframework/utils/editconfig',
+    'io.ox/office/tk/utils/deferredutils'
+], function (Events, UUID, SessionRestore, RTGroups, Utils, Logger, TriggerObject, TimerMixin, Config, DeferredUtils) {
 
     'use strict';
 
@@ -361,7 +363,7 @@ define('io.ox/office/editframework/app/rtconnection', [
         function handleResponse(promise, timeout) {
 
             var // the Deferred object to be returned
-                def = $.Deferred();
+                def = DeferredUtils.createDeferred(app, 'RTConnection: handleResponse');
 
             promise.then(function (response) {
                 handleResolvedResponse(def, response);
@@ -376,7 +378,7 @@ define('io.ox/office/editframework/app/rtconnection', [
                         RTConnection.log('Timeout reached for RT request, timeout=' + timeout + 'ms.');
                         def.reject({ cause: 'timeout' });
                     }
-                }, timeout, 'RTConnection: handleResponse');
+                }, { delay: timeout, infoString: 'RTConnection: handleResponse', app: app });
                 def.always(function () { timer.abort(); timer = null; });
             }
 
@@ -401,13 +403,13 @@ define('io.ox/office/editframework/app/rtconnection', [
         function handleGenericResponse(promise, timeout) {
 
             var // the Deferred object to be returned
-                def = $.Deferred();
+                def = DeferredUtils.createDeferred(app, 'RTConnection: handleGenericResponse');
 
             promise.then(function (data) { def.resolve(data); }, function (data) { def.reject(data); });
 
             // prevent endless waiting
             if (_.isNumber(timeout) && (timeout > 0)) {
-                self.executeDelayed(function () { def.reject({ cause: 'timeout' }); }, timeout, 'RTConnection: handleGenericResponse');
+                self.executeDelayed(function () { def.reject({ cause: 'timeout' }); }, { delay: timeout, infoString: 'RTConnection: handleGenericResponse', app: app });
             }
 
             return def.promise();
@@ -566,7 +568,7 @@ define('io.ox/office/editframework/app/rtconnection', [
                     handleJoinResponse(def, response);
                     joining = false;
                 }
-            }, 1000, 'RTConnection: joinGroup');
+            }, { delay: 1000, infoString: 'RTConnection: joinGroup', app: app });
         }
 
         /**
@@ -629,7 +631,7 @@ define('io.ox/office/editframework/app/rtconnection', [
          */
         this.connect = function (connectData) {
 
-            var connectDeferred = $.Deferred(),
+            var connectDeferred = DeferredUtils.createDeferred(app, 'RTConnection: connect'),
                 // optional connect data
                 connectOptions = { expectWelcomeMessage: true },
                 // connect data
@@ -869,7 +871,7 @@ define('io.ox/office/editframework/app/rtconnection', [
         // initialization -----------------------------------------------------
 
         RTConnection.log('RTConnection initialization');
-        this.repeatDelayed(checkPendingAcks, CHECK_PENDING_INTERVAL, 'RTConnection: checkPendingAcks');
+        this.repeatDelayed(checkPendingAcks, { delay: CHECK_PENDING_INTERVAL, infoString: 'RTConnection: checkPendingAcks', app: app, priority: 'background-proc' });
 
         // read traceable actions from page URL
         if (_.url.hash('office:trace')) {
