@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -97,29 +98,29 @@ define('io.ox/office/editframework/model/attributedmodel', [
      */
     function AttributedModel(docModel, initAttributes, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the attribute family of the style sheets
-            styleFamily = Utils.getStringOption(initOptions, 'styleFamily', null, true),
+        // the attribute family of the style sheets
+        var styleFamily = Utils.getStringOption(initOptions, 'styleFamily', null, true);
 
-            // the parent model used to build the merged attribute set
-            parentModel = Utils.getObjectOption(initOptions, 'parentModel'),
+        // the parent model used to build the merged attribute set
+        var parentModel = Utils.getObjectOption(initOptions, 'parentModel', null);
 
-            // whether to remove explicit attributes equal to the attribute defaults
-            autoClear = !styleFamily && !parentModel && Utils.getBooleanOption(initOptions, 'autoClear', false),
+        // whether to remove explicit attributes equal to the attribute defaults
+        var autoClear = !styleFamily && !parentModel && Utils.getBooleanOption(initOptions, 'autoClear', false);
 
-            // the collection of style sheets for the style family
-            styleCollection = null,
+        // the collection of style sheets for the style family
+        var styleCollection = null;
 
-            // the names of all supported attribute families, as flag set
-            supportedFamilySet = null,
+        // the names of all supported attribute families, as flag set
+        var supportedFamilySet = null;
 
-            // the (incomplete) explicit attributes of this model object
-            explicitAttributeSet = {},
+        // the (incomplete) explicit attributes of this model object
+        var explicitAttributeSet = {};
 
-            // the (complete) cached merged attributes of this model object
-            mergedAttributeSet = null;
+        // the (complete) cached merged attributes of this model object
+        var mergedAttributeSet = null;
 
         // base constructor ---------------------------------------------------
 
