@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -16,11 +17,13 @@ define('io.ox/office/editframework/model/editmodel', [
     'io.ox/office/tk/utils/logger',
     'io.ox/office/baseframework/model/basemodel',
     'io.ox/office/editframework/utils/operations',
+    'io.ox/office/editframework/utils/operationutils',
     'io.ox/office/editframework/utils/operationcontext',
     'io.ox/office/editframework/model/undomanager',
     'io.ox/office/editframework/model/operationsgenerator',
-    'io.ox/office/editframework/model/modelattributesmixin'
-], function (Utils, Logger, BaseModel, Operations, OperationContext, UndoManager, OperationsGenerator, ModelAttributesMixin) {
+    'io.ox/office/editframework/model/modelattributesmixin',
+    'io.ox/office/tk/utils/deferredutils'
+], function (Utils, Logger, BaseModel, Operations, OperationUtils, OperationContext, UndoManager, OperationsGenerator, ModelAttributesMixin, DeferredUtils) {
 
     'use strict';
 
@@ -157,6 +160,9 @@ define('io.ox/office/editframework/model/editmodel', [
         // flag to enable slide specific behavior
         var slideMode = Utils.getBooleanOption(initOptions, 'slideMode', false);
 
+        // flag to enable slide specific behavior in iOS and Android
+        var slideTouchMode = slideMode && (Utils.IOS || Utils.CHROME_ON_ANDROID);
+
         // edit mode, received dynamically from server (one editing user at a time)
         var editMode = null;
 
@@ -238,7 +244,7 @@ define('io.ox/office/editframework/model/editmodel', [
 
             // create a new deferred object which remains in pending state as long
             // as the callback function runs (and the promise it returns is pending)
-            actionsDef = $.Deferred().always(function () {
+            actionsDef = DeferredUtils.createDeferred(app, 'EditModel.enterProcessActionsMode()').always(function () {
                 var state = actionsDef ? actionsDef.state().replace(/ed$/, 'ing') : 'destructed';
                 logger.log('EditModel.enterProcessActionsMode(): ' + state + ' promise...');
             });
@@ -248,9 +254,9 @@ define('io.ox/office/editframework/model/editmodel', [
 
             // resolve the actions promise
             if (Utils.isPromise(result)) {
-                result.progress(_.bind(actionsDef.notify, actionsDef))
-                    .done(_.bind(actionsDef.resolve, actionsDef))
-                    .fail(_.bind(actionsDef.reject, actionsDef));
+                result.progress(actionsDef.notify.bind(actionsDef));
+                result.done(actionsDef.resolve.bind(actionsDef));
+                result.fail(actionsDef.reject.bind(actionsDef));
                 return result;
             }
 
@@ -368,10 +374,10 @@ define('io.ox/office/editframework/model/editmodel', [
 
                 // Check the correct operation state number of an external operation. The OSN must be
                 // identical on every client. The OSN is sent from server, when the document is loaded.
-                if (external && context.has('osn')) {
+                if (external && context.has(OperationUtils.OSN)) {
 
                     // the OSN carried in the operation
-                    var opOSN = context.getInt('osn');
+                    var opOSN = context.getInt(OperationUtils.OSN);
                     context.ensure(opOSN >= 0, 'invalid OSN: %d', opOSN);
 
                     // During loading the document, the initial OSN is sent by the server.
@@ -394,7 +400,7 @@ define('io.ox/office/editframework/model/editmodel', [
 
                 // update the current OSN of the document
                 if (operationStateNumber >= 0) {
-                    operationStateNumber += context.getOptInt('opl', 1);
+                    operationStateNumber += context.getOptInt(OperationUtils.OPL, 1);
                 }
 
                 // cache the last two operations
@@ -539,7 +545,7 @@ define('io.ox/office/editframework/model/editmodel', [
             operations = OperationsGenerator.getArray(operations, options);
 
             // immediate success on empty operations array
-            if (operations.length === 0) { return self.createResolvedPromise(); }
+            if (operations.length === 0) { return self.createResolvedPromise(null); }
 
             // enter operations mode (prevent recursive calls)
             if (beginProcessOperations(operations, external)) {
@@ -553,7 +559,6 @@ define('io.ox/office/editframework/model/editmodel', [
                         // if the operation's origin is not an external client and
                         // we don't have edit rights then we skip the operations silently
                         if (!external && !editMode) {
-                            promise.abort();
                             return Utils.BREAK;
                         }
 
@@ -561,7 +566,7 @@ define('io.ox/office/editframework/model/editmodel', [
                         if (!applyOperation(operation, external, filter, importing)) {
                             return self.createRejectedPromise({ cause: 'operation' });
                         }
-                    }, { delay: 'immediate', infoString: 'EditModel.applyOperationsAsync' });
+                    }, { delay: 'immediate', infoString: 'EditModel: applyOperationsAsync 2', app: app });
                 });
 
             } else {
@@ -711,23 +716,14 @@ define('io.ox/office/editframework/model/editmodel', [
          * Returns a promise representing the state of the 'action processing
          * mode'. If in pending state, this model currently generates, applies,
          * or sends operation actions (either synchronously or asynchronously).
-         * If in resolved state, the last operations have been applied
-         * successfully. If in rejected state, the last operations have not
-         * been applied successfully.
-         *
-         * @attention
-         *  The promise MUST NOT be cached externally. Its solely purpose is to
-         *  register done/fail callbacks from operation handlers or other code
-         *  depending on operations. Whenever new operations will be applied, a
-         *  new promise will be created representing the new operations (the
-         *  old promises returned by this method before will remain in
-         *  resolved/rejected state forever).
+         * If in resolved state, the model is ready to process new actions.
          *
          * @returns {jQuery.Promise}
          *  A promise representing the state of the action processing mode.
          */
-        this.getActionsPromise = function () {
-            return actionsDef.promise();
+        this.waitForActionsProcessed = function () {
+            // do not expose the failed state of the deferred object
+            return actionsDef.then(null, function () { return $.when(); });
         };
 
         /**
@@ -889,7 +885,7 @@ define('io.ox/office/editframework/model/editmodel', [
                 // whether the actions have been received from the server
                 var external = Utils.getBooleanOption(options, 'external', false);
                 // resulting deferred object returned by this method
-                var resultDef = $.Deferred();
+                var resultDef = DeferredUtils.createDeferred(app, 'EditModel: applyActions');
                 // start index of first operations in the current action (for progress)
                 var startIndex = 0;
                 // the promise of the inner loop processing operations of an action
@@ -913,10 +909,11 @@ define('io.ox/office/editframework/model/editmodel', [
                     // clean up after finishing the loop
                     return innerPromise.always(function () { innerPromise = null; });
 
-                }, { delay: 'immediate', infoString: 'EditModel.applyActions' });
+                }, { delay: 'immediate', infoString: 'EditModel: applyActions', app: app });
 
                 // forward the result of the timer to the own deferred object
-                timer.done(function () { resultDef.notify(1).resolve(); }).fail(_.bind(resultDef.reject, resultDef));
+                timer.done(function () { resultDef.notify(1).resolve(); });
+                timer.fail(resultDef.reject.bind(resultDef));
 
                 // create an abortable promise for the deferred object
                 return self.createAbortablePromise(resultDef, function () {
@@ -1061,7 +1058,7 @@ define('io.ox/office/editframework/model/editmodel', [
                         if (!self.invokeOperationHandler(operation)) {
                             return $.Deferred().reject({ cause: 'operation' });
                         }
-                    });
+                    }, { infoString: 'EditModel: createAndApplyOperations', app: app });
 
                     // restore the rejected state of the outer promise (unless reverting the operations fails too)
                     return promise2.then(_.constant($.Deferred().reject(result)));
@@ -1203,6 +1200,64 @@ define('io.ox/office/editframework/model/editmodel', [
             return slideMode;
         };
 
+        /**
+         * Whether the touch mode should be used in Presentation.
+         *
+         * @returns {Boolean}
+         *  Whether the touch mode is used in Presentation.
+         */
+        this.getSlideTouchMode = function () {
+            return slideTouchMode;
+        };
+
+        /**
+         * Create a busy Screen with a cancel Button and a listener which is listening if the
+         * edit rights are withdrawn. The function returns a Deferred which must resolved if the
+         * job is done to remove the 'change:editmode' listener.
+         *
+         * @param {Object} [options]
+         *  Optional parameters.
+         *
+         *  @param {String} [options.dialogText='']
+         *      The text which is displayed on the busy screen e.g. 'Please wait while paste the text'
+         *
+         *  @param {Function} [abortHandler=null]
+         *      The callback function to listen if the cancel button is pressed or the edit rights are withdrawn.
+         *
+         * @returns {jQuery.Deferred}
+         *  The new deferred object.
+         */
+        this.createAbortableBusyScreen = function (options) {
+            var dialogText = Utils.getStringOption(options, 'dialogText', '');
+            var abortHandler = Utils.getFunctionOption(options, 'abortHandler', null);
+
+            function abort() {
+                if (abortHandler) {
+                    abortHandler();
+                }
+            }
+
+            app.getView().enterBusy({
+                cancelHandler: function () {
+                    abort();
+                },
+                warningLabel: dialogText
+            });
+
+            var editModeHandler = function (event, editMode) {
+                if (!editMode) {
+                    abort();
+                }
+            };
+
+            self.listenTo(self, 'change:editmode', editModeHandler);
+
+            return DeferredUtils.createDeferred(app, 'EditModel.createAbortablePromiseCancelDialog()')
+                .always(function () {
+                    self.stopListeningTo(self, 'change:editmode', editModeHandler);
+                });
+        };
+
         // operation generators -----------------------------------------------
 
         /**
@@ -1236,7 +1291,7 @@ define('io.ox/office/editframework/model/editmodel', [
         });
 
         this.registerContextOperationHandler(Operations.INSERT_THEME, function (context) {
-            this.getThemeCollection().insertTheme(context.getStr('themeName'), context.getObj('attrs'));
+            this.getThemeCollection().insertTheme(context.getStr('themeName'), context.getObj('attrs'), context.getOptStr('target', '', true));
         });
 
         this.registerContextOperationHandler(Operations.INSERT_FONT_DESCRIPTION, function (context) {
