@@ -6,20 +6,22 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/editframework/model/modelattributesmixin', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/simplemap',
+    'io.ox/office/tk/container/simplemap',
     'io.ox/office/editframework/utils/color',
     'io.ox/office/editframework/utils/border',
+    'io.ox/office/editframework/utils/gradient',
     'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/editframework/model/fontcollection',
     'io.ox/office/editframework/model/themecollection'
-], function (Utils, SimpleMap, Color, Border, AttributeUtils, FontCollection, ThemeCollection) {
+], function (Utils, SimpleMap, Color, Border, Gradient, AttributeUtils, FontCollection, ThemeCollection) {
 
     'use strict';
 
@@ -554,28 +556,48 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
         };
 
         /**
-         * Returns a single theme from the document's theme collection.
+         * Returns the default theme from the document's theme collection for
+         * an optionally specified target.
          *
-         * @param {String} [name]
-         *  The name of the theme to be returned. If omitted or not existing,
-         *  the 'current' theme will be returned.
+         * @param {String|Array<String>} [target]
+         *  An optional target string or an ordered collection of target strings
+         *  to specify the theme's target.
          *
          * @returns {Theme}
          *  The specified theme, or the current theme. If no theme has been
          *  inserted, returns the built-in default theme.
          */
-        this.getTheme = function (name) {
-            return themeCollection.getTheme(name);
+        this.getTheme = function (target) {
+            return themeCollection.getTheme('', target);
         };
 
         /**
-         * Returns whether the current theme contains scheme color definitions.
+         * Returns whether the default theme of an optionally specified target
+         * contains scheme color definitions.
+         *
+         * @param {String|Array<String>} [target]
+         *  An optional target string or an ordered collection of target strings
+         *  to specify the theme's target.
          *
          * @returns {Boolean}
          *  Whether the current theme contains scheme color definitions.
          */
-        this.hasSchemeColors = function () {
-            return themeCollection.getTheme().hasSchemeColors();
+        this.hasSchemeColors = function (target) {
+            return themeCollection.getTheme('', target).hasSchemeColors();
+        };
+
+        /**
+         * Returns, whether a specified target is registered for a default theme.
+         * The target must be a string, NOT a string container.
+         *
+         * @param {String} target
+         *  A target string to specify the theme's target.
+         *
+         * @returns {Boolean}
+         *  Whether there is a registered default theme for the specified target.
+         */
+        this.hasDefaultScheme = function (target) {
+            return themeCollection.hasDefaultTheme(target);
         };
 
         /**
@@ -585,12 +607,16 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
          * @param {String} fontName
          *  The name of of the font (case-insensitive).
          *
+         * @param {String|Array<String>} [target]
+         *  An optional target string or an ordered collection of target strings
+         *  to specify the theme's target.
+         *
          * @returns {String}
          *  The value of the CSS 'font-family' attribute containing the
          *  specified font name and all alternative font names.
          */
-        this.getCssFontFamily = function (fontName) {
-            return fontCollection.getCssFontFamily(fontName);
+        this.getCssFontFamily = function (fontName, target) {
+            return fontCollection.getCssFontFamily(fontName, themeCollection.getTheme('', target));
         };
 
         /**
@@ -604,11 +630,15 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
          *  Additional information needed to resolve the automatic color. See
          *  method Color.resolve() for details about this parameter.
          *
+         * @param {String|Array<String>} [target]
+         *  An optional target string or an ordered collection of target strings
+         *  to specify the theme's target.
+         *
          * @returns {ColorDescriptor}
          *  A descriptor for the resulting color.
          */
-        this.resolveColor = function (color, auto) {
-            return color.resolve(auto, themeCollection.getTheme());
+        this.resolveColor = function (color, auto, target) {
+            return color.resolve(auto, themeCollection.getTheme('', target));
         };
 
         /**
@@ -623,11 +653,15 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
          * @param {Array<Color>} fillColors
          *  The source fill colors, from outermost to innermost level.
          *
+         * @param {String|Array<String>} [target]
+         *  An optional target string or an ordered collection of target strings
+         *  to specify the theme's target.
+         *
          * @returns {ColorDescriptor}
          *  A descriptor for the resulting color.
          */
-        this.resolveTextColor = function (textColor, fillColors) {
-            return textColor.resolveText(fillColors, themeCollection.getTheme());
+        this.resolveTextColor = function (textColor, fillColors, target) {
+            return textColor.resolveText(fillColors, themeCollection.getTheme('', target));
         };
 
         /**
@@ -642,12 +676,16 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
          *  Additional information needed to resolve the automatic color. See
          *  method Color.resolve() for details about this parameter.
          *
+         * @param {String|Array<String>} [target]
+         *  An optional target string or an ordered collection of target strings
+         *  to specify the theme's target.
+         *
          * @returns {String}
          *  The CSS color value converted from the passed color object.
          */
-        this.getCssColor = function (jsonColor, jsonAuto) {
+        this.getCssColor = function (jsonColor, jsonAuto, target) {
             var auto = _.isString(jsonAuto) ? jsonAuto : Color.parseJSON(jsonAuto);
-            return this.resolveColor(Color.parseJSON(jsonColor), auto).css;
+            return this.resolveColor(Color.parseJSON(jsonColor), auto, target).css;
         };
 
         /**
@@ -662,10 +700,14 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
          *  The JSON representation of the source fill colors, from outermost
          *  to innermost level, as used in document operations.
          *
+         * @param {String|Array<String>} [target]
+         *  An optional target string or an ordered collection of target strings
+         *  to specify the theme's target.
+         *
          * @returns {String}
          *  The CSS text color value converted from the passed color objects.
          */
-        this.getCssTextColor = function (jsonTextColor, jsonFillColors) {
+        this.getCssTextColor = function (jsonTextColor, jsonFillColors, target) {
 
             // the text color, as instance of the class Color
             var textColor = _.isObject(jsonTextColor) ? Color.parseJSON(jsonTextColor) : new Color('auto');
@@ -673,7 +715,7 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
             var fillColors = jsonFillColors.map(Color.parseJSON);
 
             // convert to CSS color string
-            return this.resolveTextColor(textColor, fillColors).css;
+            return this.resolveTextColor(textColor, fillColors, target).css;
         };
 
         /**
@@ -692,25 +734,59 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
          *  An optional color transformation to be inserted into the resulting
          *  JSON color.
          *
+         * @param {String|Array<String>} [target]
+         *  An optional target string or an ordered collection of target strings
+         *  to specify the theme's target.
+         *
          * @returns {Object}
          *  The resulting JSON color with the color transformation, and for ODF
          *  files with an additional property 'fallbackValue' containing the
          *  resulting RGB color value.
          */
-        this.createJSONColor = function (jsonColor, auto, transform) {
+        this.createJSONColor = function (jsonColor, auto, transform, target) {
 
             // create a Color instance from the passed JSON color, and color transformation
             var color = new Color(jsonColor.type, jsonColor.value, transform ? [transform] : null);
             jsonColor = color.toJSON();
 
             // add the fall-back RGB value for ODF
-            if (this.getApp().isODF()) { jsonColor.fallbackValue = this.resolveColor(color, auto).hex; }
+            if (this.getApp().isODF()) { jsonColor.fallbackValue = this.resolveColor(color, auto, target).hex; }
             return jsonColor;
         };
 
+        /**
+         *
+         * @param gradient
+         * @param target
+         * @returns {*}
+         */
+        this.getGradientValue = function (gradient, target) {
+            var
+                docModel      = self,
+                gradientValue = Gradient.parseCssColors(gradient, docModel, target);
+
+            return gradientValue;
+        };
+
+        /**
+         *
+         * @param gradient
+         * @param contextWrapper
+         * @param target
+         * @returns {*}
+         */
+        this.getGradientFill = function (gradient, pathCoords, contextWrapper, target) {
+            var
+                docModel     = self,
+                gradientFill = Gradient.parseFillStyle(docModel, gradient, contextWrapper.valueOf(), target, pathCoords);
+
+            return gradientFill;
+        };
+
         /**
          * Returns the effective CSS attributes for the passed border value.
-         * Scheme colors will be resolved by using the current theme.
+         * Scheme colors will be resolved by using the current theme of an
+         * optionally specified target.
          *
          * @param {Object} border
          *  The border object as used in operations.
@@ -725,6 +801,10 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
          *      If specified, a replacement color to be used in case the border
          *      object contains the automatic color.
          *
+         * @param {String|Array<String>} [target]
+         *  An optional target string or an ordered collection of target strings
+         *  to specify the theme's target.
+         *
          * @returns {Object}
          *  A map with CSS border attributes. Contains the property 'style'
          *  with the effective CSS border style as string; the property 'width'
@@ -732,14 +812,15 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
          *  entire pixels); and the property 'color' with the effective CSS
          *  color (as string with leading hash sign).
          */
-        this.getCssBorderAttributes = function (border, options) {
+        this.getCssBorderAttributes = function (border, options, target) {
             // use the static helper function from module Border, pass current theme
-            return Border.getCssBorderAttributes(border, themeCollection.getTheme(), options);
+            return Border.getCssBorderAttributes(border, themeCollection.getTheme('', target), options);
         };
 
         /**
          * Converts the passed border attribute object to a CSS border value.
-         * Scheme colors will be resolved by using the current theme.
+         * Scheme colors will be resolved by using the current theme of an
+         * optionally specified target.
          *
          * @param {Object} border
          *  The border object as used in operations.
@@ -757,12 +838,16 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
          *      If specified, a replacement color to be used in case the border
          *      object contains the automatic color.
          *
+         * @param {String|Array<String>} [target]
+         *  An optional target string or an ordered collection of target strings
+         *  to specify the theme's target.
+         *
          * @returns {String}
          *  The CSS border value converted from the passed border object.
          */
-        this.getCssBorder = function (border, options) {
+        this.getCssBorder = function (border, options, target) {
             // use the static helper function from module Border, pass current theme
-            return Border.getCssBorder(border, themeCollection.getTheme(), options);
+            return Border.getCssBorder(border, themeCollection.getTheme('', target), options);
         };
 
         /**
