@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -188,6 +189,9 @@ define('io.ox/office/editframework/model/stylecollection', [
         // layout handler, that handles including attributes from master and layout slides into merged attributes
         var layoutHandler = Utils.getFunctionOption(initOptions, 'layoutHandler');
 
+        // a (very small) format handler that is executed during loading the document
+        var immediateFormatHandler = Utils.getFunctionOption(initOptions, 'immediateFormatHandler');
+
         // preview handler, called after attributes of a GUI preview element have been changed
         var previewHandler = Utils.getFunctionOption(initOptions, 'previewHandler');
 
@@ -523,7 +527,7 @@ define('io.ox/office/editframework/model/stylecollection', [
             // get or create a style sheet object, set identifier and user-defined name of the style sheet
             var styleSheet = styleSheetMap[styleId] || (styleSheetMap[styleId] = {});
             styleSheet.id = styleId;
-            styleSheet.name = context.getOptStr('styleName', styleId);
+            styleSheet.name = context.getOptStr('styleName', styleId, true); // Empty string is allowed
 
             // set parent of the style sheet, check for cyclic references
             styleSheet.parentId = context.getOptStr('parent');
@@ -1349,6 +1353,8 @@ define('io.ox/office/editframework/model/stylecollection', [
                     // merge explicit attributes into style attributes, and update element formatting
                     docModel.extendAttributes(mergedAttributes, resolveElementAttributeSet(element), options);
                     updateElementFormatting($(element), mergedAttributes, { preview: preview });
+                } else if (!self.isImportFinished() && _.isFunction(immediateFormatHandler)) {
+                    immediateFormatHandler.call(self, $(element), newElementAttributes);
                 }
 
                 // call the passed change listener
@@ -1395,6 +1401,10 @@ define('io.ox/office/editframework/model/stylecollection', [
          *      the passed element, merged from style sheet and explicit
          *      attributes, keyed by attribute family. Used internally while
          *      updating the formatting of all child elements of a node.
+         *  @param {Object} [options.mergedAttributes=null]
+         *      A map of attribute maps (name/value pairs), keyed by attribute
+         *      family, containing the effective attribute values merged from style
+         *      sheets and explicit attributes.
          *  @param {Boolean} [options.preview=false]
          *      If set to true, a GUI element used to preview the formatting of
          *      a style sheet will be rendered. Executes the 'preview' callback
@@ -1419,24 +1429,25 @@ define('io.ox/office/editframework/model/stylecollection', [
                 styleId = AttributeUtils.getElementStyleId(element),
                 // precalculated base attributes passed to this method
                 baseAttributes = Utils.getObjectOption(options, 'baseAttributes'),
-                // the merged attributes of the passed element
-                mergedAttributes = null;
+                // precalculated merged attributes passed to this method, or 'null' if not specified
+                mergedAttributes = Utils.getObjectOption(options, 'mergedAttributes', null);
 
-            if (_.isObject(baseAttributes)) {
-                mergedAttributes = docModel.getDefaultAttributeSet(supportedFamilySet); // all families required
-                docModel.extendAttributes(mergedAttributes, baseAttributes);
-            } else {
-                mergedAttributes = resolveBaseAttributes(element);
+            if (!mergedAttributes) {
+                if (_.isObject(baseAttributes)) {
+                    mergedAttributes = docModel.getDefaultAttributeSet(supportedFamilySet); // all families required
+                    docModel.extendAttributes(mergedAttributes, baseAttributes);
+                } else {
+                    mergedAttributes = resolveBaseAttributes(element);
+                }
+
+                // call the passed layout listener to add attributes from layout/master slide
+                // -> this needs to be done, before explicit attributes
+                if (_.isFunction(layoutHandler)) { layoutHandler.call(self, $(element), mergedAttributes); }
+
+                // add attributes of the style sheet and its parents, and the explicit attributes of the element
+                docModel.extendAttributes(mergedAttributes, resolveStyleAttributeSet(styleId, element));
+                docModel.extendAttributes(mergedAttributes, resolveElementAttributeSet(element), { special: true });
             }
-
-            // call the passed layout listener to add attributes from layout/master slide
-            // -> this needs to be done, before explicit attributes
-            if (_.isFunction(layoutHandler)) { layoutHandler.call(self, $(element), mergedAttributes); }
-
-            // add attributes of the style sheet and its parents, and the explicit attributes of the element
-            docModel.extendAttributes(mergedAttributes, resolveStyleAttributeSet(styleId, element));
-            docModel.extendAttributes(mergedAttributes, resolveElementAttributeSet(element), { special: true });
-
             // update the formatting of the element
             return updateElementFormatting($(element), mergedAttributes, options);
         };
