@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Malte Timmermann <malte.timmermann@open-xchange.com>
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
@@ -358,21 +359,6 @@ define('io.ox/office/editframework/model/undomanager', [
             return this;
         };
 
-        /**
-         * Clears all undo actions in the stack that are above the current
-         * pointer position. This disables the redo stack.
-         *
-         * @returns {UndoManager}
-         *  A reference to this instance.
-         */
-        this.disableRedo = function () {
-
-            if (currentAction < actions.length) {
-                actions.splice(currentAction);
-            }
-            return this;
-        };
-
         /**
          * Opens an undo action group and executes the specified callback
          * function. All undo operations added by the callback function will be
