@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -232,23 +233,28 @@ define('io.ox/office/editframework/utils/border', [
     };
 
     /**
-     * Comparing two borders. These are equal if both borders have the same style, width and color
+     * Returns whether the passed borders are equal.
      *
      * @param {Border|Null} border1
-     * The first border to compare
+     * The first border to compare. A falsy value (null or undefined) will be
+     * considered to be equal to an invisible border.
      *
      * @param {Border|Null} border2
-     * The second border to compare
+     * The second border to compare. A falsy value (null or undefined) will be
+     * considered to be equal to an invisible border.
      *
      * @returns {Boolean}
-     * Whether the two borders are equal.
+     *  Whether the two borders are equal.
      */
     Border.isEqual = function (border1, border2) {
-        return (border1 &&
-                border2 &&
-                ((!('style' in border1) && (!('style' in border2))) || (('style' in border1) && ('style' in border2) && (border1.style === border2.style))) &&
-                ((!('width' in border1) && (!('width' in border2))) || (('width' in border1) && ('width' in border2) && (border1.width === border2.width))) &&
-                ((!('color' in border1) && (!('color' in border2))) || (('color' in border1) && ('color' in border2) && (Color.isEqual(border1.color, border2.color)))));
+        var visible1 = Border.isVisibleBorder(border1);
+        var visible2 = Border.isVisibleBorder(border2);
+        return (!visible1 && !visible2) || (
+            visible1 && visible2 &&
+            ((!('style' in border1) && (!('style' in border2))) || (('style' in border1) && ('style' in border2) && (border1.style === border2.style))) &&
+            ((!('width' in border1) && (!('width' in border2))) || (('width' in border1) && ('width' in border2) && (border1.width === border2.width))) &&
+            ((!('color' in border1) && (!('color' in border2))) || (('color' in border1) && ('color' in border2) && (Color.isEqual(border1.color, border2.color))))
+        );
     };
 
     /**
