@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -14,73 +15,93 @@
 define('io.ox/office/editframework/utils/editconfig', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/io',
-    'io.ox/office/tk/config'
-], function (Utils, IO, Config) {
+    'io.ox/office/baseframework/utils/baseconfig'
+], function (Utils, IO, BaseConfig) {
 
     'use strict';
 
     // static class EditConfig ================================================
 
-    var EditConfig = _.clone(Config);
+    /**
+     * Additional static configuration settings for edit applications.
+     *
+     * @extends BaseConfig
+     */
+    var EditConfig = _.clone(BaseConfig);
+
+    // constants --------------------------------------------------------------
 
     /**
-     * A Boolean flag specifying whether the local browser storage will be used
-     * for saving documents.
+     * Specifies whether the local browser storage will be used for saving
+     * documents.
      *
      * @constant
+     *
+     * @type {Boolean}
      */
     EditConfig.USE_LOCAL_STORAGE = EditConfig.getFlag('useLocalStorage', true);
 
     /**
-     * A Boolean flag specifying whether the current selection of remote users
-     * will be displayed in all OX Documents edit applications.
+     * Specifies whether the current selection of remote users will be
+     * displayed in all OX Documents edit applications.
      *
      * @constant
+     *
+     * @type {Boolean}
      */
     EditConfig.SHOW_REMOTE_SELECTIONS = EditConfig.getFlag('showRemoteSelections', true);
 
     /**
-     * A Boolean flag specifying whether detailed performance data will be sent
-     * to and logged at the server.
+     * Specifies whether detailed performance data will be sent to and logged
+     * at the server.
      *
      * @constant
+     *
+     * @type {Boolean}
      */
     EditConfig.LOG_PERFORMANCE_DATA = EditConfig.getFlag('logPerformanceData', false);
 
     /**
-     * A Boolean flag specifying whether the error and other important data
-     * for bug hunting will be sent to and logged by the server.
+     * Specifies whether the error and other important data for bug hunting
+     * will be sent to and logged by the server.
      *
      * @constant
+     *
+     * @type {Boolean}
      */
     EditConfig.LOG_ERROR_DATA = EditConfig.getFlag('logErrorData', false);
 
     /**
-     * A Boolean flag specifying whether the Document Name edit field should enabled or
-     * disabled. This ensures that in environments, which don't support transparent
-     * changes of the file name, don't break an active RT connection.
+     * Specifies whether the "document name" edit field should be enabled. This
+     * ensures that environments which don't support transparent changes of the
+     * file name don't break an active RT connection.
      *
      * @constant
+     *
+     * @type {Boolean}
      */
     EditConfig.RENAME_DISABLED = EditConfig.getFlag('renamedisabled', false);
 
     /**
-     * A Boolean flag specifying whether the Application should support to restore
-     * a document or not.
+     * Specifies whether the application should support to restore a document.
      *
      * @constant
+     *
+     * @type {Boolean}
      */
     EditConfig.ENABLED_RESTORE_DOCUMENT = EditConfig.getFlag('documentRestoreEnabled', true);
 
     /**
-     * A Boolean flag specifying whether the Application should load rescue documents
-     * in read-only mode or not.
+     * Specifies whether the application should load rescue documents in
+     * read-only mode.
      *
      * @constant
+     *
+     * @type {Boolean}
      */
     EditConfig.RESCUE_DOCUMENT_READONLY = EditConfig.getFlag('rescueDocumentReadOnly', true);
 
-    // static methods =========================================================
+    // static methods ---------------------------------------------------------
 
     /**
      * Retrieves the locale identifiers with a dictionary available for spell
