@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -66,7 +67,7 @@ define('io.ox/office/editframework/view/control/applicationstatuslabel', [
 
             // if the application state is a temporary 'busy' state, defer showing the caption
             if (delay > 0) {
-                timer = self.executeDelayed(function () { self.setCaption(caption); }, delay);
+                timer = self.executeDelayed(function () { self.setCaption(caption); }, { delay: delay, infoString: 'ApplicationStatusLabel: updateCaption', app: docView.getApp() });
                 timer.always(function () { timer = null; });
             } else {
                 self.setCaption(caption);
