@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -42,7 +43,9 @@ define('io.ox/office/editframework/view/control/fontfamilypicker', [
             self = this,
 
             // the collection of fonts of the edited document
-            fontCollection = docView.getDocModel().getFontCollection();
+            fontCollection = docView.getDocModel().getFontCollection(),
+
+            app = docView.getApp();
 
         // base constructors --------------------------------------------------
 
@@ -52,7 +55,7 @@ define('io.ox/office/editframework/view/control/fontfamilypicker', [
             typeAhead: true
         }, initOptions));
 
-        AppObjectMixin.call(this, docView.getApp());
+        AppObjectMixin.call(this, app);
 
         // public methods -----------------------------------------------------
 
@@ -74,7 +77,7 @@ define('io.ox/office/editframework/view/control/fontfamilypicker', [
                     labelStyle: { fontFamily: fontCollection.getCssFontFamily(fontName), fontSize: '115%' }
                 });
             });
-        });
+        }, { infoString: 'FontFamilyPicker: fillList', app: app });
 
         // initialization -----------------------------------------------------
 
