@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -95,6 +96,9 @@ define('io.ox/office/editframework/view/control/tablesizepicker', [
         // current position of mouse pointer (page coordinates)
         var mousePos = null;
 
+        // handling an 'Enter', if the table size picker was prepared with mouse movements
+        var isSimulatedClick = false;
+
         // base constructors --------------------------------------------------
 
         Group.call(this, Utils.extendOptions({
@@ -140,6 +144,10 @@ define('io.ox/office/editframework/view/control/tablesizepicker', [
                 case KeyCodes.DOWN_ARROW:
                     gridSize.height += (growTop ? -1 : 1);
                     break;
+                case KeyCodes.ENTER:
+                    isSimulatedClick = true;
+                    gridButtonNode.click(); // pressing 'Enter' after opening table size picker with mouse
+                    break;
                 default:
                     return;
             }
@@ -314,7 +322,7 @@ define('io.ox/office/editframework/view/control/tablesizepicker', [
         gridButtonNode.on('click', function (event) {
             // bug 31170: restrict to 'click' events that originate from keyboard shortcuts
             // (prevent double trigger from 'tracking:end' and 'click')
-            if (_.isNumber(event.keyCode)) {
+            if (_.isNumber(event.keyCode) || isSimulatedClick) {
                 self.triggerChange(gridSize, { sourceEvent: event });
             }
         });
