@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -74,6 +75,13 @@ define('io.ox/office/editframework/view/editcontrols', [
      * @constructor
      *
      * @extends ColorPicker
+     *
+     * @param {EditView} docView
+     *  The document view that contains this color picker.
+     *
+     * @param {Object} [initOptions]
+     *  Optional parameters. Supports all options of the ColorPicker base
+     *  class.
      */
     EditControls.TextColorPicker = ColorPicker.extend({ constructor: function (docView, initOptions) {
 
@@ -95,6 +103,13 @@ define('io.ox/office/editframework/view/editcontrols', [
      * @constructor
      *
      * @extends ColorPicker
+     *
+     * @param {EditView} docView
+     *  The document view that contains this color picker.
+     *
+     * @param {Object} [initOptions]
+     *  Optional parameters. Supports all options of the ColorPicker base
+     *  class.
      */
     EditControls.FillColorPicker = ColorPicker.extend({ constructor: function (docView, initOptions) {
 
@@ -116,16 +131,11 @@ define('io.ox/office/editframework/view/editcontrols', [
      * @extends ColorPicker
      *
      * @param {Object} [initOptions]
-     *  Optional parameters. Supports all options of the RadioList base class,
-     *  and the following options:
-     *  @param {Boolean} [initOptions.showAutoColor=false]
-     *      Whether to show a button for the automatic color on top of the
-     *      droop-down menu. Will be shown as 'Black' by default, but can be
-     *      changed with the method ColorPicker.setAutoColor().
+     *  Optional parameters. Supports all options of the RadioList base class
      */
     EditControls.BorderColorPicker = ColorPicker.extend({ constructor: function (docView, initOptions) {
 
-        ColorPicker.call(this, docView, Utils.getBooleanOption(initOptions, 'showAutoColor', false) ? 'line' : null, Utils.extendOptions({
+        ColorPicker.call(this, docView, null, Utils.extendOptions({
             icon: 'docs-drawing-line-color',
             tooltip: gt.pgettext('borders', 'Border color'),
             title: gt.pgettext('borders', 'Border color')
