@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -419,7 +420,7 @@ define('io.ox/office/editframework/view/edittoolpane', [
 
             // reset status (actually not in layout-progess)
             reLayout = false;
-        }, { delay: 500, infoString: 'EditToolPane: paneLayoutHandler' });
+        }, { delay: 500, infoString: 'EditToolPane: paneLayoutHandler', app: docView.getApp() });
 
         /**
          *  Checks the height of the window-node and (de-)activates the flat-pane
