@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -28,28 +29,19 @@ define('io.ox/office/editframework/view/editview', [
     'io.ox/office/editframework/view/editdialogs',
     'io.ox/office/editframework/view/mobilesearchgroup',
     'io.ox/office/editframework/view/popup/userslayermenu',
+    'io.ox/office/tk/utils/deferredutils',
     'gettext!io.ox/office/editframework/main',
     'less!io.ox/office/editframework/view/editstyle'
-], function (Utils, ExtensionRegistry, BaseView, BaseLabels, Config, ToolBarTabCollection, TopPane, EditToolPane, SearchPane, OperationsPane, ClipboardPane, Labels, Controls, Dialogs, MobileSearchGroup, UsersLayerMenu, gt) {
+], function (Utils, ExtensionRegistry, BaseView, BaseLabels, Config, ToolBarTabCollection, TopPane, EditToolPane, SearchPane, OperationsPane, ClipboardPane, Labels, Controls, Dialogs, MobileSearchGroup, UsersLayerMenu, DeferredUtils, gt) {
 
     'use strict';
 
-    var // default search configuration
-        DEFAULT_SEARCH_SETTINGS = {
-            // current search query
-            query: '',
-            // whether 'query' is a regular expression
-            regexp: false,
-            // the replacement string
-            replace: ''
-        },
+    // beneath this minimum screen width or height, the tool/tab bars should be combined
+    // Nexus 7 = min resolution 601
+    var PANES_COMBINED_MIN_SIZE = 610;
 
-        // beneath this minimum screen width or height, the tool/tab bars should be combined
-        // Nexus 7 = min resolution 601
-        PANES_COMBINED_MIN_SIZE = 610,
-
-        // combined panes mode via URL flag in debug mode
-        DEBUG_PANES_COMBINED = Config.getDebugUrlFlag('office:panes-combined');
+    // combined panes mode via URL flag in debug mode
+    var DEBUG_PANES_COMBINED = Config.getDebugUrlFlag('office:panes-combined');
 
     // class EditView =========================================================
 
@@ -66,25 +58,6 @@ define('io.ox/office/editframework/view/editview', [
      * @param {EditModel} docModel
      *  The document model created by the passed application.
      *
-     * @param {Function} searchHandler
-     *  A callback function that will implement searching for a specific query
-     *  string entered in the search/replace tool bar. Receives the following
-     *  parameters:
-     *  (1) {String} command
-     *      The search command to be executed. See description of the method
-     *      EditView.executeSearchOperation() for details.
-     *  (2) {Object} settings
-     *      The current search settings. See the description of the method
-     *      EditView.getSearchSettings() for details about the properties
-     *      contained in this object.
-     *  The function may return a promise, if the search action involves
-     *  asynchronous operations. The view will be locked until the promise has
-     *  been resolved or rejected. The promise may be rejected with an error
-     *  code string which may result in an alert message box shown in the user
-     *  interface. Alternatively, the function may return an explicit error
-     *  code string synchronously (without using a promise). The function will
-     *  be called in the context of this view instance.
-     *
      * @param {Object} [initOptions]
      *  Optional parameters. Supports all options that are supported by the
      *  constructor of the base class BaseView, with the following additions
@@ -128,7 +101,7 @@ define('io.ox/office/editframework/view/editview', [
      *      containing a page settings button to show a page settings dialog
      *      for the current document.
      */
-    function EditView(app, docModel, searchHandler, initOptions) {
+    function EditView(app, docModel, initOptions) {
 
         var // self reference
             self = this,
@@ -145,17 +118,28 @@ define('io.ox/office/editframework/view/editview', [
             // the search/replace pane below the tool pane
             searchGroup = null,
 
-            // the current search configuration
-            searchSettings = _.clone(DEFAULT_SEARCH_SETTINGS),
-
             // collaborator list
             collaboratorPopup = null,
 
+            // normal file buttons, but we need handle if some app wants to add more
+            commonToolbar = null,
+
+            // print button
+            printToolbar = null,
+
+            // shareToolbar for link sharing and user inviting
+            shareToolbar = null,
+
+            // no filled by this class, but can be filled by addToFileToolbar() & addSeparatorToFileToolbar()
+            extraToolbar = null,
+
             // show combined Panes
             panesCombined = false,
 
             userLayerShowOwnColor = Utils.getBooleanOption(initOptions, 'userLayerShowOwnColor', false);
 
+        var mailToolbar = null;
+
         // base constructor ---------------------------------------------------
 
         BaseView.call(this, app, docModel, Utils.extendOptions(initOptions, {
@@ -186,7 +170,7 @@ define('io.ox/office/editframework/view/editview', [
             self.listenTo(docModel, 'change:editmode', function () { self.disableBrowserEditControls(); });
 
             // create the tool bars (initialize themselves internally)
-            self.addPane(topPane = new TopPane(self, toolBarTabs));
+            self.addPane(topPane = new TopPane(self, toolBarTabs, { enablePresenter: Utils.getBooleanOption(initOptions, 'enablePresenter', false) }));
             self.addPane(toolPane = new EditToolPane(self, toolBarTabs, { landmark: false }));
 
             if (panesCombined) {
@@ -240,7 +224,7 @@ define('io.ox/office/editframework/view/editview', [
                         get: function () { return clipboardPane.isVisible(); },
                         set: function (state) { clipboardPane.toggle(state); }
                     },
-                    'debug/highlight': {
+                    'debug/highlight/dom': {
                         parent: 'debug/enabled',
                         get: function () { return app.getWindowNode().hasClass('debug-highlight'); },
                         set: function (state) { app.getWindowNode().toggleClass('debug-highlight', state); }
@@ -265,7 +249,7 @@ define('io.ox/office/editframework/view/editview', [
                     },
                     'debug/view/busy': {
                         parent: 'debug/enabled',
-                        set: function (cancelable) { return cancelable ? self.createAbortablePromise($.Deferred()) : $.Deferred(); },
+                        set: function (cancelable) { return cancelable ? self.createAbortablePromise(DeferredUtils.createDeferred(app, 'EditView: debug/view/busy cancelable')) : DeferredUtils.createDeferred(app, 'EditView: debug/view/busy !cancelable'); },
                         cancel: true
                     },
                     'debug/quit': {
@@ -275,12 +259,15 @@ define('io.ox/office/editframework/view/editview', [
                 });
             }
 
-            // call initialization handler passed by sub class
-            var result = Utils.getFunctionOption(initOptions, 'initHandler', $.noop).call(self);
+            // call initialization handler passed from sub class constructor
+            var result = Utils.getFunctionOption(initOptions, 'initHandler', _.noop).call(self);
 
-            // call debug initialization handler passed by sub class
+            // call debug initialization handler passed from sub class constructor
             if (Config.DEBUG) {
-                result = $.when(result).then(_.bind(Utils.getFunctionOption(initOptions, 'initDebugHandler', $.noop), self, operationsPane, clipboardPane));
+                result = $.when(result).then(function () {
+                    var initDebugHandler = Utils.getFunctionOption(initOptions, 'initDebugHandler', _.noop);
+                    return initDebugHandler.call(self, operationsPane, clipboardPane);
+                });
             }
 
             return result;
@@ -298,7 +285,6 @@ define('io.ox/office/editframework/view/editview', [
                 renameToolbar = null,
                 saveToolbar   = null,
                 pageToolbar   = null,
-                commonToolbar = null,
                 actionToolbar = null,
 
                 btnDownload        = new Controls.Button({ icon: Labels.DOWNLOAD_ICON, tooltip: gt('Download'), classes: 'link-style', dropDownVersion: { label: gt('Download') } }),
@@ -307,13 +293,8 @@ define('io.ox/office/editframework/view/editview', [
                 btnSendMail        = null,
                 btnSendMailKey     = 'document/sendmail',
 
-              // no configuration at all, automatically always defaults to the file-attachment build-in.
-              //sendMailAttachmentConfig    = { attachMode: 'attachment' },
-                sendMailPDFAttachmentConfig = { attachMode: 'pdf-attachment' },
-                sendMailInlineHTMLConfig    = { attachMode: 'inline-html' },
-
-                canConvertToPDFAttachment   = app.canConvertTo('pdf-mail-attachment'),
-                canConvertToInlineHTML      = app.canConvertTo('inline-html-document'),
+                canConvertToPDFAttachment = app.canConvertTo('pdf-attachment'),
+                canConvertToInlineHTML    = app.canConvertTo('inline-html'),
 
                 btnReload          = new Controls.Button({ icon: 'fa-repeat', label: gt('Reload'), tooltip: gt('Reload document'), classes: 'link-style' }),
                 btnAcquireEdit     = new Controls.AcquireEditButton(self, { classes: 'link-style' }),
@@ -338,12 +319,10 @@ define('io.ox/office/editframework/view/editview', [
                 .addGroup('document/sendmail', new Controls.Button({ label: BaseLabels.ATTACH_AS_FILE_TO_MAIL_LABEL }));
 
                 if (canConvertToPDFAttachment) {
-                    btnSendMail
-                        .addGroup('document/sendmail/pdf-attachment', new Controls.Button({ value: sendMailPDFAttachmentConfig, label: BaseLabels.ATTACH_AS_PDF_TO_MAIL_LABEL }));
+                    btnSendMail.addGroup('document/sendmail/pdf-attachment', new Controls.Button({ value: { attachMode: 'pdf-attachment' }, label: BaseLabels.ATTACH_AS_PDF_TO_MAIL_LABEL }));
                 }
                 if (canConvertToInlineHTML) {
-                    btnSendMail
-                        .addGroup('document/sendmail/inline-html', new Controls.Button({ value: sendMailInlineHTMLConfig, label: BaseLabels.SEND_CONTENT_AS_NEW_MAIL_LABEL }));
+                    btnSendMail.addGroup('document/sendmail/inline-html',    new Controls.Button({ value: { attachMode: 'inline-html' },    label: BaseLabels.SEND_CONTENT_AS_NEW_MAIL_LABEL }));
                 }
 
                 btnSendMailKey = 'document/sendmail/menu';
@@ -379,8 +358,12 @@ define('io.ox/office/editframework/view/editview', [
                 pageToolbar = self.createToolBar('file', { priority: 3, label: gt('Page'), classes: 'link-style', prepareShrink: true });
             }
 
-            commonToolbar       = self.createToolBar('file', { priority: 3, label: gt('Actions'), classes: 'link-style', prepareShrink: true });
-            actionToolbar       = self.createToolBar('file', { priority: 1, tooltip: gt('actions'), classes: 'link-style' });
+            commonToolbar = self.createToolBar('file', { priority: 3, label: gt('Actions'), classes: 'link-style', prepareShrink: true });
+            printToolbar  = self.createToolBar('file', { priority: 3, label: gt('Actions'), classes: 'link-style', prepareShrink: true, visibleKey: 'document/print' });
+            mailToolbar   = self.createToolBar('file', { priority: 3, label: BaseLabels.SEND_AS_MAIL_LABEL, classes: 'link-style noSeparator', visibleKey: btnSendMailKey });
+            shareToolbar  = self.createToolBar('file', { priority: 3, label: gt('Share'), classes: 'link-style', visibleKey: 'document/share' });
+            extraToolbar  = self.createToolBar('file', { priority: 3, tooltip: gt('Actions'), classes: 'link-style' });
+            actionToolbar = self.createToolBar('file', { priority: 1, tooltip: gt('Actions'), classes: 'link-style' });
 
             // -----------------------------------------------------
             // CONTROLS
@@ -422,26 +405,26 @@ define('io.ox/office/editframework/view/editview', [
                 if (enablePageSettings) {
                     pageToolbar.addGroup('document/pagesettings', new Controls.Button({
                         icon: 'docs-page-layout',
-                        tooltip: gt('Page settings'),
+                        tooltip: docModel.useSlideMode() ? gt('Slide settings') : gt('Page settings'),
                         classes: 'link-style',
                         dropDownVersion: { label: gt('Page settings') }
                     }));
                 }
             }
 
-            commonToolbar
-                .addGroup('document/download', btnDownload)
-                .addGap()
-                .addGroup('document/print', btnPrint)
-                .addGap()
-                // provide different appearance of "send mail" button(s) in dependency of an application's ([app]'s) send mail operations/methods.
-                .addGroup(btnSendMailKey, btnSendMail)
-                .addGroup('document/share', btnShare);
+            commonToolbar.addGroup('document/download', btnDownload);
+
+            printToolbar.addGroup('document/print', btnPrint);
+
+            // provide different appearance of "send mail" button(s) in dependency of an application's ([app]'s) send mail operations/methods.
+            mailToolbar.addGroup(btnSendMailKey, btnSendMail);
 
             actionToolbar
                 .addGroup('document/acquireeditOrPending', btnAcquireEdit, { visibleKey: 'document/acquireedit' })
                 .addGroup('document/reload', btnReload, { visibleKey: 'document/reload' });
 
+            shareToolbar.addGroup('document/share', btnShare);
+
             // call initialization handler passed by sub class
             var result = Utils.getFunctionOption(initOptions, 'initGuiHandler', $.noop).call(self, topPane.getViewMenuGroup());
 
@@ -470,7 +453,7 @@ define('io.ox/office/editframework/view/editview', [
                 .addGroup('debug/operationspane', new Controls.CheckBox({ label: _.noI18n('Show operations panel') }))
                 .addGroup('debug/clipboardpane',  new Controls.CheckBox({ label: _.noI18n('Show clipboard panel') }))
                 .addGroup('debug/console',        new Controls.CheckBox({ label: _.noI18n('Show overlay log console') }))
-                .addGroup('debug/highlight',      new Controls.CheckBox({ label: _.noI18n('Highlight DOM elements') }));
+                .addGroup('debug/highlight/dom',  new Controls.CheckBox({ label: _.noI18n('Highlight DOM elements') }));
 
             // create the drop-down list for the debug actions
             actionMenuGroup = new Controls.CompoundButton(self, { icon: 'fa-wrench', label: Labels.ACTIONS_LABEL, tooltip: _.noI18n('Additional debug actions'), classes: 'link-style' })
@@ -673,7 +656,7 @@ define('io.ox/office/editframework/view/editview', [
                     window.document.execCommand('enableInlineTableEditing', false, false);
                 } catch (ex) {
                 }
-            }, undefined, 'EditFramework: disableBrowserEditControls');
+            }, { infoString: 'EditFramework: disableBrowserEditControls', app: app });
             return this;
         };
 
@@ -823,9 +806,7 @@ define('io.ox/office/editframework/view/editview', [
 
                 newFileName = oldFileName;
 
-                // use original extension as fallback - possible if a template
-                // document should be stored via save as as template.
-                templateExt = ExtensionRegistry.getTemplateExtensionForFileName(app.getFullFileName()) || app.getFileExtension();
+                templateExt = ExtensionRegistry.getTemplateExtension(app.getFullFileName());
 
                 //#. %1$s is the file extension used for the template file
                 //#, c-format
@@ -838,17 +819,11 @@ define('io.ox/office/editframework/view/editview', [
                 });
             } else if (type === 'pdf') {  // DOCS-122 :: misinterpreted story - [https://jira.open-xchange.com/browse/DOCS-122] :: but hereby saved for good.
 
-            //  newFileName = oldFileName + '.pdf';
-                newFileName = oldFileName;
-                var
-                    len     = newFileName.length,
-                    idx     = newFileName.lastIndexOf('.');
-
-                newFileName = newFileName.substring(0, ((idx >= 0) ? idx : len)) + '.pdf';
+                newFileName = Utils.getFileBaseName(oldFileName);
                 title = gt('Export as PDF');
 
                 // create the dialog
-                dialog = new Dialogs.SaveAsFileDialog({ title: title, value: newFileName, preselect: app.getFileParameters().folder_id, exportAsPdf: true });
+                dialog = new Dialogs.SaveAsFileDialog({ title: title, value: newFileName, preselect: app.getFileParameters().folder_id });
 
             } else {
 
@@ -975,103 +950,12 @@ define('io.ox/office/editframework/view/editview', [
             return docModel.getUndoManager().redo();
         };
 
-        // search/replace -----------------------------------------------------
-
-        /**
-         * Returns the current search settings, as currently configured in the
-         * search pane.
-         *
-         * @returns {Object}
-         *  The current search settings, with the following properties:
-         *  - {String} query
-         *      The search query string.
-         *  - {Boolean} regexp
-         *      Whether the query string shall be interpreted as regular
-         *      expression, instead of literal search string.
-         */
-        this.getSearchSettings = function () {
-            return _.clone(searchSettings);
+        this.addToCommonToolbar = function (key, group, options) {
+            extraToolbar.addGroup(key, group, options);
         };
 
-        /**
-         * Changes a property in the search configuration, and initiates a new
-         * search session with the current settings by invoking the search
-         * handler passed to the constructor.
-         *
-         * @param {String} name
-         *  The name of the property to be changed in the search configuration.
-         *  MUST be the name of a supported search configuration property.
-         *
-         * @param {Any} value
-         *  The new value for the configuration property.
-         *
-         * @returns {jQuery.Promise}
-         *  The promise of a Deferred object that will be resolved when
-         *  searching with the new configuration has finished, or rejected with
-         *  an error code that may lead to an alert message box.
-         */
-        this.changeSearchSettings = function (newSettings) {
-            _.extend(searchSettings, newSettings);
-            return this;
-        };
-
-        /**
-         * Invokes the search/replace handler passed to the constructor of this
-         * instance.
-         *
-         * @param {String} command
-         *  The search/replace command to be executed. Will be one of the
-         *  following commands:
-         *  - 'search:start'
-         *      Start a new search/replace session. Will be sent after entering
-         *      some text in the query input field, or changing any search
-         *      options which influence the matching document contents.
-         *  - 'search:prev'
-         *      Search for the previous occurrence of the current query string.
-         *  - 'search:next'
-         *      Search for the next occurrence of the current query string.
-         *  - 'search:end'
-         *      Finish the current search/replace session, remove all feedback
-         *      for search/replace in the user interface. Will be sent after
-         *      closing the search pane.
-         *  - 'replace:next'
-         *      Replace the next occurrence of the current query string with
-         *      the replacement text.
-         *  - 'replace:all'
-         *      Replace all occurrences of the current query string with the
-         *      replacement text.
-         *
-         * @param {Object} [newSettings]
-         *  New properties for the search configuration object. Will be
-         *  inserted into the configuration before invoking the serahc handler.
-         *
-         * @returns {jQuery.Promise}
-         *  The promise of a Deferred object that will be resolved when the
-         *  search handler has finished the specified operation, or that will
-         *  be rejected on any error.
-         */
-        this.executeSearchOperation = function (command, newSettings) {
-
-            var // the original result of the search handler
-                result = null,
-                // the promise returned by this method
-                promise = null;
-
-            // change the specified configuration properties
-            if (_.isObject(newSettings)) { this.changeSearchSettings(newSettings); }
-
-            // invoke the search handler
-            result = searchHandler.call(this, command, _.clone(searchSettings));
-
-            // convert error code (non-empty strings) to rejected promise
-            promise = (_.isString(result) && result) ? $.Deferred().reject(result) : $.when(result);
-
-            // TODO: show alert messages for generic errors
-            promise.fail(function (result) {
-                Utils.error('executeSearchOperation failed', result);
-            });
-
-            return promise;
+        this.addSeparatorToCommonToolbar = function () {
+            // do nothing
         };
 
         // initialization -----------------------------------------------------
@@ -1084,7 +968,7 @@ define('io.ox/office/editframework/view/editview', [
         this.registerDestructor(function () {
             toolBarTabs.destroy();
             collaboratorPopup.destroy();
-            app = searchHandler = initOptions = self = docModel = null;
+            app = initOptions = self = docModel = null;
             toolBarTabs = topPane = toolPane = searchGroup = null;
             collaboratorPopup = null;
         });
