@@ -6,25 +6,27 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  */
 
 define('io.ox/office/editframework/view/mobilesearchgroup', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/forms',
     'io.ox/office/tk/object/triggerobject',
     'io.ox/office/tk/object/timermixin',
     'io.ox/office/baseframework/view/toolpane',
     'io.ox/office/baseframework/view/toolbar',
     'io.ox/office/baseframework/view/basecontrols',
     'io.ox/office/editframework/view/editlabels'
-], function (Utils, Forms, TriggerObject, TimerMixin, ToolPane, ToolBar, Controls, Labels) {
+], function (Utils, TriggerObject, TimerMixin, ToolPane, ToolBar, Controls, Labels) {
 
     'use strict';
 
-    function MobileSearchGroup(docView) {
+    // class MobileSearchGroup ================================================
+
+    var MobileSearchGroup = TriggerObject.extend({ constructor: function (docView) {
 
         var searchBar = docView.createToolBar('view/searchgroup');
         var searchReplaceBar = docView.createToolBar('view/replacegroup');
@@ -35,7 +37,7 @@ define('io.ox/office/editframework/view/mobilesearchgroup', [
         var searchBtn = null;
         var searchReplaceBtn = null;
 
-        // base constructor ---------------------------------------------------
+        // base constructors --------------------------------------------------
 
         TriggerObject.call(this);
         TimerMixin.call(this);
@@ -59,12 +61,12 @@ define('io.ox/office/editframework/view/mobilesearchgroup', [
             searchReplaceBtn.show();
         }
 
-        var delayClose = this.createDebouncedMethod(Utils.NOOP, function () {
+        var delayClose = this.createDebouncedMethod(_.noop, function () {
             if (!searchBar.isVisible() && !searchReplaceBar.isVisible()) {
-                docView.executeSearchOperation('search:end', { query: '', replace: '' });
+                docView.executeControllerItem('document/search/end');
                 showSearch();
             }
-        });
+        }, { infoString: 'MobileSearchGroup: delayClose', app: docView.getApp() });
 
         // public methods ---------------------------------------------------
 
@@ -145,9 +147,11 @@ define('io.ox/office/editframework/view/mobilesearchgroup', [
             replacePane = replaceBar = replaceSplit = null;
             searchBtn = searchReplaceBtn = null;
         });
-    }
+
+    } }); // class MobileSearchGroup
 
     // exports ================================================================
-    return TriggerObject.extend({ constructor: MobileSearchGroup });
+
+    return MobileSearchGroup;
 
 });
