@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -16,9 +17,10 @@ define('io.ox/office/editframework/view/operationspane', [
     'io.ox/office/tk/forms',
     'io.ox/office/tk/keycodes',
     'io.ox/office/baseframework/view/pane',
+    'io.ox/office/editframework/utils/operationutils',
     'io.ox/office/editframework/app/rtconnection',
     'io.ox/office/editframework/view/popup/attributestooltip'
-], function (Utils, Forms, KeyCodes, Pane, RTConnection, AttributesToolTip) {
+], function (Utils, Forms, KeyCodes, Pane, OperationUtils, RTConnection, AttributesToolTip) {
 
     'use strict';
 
@@ -122,15 +124,15 @@ define('io.ox/office/editframework/view/operationspane', [
 
                 var operation = _.clone(entry.operation);
                 var name = operation.name || '';
-                var osn = ('osn' in operation) ? operation.osn : '';
-                var opl = ('opl' in operation) ? operation.opl : '';
+                var osn = OperationUtils.getOSN(operation);
+                var opl = OperationUtils.getOPL(operation);
 
                 // bug 29601: skip operations, that were 'optimized' in 'sendActions' in the
                 // optimizeOperationHandler. Otherwise the debug pane will be irritating, because
                 // 'merged operations' are followed by the operations, that will not be sent to
                 // the server, because they were removed by the 'optimizeOperationHandler'.
                 if (!entry.external) {
-                    if (_.isNumber(opl) && (opl > 1)) {
+                    if (opl > 1) {
                         skipCount = opl - 1;
                     } else if (skipCount > 0) {
                         skipCount -= 1;
@@ -150,8 +152,8 @@ define('io.ox/office/editframework/view/operationspane', [
                 markup += '<tr class="' + classes + '">';
                 markup += '<td>' + operationsCount + '</td>';
                 markup += '<td title="' + source + ' operation">' + source[0] + '</td>';
-                markup += '<td style="text-align:right;">' + osn + '</td>';
-                markup += '<td style="text-align:right;">' + opl + '</td>';
+                markup += '<td style="text-align:right;">' + ((osn >= 0) ? osn : '') + '</td>';
+                markup += '<td style="text-align:right;">' + ((opl > 0) ? opl : '') + '</td>';
                 markup += '<td>' + Utils.escapeHTML(name) + '</td>';
                 markup += '<td title="' + Forms.createLoggingTooltipMarkup(operation) + '">' + Utils.escapeHTML(Utils.stringifyForDebug(operation)) + '</td>';
                 markup += '</tr>';
@@ -181,15 +183,17 @@ define('io.ox/office/editframework/view/operationspane', [
                     opTableNode.append(markup);
                     scrollDownOperationsNode();
                 }
-            }, 1000);
+            }, { delay: 1000, infoString: 'OperationsPane: startLogger', app: app });
         }
 
         /**
          * Stops the background loop that logs collected pending operations.
          */
         function abortLogger() {
-            logOperationsTimer.abort();
-            logOperationsTimer = null;
+            if (logOperationsTimer) {
+                logOperationsTimer.abort();
+                logOperationsTimer = null;
+            }
         }
 
         /**
@@ -329,7 +333,7 @@ define('io.ox/office/editframework/view/operationspane', [
 
         // add the operations table and the info table to the debug pane
         [{ node: opTableNode, cls: 'ops' }, { node: infoTableNode, cls: 'info' }].forEach(function (entry) {
-            var scrollNode = $('<div tabindex="1">').append(entry.node);
+            var scrollNode = $('<div tabindex="0">').append(entry.node);
             self.getNode().append($('<div class="debug-table ' + entry.cls + '">').append(scrollNode));
         });
 
@@ -393,7 +397,7 @@ define('io.ox/office/editframework/view/operationspane', [
             // start logging of initial import operations after a delay
             this.executeDelayed(function () {
                 if (!logOperationsTimer && self.isVisible()) { startLogger(); }
-            }, 3000);
+            }, { delay: 3000, infoString: 'OperationsPane: waitForImport', app: app });
 
         }, this);
 
