@@ -6,18 +6,22 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/editframework/view/toppane', [
+    'io.ox/office/tk/utils',
     'io.ox/office/baseframework/view/toolpane',
     'io.ox/office/baseframework/view/toolbar',
     'io.ox/office/editframework/view/editlabels',
     'io.ox/office/editframework/view/editcontrols',
+    'io.ox/office/tk/control/label',
+    'io.ox/office/tk/forms',
     'gettext!io.ox/office/editframework/main'
-], function (ToolPane, ToolBar, Labels, Controls, gt) {
+], function (Utils, ToolPane, ToolBar, Labels, Controls, Label, Forms, gt) {
 
     'use strict';
 
@@ -38,7 +42,7 @@ define('io.ox/office/editframework/view/toppane', [
      * @param {ToolBarTabCollection} toolBarTabs
      *  The collection of all registered tool bar tabs.
      */
-    function TopPane(docView, toolBarTabs) {
+    function TopPane(docView, toolBarTabs, initOptions) {
 
         var // self reference
             self = this,
@@ -241,6 +245,13 @@ define('io.ox/office/editframework/view/toppane', [
             .addGroup('view/toolbars/tab', tabList.hide()),
         { targetArea: 'leading' });
 
+        // Icon for encyrpted documents
+        if (docView.getApp().isDocumentEncrypted()) {
+            var encryptLabel = new Label({ icon: 'fa-lock', style: { 'padding-left': 0, 'padding-right': 12 } });
+            encryptLabel.setToolTip(gt('Document is encrypted'));
+            this.addViewComponent(new ToolBar(docView).addGroup(null, encryptLabel));
+        }
+
         // create the tool bar containing the application status label
         statusLabel = new Controls.ApplicationStatusLabel(docView, { smallerVersion: { css: { width: 20 }, hideLabel: true } });
         this.addViewComponent(new ToolBar(docView).addGroup(null, statusLabel));
@@ -254,16 +265,23 @@ define('io.ox/office/editframework/view/toppane', [
         viewMenuGroup = new Controls.CompoundButton(docView, { label: Labels.VIEW_LABEL, anchorPadding: -3 });
 
         // create the tool bar with the standard controls
-        this.addViewComponent(new ToolBar(docView)
-            .addGroup('document/undo', new Controls.Button({ icon: 'docs-undo', tooltip: gt('Revert last operation') }), { visibleKey: 'document/editable' })
+        var standardControls = new ToolBar(docView);
+
+        standardControls.addGroup('document/undo', new Controls.Button({ icon: 'docs-undo', tooltip: gt('Revert last operation') }), { visibleKey: 'document/editable' })
             .addGroup('document/redo', new Controls.Button({ icon: 'docs-redo', tooltip: gt('Restore last operation') }), { visibleKey: 'document/editable' })
             .addGap()
             .addGroup('view/searchgroup', new Controls.Button({ icon: 'fa-search', tooltip: gt('Toggle search'), toggle: true }), { visibleKey: 'app/valid' })
-            .addGap()
-            .addGroup(null, viewMenuGroup)
+            .addGap();
+
+        if (Utils.getBooleanOption(initOptions, 'enablePresenter', false)) {
+            standardControls.addGroup('document/present', new Controls.Button({ tooltip: gt('Present'), label: gt('Present'), icon: 'fa-play-circle' }));
+        }
+
+        standardControls.addGroup(null, viewMenuGroup)
             .addSeparator()
-            .addGroup('app/quit', new Controls.Button(Labels.QUIT_BUTTON_OPTIONS), { visibleKey: 'app/bundled' }),
-        { targetArea: 'trailing' });
+            .addGroup('app/quit', new Controls.Button(Labels.QUIT_BUTTON_OPTIONS), { visibleKey: 'app/bundled' });
+
+        this.addViewComponent(standardControls, { targetArea: 'trailing' });
 
         // update view pane after it has been resized, or contents have been changed
         this.on('pane:layout', paneLayoutHandler);
