@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Edy Haryono <edy.haryono@open-xchange.com>
  */
@@ -20,8 +21,9 @@ define('io.ox/office/portal/action/templateactions', [
     'io.ox/office/tk/utils/driveutils',
     'io.ox/office/portal/portalutils',
     'io.ox/office/portal/view/contextmenu',
+    'io.ox/office/tk/utils/scheduler',
     'gettext!io.ox/office/portal/main'
-], function (Ext, Links, CoreActions, DriveUtils, Utils, ContextMenu, gt) {
+], function (Ext, Links, CoreActions, DriveUtils, Utils, ContextMenu, Scheduler, gt) {
 
     'use strict';
 
@@ -115,20 +117,19 @@ define('io.ox/office/portal/action/templateactions', [
             thumbnailSize = null;
 
         /*
-         * Function returning the URL to the global templates using
-         * the file descriptor for the creation of the URL.
+         * Returns the URL to a template file using the passed file descriptor.
          *
          * @param {Object} data
          *  The file descriptor object.
          *
          * @param {Object} [options]
-         *  Additional optional options.
-         *  @param {Boolean} [options.isGlobal=true]
-         *      If set to true, the url for global templates is created,
-         *      otherwise for user templates.
+         *  Optional parameters:
+         *  @param {Boolean} [options.global=false]
+         *      If set to true, the URL for a global template file will be
+         *      created, otherwise for a user template.
          *
          * @returns {String}
-         *  The url string for the template.
+         *  The URL for the template.
          */
         var createTemplateURL = function (data, options) {
             // Thumbnails have a different size for presentation and text/spreadsheet.
@@ -143,134 +144,123 @@ define('io.ox/office/portal/action/templateactions', [
             }
 
             var // whether the template files are local or global
-                isGlobal = Utils.getBooleanOption(options, 'isGlobal', true),
+                isGlobal = Utils.getBooleanOption(options, 'global', false),
+                // the used scale type for the preview
+                scaleType = '&scaleType=contain',
                 // the constructed url
                 url = isGlobal ? ox.abs + ox.apiRoot + '/oxodocumentfilter?action=templatepreview&id=' + data.id +
-                    '&folder=' + data.folder_id + '&format=preview_image&delivery=view&scaleType=contains' :
+                    '&folder=' + data.folder_id + '&format=preview_image&delivery=view' :
                     DriveUtils.getFileUrl(data, 'preview');
 
-            url += thumbnailSize + '&dummy=' + data.last_modified;
+            url += thumbnailSize + scaleType + '&dummy=' + data.last_modified;
             return url;
         };
 
         /*
-         * Helper function to generate the draw-functions for the
-         * different extension points for creating new documents from
-         * global or user templates.
-         * The templates are displayed differently in the presentation and
-         * text/spreadsheet portal. In the presentation portal the templates are
-         * rendered with their aspect ratio, in text/spreadsheet a predefined
-         * container is used.
+         * Draws the item to create a new document from a global or a user
+         * template file.
          *
-         * @param {itemClass} String
-         *  A class name specific for the application and for global or
-         *  user templates.
+         * @param {Object} baton
+         *  The file descriptor.
          *
          * @param {Object} [options]
-         *  Additional optional options.
-         *  @param {Boolean} [options.isGlobal=true]
-         *      If set to true, the url for global templates is created,
-         *      otherwise for user templates.
-         *
-         * @returns {Function}
-         *  The draw function for the extension.
+         *  Optional parameters:
+         *  @param {Boolean} [options.global=false]
+         *      If set to true, the URL for a global template file will be
+         *      created, otherwise for a user template.
          */
-        var getDrawFunction = function (itemClass, options) {
+        function drawItem(baton, options) {
 
-            // baton : a template file descriptor
-            return function (baton) {
+            // This block sets the data to get a different layout
+            // in the presentation and text/spreadsheet portal.
 
-                // This block sets the data to get a different layout
-                // in the presentation and text/spreadsheet portal.
-                var // appBaseName for the currently used portal
-                    appBaseName = baton.data.type,
-                    fullFileName = baton.data['com.openexchange.file.sanitizedFilename'] || baton.data.filename,
-                    // set classes according to the current app portal to get the right css layout
-                    templateItemClass = 'template-item ' + itemClass + ' ' + appBaseName,
-                    // the element which should be highlighted, it has to be different in presentation or text/spreadsheet
-                    highLightElement = null;
+            // appBaseName for the currently used portal
+            var appBaseName = baton.data.type;
+            // the element which should be highlighted, it has to be different in presentation or text/spreadsheet
+            var highLightElement = null;
+            var fullFileName = baton.data['com.openexchange.file.sanitizedFilename'] || baton.data.filename;
+            // the template container
+            var templateItem = $('<a class="template-item" tabindex="0">').addClass(appBaseName).attr({
+                'data-toggle': 'tooltip',
+                'data-animation': false,
+                'data-delay': '{ "show": 1400 }',
+                title: _.noI18n(fullFileName)
+            });
+            var previewBox = $('<div class="preview-box">');
+            var displayName = _.noI18n(Utils.removeFileExtension(fullFileName));
+            var nameBox = $('<p class="template-name">').text(displayName);
+            var previewImg = $('<img>').attr('name', displayName);
+            var iconNode = Utils.createDocumentIcon(fullFileName);
 
-                var // the template container
-                    templateItem = $('<a class="' + templateItemClass + '">')
-                    .attr({
-                        'data-toggle': 'tooltip',
-                        'data-animation': 'false',
-                        'data-delay': '{ "show": 1400 }',
-                        title: _.noI18n(fullFileName),
-                        tabindex: 0
-                    }),
-                    templatePreview = $('<div class="template-preview">'),
-                    showName = _.noI18n(Utils.removeFileExtension(fullFileName)),
-                    templatePreviewIMG = $('<img class = "templateIMG" name = "' + showName + '"/>'),
-                    templateName = $('<p>').addClass('template-name').text(showName),
-                    icon = Utils.createDocumentIcon(fullFileName);
+            // show the item in "blank document" style while loading the image
+            previewBox.addClass('new-blank').append(iconNode);
+            previewImg.css('visibility', 'hidden');
+            // shown delayed to prevent flickering icons when the images are loaded very fast (e.g. from cache)
+            iconNode.hide().delay(200).fadeIn(100);
 
-                //----------------------------------------------
-                templatePreview.addClass('new-blank');
-                templateItem.addClass('template-blank');
-                templatePreview.append(icon);
-                templatePreviewIMG.css('visibility', 'hidden');
-                // showed delayed to prevent flickering icons when the images are loaded very fast (e.g. from cache)
-                icon.hide().delay(200).fadeIn(100);
+            previewImg.on('load', function () {
+                previewBox.removeClass('new-blank');
+                previewImg.css('visibility', 'visible');
+                iconNode.remove();
+            });
+            previewImg.on('error', function () {
+                previewImg.remove();
+            });
 
-                templatePreviewIMG.on('load', function () {
-                    templatePreview.removeClass('new-blank');
-                    templateItem.removeClass('template-blank');
-                    templatePreviewIMG.css('visibility', 'visible');
-                    icon.remove();
-                });
-                templatePreviewIMG.on('error', function () {
-                    templatePreviewIMG.remove();
-                });
-                //----------------------------------------------
+            loadImageInQueue(previewImg, createTemplateURL(baton.data, options));
 
-                loadImageInQueue(templatePreviewIMG, createTemplateURL(baton.data, options));
+            // attach the preview img to the template
+            previewBox.append(previewImg);
 
-                // attach the preview img to the template
-                templatePreview.append(templatePreviewIMG);
+            // set the element which should be highlighted
+            highLightElement = (appBaseName === 'presentation') ? previewImg : previewBox;
 
-                // set the element which should be highlighted
-                highLightElement = (appBaseName === 'presentation') ? templatePreviewIMG : templatePreview;
+            // add new preview to the template container
+            templateItem.append(previewBox, nameBox);
 
-                // add new preview to the template container
-                templateItem.append(templatePreview, templateName);
+            // Get file descriptor of the newly created file as result, and open it with an office app.
+            templateItem.click(function () {
 
-                // Get file descriptor of the newly created file as result, and open it with an office app.
-                templateItem.click(function () {
+                // only invoke the action when no context menu is open
+                // use case: the user can click everywere on the screen to close the contextmenu
+                if (!ContextMenu.isOpen()) {
 
-                    // only invoke the action when no context menu is open
-                    // use case: the user can click everywere on the screen to close the contextmenu
-                    if (!ContextMenu.isOpen()) {
+                    // provide feedback to the user which element will be opened
+                    Utils.markElement(highLightElement);
 
-                        // provide feedback to the user which element will be opened
-                        Utils.markElement(highLightElement);
-
-                        CoreActions.invoke(templateExtension + '/action/open', this, baton.data);
-                    }
-                });
-
-                templateItem.on('keydown', { grid: true }, Utils.keydownHandler);
-
-                // handle context menu
-                templateItem.on('contextmenu', function (e) {
-                    contextMenuHandler(e, templateItem, baton, highLightElement);
-                });
-
-                // prevent focus change on click due to mousedown
-                templateItem.on('mousedown', function (e) {
-                    e.preventDefault();
-                });
-
-                // iOS: check if there is a long tap to invoke a 'contextmenu' event
-                if (Utils.IOS) {
-                    templateItem.on('touchstart', function (event) {
-                        Utils.iosContextEventHandler(event, templateItem);
-                    });
+                    CoreActions.invoke(templateExtension + '/action/open', this, baton.data);
                 }
+            });
 
-                this.append(templateItem);
-            };
-        };
+            templateItem.on('keydown', { grid: true }, Utils.keydownHandler);
+
+            // handle context menu
+            templateItem.on('contextmenu', function (e) {
+                contextMenuHandler(e, templateItem, baton, highLightElement);
+            });
+
+            // prevent focus change on click due to mousedown
+            templateItem.on('mousedown', function (e) {
+                e.preventDefault();
+            });
+
+            // iOS: check if there is a long tap to invoke a 'contextmenu' event
+            if (Utils.IOS) {
+                templateItem.on('touchstart', function (event) {
+                    Utils.iosContextEventHandler(event, templateItem);
+                });
+            }
+
+            this.append(templateItem);
+        }
+
+        function drawGlobalItem(baton) {
+            return drawItem.call(this, baton, { global: true });
+        }
+
+        function drawLocalItem(baton) {
+            return drawItem.call(this, baton);
+        }
 
         /*
          * A Handler function to generate the the context menu for templates in
@@ -372,7 +362,7 @@ define('io.ox/office/portal/action/templateactions', [
                 // After a click event the context menu is closed by the basemenu globalClickHandler().
                 // When a context menu is open, clicking on an element should not invoke it's attached action, but just close the context menu.
                 // As 'closing' and 'invocation' due to a click event happens at the same time, ContextMenu.setOpen(false) must be called delayed.
-                window.setTimeout(function () { ContextMenu.setOpen(false); }, 300);
+                Scheduler.setTimeout(function () { ContextMenu.setOpen(false); }, 300, null, 'TemplateActions contextMenuHandler');
 
                 // destroy the context menu
                 cmenu = null;
@@ -403,27 +393,21 @@ define('io.ox/office/portal/action/templateactions', [
 
                 // This block sets the data to get a different layout
                 // in the presentation and text/spreadsheet portal.
-                var // appBaseName for the currently used portal
-                    appBaseName = baton.appBaseName,
-                    // set classes according to the current app portal to get the right css layout
-                    templateClass = 'new-blank template-preview',
-                    templateItemClass = 'template-item template-blank ' + appBaseName;
 
-                var // the template container
-                    templateItem = $('<a>').addClass(templateItemClass)
-                    .attr({
-                        'data-toggle': 'tooltip',
-                        'data-animation': 'false',
-                        'data-delay': '{ "show": 1400 }',
-                        title: _.noI18n(fileName),
-                        tabindex: 0
-                    }),
-                    templatePreview = $('<div>').addClass(templateClass)
-                        .append($('<i>').addClass('fa fa-plus')),
-                    templateName = $('<p>').addClass('template-name').text(_.noI18n(fileName));
+                // the template container (class "blank-doc" expected and used by Portal Welcome Tour!)
+                var templateItem = $('<a class="template-item blank-doc">').addClass(baton.appBaseName).attr({
+                    'data-toggle': 'tooltip',
+                    'data-animation': 'false',
+                    'data-delay': '{ "show": 1400 }',
+                    title: _.noI18n(fileName),
+                    tabindex: 0
+                });
+
+                var previewBox = $('<div class="preview-box new-blank">').append($('<i class="fa fa-plus">'));
+                var nameBox = $('<p class="template-name">').text(_.noI18n(fileName));
 
                 // add new blank template to the template container
-                templateItem.append(templatePreview, templateName);
+                templateItem.append(previewBox, nameBox);
 
                 templateItem.click(function () {
 
@@ -432,7 +416,7 @@ define('io.ox/office/portal/action/templateactions', [
                     if (!ContextMenu.isOpen()) {
 
                         // provide feedback to the user which element will be opened
-                        Utils.markElement(templatePreview);
+                        Utils.markElement(previewBox);
 
                         CoreActions.invoke(invokeId, this, baton);
                     }
@@ -521,13 +505,13 @@ define('io.ox/office/portal/action/templateactions', [
         // define extension for creating text documents with global templates
         this.textglobal.extend({
             id: 'text_global_template',
-            draw: getDrawFunction('template-text-global', { isGlobal: true })
+            draw: drawGlobalItem
         });
 
         // define extension for creating text documents with user templates
         this.textuser.extend({
             id: 'text_user_template',
-            draw: getDrawFunction('template-text-local', { isGlobal: false })
+            draw: drawLocalItem
         });
 
         // define extension for creating spreadsheet with a blank template
@@ -539,13 +523,13 @@ define('io.ox/office/portal/action/templateactions', [
         // define extension for creating spreadsheet with global templates
         this.spreadsheetglobal.extend({
             id: 'spreadsheet_global_template',
-            draw: getDrawFunction('template-spreadsheet-global', { isGlobal: true })
+            draw: drawGlobalItem
         });
 
         // define extension for creating spreadsheet with user templates
         this.spreadsheetuser.extend({
             id: 'spreadsheet_user_template',
-            draw: getDrawFunction('template-spreadsheet-local', { isGlobal: false })
+            draw: drawLocalItem
         });
 
         // define extension for creating presentation with a blank template
@@ -557,13 +541,13 @@ define('io.ox/office/portal/action/templateactions', [
         // define extension for creating presentation with global templates
         this.presentationglobal.extend({
             id: 'presentation_global_template',
-            draw: getDrawFunction('template-presentation-global', { isGlobal: true })
+            draw: drawGlobalItem
         });
 
         // define extension for creating presentation with user templates
         this.presentationuser.extend({
             id: 'presentation_user_template',
-            draw: getDrawFunction('template-presentation-local', { isGlobal: false })
+            draw: drawLocalItem
         });
 
     } // class TemplateExtensions
