@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -101,7 +102,12 @@ define('io.ox/office/portal/action/toolbaractionsimpl', [
                     var dialog = new FilePicker({
                         // filter files of disabled applications (capabilities)
                         filter: function (file) {
-                            return ExtensionRegistry.isEditable(file.filename);
+                            // Bug 47431: check if there is a file name (String), otherwise return false
+                            if (_.isString(file.filename)) {
+                                // Bug 49564 DriveUtils.canModify use for new folders like "My Attachments"
+                                return ExtensionRegistry.isEditable(file.filename) && DriveUtils.canModify(file);
+                            }
+                            return false;
                         },
                         sorter: function (file) {
                             return (file.filename || file.title).toLowerCase();
