@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -21,8 +22,14 @@ define('io.ox/office/portal/portaltour', [
 
     'use strict';
 
-    var // the 'shown' configuration key for any of the portal tours
-        ANY_PORTAL_TOUR_SHOWN_KEY = 'io.ox/office/portal/alltours/shown';
+    // the 'shown' configuration key for any of the portal tours
+    var ANY_PORTAL_TOUR_SHOWN_KEY = 'io.ox/office/portal/alltours/shown';
+
+    // selector for any tool pane without hidden contents
+    var TOOL_PANE_SELECTOR = '.tool-pane:not(.hidden-contents)';
+
+    // debug mode: whether to always show the long version of the tours
+    var DEBUG_FULL_TOURS = Config.getDebugUrlFlag('office:full-tours');
 
     // class PortalTour =======================================================
 
@@ -36,7 +43,7 @@ define('io.ox/office/portal/portaltour', [
      * @param {String} appBaseName
      *  The base name of the application represented by this tour.
      */
-    function PortalTour(appBaseName) {
+    function PortalTour(appBaseName, options) {
 
         // self reference
         var self = this;
@@ -56,6 +63,9 @@ define('io.ox/office/portal/portaltour', [
         // the launch options used to show the existing editor application
         var editLaunchOptions = null;
 
+        // whether to show the short version of the tour
+        var shortTour = !DEBUG_FULL_TOURS && (options && options.auto && PortalTour.isAnyPortalTourShown());
+
         // base constructor ---------------------------------------------------
 
         GuidedTour.call(this, appBaseName);
@@ -63,18 +73,30 @@ define('io.ox/office/portal/portaltour', [
         // constants ----------------------------------------------------------
 
         // selector for the root window node of the editor application
-        this.EDITOR_WINDOW_SELECTOR = '.window-container[data-app-name="' + EDITOR_APP_TYPE + '"]:visible';
+        this.EDITOR_WINDOW_SELECTOR = '.window-container[data-app-name="' + EDITOR_APP_TYPE + '"][data-doc-loaded="true"]:visible';
 
         // selector for the top pane of the editor application
-        this.EDITOR_TOP_PANE_SELECTOR = this.EDITOR_WINDOW_SELECTOR + ' .tool-pane.top-pane';
+        this.EDITOR_TOP_PANE_SELECTOR = this.EDITOR_WINDOW_SELECTOR + ' ' + TOOL_PANE_SELECTOR + '.top-pane';
 
         // selector for the main tool pane of the editor application
-        this.EDITOR_TOOL_PANE_SELECTOR = this.EDITOR_WINDOW_SELECTOR + ' .tool-pane.edit-pane';
+        this.EDITOR_TOOL_PANE_SELECTOR = this.EDITOR_WINDOW_SELECTOR + ' ' + TOOL_PANE_SELECTOR + '.edit-pane';
 
         // selector for the application pane of the editor application
         this.EDITOR_APP_PANE_SELECTOR = this.EDITOR_WINDOW_SELECTOR + ' .app-pane';
 
-       // specific portal tour steps -----------------------------------------
+        // public methods -----------------------------------------------------
+
+        /**
+         * Returns whether to show the short version of this tour.
+         *
+         * @returns {Boolean}
+         *  Whether to show the short version of this tour.
+         */
+        this.isShortTour = function () {
+            return shortTour;
+        };
+
+        // specific portal tour steps -----------------------------------------
 
         /**
          * Immediately launches the Drive application.
@@ -157,7 +179,7 @@ define('io.ox/office/portal/portaltour', [
         this.blankDocumentStep = function () {
             return this.step()
                 // wait for the element in case this step is shown via Back button from next step
-                .waitForAndReferTo('.office-portal-templates .template-item.template-blank', { position: 'bottom', hotspot: '.template-preview' });
+                .waitForAndReferTo('.office-portal-templates .template-item.blank-doc', { position: 'bottom', hotspot: '.preview-box' });
         };
 
         /**
@@ -177,7 +199,7 @@ define('io.ox/office/portal/portaltour', [
                 // register the application launcher, create a new blank document
                 .navigateTo(EDITOR_APP_TYPE + '/main', PortalUtils.getNewLaunchOptions())
                 // wait for the application window node, and the 'data-doc-loaded' marker that will be set after import
-                .waitFor(this.EDITOR_WINDOW_SELECTOR + '[data-doc-loaded="true"]', 10)
+                .waitFor(this.EDITOR_TOP_PANE_SELECTOR, 10)
                 // highlight the entire edit tool pane (bug 44195: use first embedded tool bar element to prevent positioning problems with full-width pane)
                 .referTo(this.EDITOR_TOOL_PANE_SELECTOR + ' .toolbar:visible:eq(0)', { position: 'bottom', hotspot: true })
                 // once the document has been created, change this step so that it navigates to the existing document
@@ -198,7 +220,8 @@ define('io.ox/office/portal/portaltour', [
          *
          * @param {Function} callback
          *  A callback function that must insert some contents into the new
-         *  document, in order to show the 'Saving changes' label.
+         *  document, in order to show the 'Saving changes' label. Will only be
+         *  called once when reaching this step the first time.
          *
          * @returns {Step}
          *  The new tour step. The instance has been extended with the mix-in
@@ -211,9 +234,9 @@ define('io.ox/office/portal/portaltour', [
                 // invoke the callback function that will insert some contents into the document
                 .once('before:show', callback)
                 // wait for the application window node, and the 'data-doc-loaded' marker that will be set after import
-                .waitFor(this.EDITOR_TOP_PANE_SELECTOR + ' .app-status-label i')
+                .waitFor(this.EDITOR_TOP_PANE_SELECTOR + ' .app-status-label .caption i')
                 // highlight the 'All changes saved' status label
-                .referTo(this.EDITOR_TOP_PANE_SELECTOR + ' .app-status-label', { position: 'bottom', hotspot: 'i' });
+                .referTo(this.EDITOR_TOP_PANE_SELECTOR + ' .app-status-label', { position: 'bottom', hotspot: '.caption i' });
         };
 
         /**
@@ -247,7 +270,7 @@ define('io.ox/office/portal/portaltour', [
         this.saveAsStep = function () {
             return this.step()
                 .title(gt.pgettext('tour', 'Saving options'))
-                .content(gt.pgettext('tour', 'If you would like to store your document in a specific folder, just click on "Save as".'))
+                .content(gt.pgettext('tour', 'If you would like to store your document in a specific folder, just click on "Save as". You can also click on "Save as template" to create your own templates.'))
                 .content($('<br>'))
                 .content(gt.pgettext('tour', 'You can also click on "Save as template" to create your own templates.'))
                 // open and highlight the 'Save As' drop-down menu
@@ -259,15 +282,22 @@ define('io.ox/office/portal/portaltour', [
          * Defines the tour step that refers to the 'Send As Mail' button. The
          * mail step will already contain a title and a description text.
          *
+         * @param {Obejct} [options]
+         *  Optional parameters:
+         *  @param {Boolean} [options.asDropDown=false]
+         *      If set to true, the "Send as mail" control is a drop-down menu
+         *      button, instead of a simple push button.
+         *
          * @returns {Step}
          *  The new tour step. The instance has been extended with the mix-in
          *  class StepMixin defined in the GuidedTour module.
          */
-        this.sendAsMailStep = function () {
+        this.sendAsMailStep = function (options) {
+            var groupKey = (options && options.asDropDown) ? 'document/sendmail/menu' : 'document/sendmail';
             return this.step()
                 .title(gt.pgettext('tour', 'Sending your document'))
                 .content(gt.pgettext('tour', 'Sending your document by email is easy. Just click on the mail icon and you are ready to go!'))
-                .referToGroup(this.EDITOR_TOOL_PANE_SELECTOR, 'document/sendmail', { position: 'bottom', hotspot: 'i' });
+                .referToGroup(this.EDITOR_TOOL_PANE_SELECTOR, groupKey, { position: 'bottom', hotspot: '.caption i' });
         };
 
         /**
@@ -284,7 +314,7 @@ define('io.ox/office/portal/portaltour', [
                 .title(gt.pgettext('tour', 'Closing document'))
                 .content(gt.pgettext('tour', 'The document can be closed now. As all changes are stored automatically, you do not need to save documents manually.'))
                 // wait for the element in case this step is shown via Back button from next step
-                .waitForAndReferToGroup(this.EDITOR_TOP_PANE_SELECTOR, 'app/quit', { position: 'bottom', hotspot: 'i' });
+                .waitForAndReferToGroup(this.EDITOR_TOP_PANE_SELECTOR, 'app/quit', { position: 'bottom', hotspot: '.caption i' });
         };
 
         /**
@@ -323,8 +353,8 @@ define('io.ox/office/portal/portaltour', [
                 .content(gt.pgettext('tour', 'Hint: you can start guided tours, any time you need them, from the system menu.'))
                 // show the Portal application again
                 .navigateTo(PORTAL_APP_TYPE + '/main')
-                // open the global drop-down menu
-                .on('navigate', function () { $('#io-ox-topbar-dropdown-icon>a').dropdown('toggle'); })
+                // open and close the global drop-down menu
+                .on('navigate before:hide', function () { $('#io-ox-topbar-dropdown-icon>a').dropdown('toggle'); })
                 // wait for and highlight the 'Restart tour' menu entry
                 .waitForAndReferTo('#topbar-settings-dropdown [data-action="guided-tour"]', { position: 'left', hotspot: true });
         };
@@ -341,7 +371,7 @@ define('io.ox/office/portal/portaltour', [
         this.on('stop', function () {
 
             // launch the portal application (the tour may have been canceled elsewhere)
-            self.launchPortalApp();
+            this.launchPortalApp();
 
             // close the editor application, and delete the document from Drive
             if (editApp) {
