@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Edy Haryono <edy.haryono@open-xchange.com>
  */
@@ -17,8 +18,9 @@ define('io.ox/office/portal/portalutils', [
     'io.ox/office/tk/utils/dateutils',
     'io.ox/office/tk/utils/driveutils',
     'io.ox/office/baseframework/app/extensionregistry',
+    'io.ox/office/tk/utils/scheduler',
     'gettext!io.ox/office/portal/main'
-], function (Capabilities, Utils, KeyCodes, DateUtils, DriveUtils, ExtensionRegistry, gt) {
+], function (Capabilities, Utils, KeyCodes, DateUtils, DriveUtils, ExtensionRegistry, Scheduler, gt) {
 
     'use strict';
 
@@ -30,8 +32,6 @@ define('io.ox/office/portal/portalutils', [
     // copy tk/utils methods
     var PortalUtils = _.clone(Utils);
 
-    // constants --------------------------------------------------------------
-
     // static methods ---------------------------------------------------------
 
     /**
@@ -97,7 +97,7 @@ define('io.ox/office/portal/portalutils', [
                 iconClasses += 'fa-file-text text';
                 break;
             case 'io.ox/office/presentation':
-                iconClasses += 'fa-film presentation';
+                iconClasses += 'fa-list-alt presentation';
                 break;
             default:
                 iconClasses += 'fa-file';
@@ -282,7 +282,7 @@ define('io.ox/office/portal/portalutils', [
 
         if (!nodeToFocus) { return; }
 
-        nodeToFocus.focus();
+        Utils.setFocus(nodeToFocus);
     };
 
     /**
@@ -393,7 +393,7 @@ define('io.ox/office/portal/portalutils', [
         link.on('touchend', cancel);
 
         // check if a long tap should be triggered after 750 ms
-        window.setTimeout(hold, 750);
+        Scheduler.setTimeout(hold, 750, null, 'PortalUtils iosContextEventHandler');
 
     };
 
@@ -405,7 +405,7 @@ define('io.ox/office/portal/portalutils', [
      *  A reference to the element.
      */
     PortalUtils.markElement = function (link) {
-        link.addClass('permanentHover');
+        link.addClass('permanent-hover');
     };
 
     /**
@@ -416,7 +416,7 @@ define('io.ox/office/portal/portalutils', [
      *  A reference to the element.
      */
     PortalUtils.removeMark = function (link) {
-        link.removeClass('permanentHover');
+        link.removeClass('permanent-hover');
     };
 
     /**
@@ -488,6 +488,38 @@ define('io.ox/office/portal/portalutils', [
         });
     };
 
+    /**
+     * Shows the document in the Presenter.
+     *
+     * @param {Object} baton
+     * A baton object which has a backbone cid.
+     * Note: Unfortunately there are cases where the cid is the file-descriptor (e.g. in Drive),
+     * so better take a look at the baton before using it here.
+     *
+     * @param {Boolean} [default=false]
+     *  If assigned current ox app is set to busy mode
+     *  and back to idle after drive is loaded
+     *
+     */
+    PortalUtils.showInPresenter = function (baton, busy) {
+        var win = null;
+        if (busy) {
+            win = ox.ui.App.getCurrentApp().getWindow();
+            win.busy();
+        }
+        // There are two different kinds of batons, one with a backbone cid and
+        // one which has a file descriptor as a cid (e.g. in Drive). This baton
+        // is expected to have a backbone cid. To launch the Presenter, a baton
+        // with a file descriptor as a cid is needed. Therefore 'getFileModelFromDescriptor'
+        // is used to create it.
+        DriveUtils.getFileModelFromDescriptor(baton.data).then(function (data) {
+            return ox.launch('io.ox/presenter/main', data).then(function () {
+
+                if (win) { win.idle(); }
+            });
+        });
+    };
+
     // exports ================================================================
 
     return PortalUtils;
