@@ -6,19 +6,21 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Sven Jacobi <sven.jacobi@open-xchange.com>
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
 
 define('io.ox/office/presentation/app/application', [
+    'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/driveutils',
     'io.ox/office/editframework/app/editapplication',
     'io.ox/office/presentation/model/model',
     'io.ox/office/presentation/view/view',
-    'io.ox/office/presentation/app/controller',
-    'io.ox/office/tk/utils'
-], function (EditApplication, PresentationModel, PresentationView, PresentationController, Utils) {
+    'io.ox/office/presentation/app/controller'
+], function (Utils, DriveUtils, EditApplication, PresentationModel, PresentationView, PresentationController) {
 
     'use strict';
 
@@ -115,6 +117,11 @@ define('io.ox/office/presentation/app/application', [
                 return self;
             }
 
+            // do not send attributes, if undo/redo is running (48211)
+            if (self.getModel().isUndoRedoRunning()) {
+                return self;
+            }
+
             // whether the document is modified
             var modified = self.isLocallyModified();
 
@@ -133,6 +140,44 @@ define('io.ox/office/presentation/app/application', [
 
         }
 
+        // public methods -----------------------------------------------------
+
+        /**
+         * Launches the OX Presenter application with this presentation.
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved when the new presenter application
+         *  has been launched.
+         */
+        this.startPresenter = function () {
+
+            // block the screen while flushing and initializing presenter
+            this.getView().enterBusy({ immediate: true });
+
+            // flush document, needed to have recent changes in the file
+            var promise = this.flushDocument('present');
+
+            // propagate changed file to the files API
+            promise = promise.then(function () {
+                return DriveUtils.propagateChangeFile(self.getFileDescriptor());
+            });
+
+            // resolve the file model from OX Drive
+            promise = promise.then(function () {
+                return DriveUtils.getFileModelFromDescriptor(self.getFileDescriptor());
+            });
+
+            // launch the Presenter application
+            promise = promise.then(function (model) {
+                return ox.launch('io.ox/presenter/main', model);
+            });
+
+            // release the blocked screen of this application
+            return promise.always(function () {
+                self.getView().leaveBusy();
+            });
+        };
+
         // initialization -----------------------------------------------------
 
         // destroy all class members
