@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
@@ -18,6 +19,8 @@ define('io.ox/office/presentation/app/controller', [
     'io.ox/office/editframework/utils/hyperlinkutils',
     'io.ox/office/editframework/utils/mixedborder',
     'io.ox/office/editframework/app/editcontroller',
+    'io.ox/office/editframework/utils/paragraphspacing',
+    'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/drawinglayer/utils/drawingutils',
     'io.ox/office/drawinglayer/view/drawinglabels',
     'io.ox/office/presentation/format/paragraphstyles',
@@ -25,7 +28,7 @@ define('io.ox/office/presentation/app/controller', [
     'io.ox/office/textframework/components/hyperlink/hyperlink',
     'io.ox/office/textframework/utils/position',
     'io.ox/office/textframework/format/tablestyles'
-], function (Utils, Color, HyperlinkUtils, MixedBorder, EditController, DrawingUtils, DrawingLabels, ParagraphStyles, Config, Hyperlink, Position, TableStyles) {
+], function (Utils, Color, HyperlinkUtils, MixedBorder, EditController, ParagraphSpacing, AttributeUtils, DrawingUtils, DrawingLabels, ParagraphStyles, Config, Hyperlink, Position, TableStyles) {
 
     'use strict';
 
@@ -40,23 +43,33 @@ define('io.ox/office/presentation/app/controller', [
      */
     function PresentationController(app, docModel, docView) {
 
-        var // self reference
-            self = this;
+        // self reference
+        var self = this;
 
         // base constructor ---------------------------------------------------
 
-        EditController.call(this, app, docModel, docView, { updateDelay: 200 });
+        EditController.call(this, app, docModel, docView, searchHandler, { updateDelay: 200 });
 
         // private methods ----------------------------------------------------
 
+        /**
+         * Executes a search/replace operation, as requested by the base class
+         * EditController.
+         */
+        function searchHandler(command, settings) {
+            return docModel.getSearchHandler().executeCommand(command, settings);
+        }
+
         // initialization -----------------------------------------------------
 
         if (_.browser.Android) {
-            var originalUpdate = self.update;
+            var originalUpdate = _.wrap(self.update, function (update) {
+                return update.call(self);
+            });
 
             self.update = function () {
                 if (docModel.isAndroidTyping()) {
-                    self.executeDelayed(self.update, 1000, 'Text: android: update');
+                    self.executeDelayed(self.update, { delay: 1000, infoString: 'Text: android: update', app: app });
                 } else {
                     originalUpdate();
                 }
@@ -97,11 +110,31 @@ define('io.ox/office/presentation/app/controller', [
                 set: function (state) { docView.getSlidePane().toggle(state); }
             },
 
-            'document/editable/text': {
+            'document/slideexists': {
+                parent: 'app/valid',
+                enable: function () { return !docModel.isEmptySlideView(); }
+            },
+
+            'document/editable/slideexists': {
+                parent: 'document/editable',
+                enable: function () { return !docModel.isEmptySlideView(); }
+            },
+
+            'document/editable/text/format': { // used to set visibility of 'Format' top bar
                 parent: 'document/editable',
                 enable: function () { return docModel.isTextSelected() || docModel.getSelection().isAnyTextFrameDrawingSelection(); }
             },
 
+            'document/text': {
+                parent: 'document/slideexists',
+                enable: function () { return (docModel.isTextSelected() && !docModel.getSelection().isTopLevelTextCursor()) || docModel.getSelection().isAnyTextFrameDrawingSelection(); }
+            },
+
+            'document/editable/text': {
+                parent: 'document/editable/slideexists',
+                enable: function () { return (docModel.isTextSelected() && !docModel.getSelection().isTopLevelTextCursor()) || docModel.getSelection().isAnyTextFrameDrawingSelection(); }
+            },
+
             'document/editable/text/notextframe': {
                 parent: 'document/editable/text',
                 enable: function () {
@@ -184,10 +217,16 @@ define('io.ox/office/presentation/app/controller', [
             // Page settings
 
             'document/pagesettings': {
-                parent: 'document/editable/text',
+                parent: 'document/editable',
                 set: function () { return docView.showPageSettingsDialog(); }
             },
 
+            'document/present': {
+                parent: 'app/valid',
+                enable: function () { return Config.PRESENTER_AVAILABLE && !app.isDocumentEncrypted(); },
+                set: function () { return app.startPresenter(); }
+            },
+
             // paragraphs
 
             'paragraph/group': {
@@ -221,6 +260,33 @@ define('io.ox/office/presentation/app/controller', [
                     { keyCode: '2', ctrlOrMeta: true, value: LineHeight.DOUBLE }
                 ]*/
             },
+            'paragraph/spacing': {
+                parent: ['paragraph/attributes', 'insert/comment/supported/odf'],
+                get: function (attributes) { return ParagraphSpacing.helper.computeMultiplier(attributes, docModel); },
+                set: function (multiplier) {
+                    var marginBottom = ParagraphSpacing.helper.computeMarginBottom(multiplier, docModel);
+
+                    // bug 46249:  margin top needs to be considered when 'Paragraph spacing' is set to none in our GUI
+                    var marginTop = ParagraphSpacing.helper.getZeroSpaceMargin();
+                    docModel.setAttributes('paragraph', { paragraph: { marginTop: marginTop, marginBottom: marginBottom } });
+                }
+            },
+
+            'paragraph/explicit': {
+                parent: 'paragraph/attributes',
+                get: function () {
+                    // the selection object
+                    var selection = docModel.getSelection();
+                    // target for operation
+                    var target = docModel.getActiveTarget();
+                    // the paragraph node at the start position
+                    var paragraph = Position.getParagraphElement(docModel.getCurrentRootNode(target), _.initial(selection.getStartPosition()));
+                    // the explicit attributes
+                    var explicitAttrs = paragraph ? AttributeUtils.getExplicitAttributes(paragraph) : null;
+                    // the explicit paragraph attributes
+                    return explicitAttrs && explicitAttrs.paragraph ? explicitAttrs.paragraph : null;
+                }
+            },
 
             // parent for controller items only enabled inside lists
             'paragraph/list/enabled': {
@@ -252,14 +318,14 @@ define('io.ox/office/presentation/app/controller', [
             },
             // increase list level by one
             'paragraph/list/incindent': {
-                parent: 'paragraph/list/indent',
-                enable: function () { return docModel.isListIndentChangeable({ increase: true }); },
+                parent: ['paragraph/explicit', 'paragraph/list/indent'],
+                enable: function (paraAttrs) { return docModel.isListIndentChangeable(paraAttrs, { increase: true }); },
                 set: function () { docModel.changeListIndent({ increase: true, validatedLevel: true }); }
             },
             // decrease list level by one
             'paragraph/list/decindent': {
-                parent: 'paragraph/list/indent',
-                enable: function () { return docModel.isListIndentChangeable({ increase: false }); },
+                parent: ['paragraph/explicit', 'paragraph/list/indent'],
+                enable: function (paraAttrs) { return docModel.isListIndentChangeable(paraAttrs, { increase: false }); },
                 set: function () { docModel.changeListIndent({ increase: false, validatedLevel: true }); }
             },
             // slides
@@ -275,20 +341,25 @@ define('io.ox/office/presentation/app/controller', [
                 enable: function () { return docModel.isMasterView(); },
                 set: function () { docModel.insertLayoutSlide(); }
             },
+            'slide/duplicateslides': {
+                parent: 'document/editable',
+                enable: function () { return !docModel.isMasterSlideId(docModel.getActiveSlideId()) && !docModel.isEmptySlideView(); },
+                set: function () { docModel.duplicateSlides(); }
+            },
             'slide/deleteslide': {
                 parent: 'document/editable',
                 enable: function () { return docModel.isSlideSelectionDeletable(docModel.getSlidePaneSelection()); },
                 set: function () { docModel.deleteMultipleSlides(docModel.getSlidePaneSelection()); }
             },
             'slide/hideslide': {
-                parent: 'document/editable',
+                parent: 'document/editable/slideexists',
                 enable: function () { return !docModel.isMasterView() && !docModel.isHiddenSlide() && !docModel.isEmptySlideView(); },
-                set: function () { docModel.setHiddenSlide(true); }
+                set: function () { docModel.hideMultipleSlides(docModel.getSlidePaneSelection(), true); }
             },
             'slide/unhideslide': {
                 parent: 'document/editable',
                 enable: function () { return !docModel.isMasterView() &&  docModel.isHiddenSlide() && !docModel.isEmptySlideView(); },
-                set: function () { docModel.setHiddenSlide(false); }
+                set: function () { docModel.hideMultipleSlides(docModel.getSlidePaneSelection(), false); }
             },
             'slide/move': {
                 parent: 'document/editable',
@@ -302,13 +373,29 @@ define('io.ox/office/presentation/app/controller', [
                 enable: function () { return !docModel.isLastSlideActive(); },
                 set: function (selection) { docModel.moveSlectedSlidesOneStep({ downwards: true }, selection); }
             },
-
+            'slide/masternormalslide': {
+                parent: 'app/valid',
+                set: function () { docModel.selectSlideView({ showMaster: !docModel.isMasterView() }); }
+            },
+            'slide/activemasterslide': {
+                parent: 'app/valid',
+                get: function () { return docModel.isMasterView(); },
+                set: function () { docModel.selectSlideView({ showMaster: !docModel.isMasterView() }); }
+            },
+            'slide/setbackgroundimage': {
+                parent: 'debug/slideattributes',
+                set: function (dialogType) { return docModel.showInsertImageDialogForSlideBackground(dialogType); }
+            },
             // characters
 
             'character/group': {
                 parent: 'document/editable/text',
                 get: function () { return docModel.getAttributes('character', { maxIterations: 10 }) || {}; }
             },
+            'character/text/group': {
+                parent: 'document/text',
+                get: function () { return docModel.getAttributes('character', { maxIterations: 10 }) || {}; }
+            },
             'character/stylesheet': {
                 parent: 'character/group',
                 get: function (character) { return character.styleId; },
@@ -318,9 +405,20 @@ define('io.ox/office/presentation/app/controller', [
                 parent: 'character/group',
                 get: function (character) { return character.character || {}; }
             },
+            'character/text/attributes': {
+                parent: 'character/text/group',
+                get: function (character) { return character.character || {}; }
+            },
             'character/fontname': {
                 parent: 'character/attributes',
-                get: function (attributes) { return attributes.fontName; },
+                get: function (attributes) {
+                    var fontName = attributes.fontName;
+                    if (AttributeUtils.isCharacterFontThemed(attributes)) {
+                        var target = docModel.getTargetChainForNode(docModel.getSelection().getEnclosingParagraph());
+                        if (target) { fontName = docModel.getThemeCollection().getTheme('', target).getFontName(fontName); }
+                    }
+                    return fontName;
+                },
                 set: function (fontName) { docModel.setAttribute('character', 'fontName', fontName); }
             },
             'character/fontsize': {
@@ -353,8 +451,13 @@ define('io.ox/office/presentation/app/controller', [
             },
             'character/vertalign': {
                 parent: 'character/attributes',
-                get: function (attributes) { return attributes.vertAlign; },
-                set: function (align) { docModel.setAttribute('character', 'vertAlign', align); }
+                get: function (attributes) {
+                    return (attributes.baseline < 0) ? 'sub' : ((attributes.baseline > 0) ? 'super' : 'baseline');
+                },
+                set: function (align) {
+                    var baseline = (align === 'super') ? 30 : ((align === 'sub') ? -25 : 0);
+                    docModel.setAttribute('character', 'baseline', baseline);
+                }
             },
             'character/color': {
                 parent: ['character/attributes', 'insert/comment/odf/supported'],
@@ -368,12 +471,11 @@ define('io.ox/office/presentation/app/controller', [
             },
             'character/hyperlink': {
                 parent: 'character/attributes',
-                enable: function () { return docModel.hasEnclosingParagraph(); },
-                get: function (attributes) { return attributes.url; }
+                get: function (attributes) { return attributes && attributes.url; }
                 // no direct setter (see item 'character/hyperlink/dialog')
             },
             'character/hyperlink/dialog': {
-                parent: 'character/hyperlink',
+                parent: ['document/editable/slideexists'],
                 get: function () { return Hyperlink.hasPopup(docModel); },
                 set: function () { return docModel.insertHyperlinkDialog(); }
                 // removed for the 7.2.0 due to clashes with browser shortcuts
@@ -385,7 +487,7 @@ define('io.ox/office/presentation/app/controller', [
             },
 
             'character/hyperlink/valid': {
-                parent: 'character/attributes',
+                parent: 'character/text/attributes',
                 enable: function (attrs) { return attrs.url && HyperlinkUtils.hasSupportedProtocol(attrs.url) && HyperlinkUtils.isValidURL(attrs.url); }
             },
 
@@ -437,44 +539,57 @@ define('io.ox/office/presentation/app/controller', [
             // tables
 
             'table/group': {
-                parent: 'document/editable/text',
+                parent: 'document/editable/slideexists',
+                enable: function () {
+                    var drawing = docModel.getSelection().getSelectedDrawing();
+                    if (drawing && drawing.attr('data-type') === 'table') { return true; }
+                    if (docModel.isPositionInTable()) { return true; }
+                },
                 get: function () { return docModel.getAttributes('table') || {}; }
             },
             'table/insert/available': {
                 enable: function () { return Config.MAX_TABLE_CELLS > 0; }
             },
+
             'table/insert': {
-                parent: ['document/editable/text', 'table/insert/available', 'insert/textframe/supported', 'insert/comment/odf/supported'],
-                set: function (size) { docModel.insertTextFrame({ insertTable: true, size: size }); },
+                parent: ['document/editable/slideexists', 'table/insert/available'],
+                set: function (size) {
+                    // special ios behavior
+                    if (docModel.getSlideTouchMode()) {
+                        docModel.insertTextFrame({ insertTable: true, size: size, selectDrawingOnly: true  });
+                    } else {
+                        // normal
+                        docModel.insertTextFrame({ insertTable: true, size: size });
+                    }
+                },
                 preserveFocus: true // do not return focus to document
             },
 
             'document/editable/table': {
+                parent: 'table/group'
+            },
+            'document/editable/insidetable': {
                 parent: 'table/group',
                 enable: function () { return docModel.isPositionInTable(); }
             },
-            'document/show/tabletab': {
-                parent: 'document/editable/table',
-                enable: function () { return docModel.isCellRangeSelected() || (!docModel.isCellRangeSelected() && !docModel.hasSelectedRange()); }
-            },
             'table/delete': {
                 parent: 'document/editable/table',
                 set: function () { return docModel.deleteTable(); }
             },
             'table/insert/row': {
-                parent: 'document/editable/table',
+                parent: 'document/editable/insidetable',
                 set: function () { docModel.insertRow(); }
             },
             'table/insert/column': {
-                parent: 'document/editable/table',
+                parent: 'document/editable/insidetable',
                 set: function () { docModel.insertColumn(); }
             },
             'table/delete/row': {
-                parent: 'document/editable/table',
+                parent: 'document/editable/insidetable',
                 set: function () { return docModel.deleteRows(); }
             },
             'table/delete/column': {
-                parent: 'document/editable/table',
+                parent: 'document/editable/insidetable',
                 set: function () { return docModel.deleteColumns(); }
             },
 
@@ -489,19 +604,23 @@ define('io.ox/office/presentation/app/controller', [
             },
             'table/cellattributes': {
                 parent: 'document/editable/table',
-                get: function () { return docModel.getAttributes('cell').cell || {}; }
+                get: function () {
+                    return docModel.getAttributes('cell').cell || {};
+                }
             },
             'table/cellborder': {
                 parent: 'table/attributes',
                 get: function (attributes) { return MixedBorder.getBorderMode(attributes); },
                 set: function (borderMode) {
-                    var borderAttrs = MixedBorder.getBorderAttributes(borderMode, this.getParentValue(), ParagraphStyles.SINGLE_BORDER);
+                    var borderAttrs = MixedBorder.getBorderAttributes(borderMode, this.getParentValue(), ParagraphStyles.SINGLE_BORDER, { fullBorderSet: true });
                     docModel.setAttributes('table', { table: borderAttrs }, { cellSpecificTableAttribute: true });
                 }
             },
             'table/borderwidth': {
                 parent: 'table/cellattributes',
-                get: function (attributes) { return TableStyles.getBorderStyleFromAttributes(attributes); },
+                get: function (attributes) {
+                    return TableStyles.getBorderStyleFromAttributes(attributes);
+                },
                 set: function (borderWidth) {
                     docModel.setAttributes('table', {
                         table: TableStyles.getAttributesFromBorderStyle(borderWidth, docModel.getAttributes('table').table)
@@ -513,10 +632,6 @@ define('io.ox/office/presentation/app/controller', [
                 get: function (attributes) { return attributes.fillColor; },
                 set: function (color) { docModel.setAttribute('cell', 'fillColor', color); }
             },
-            'table/split': {
-                parent: 'document/editable/table',
-                set: function () { docModel.splitTable(); }
-            },
 
             // drawing
 
@@ -528,6 +643,14 @@ define('io.ox/office/presentation/app/controller', [
                 parent: 'document/editable',
                 enable: function () { return docModel.getSelection().isAnyDrawingSelection(); }
             },
+            'document/editable/anydrawingexcepttable': {
+                parent: 'document/editable',
+                enable: function () { return docModel.getSelection().isAnyDrawingSelectionExceptTable(); }
+            },
+            'document/editable/anydrawingexceptsingletable': {
+                parent: 'document/editable',
+                enable: function () { return docModel.getSelection().isAnyDrawingSelectionExceptTable() || docModel.getSelection().isMultiSelection(); }
+            },
             'document/editable/onlysupporteddrawings': {
                 parent: 'document/editable',
                 enable: function () { return docModel.getSelection().areOnlySupportedDrawingsSelected(); }
@@ -548,7 +671,7 @@ define('io.ox/office/presentation/app/controller', [
             },
 
             'drawing/attributes/full': {
-                parent: 'document/editable/anydrawing',
+                parent: 'document/editable/anydrawingexcepttable',
                 get: function () { return docModel.getAttributes('drawing') || {}; }
             },
 
@@ -587,20 +710,23 @@ define('io.ox/office/presentation/app/controller', [
                 enable: function () { return docModel.getSelection().isAnyTextFrameSelection({ allDrawingTypesAllowed: true }); }
             },
 
-            'drawing/textframeautofit': {
-                parent: ['drawing/anydrawing'],
-                get: function () { return docModel.isAutoResizableTextFrame(); },
-                set: function (autoResizeHeight) { docModel.handleTextFrameAutoFit(autoResizeHeight, autoResizeHeight ? false : undefined); }
+            'drawing/anydrawingexcepttable': {
+                enable: function () { return docModel.getSelection().isAnyDrawingSelectionExceptTable(); }
             },
 
-            'drawing/textframeautotextheight': {
-                parent: ['drawing/anydrawing'],
-                get: function () { return docModel.isAutoTextHeightTextFrame() && !docModel.isAutoResizableTextFrame(); },
-                set: function (autoResizeText) { docModel.handleTextFrameAutoFit(autoResizeText ? false : undefined, autoResizeText); }
+            'drawing/notsingledrawing': {
+                parent: 'document/editable/anydrawing',
+                enable: function () { return docModel.getSelection().isUngroupableSelection() || !docModel.getSelection().getClosestSelectedDrawingType(); }
+            },
+
+            'drawing/textframeautofit': {
+                parent: ['drawing/anydrawing', 'drawing/anydrawingexcepttable'],
+                get: function () { return docModel.isAutoResizableTextFrame() ? 'autofit' : (docModel.isAutoTextHeightTextFrame() ? 'autotextheight' : 'noautofit'); },
+                set: function (fitState) { docModel.handleTextFrameAutoFit(fitState === 'autofit', fitState === 'autotextheight'); }
             },
 
             'drawing/lockratio': {
-                enable: function () { return docModel.getSelection().isAnyDrawingSelection() || (docModel.getSelection().isMultiSelectionSupported() && docModel.getSelection().isMultiSelection()); },
+                enable: function () { return docModel.getSelection().isAnyDrawingSelectionExceptTable() || (docModel.getSelection().isMultiSelectionSupported() && docModel.getSelection().isMultiSelectionWithoutTable()); },
                 get: function () { return docModel.isLockedRatioDrawing(); },
                 set: function (state) { docModel.handleDrawingLockRatio(state); }
             },
@@ -666,6 +792,11 @@ define('io.ox/office/presentation/app/controller', [
                 set: function (value) { docModel.changeDrawingOrder(value); }
             },
 
+            'drawing/rotate': {
+                enable: function () { return docModel.getSelection().isAnyDrawingSelectionExceptTable(); },
+                set: function (value) { docModel.rotateFlipDrawing(value); }
+            },
+
             // drawing/s alignment
 
             'drawing/align': {
@@ -673,14 +804,26 @@ define('io.ox/office/presentation/app/controller', [
                 set: function (position) { docModel.changeAlignment(position); }
             },
 
+            'drawing/distribute': {
+                enable: function () { return docModel.getSelection().isAnyDrawingSelection(); },
+                set: function (mode) { docModel.distributeDrawings(mode); }
+            },
+
+            'drawing/distributeamong': {
+                enable: function () { return docModel.getSelection().isMultiSelection() && docModel.getSelection().getMultiSelection().length > 2; },
+                set: function (mode) { docModel.distributeDrawings(mode); }
+            },
+
             // text frames
 
             'textframe/insert': {
-                parent: ['document/editable', 'insert/comment/odf/supported'],
+                parent: ['document/editable/slideexists'],
                 get: function () { return docModel.isInsertTextFrameActive(); },
                 set: function (value, inputOptions) {
                     if (Utils.getStringOption(inputOptions, 'sourceType') === 'keyboard') {
                         return docModel.insertTextFrameWithDefaultBox();
+                    } else if (docModel.getSlideTouchMode()) {
+                        return docModel.insertTextFrameWithDefaultBox({ selectDrawingOnly: true });
                     } else {
                         return docModel.insertTextFramePreparation();
                     }
@@ -728,16 +871,18 @@ define('io.ox/office/presentation/app/controller', [
             // images
 
             'image/insert/dialog': {
-                parent: ['insert/textframe/supported', 'insert/comment/odf/supported'],
+                parent: ['document/editable/slideexists'],
                 set: function (dialogType) { return docModel.showInsertImageDialog(dialogType); }
             },
 
             'shape/insert': {
-                parent: ['document/editable'],
+                parent: ['document/editable/slideexists'],
                 get: function () { return docModel.isInsertShapeActive(); },
                 set: function (presetShape, inputOptions) {
                     if (Utils.getStringOption(inputOptions, 'sourceType') === 'keyboard') {
                         return docModel.insertShapeWithDefaultBox(presetShape);
+                    } else if (docModel.getSlideTouchMode()) {
+                        return docModel.insertShapeWithDefaultBox(presetShape, { selectDrawingOnly: true });
                     } else {
                         return docModel.insertShapePreparation(presetShape);
                     }
@@ -781,12 +926,19 @@ define('io.ox/office/presentation/app/controller', [
                     return docModel.getLayoutSlideId(docModel.getActiveSlideId());
                 },
                 set: function (slideId) {
-                  //Utils.info('+++ slide/changelayout +++ slideId : ', slideId);
-
-                    docModel.changeLayout(slideId);
+                    docModel.changeLayoutForMultipleSlides(slideId, docModel.getSlidePaneSelection());
                 }
             },
 
+            'slide/setbackground': {
+                parent: 'document/editable/slideexists',
+                set: function () { docView.openSlideBackgroundDialog(); }
+            },
+            'slide/resetbackground': {
+                enable: function () { return docModel.isSlideWithExplicitBackground(); },
+                set: function () { docModel.resetBackground(); }
+            },
+
             'debug/recordoperations': {
                 get: function () { return docModel.isRecordingOperations(); },
                 set: function (state) { docModel.setRecordingOperations(state); }
@@ -806,32 +958,31 @@ define('io.ox/office/presentation/app/controller', [
                 enable: function () { return !docModel.isMasterView(); },
                 set: function () { docModel.insertSlide(); }
             },
+            'debug/slideattributes': {
+                parent: 'document/editable/slideexists',
+                get: function () { return docModel.getAllFamilySlideAttributes(); }
+            },
+            'debug/hiddenslide': {
+                parent: 'document/editable/slideexists',
+                enable: function () { return !docModel.isMasterView(); },
+                get: function () { return docModel.isHiddenSlide(); },
+                set: function () { docModel.hideMultipleSlides(docModel.getSlidePaneSelection(), !docModel.isHiddenSlide()); }
+            },
             'debug/followmastershapes': {
+                parent: 'document/editable/slideexists',
                 enable: function () { return !docModel.isMasterSlideId(docModel.getActiveSlideId()); },
                 get: function () { return docModel.isFollowMasterShapeSlide(); },
                 set: function () { docModel.setFollowMasterShape(!docModel.isFollowMasterShapeSlide()); }
             },
-            'debug/hiddenslide': {
-                enable: function () { return !docModel.isMasterView(); },
-                get: function () { return docModel.isHiddenSlide(); },
-                set: function () { docModel.setHiddenSlide(!docModel.isHiddenSlide()); }
-            },
-            'debug/resetbackground': {
-                enable: function () { return docModel.isSlideWithBackground(); },
-                set: function () { docModel.resetBackground(); }
-            },
-            'debug/slideattributes': {
-                get: function () { return docModel.getAllFamilySlideAttributes(); }
-            },
             'debug/setbackgroundcolor': {
-                parent: ['debug/slideattributes'],
+                parent: 'debug/slideattributes',
                 get: function (attrs) { return attrs && attrs.fill && attrs.fill.color ? attrs.fill.color : undefined; },
                 set: function (color) { docModel.setBackgroundColor(color); }
             },
             'debug/setbackgroundimage': {
-                parent: ['debug/slideattributes'],
+                parent: 'debug/slideattributes',
                 get: function (attrs) { return attrs && attrs.fill && attrs.fill.color; },
-                set: function (dialogType) { return docModel.showInsertImageDialogForSlideBackground(dialogType); }
+                set: function (dialogType) { return docModel.showInsertImageDialogForSlideBackgroundDebug(dialogType); }
             },
             'debug/normalslideview': {
                 enable: function () { return docModel.isMasterView(); },
@@ -881,19 +1032,19 @@ define('io.ox/office/presentation/app/controller', [
                 set: function () { docModel.getFieldManager().removeField(); }
             },
             'document/insertfooter': {
-                parent: 'document/editable/text',
+                parent: 'document/editable/slideexists',
                 set: function () { docModel.getFieldManager().openFooterDialog(); }
             },
             'document/insertfield': {
-                parent: 'document/editable/text',
+                parent: 'document/editable/slideexists',
                 set: function (value) { docModel.getFieldManager().dispatchInsertField(value); }
             },
             insertSlideNumber: {
-                parent: 'document/editable',
+                parent: 'document/editable/slideexists',
                 set: function () { docModel.getFieldManager().dispatchInsertField('slidenum'); }
             },
             insertDateTime: {
-                parent: 'document/editable',
+                parent: 'document/editable/slideexists',
                 set: function () { docModel.getFieldManager().dispatchInsertField('datetime'); }
             },
             'document/formatfield': {
