@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Miroslav Dzunic <miroslav.dzunic@open-xchange.com>
  */
@@ -144,8 +145,8 @@ define('io.ox/office/presentation/components/field/slidefield', [
          */
         function createDateFromType(fieldType, date) {
 
-            var formatIndexStr = fieldType && fieldType.match(/\d+/) && fieldType.match(/\d+/)[0] || null;
-            var formatIndex = formatIndexStr && parseInt(formatIndexStr, 10) ||  null;
+            var formatIndexStr = (fieldType && fieldType.match(/\d+/) && fieldType.match(/\d+/)[0]) || null;
+            var formatIndex = (formatIndexStr && parseInt(formatIndexStr, 10)) || null;
             var localFormat = formatIndex  && localFormatList.date[formatIndex - 1] && localFormatList.date[formatIndex - 1].option;
             var formatCode = localFormat ? localFormat : LocaleData.SHORT_DATE;
             var parsedFormat = numberFormatter.getParsedFormat(formatCode);
@@ -169,6 +170,7 @@ define('io.ox/office/presentation/components/field/slidefield', [
          */
         function checkHighlighting(event, options) {
             var isSimpleTextSelection = Utils.getBooleanOption(options, 'simpleTextSelection', false),
+                isSlideSelection = Utils.getBooleanOption(options, 'slideSelection', false),
                 domPos = null,
                 node = null,
                 atEndOfSpan = null,
@@ -177,7 +179,7 @@ define('io.ox/office/presentation/components/field/slidefield', [
                 mouseTouchEvent = _.isObject(browserEvent) && _.contains(relevantEvents, browserEvent.type),
                 rightClick = _.isObject(browserEvent) && (browserEvent.type === 'mousedown') && (browserEvent.button === 2);
 
-            if (self.isEmpty() || isSimpleTextSelection || selection.hasRange()) {
+            if (self.isEmpty() || (isSimpleTextSelection && !isSlideSelection) || selection.hasRange()) {
                 return;
             } else {
                 domPos = Position.getDOMPosition(selection.getRootNode(), selection.getStartPosition());
@@ -225,9 +227,9 @@ define('io.ox/office/presentation/components/field/slidefield', [
             var node,
                 domPos,
                 atEndOfSpan,
-                fieldValue = options && options.value || null,
-                fieldFormat = options && options.format || null,
-                standardizedDate = options && options.standard || null;
+                fieldValue = (options && options.value) || null,
+                fieldFormat = (options && options.format) || null,
+                standardizedDate = (options && options.standard) || null;
 
             if (!fieldValue) {
                 if (!fieldFormat) { return; } // no data to update, exit
@@ -329,19 +331,19 @@ define('io.ox/office/presentation/components/field/slidefield', [
                 slideAttrs = slideAttrs && slideAttrs.slide;
                 if (slideAttrs) {
                     if (slideAttrs.isFooter) {
-                        ftr = drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(activeSlideId, 'ftr', 0);
+                        ftr = drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(activeSlideId, 'ftr');
                     }
                     if (slideAttrs.isSlideNum) {
-                        sldNum = drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(activeSlideId, 'sldNum', 0);
+                        sldNum = drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(activeSlideId, 'sldNum');
                     }
                     if (slideAttrs.isDate) {
-                        dt = drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(activeSlideId, 'dt', 0);
+                        dt = drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(activeSlideId, 'dt');
                     }
                 }
             } else {
-                ftr = drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(activeSlideId, 'ftr', 0);
-                sldNum = drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(activeSlideId, 'sldNum', 0);
-                dt = drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(activeSlideId, 'dt', 0);
+                ftr = drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(activeSlideId, 'ftr');
+                sldNum = drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(activeSlideId, 'sldNum');
+                dt = drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(activeSlideId, 'dt');
             }
 
             if (sldNum && sldNum.length) { options.push({ type: 'sldNum' }); }
@@ -388,7 +390,7 @@ define('io.ox/office/presentation/components/field/slidefield', [
             var deleteOperations = [];
             var operation = null;
             _.each(deleteOptions, function (option) {
-                var slideDrawing = drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(currentSlideId, option.type, 0);
+                var slideDrawing = drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(currentSlideId, option.type);
 
                 if (slideDrawing.length) {
                     operation = { start: Position.getOxoPosition(model.getNode(), slideDrawing) };
@@ -515,7 +517,7 @@ define('io.ox/office/presentation/components/field/slidefield', [
          */
         this.getSimpleField = function (id) {
             var fieldObj = _.findWhere(allFields, { fid: id });
-            return fieldObj && fieldObj.node || null;
+            return (fieldObj && fieldObj.node) || null;
         };
 
         /**
@@ -623,7 +625,7 @@ define('io.ox/office/presentation/components/field/slidefield', [
             if (highlightedFieldType && isSupportedFormat && isMouseTouchEvent && !isRightClick && isNotChangeTracked) {
                 fieldFormatPopupTimeout = self.executeDelayed(function () {
                     app.getView().showFieldFormatPopup(fieldinstruction, node, options);
-                }, 500, 'Presentation: SlideField: fieldFormatPopupTimeout');
+                }, { delay: 500, infoString: 'Presentation: SlideField: fieldFormatPopupTimeout', app: app });
             }
 
             // for debugging ->
@@ -757,7 +759,7 @@ define('io.ox/office/presentation/components/field/slidefield', [
                 });
 
                 // iterate objects
-                generateDef = self.iterateObjectSliced(self.getAllFields(), handleFieldUpdate, { delay: 'immediate', infoString: 'Text: handleFieldUpdate' })
+                generateDef = self.iterateObjectSliced(self.getAllFields(), handleFieldUpdate, { delay: 'immediate', infoString: 'Text: handleFieldUpdate', app: app })
                 .always(function () {
                     // leave busy state
                     app.getView().leaveBusy().grabFocus();
@@ -1143,9 +1145,9 @@ define('io.ox/office/presentation/components/field/slidefield', [
                     var fieldPos = null;
                     var fieldType = opt.type;
                     var layoutId = model.getLayoutSlideId(currentSlideId);
-                    var layoutDrawing = layoutId && drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(layoutId, fieldType, 0);
+                    var layoutDrawing = layoutId && drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(layoutId, fieldType);
                     var elementAttrs = layoutDrawing && layoutDrawing.length && AttributeUtils.getExplicitAttributes(layoutDrawing); // getElementAttributes is not necessary
-                    var slideDrawing = drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(currentSlideId, fieldType, 0);
+                    var slideDrawing = drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(currentSlideId, fieldType);
                     var slideDrawingContent = null;
                     var len = null;
 
@@ -1328,9 +1330,9 @@ define('io.ox/office/presentation/components/field/slidefield', [
                     var fieldPos = null;
                     var fieldType = opt.type;
                     var slideLayoutId = model.getLayoutSlideId(currentSlideId);
-                    var layoutDrawing = slideLayoutId && drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(slideLayoutId, fieldType, 0);
+                    var layoutDrawing = slideLayoutId && drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(slideLayoutId, fieldType);
                     var elementAttrs = layoutDrawing && layoutDrawing.length && AttributeUtils.getExplicitAttributes(layoutDrawing);
-                    var slideDrawing = drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(currentSlideId, fieldType, 0);
+                    var slideDrawing = drawingStyles.getAllPlaceHolderDrawingsOnSlideBySelector(currentSlideId, fieldType);
                     var slideDrawingContent = null;
                     var len = null;
 
