@@ -6,9 +6,10 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
- * @author Daniel Rentz <daniel.rentz@open-xchange.com>
+ * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
 
 define('io.ox/office/presentation/format/paragraphstyles', [
@@ -19,8 +20,9 @@ define('io.ox/office/presentation/format/paragraphstyles', [
     'io.ox/office/editframework/utils/border',
     'io.ox/office/editframework/utils/lineheight',
     'io.ox/office/editframework/model/stylecollection',
-    'io.ox/office/textframework/utils/dom'
-], function (PresentationUtils, Utils, AttributeUtils, Color, Border, LineHeight, StyleCollection, DOM) {
+    'io.ox/office/textframework/utils/dom',
+    'io.ox/office/drawinglayer/view/drawingframe'
+], function (PresentationUtils, Utils, AttributeUtils, Color, Border, LineHeight, StyleCollection, DOM, DrawingFrame) {
 
     'use strict';
 
@@ -30,7 +32,27 @@ define('io.ox/office/presentation/format/paragraphstyles', [
             alignment: {
                 def: 'left',
                 format: function (element, value) {
-                    element.css('text-align', value);
+                    var drawingNode = element.closest(DrawingFrame.NODE_SELECTOR);
+                    var alignSelfVal = '';
+
+                    // #49446
+                    if (DrawingFrame.isNoWordWrapDrawingFrame(drawingNode) && !DrawingFrame.isAutoResizeHeightDrawingFrame(drawingNode)) {
+                        switch (value) {
+                            case 'center':
+                                alignSelfVal = value;
+                                break;
+                            case 'left':
+                                alignSelfVal = 'flex-start';
+                                break;
+                            case 'right':
+                                alignSelfVal = 'flex-end';
+                                break;
+                            case 'justify':
+                                alignSelfVal = 'stretch';
+                                break;
+                        }
+                    }
+                    element.css({ textAlign: value, alignSelf: alignSelfVal });
                 },
                 preview: true // 'true' calls the own 'format' method
             },
@@ -58,7 +80,8 @@ define('io.ox/office/presentation/format/paragraphstyles', [
              * span with a font size of 6pt, resulting in a relative line
              * height of 24pt/6pt = 400% instead of the expected 200%.
              */
-            lineHeight: { def: LineHeight.SINGLE },
+            lineHeight: { def: LineHeight._115 },
+            // workaround for Bug 47960 & Bug 45951, lineHeight in powerpoint is based on "baseline" instead of "fontsize"
 
             listLabelHidden: { def: false },
 
@@ -131,7 +154,7 @@ define('io.ox/office/presentation/format/paragraphstyles', [
 
             bulletSize: { def: { type: 'followText', size: 0 } },
 
-            defaultTabSize: { def: 0 },
+            defaultTabSize: { def: 2540 }, // default in presentation app: one inch (47964)
 
             spacingBefore: { def: 0 },
 
@@ -156,9 +179,10 @@ define('io.ox/office/presentation/format/paragraphstyles', [
             Border.isVisibleBorder(attributes1.borderTop) ||
             Border.isVisibleBorder(attributes1.borderBottom) ||
             Border.isVisibleBorder(attributes1.borderInside)) &&
-            Utils.hasEqualProperties(attributes1, attributes2,
-                ['borderLeft', 'borderRight', 'borderTop', 'borderBottom', 'borderInside',
-                 'listStyleId', 'listLevel', 'indentLeft', 'indentRight', 'indentFirstLine']);
+            Utils.hasEqualProperties(attributes1, attributes2, [
+                'borderLeft', 'borderRight', 'borderTop', 'borderBottom', 'borderInside',
+                'listStyleId', 'listLevel', 'indentLeft', 'indentRight', 'indentFirstLine'
+            ]);
     }
 
     /**
@@ -279,8 +303,7 @@ define('io.ox/office/presentation/format/paragraphstyles', [
                 indentFirstLine = mergedAttributes.paragraph.indentFirstLine,
                 // intersect function
                 intersect = function (xs1, xe1, xs2, xe2) {
-                    return ((xs1 <= xs2) && (xe1 >= xs2) ||
-                             (xs2 <= xs1) && (xe2 >= xs1));
+                    return ((xs1 <= xs2) && (xe1 >= xs2)) || ((xs2 <= xs1) && (xe2 >= xs1));
                 },
                 // active paragraph tab stops
                 activeParaTabStops = null,
@@ -604,8 +627,10 @@ define('io.ox/office/presentation/format/paragraphstyles', [
                 nextAttributes = (nextParagraph.length > 0) ? self.getElementAttributes(nextParagraph) : { paragraph: {} },
                 collectedAttrs =  {},
                 prevCollectedAttrs =  {},
-                textIndent = 0;
-//                explicitParaAttributes = null;
+                textIndent = 0,
+                // target for targetChain for themes
+                target;
+                // explicitParaAttributes = null;
 
             function setBorder(border, position, addSpace, para) {
                 var space = addSpace + ((border && border.space) ? border.space : 0),
@@ -628,13 +653,33 @@ define('io.ox/office/presentation/format/paragraphstyles', [
                 return -space;
             }
 
-            function calcSpacingHmm(space) {
-                var lineHeight = characterStyles.calculateLineHeight(space, mergedAttributes.character);
-                if (lineHeight.type === 'px') {
-                    return Utils.convertLengthToHmm(lineHeight.val, 'px');
+            function calcSpacingHmm(lineHeight) {
+                // fix for Bug 48442
+                if (!lineHeight.value) { return 0; }
+
+                var height = 0;
+                var fontHeight = Utils.convertLength(mergedAttributes.character.fontSize, 'pt', 'px');
+
+                if (lineHeight.type === 'fixed') {
+                    height = Utils.convertHmmToLength(lineHeight.value, 'px');
+                } else if (lineHeight.type === 'percent') {
+                    height = fontHeight * lineHeight.value / 100;
                 } else {
-                    return Utils.convertLengthToHmm((lineHeight.val / 100) * mergedAttributes.character.fontSize, 'pt');
+                    Utils.warn('ParagraphStyles.calcSpacingHmm(): invalid line height type', lineHeight.type);
+                    return 0;
                 }
+                // workaround for bug 47960 & Bug 48476
+                var fontCollection = docModel.getFontCollection();
+                var options = { zoom: 10 };
+
+                if (!target && docModel.useSlideMode() && AttributeUtils.isCharacterFontThemed(mergedAttributes.character)) { target = docModel.getTargetChainForNode(paragraph); }
+                if (target) { options.theme = docModel.getThemeCollection().getTheme('', target); }
+
+                var normalLineHeight = fontCollection.getNormalLineHeight(mergedAttributes.character, options) / 10;
+                height -= (normalLineHeight - fontHeight);
+                height = Math.max(0, height);
+                return Utils.convertLengthToHmm(height, 'px');
+
             }
 
             // Always update character formatting of all child nodes which may
@@ -790,7 +835,7 @@ define('io.ox/office/presentation/format/paragraphstyles', [
                 bottomMargin = 0;
             }
 
-            if (paragraphAttributes.spacingBefore && prevParagraph.length) {
+            if (paragraphAttributes.spacingBefore) {
                 topMargin += calcSpacingHmm(paragraphAttributes.spacingBefore);
             }
             if (paragraphAttributes.spacingAfter && nextParagraph.length) {
@@ -897,8 +942,9 @@ define('io.ox/office/presentation/format/paragraphstyles', [
             var // the default attributes for a specified level
                 defaultAttrs = docModel.getDefaultTextListStylesForLevel(paraLevel),
                 // the hard list style attributes at the drawing (45279)
-                explicitDrawingAttrs = docModel.getDrawingStyles().getDrawingListStyleAttributes(drawing);
-                // explicitDrawingAttrs = AttributeUtils.getExplicitAttributes(drawing);
+                explicitDrawingAttrs = docModel.getDrawingStyles().getDrawingListStyleAttributes(drawing),
+                // the explicit character attributes at the drawing
+                explicitCharAttributes = null;
 
             defaultAttrs = docModel.extendAttributes({}, defaultAttrs);
 
@@ -906,6 +952,13 @@ define('io.ox/office/presentation/format/paragraphstyles', [
                 defaultAttrs = docModel.extendAttributes(defaultAttrs, explicitDrawingAttrs[paraLevel]);
             }
 
+            // also checking explicit character attributes at the drawing
+            explicitCharAttributes = AttributeUtils.getExplicitAttributes(drawing, { family: 'character' });
+
+            if (explicitCharAttributes && !_.isEmpty(explicitCharAttributes)) {
+                defaultAttrs = docModel.extendAttributes(defaultAttrs, { character: explicitCharAttributes });
+            }
+
             return defaultAttrs;
         }
 
@@ -1015,6 +1068,57 @@ define('io.ox/office/presentation/format/paragraphstyles', [
             return attributes;
         }
 
+        /**
+         * A helper function to set the valid paragraph and character attributes to paragraphs
+         * inside tables.
+         *
+         * @param {Object} attributes
+         *  The attribute set specified for the given paragraph. For paragraphs inside tables this
+         *  already includes the table specific attributes. This makes it difficult in this case,
+         *  because the table specific attributes must not be overwritten in this step.
+         *
+         * @param {Object} placeHolderAttributes
+         *  The collection of attributes that are collected in the function 'addLayoutAttributes'.
+         *  For paragraphs inside tables this are the 'other' attributes specified on the master
+         *  slide for place holder drawings.
+         */
+        function handleParagraphInTableAttributes(attributes, placeHolderAttributes) {
+
+            // Some attributes are inherited from the table style and must not be overwritten, for
+            // example font color, that is dependent from the position inside the table.
+            // But other attributes are not inherited and also the default value should not be used.
+            // This is the case for the font size, where the default of 11pt is too small. But the
+            // default font color must not overwrite the value specified by the table style.
+            // Unfortunately it is not clear at this point, which attributes are inherited from the
+            // table and which are the default values.
+            //
+            // -> Removing those values from the place holder attributes, for that the given attributes
+            //    are NOT the default values
+
+            var allFamilies = null;
+            var allDefaultAttributes = null;
+
+            if (placeHolderAttributes && attributes) {
+
+                allFamilies = _.keys(placeHolderAttributes);
+                allDefaultAttributes = docModel.getDefaultAttributeSet(allFamilies);
+
+                _.each(allFamilies, function (family) {
+
+                    var placeHolderAttrsFamily = placeHolderAttributes[family];
+
+                    if (attributes[family]) {
+                        // iterating over all place holder attributes and check if the given attribute set uses the default value
+                        _.each(_.keys(placeHolderAttrsFamily), function (attr) {
+                            if (!_.isEqual(attributes[family][attr], allDefaultAttributes[family][attr])) {
+                                delete placeHolderAttrsFamily[attr]; // -> not overwriting specified non-default value
+                            }
+                        });
+                    }
+                });
+            }
+        }
+
         /**
          * Adding attributes of master and layout slide into the merge attributes. This has to happen
          * before the explicit attributes are set into the specified attribute set.
@@ -1022,7 +1126,7 @@ define('io.ox/office/presentation/format/paragraphstyles', [
          * @param {jQuery} element
          *  The node whose attributes have been changed, as jQuery object.
          *
-         * @param {Object} mergedAttributes
+         * @param {Object} attributes
          *  A map of attribute maps (name/value pairs), keyed by attribute family, containing the
          *  effective attribute values merged from style sheets, but without explicit attributes.
          */
@@ -1039,7 +1143,9 @@ define('io.ox/office/presentation/format/paragraphstyles', [
                 // the explicit drawing attributes
                 drawingAttrs = null,
                 // the paragraph level attribute
-                paraLevel = 0;
+                paraLevel = 0,
+                // whether the paragraph is inside a table (attributes can be defined at table, never overwrite)
+                insideTable = DOM.isCellContentNode(paragraph.parent());
 
             // check, if the drawing, containing the paragraph, is a 'placeholder' drawing
             if (drawing.length > 0) { drawingAttrs = AttributeUtils.getExplicitAttributes(drawing, { direct: true }); }
@@ -1047,7 +1153,7 @@ define('io.ox/office/presentation/format/paragraphstyles', [
             paraLevel = self.getParagraphLevel(paragraph);
             paraLevel = self.generateKeyFromLevel(paraLevel);
 
-            if (PresentationUtils.isPlaceHolderAttributeSet(drawingAttrs)) {
+            if (PresentationUtils.isPlaceHolderAttributeSet(drawingAttrs) && !insideTable) { // place holder, but not in table
 
                 id = DOM.getTargetContainerId(drawing.parent()); // checking only direct children of slide
                 placeHolderType = drawingAttrs.presentation.phType;
@@ -1066,6 +1172,22 @@ define('io.ox/office/presentation/format/paragraphstyles', [
                 } else if (docModel.isMasterSlideId(id)) {
                     placeHolderAttributes = getMergedPlaceHolderAttributes(null, id, placeHolderType, placeHolderIndex, paraLevel);
                 }
+            } else if (insideTable) {
+
+                id = DOM.getTargetContainerId(drawing.parent()); // checking only direct children of slide
+                masterId = docModel.getCorrespondingMasterSlideId(id);
+                // using the 'other' attributes from master slide
+                placeHolderAttributes = docModel.getListStylesAttributesOfSlide(masterId, docModel.getDefaultPlaceHolderListStyleType());
+
+                if (placeHolderAttributes && placeHolderAttributes[paraLevel]) {
+                    placeHolderAttributes = placeHolderAttributes[paraLevel];
+                } else {
+                    placeHolderAttributes = getMergedNonPlaceHolderAttributes(drawing, paraLevel); // fallback to non-placeholder default attributes
+                }
+
+                // merge handling for paragraphs inside tables
+                handleParagraphInTableAttributes(attributes, placeHolderAttributes);
+
             } else {
 
                 // using the default text list styles
@@ -1112,7 +1234,7 @@ define('io.ox/office/presentation/format/paragraphstyles', [
             var // the explicit attributes at a paragraph
                 paraAttrs = AttributeUtils.getExplicitAttributes(paragraph, { direct: true });
 
-            return paraAttrs && paraAttrs.paragraph && paraAttrs.paragraph.level || 0;
+            return (paraAttrs && paraAttrs.paragraph && paraAttrs.paragraph.level) || 0;
         };
 
         /**
@@ -1203,10 +1325,12 @@ define('io.ox/office/presentation/format/paragraphstyles', [
 
     /**
      * Default solid border line for paragraphs and tables.
+     * 'auto' is not supported in Presentation app.
+     * The 'fallbackValue' is specified for ODF.
      *
      * @constant
      */
-    ParagraphStyles.SINGLE_BORDER = { style: 'single', width: 17, space: 140, color: Color.AUTO };
+    ParagraphStyles.SINGLE_BORDER = { style: 'single', width: 17, space: 140, color: { type: 'scheme', value: 'text1', fallbackValue: '000000' } };
 
     /**
      * The name of the property in the drawing attributes, that contains the list style definitions.
