@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Sven Jacobi <sven.jacobi@open-xchange.com>
  */
@@ -19,7 +20,7 @@ define('io.ox/office/presentation/main', [
 
     // entry point for the OX AppSuite front-end to launch a new OX Presentation instance
     return ApplicationLauncher.createLauncher('io.ox/office/presentation', {
-        icon: 'fa-film',
+        icon: 'fa-list-alt',
         trackingId: 'io.ox/presentation-editor'
     });
 
