@@ -6,17 +6,21 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  */
 
 define('io.ox/office/presentation/model/dynfontsizemixin', [
     'io.ox/office/textframework/utils/dom',
+    'io.ox/office/drawinglayer/view/drawingframe',
     'io.ox/office/tk/utils',
+    'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/textframework/utils/position',
-    'io.ox/office/textframework/utils/operations'
-], function (DOM, Utils, Position, Operations) {
+    'io.ox/office/textframework/utils/operations',
+    'io.ox/office/presentation/utils/presentationutils'
+], function (DOM, DrawingFrame, Utils, AttributeUtils, Position, Operations, PresentationUtils) {
 
     'use strict';
 
@@ -44,11 +48,17 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
             // var currentHeight = lastP.offsetTop + lastP.offsetHeight;
 
             var currentHeight = 0;
-            textframe.children().get().forEach(function (para) {
-                currentHeight += $(para).outerHeight(true);
+            var paraChildren = textframe.children().get();
+            paraChildren.forEach(function (para, index) {
+                para = $(para);
+                // fix for Bug 47960
+                if (index === paraChildren.length - 1 && (para.hasClass(DOM.PARAGRAPH_NODE_LIST_EMPTY_CLASS) || para.find('>span:empty').length)) {
+                    return;
+                } else {
+                    currentHeight += para.outerHeight(true);
+                }
             });
 
-            // console.log('diff', maxHeight, currentHeight);
             /*
             console.log('iter', i, 'currentHeight', currentHeight, 'maxHeight', maxHeight, 'currentFontSize', currentFontSize);
             if (i === 6) {
@@ -108,6 +118,75 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
             var initialFontSize = parseFloat(textframecontent.css('font-size'));
             var initialLineReduction = parseFloat(textframecontent.attr('linereduction'));
             var textFrame = textframecontent.find('>.textframe');
+            var drawingHeight = null;
+            var currentHeight = null;
+            var drawingWidth = null;
+            var currentWidth = null;
+            var drawingAttrs = null;
+            var angle = DrawingFrame.getDrawingRotationAngle(self, drawing);
+
+            // local method to get left position value for drawing with auto resize and no wrap word,
+            // depending on alignment of first paragraph child
+            function getLeftPostion() {
+                var pAlignment = null;
+                var leftPos = null;
+
+                if (_.isNumber(angle) && angle % 360 !== 0) {
+                    // if rotated, treat like center alignment
+                    leftPos = parseFloat(drawing.style.left) - (currentWidth - drawingWidth) / 2;
+                } else {
+                    pAlignment = AttributeUtils.getExplicitAttributes($drawing.find('.p').first());
+                    pAlignment = pAlignment && pAlignment.paragraph && pAlignment.paragraph.alignment;
+
+                    switch (pAlignment) {
+                        case 'left':
+                            leftPos = parseFloat(drawing.style.left);
+                            break;
+                        case 'center':
+                        case 'justify':
+                            leftPos = parseFloat(drawing.style.left) - (currentWidth - drawingWidth) / 2;
+                            break;
+                        case 'right':
+                            leftPos = parseFloat(drawing.style.left) - (currentWidth - drawingWidth);
+                            break;
+                        default:
+                            leftPos = parseFloat(drawing.style.left);
+                    }
+                }
+
+                return Utils.convertLengthToHmm(leftPos, 'px');
+            }
+
+            // local method to get top position value for drawing with auto resize and wrap word,
+            // depending on shape vertical alignment
+            function getTopPostion() {
+                var vAlignment = null;
+                var topPos = null;
+
+                if (_.isNumber(angle) && angle % 360 !== 0) {
+                    // if rotated, treat like centered vertical alignment
+                    topPos = parseFloat(drawing.style.top) - (currentHeight - drawingHeight) / 2;
+                } else {
+                    vAlignment = AttributeUtils.getExplicitAttributes($drawing);
+                    vAlignment = vAlignment && vAlignment.shape && vAlignment.shape.anchor;
+
+                    switch (vAlignment) {
+                        case 'top':
+                            topPos = parseFloat(drawing.style.top);
+                            break;
+                        case 'centered':
+                            topPos = parseFloat(drawing.style.top) - (currentHeight - drawingHeight) / 2;
+                            break;
+                        case 'bottom':
+                            topPos = parseFloat(drawing.style.top) - (currentHeight - drawingHeight);
+                            break;
+                        default:
+                            topPos = parseFloat(drawing.style.top);
+                    }
+                }
+
+                return Utils.convertLengthToHmm(topPos, 'px');
+            }
 
             if (!textFrame.children().length) {
                 //empty drawing
@@ -116,39 +195,57 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
 
             // console.log('updateDrawing', textframecontent.attr('class'));
             if (textframecontent.hasClass('autoresizeheight') || !textframecontent.hasClass('autoresizetext')) {
+
                 if (initialFontSize !== DEFAULT_FONT_SIZE || initialLineReduction !== 0) {
+
                     textframecontent.css('font-size', DEFAULT_FONT_SIZE + 'px');
                     textframecontent.attr('font-scale', null);
                     textframecontent.attr('linereduction', null);
                 }
                 if (textframecontent.hasClass('autoresizeheight')) {
-                    var drawingHeight = $drawing.data('drawingHeight') || 0;
-                    var currentHeight = $drawing.height();
 
-                    if (Math.abs(drawingHeight - currentHeight) > 1) {
+                    drawingHeight = $drawing.data('drawingHeight') || 0;
+                    currentHeight = $drawing.height();
+                    drawingWidth = $drawing.data('drawingWidth') || 0;
+                    currentWidth = $drawing.width();
+
+                    if (textframecontent.hasClass(DrawingFrame.NO_WORDWRAP_CLASS) && Math.abs(drawingWidth - currentWidth) > 1) {
+                        $drawing.data('drawingWidth', currentWidth);
+
+                        drawingAttrs = {
+                            height: Utils.convertLengthToHmm(currentHeight, 'px'),
+                            width: Utils.convertLengthToHmm(currentWidth, 'px'),
+                            left: getLeftPostion(),
+                            top: Utils.convertLengthToHmm(parseFloat(drawing.style.top), 'px')
+                        };
+                        return $.when({ attrs: { drawing: drawingAttrs }, drawing: drawing });
+                    } else if (Math.abs(drawingHeight - currentHeight) > 1) {
 
                         $drawing.data('drawingHeight', currentHeight);
 
-                        var drawingAttrs = {
+                        drawingAttrs = {
                             height: Utils.convertLengthToHmm(currentHeight, 'px'),
                             width: Utils.convertLengthToHmm($drawing.width(), 'px'),
                             left: Utils.convertLengthToHmm(parseFloat(drawing.style.left), 'px'),
-                            top: Utils.convertLengthToHmm(parseFloat(drawing.style.top), 'px')
+                            top: getTopPostion()
                         };
                         return $.when({ attrs: { drawing: drawingAttrs }, drawing: drawing });
                     }
                 }
                 return;
             }
+            var maxHeight = 0;
+            if (_.browser.IE) {
+                // fix for Bug 48665
+                maxHeight = $drawing.data('widthHeightRev') ? $drawing.width() : $drawing.height();
+                maxHeight = maxHeight - (parseFloat(textFrame[0].style.top) || 0) - (parseFloat(textFrame[0].style.paddingBottom) || 0);
+            } else {
+                maxHeight = $drawing.data('widthHeightRev') ? textFrame.width() : textFrame.height();
+            }
 
-            //var maxHeight = textframecontent.height();
-            //var maxHeight = parseFloat(drawing[0].style.height);
-            var maxHeight = textframecontent.data('shapeHeight');
             if (!maxHeight) {
-                // console.warn('noooo', textframecontent[0]);
                 return;
             }
-            maxHeight = maxHeight - (parseFloat(textFrame[0].style.paddingTop) || 0) - (parseFloat(textFrame[0].style.paddingBottom) || 0);
             var lastHeight = -1;
 
             function innerUpdate(i) {
@@ -181,7 +278,7 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
 
             var def = null;
             if (_.browser.IE) {
-                def = self.iterateArraySliced(INDEX_ARRAY, innerUpdate, { slice: 1, infoString: 'DynFontSizeMixin:updateDrawing()' });
+                def = self.iterateArraySliced(INDEX_ARRAY, innerUpdate, { slice: 1, infoString: 'DynFontSizeMixin:updateDrawing()', app: self.getApp() });
             } else {
                 _.each(INDEX_ARRAY, innerUpdate);
                 def = $.when(true);
@@ -242,10 +339,15 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
             }
         }
 
-        // The drawing element(s) as DOM node or jQuery object.
-        function registerDrawing(newDrawings) {
+        // The drawing element as DOM node or jQuery object.
+        function registerDrawing(newDrawing) {
             // store the new drawing(s) in the collection (jQuery keeps the collection unique)
-            if (newDrawings) { drawingQueue = drawingQueue.add(newDrawings); }
+            // -> but not storing images or tables
+            if (newDrawing && (DrawingFrame.isShapeDrawingFrame(newDrawing) || DrawingFrame.isGroupDrawingFrame(newDrawing)) && !DrawingFrame.isTableDrawingFrame(newDrawing)) {
+                drawingQueue = drawingQueue.add(newDrawing);
+            }
+            // TODO: Remove asap check for tables (problem in DrawingFrame.isShapeDrawingFrame)
+            // if (newDrawing && (DrawingFrame.isShapeDrawingFrame(newDrawing) || DrawingFrame.isGroupDrawingFrame(newDrawing))) { drawingQueue = drawingQueue.add(newDrawing); }
         }
 
         function updateDynFontSizeInDrawings() {
@@ -265,9 +367,14 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
             var slideID = null;
             // iterating over all drawings
             _.each(drawings, function (drawing) {
+                // TODO: operate correct on grouped drawings (width/height are different to ungrouped drawings)
+                if ($(drawing).is('.grouped')) { return; }
+
                 var slide = $(drawing).closest(DOM.SLIDE_SELECTOR);
                 slideID = self.getSlideId(slide);
 
+                self.appendSlideToDom(slideID); // attaching the slide node to the DOM
+
                 // skip slides if they are not formatted at all -> asking slide format manager
                 if (!self.getSlideFormatManager().isUnformattedSlide(slideID)) {
                     var change = updateSlide(slide, slideID, $(drawing));
@@ -346,6 +453,12 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
                 operationOptions.start = selection.getStartPosition();
             }
 
+            if (autoResizeText || autoResizeHeight) {
+                // Bug 48714 fix for undo
+                operationOptions.attrs.drawing = {};
+                PresentationUtils.extendPlaceholderProp(self.getApp(), textFrame, operationOptions);
+            }
+
             // generate the 'setAttributes' operation
             generator.generateOperation(Operations.SET_ATTRIBUTES, operationOptions);
 
@@ -355,7 +468,7 @@ define('io.ox/office/presentation/model/dynfontsizemixin', [
             self.updateDynFontSizeDebounced(textFrame);
         };
 
-        self.updateDynFontSizeDebounced = self.createDebouncedMethod(registerDrawing, updateDynFontSizeInDrawings, { delay: 500, infoString: 'Presentation: DynfontSizeMixin.updateDynFontSizeDebounced' });
+        self.updateDynFontSizeDebounced = self.createDebouncedMethod(registerDrawing, updateDynFontSizeInDrawings, { delay: 500, infoString: 'Presentation: DynfontSizeMixin.updateDynFontSizeDebounced', app: self.getApp() });
 
         self.getPreFlushDocumentPromise = function () { return updateDynFontSizeInDrawings(); };
 
