@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -247,6 +248,11 @@ define('io.ox/office/presentation/model/listhandlermixin', [
                 // receiving the logical position of the paragraph, if not specified as parameter
                 if (!position) { position = Position.getOxoPosition(self.getCurrentRootNode(self.getActiveTarget()), paragraph, 0); }
 
+                // handling of implicit paragraphs (in tables)
+                if (DOM.isImplicitParagraphNode(paragraph) && Position.getParagraphNodeLength(paragraph) === 0) {
+                    generator.generateOperation(Operations.PARA_INSERT, { start: position });
+                }
+
                 // generate the 'setAttributes' operation for each paragraph
                 generator.generateOperation(Operations.SET_ATTRIBUTES, { start: position, attrs: { paragraph: localParaAttrs } });
             }
@@ -430,7 +436,7 @@ define('io.ox/office/presentation/model/listhandlermixin', [
                 // the paragraph attributes
                 paraAttrs = attrs && attrs.paragraph;
 
-            return paraAttrs && paraAttrs.bullet && paraAttrs.bullet.type && paraAttrs.bullet.numType || null;
+            return (paraAttrs && paraAttrs.bullet && paraAttrs.bullet.type && paraAttrs.bullet.numType) || null;
         }
 
         /**
@@ -901,6 +907,21 @@ define('io.ox/office/presentation/model/listhandlermixin', [
             return listStyleId;
         }
 
+        /**
+         * Adding the default font size that is used by PP (Arial, 18 pt, black) to the
+         * default text list styles (if not specified via operation). This is used for example,
+         * if a new text frame is inserted.
+         */
+        function addDefaultValuesToTextListStyles() {
+            _.each(_.keys(defaultTextListStyles), function (key) {
+                if (!defaultTextListStyles[key].character) {
+                    defaultTextListStyles[key].character = { fontSize: ListHandlerMixin.DEFAULT_FONT_SIZE };
+                } else if (!_.isNumber(defaultTextListStyles[key].character.fontSize)) {
+                    defaultTextListStyles[key].character.fontSize = ListHandlerMixin.DEFAULT_FONT_SIZE;
+                }
+            });
+        }
+
         // public methods -----------------------------------------------------
 
         /**
@@ -1282,29 +1303,20 @@ define('io.ox/office/presentation/model/listhandlermixin', [
          * contains additional paragraphs, that cannot be modified, no operations are
          * generated for those paragraphs. But this function 'isListIndentChangeable' must
          * be performant, because it is used for updating the buttons in the UI.
-         *
+         * @param {Object} [paraAttrs]
+         *  explicit attributes of paragraph
          * @param {Object} [options]
          *  Optional parameters:
          *  @param {Boolean} [options.increase=true]
          *      Whether the indentation level of the selected paragraph(s) shall be
          *      increased or decreased.
          */
-        this.isListIndentChangeable = function (options) {
+        this.isListIndentChangeable = function (paraAttrs, options) {
 
-            var // the selection object
-                selection = self.getSelection(),
-                // target for operation
-                target = self.getActiveTarget(),
-                // the paragraph node at the start position
-                paragraph = Position.getParagraphElement(self.getCurrentRootNode(target), _.initial(selection.getStartPosition())),
-                // whether the level shall be increased or decreased
-                doIncrease = Utils.getBooleanOption(options, 'increase', true),
-                // the explicit attributes
-                explicitAttrs = paragraph ? AttributeUtils.getExplicitAttributes(paragraph) : null,
-                // the explicit paragraph attributes
-                paraAttrs = explicitAttrs && explicitAttrs.paragraph ? explicitAttrs.paragraph : null,
-                // the paragraphs current indent level
-                currentIndent = paraAttrs && _.isNumber(paraAttrs.level) ? paraAttrs.level : 0;
+            // whether the level shall be increased or decreased
+            var doIncrease = Utils.getBooleanOption(options, 'increase', true);
+            // the paragraphs current indent level
+            var currentIndent = paraAttrs && _.isNumber(paraAttrs.level) ? paraAttrs.level : 0;
 
             if ((!doIncrease && currentIndent > 0) || (doIncrease && currentIndent < self.getMaxListLevel())) { return true; }
 
@@ -1322,6 +1334,9 @@ define('io.ox/office/presentation/model/listhandlermixin', [
          */
         this.setDefaultTextListStyles = function (listStyles) {
             defaultTextListStyles = listStyles;
+
+            // there are some hard coded default values, that need to be added here (48628)
+            addDefaultValuesToTextListStyles();
         };
 
         /**
@@ -1385,7 +1400,7 @@ define('io.ox/office/presentation/model/listhandlermixin', [
          *  bullet numbering type.
          */
         this.isNumberedListParagraph = function (paragraphAttrs) {
-            return paragraphAttrs && paragraphAttrs.bullet && paragraphAttrs.bullet.type && paragraphAttrs.bullet.type && paragraphAttrs.bullet.type === 'numbering' || false;
+            return (paragraphAttrs && paragraphAttrs.bullet && paragraphAttrs.bullet.type && paragraphAttrs.bullet.type && paragraphAttrs.bullet.type === 'numbering') || false;
         };
 
         /**
@@ -1498,10 +1513,14 @@ define('io.ox/office/presentation/model/listhandlermixin', [
                 // whether the old selected paragraph is an empty list paragraph now
                 isEmptyListParagraph = false,
                 // the drawing content node that contains the old paragraph
-                drawingContent = null;
+                drawingContent = null,
+                // the parent of the paragraph
+                paraParent = null,
+                // the drawing node
+                drawing = null;
 
             // getting the new paragraph
-            if (selection.getSelectionType() === 'text' && !selection.hasRange()) {
+            if (selection.getSelectionType() === 'text' && !selection.hasRange() && !selection.isEmptySelection()) {
                 newSelectedParagraph = Position.getParagraphElement(selection.getRootNode(), _.initial(selection.getStartPosition()));
             }
 
@@ -1518,6 +1537,10 @@ define('io.ox/office/presentation/model/listhandlermixin', [
                     if (drawingContent.hasClass(DrawingFrame.EMPTYTEXTFRAME_CLASS)) {
                         drawingContent.removeClass(DrawingFrame.EMPTYTEXTFRAME_CLASS);
                     }
+                    if (DrawingFrame.isTextFrameNode(selectedParagraph.parent())) { // only for top level text, for example not in tables
+                        drawing = drawingContent.parent();
+                        self.getDrawingStyles().handleImageTemplateContainer(drawing, false); // remove an image template container
+                    }
                 }
             }
 
@@ -1541,6 +1564,15 @@ define('io.ox/office/presentation/model/listhandlermixin', [
                 if (paragraphAttributes && paragraphAttributes.paragraph && self.isNumberedListParagraph(paragraphAttributes.paragraph)) {
                     self.updateListsDebounced(selectedParagraph);
                 }
+
+                if (newEmptyListParagraph) {
+                    paraParent = selectedParagraph.parent();
+                    if (DrawingFrame.isTextFrameNode(paraParent) && paraParent.children(DOM.PARAGRAPH_NODE_SELECTOR).length === 1) { // only for top level text, for example not in tables
+                        drawingContent = drawingContent || selectedParagraph.closest(DrawingFrame.CONTENT_NODE_SELECTOR);
+                        drawing = drawingContent.parent();
+                        self.getDrawingStyles().handleImageTemplateContainer(drawing, true); // insert an image template container
+                    }
+                }
             }
 
         };
@@ -1600,6 +1632,12 @@ define('io.ox/office/presentation/model/listhandlermixin', [
      */
     ListHandlerMixin.PREDEFINED_INDENT_FIRST_LINE_DEFAULT = -1500;
 
+    /**
+     * A constant that will be used to specify the default font size, that is hard
+     * coded in PP.
+     */
+    ListHandlerMixin.DEFAULT_FONT_SIZE = 18;
+
     // exports ================================================================
 
     return ListHandlerMixin;
