@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
@@ -17,11 +18,11 @@ define('io.ox/office/presentation/model/modelattributesmixin', [
     'io.ox/office/presentation/format/paragraphstyles',
     'io.ox/office/presentation/format/pagestyles',
     'io.ox/office/presentation/format/slidestyles',
+    'io.ox/office/presentation/format/tablecellstyles',
     'io.ox/office/textframework/format/characterstyles',
     'io.ox/office/textframework/format/tablestyles',
-    'io.ox/office/textframework/format/tablerowstyles',
-    'io.ox/office/textframework/format/tablecellstyles'
-], function (DrawingStyles, ParagraphStyles, PageStyles, SlideStyles, CharacterStyles, TableStyles, TableRowStyles, TableCellStyles) {
+    'io.ox/office/textframework/format/tablerowstyles'
+], function (DrawingStyles, ParagraphStyles, PageStyles, SlideStyles, TableCellStyles, CharacterStyles, TableStyles, TableRowStyles) {
 
     'use strict';
 
@@ -46,7 +47,8 @@ define('io.ox/office/presentation/model/modelattributesmixin', [
         PRESENTATION_ATTRIBUTE_DEFINITIONS = {
             phType: { def: 'obj', scope: 'element' },
             phSize: { def: 'full', scope: 'element' },
-            phIndex: { def: 0, scope: 'element' }
+            phIndex: { def: 0, scope: 'element' },
+            customPrompt: { def: false, scope: 'element' }
         },
 
         // definitions for change tracking attributes (TODO: Removing this attributes asap)--
