@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -16,8 +17,9 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
     'io.ox/office/textframework/utils/position',
     'io.ox/office/textframework/components/hyperlink/hyperlink',
     'io.ox/office/textframework/components/table/tableresize',
-    'io.ox/office/drawinglayer/view/drawingframe'
-], function (DOM, Position, Hyperlink, TableResize, DrawingFrame) {
+    'io.ox/office/drawinglayer/view/drawingframe',
+    'io.ox/office/tk/utils'
+], function (DOM, Position, Hyperlink, TableResize, DrawingFrame, Utils) {
 
     'use strict';
 
@@ -35,7 +37,9 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
     function PageHandlerMixin(app) {
 
         var // self reference for local functions
-            self = this;
+            self = this,
+            // time stamp from the touchstart
+            touchEventTimeStamp = 0;
 
         // private methods ----------------------------------------------------
 
@@ -71,10 +75,67 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
                 // the currently activated node
                 activeRootNode = self.getCurrentRootNode(),
                 // whether the right mouse-button was clicked, or not
-                rightClick = (event.button === 2);
+                rightClick = (event.button === 2),
+                // whether this was a doubleTap
+                doubleTap = false,
+                // time stamp for the previous touchstart
+                prevTouchEventTimeStamp = 0,
+                // the drawing node for touch start events
+                currentDrawing = null,
+                // whether the found drawing is a selection drawing
+                isSelectionDrawing = false,
+                // whether the touchstart is on the slide or app-content
+                touchClickedOnSlide = false;
+
+            // special behavior for iOS in Presentation
+            if (self.getSlideTouchMode()) {
+                // bug 50009: do not execute this function when the layoutpicker is open, because it would be closed by this
+                if (app.getView().getContentRootNode().hasClass('popup-open')) { return; }
+
+                currentDrawing = $eventTarget.closest(DrawingFrame.TEXTFRAMECONTENT_NODE_SELECTOR).parent();
+
+                // ignore mouse events that are triggered after touch events in iOS
+                if (event.type === 'mousedown') { return; }
+
+                // doubletap detection
+                if (event.type === 'touchstart') {
+                    prevTouchEventTimeStamp = touchEventTimeStamp;
+                    touchEventTimeStamp = event.timeStamp;
+                    doubleTap = (touchEventTimeStamp - prevTouchEventTimeStamp) < Utils.DBL_CLICK_TIMEOUT;
+                }
+
+                // 1) set drawing in editable state
+                if (doubleTap) {
+                    currentDrawing.attr('contenteditable', 'true').addClass('active-edit');
+                    if (currentDrawing.data('selection')) { currentDrawing.data('selection').addClass('active-edit'); }
+                    return;
+                // 2) when drawing is in editable state
+                } else if (currentDrawing.hasClass('active-edit')) {
+                    return;
+                // 3) touched elsewhere or in all other cases: remove drawing edit state, prevent setting the browser selection and close the soft-keyboard
+                } else {
+                    touchClickedOnSlide = DOM.isSlideNode($eventTarget) || DOM.isAppContentNode($eventTarget);
+                    // preventDefault to prevent selectionChange events
+                    // but not preventDefault on the slide/app-content, because that would prevent panning
+                    if (!touchClickedOnSlide) { event.preventDefault(); }
+                    // set to default position in the slide, triggerChange is false to prevent scrolling to 0.0
+                    self.getSelection().setSlideSelection({ triggerChange: false });
+                    // move focus to close a open soft-keyboard
+                    self.getSelection().setFocusIntoClipboardNode({ specialTouchHandling: true });
+                    // reset the browser selection
+                    window.getSelection().removeAllRanges();
+
+                    // remove all contenteditable
+                    Utils.removeContentEditable(app.getView().getAppPaneNode()); //TODO check with other open apps
+                    // remove the active-edit state
+                    app.getView().getAppPaneNode().find('.active-edit').removeClass('active-edit');
+                }
+                 // when touched on the slide/app-content, it may be the start from a touchmove for panning - therefore return here so that no preventDefault is called later
+                if (touchClickedOnSlide) { return; }
+            }
 
             // fix for not clearing annoying selection range in Chrome on click
-            if (_.browser.Chrome && self.getSelection().hasRange() && !rightClick) { window.getSelection().empty(); }
+            if (_.browser.Chrome && self.getSelection().hasRange() && !rightClick && !event.shiftKey) { window.getSelection().empty(); }
 
             // expanding a waiting double click to a triple click
             if (self.getDoubleClickEventWaiting()) {
@@ -85,6 +146,9 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
 
             // -> if the click happened on the slide, the selection box already handles the event
             if (DOM.isSlideNode($eventTarget)) {
+                if (rightClick) {
+                    app.getView().grabFocus(); // #48689
+                }
                 event.preventDefault();
                 return;
             }
@@ -105,6 +169,13 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
                 return;
             }
 
+            // handling the image template in empty place holder drawings
+            if (DOM.isPlaceholderTemplateButton($eventTarget.parent()) && !self.isMasterView() && !readOnly) {
+                self.handleTemplateImageEvent($eventTarget.parent());
+                event.preventDefault();
+                return;
+            }
+
             // Fix for 29409: preventing default to avoid grabbers in table cells or inline components
             if ((_.browser.IE === 11) &&
                 ($eventTarget.is('div.cell') ||
@@ -137,8 +208,11 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
                     return;
                 }
 
+                // check, if the drawing is the drawing inside the selection overlay (class 'drawingselection' is set)
+                isSelectionDrawing = drawingNode.hasClass('selectiondrawing');
+
                 // presentation specific code
-                if (DOM.isInsideSlideContainerNode(drawingNode)) {  // TODO: This should always be the case
+                if (DOM.isInsideSlideContainerNode(drawingNode)) {  // This should always be the case, except if 'isSelectionDrawing' is true
 
                     slideRootNode = drawingNode.closest(DOM.SLIDECONTAINER_SELECTOR);
 
@@ -152,9 +226,11 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
                     activatedSlideId = DOM.getTargetContainerId(slideRootNode);
                     self.setActiveTarget(activatedSlideId);
                 }
-
-                if (DrawingFrame.isOnlyBorderMoveableDrawing(drawingNode) && $eventTarget.closest(DrawingFrame.TEXTFRAME_NODE_SELECTOR).length > 0 && !(rightClick && self.getSelection().isMultiSelection())) {
-                    drawingNode = $();
+                // do not clear the drawing node in slideTouchMode, so that in every case just the drawing is selected and not the text inside the drawing
+                if (!self.getSlideTouchMode()) {
+                    if (DrawingFrame.isOnlyBorderMoveableDrawing(drawingNode) && $eventTarget.closest(DrawingFrame.TEXTFRAME_NODE_SELECTOR).length > 0 && !(rightClick && self.getSelection().isMultiSelection())) {
+                        drawingNode = $();
+                    }
                 }
             } else {
                 // no drawing selected -> click on slide
@@ -167,7 +243,8 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
             }
 
             // deactivating active target, but not if it was activated before (presentation specific code)
-            if (self.getActiveTarget() !== '' && !activatedSlideId) {
+            // -> checking for 'isSelectionDrawing', so that the target is not removed  (50005, 50067)
+            if (self.getActiveTarget() !== '' && !activatedSlideId && !isSelectionDrawing) {
                 self.getSelection().setNewRootNode(self.getNode());
                 self.setActiveTarget('');
             }
@@ -191,32 +268,48 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
                 // set focus to the document container (may be located in GUI edit fields)
                 app.getView().grabFocus();
 
-                // do nothing if the drawing is already selected (prevent endless
+                if (drawingNode.is('.selectiondrawing') && self.getSelection().isAdditionalTextframeSelection()) {
+                    self.getSelection().toggleTextFrameAndTextSelection(); // selecting the drawing
+                    drawingNode = self.getSelection().getSelectedDrawing();
+                    drawingNode.trigger(event);
+                    return event.type === 'touchstart';
+                }
+
+                // do nothing if the drawing or its surrounding group is already selected (prevent endless
                 // recursion when re-triggering the event, to be able to start
                 // moving the drawing immediately, see below)
                 // Also create a drawing selection, if there is an additional text frame selection,
                 // that also has a text selection. In this case the text selection is removed.
                 if (!DrawingFrame.isSelected(drawingNode) || self.getSelection().isAdditionalTextframeSelection()) {
 
-                    // select the drawing
-                    startPosition = Position.getOxoPosition(activeRootNode, drawingNode[0], 0);
-                    endPosition = Position.increaseLastIndex(startPosition);
-                    self.getSelection().setTextSelection(startPosition, endPosition, { event: event });
+                    // also do nothing if the surrounding group is already selected (47786)
+                    // -> but set a new selection, if the selected surrounding group is an additional text frame selection (48177)
+                    if (!(DrawingFrame.isGroupedDrawingFrame(drawingNode) && !self.getSelection().isAdditionalTextframeSelection() && DrawingFrame.isSelected(DrawingFrame.getGroupNode(drawingNode, { farthest: true, rootNode: activeRootNode })))) {
 
-                    // The following triggering of the event is necessary to move a drawing without a further mousedown
-                    // or touchstart event. Without this additional trigger the first mousedown/touchstart would only select
-                    // the drawing. For moving it, a further mousedown/touchstart is requrired. By triggering this event
-                    // again, it is possible to move a drawing already with the first mousedown/touchstart.
-                    // For moving a drawing, a tracker node was created and registered for 'tracking:start' in the
-                    // preceeding selection.drawDrawingSelection() call. This additional mousedown/touchstart
-                    // generates a 'tracking:start' event, that will be handled by the tracker node.
-                    // The event target for this event in 'processMouseDown' could be the 'img' or the 'div.drawing'. But
-                    // it has to be sent to the tracker. Therefore it is necessary to adapt the event target, before
-                    // triggering it again.
-                    moveNode = drawingNode.find('.tracker');
-                    if (moveNode.length > 0) {
-                        event.target = moveNode[0];
-                        moveNode.trigger(event);
+                        // select the drawing
+                        startPosition = Position.getOxoPosition(activeRootNode, drawingNode[0], 0);
+                        endPosition = Position.increaseLastIndex(startPosition);
+                        self.getSelection().setTextSelection(startPosition, endPosition, { event: event });
+
+                        // The following triggering of the event is necessary to move a drawing without a further mousedown
+                        // or touchstart event. Without this additional trigger the first mousedown/touchstart would only select
+                        // the drawing. For moving it, a further mousedown/touchstart is requrired. By triggering this event
+                        // again, it is possible to move a drawing already with the first mousedown/touchstart.
+                        // For moving a drawing, a tracker node was created and registered for 'tracking:start' in the
+                        // preceeding selection.drawDrawingSelection() call. This additional mousedown/touchstart
+                        // generates a 'tracking:start' event, that will be handled by the tracker node.
+                        // The event target for this event in 'processMouseDown' could be the 'img' or the 'div.drawing'. But
+                        // it has to be sent to the tracker. Therefore it is necessary to adapt the event target, before
+                        // triggering it again.
+                        if (drawingNode.data('selection')) {
+                            moveNode = drawingNode.data('selection').find('.tracker');
+                        }
+
+                        // do not double trigger in ios!
+                        if (!self.getSlideTouchMode() && moveNode && moveNode.length > 0) {
+                            event.target = moveNode[0];
+                            moveNode.trigger(event);
+                        }
                     }
                 }
 
