@@ -6,17 +6,20 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
 
 define('io.ox/office/presentation/model/slideformatmanager', [
-    'io.ox/office/textframework/utils/dom',
+    'io.ox/office/tk/utils',
     'io.ox/office/tk/object/triggerobject',
     'io.ox/office/tk/object/timermixin',
-    'io.ox/office/tk/utils'
-], function (DOM, TriggerObject, TimerMixin, Utils) {
+    'io.ox/office/textframework/utils/config',
+    'io.ox/office/textframework/utils/dom',
+    'io.ox/office/presentation/utils/presentationutils'
+], function (Utils, TriggerObject, TimerMixin, Config, DOM, PresentationUtils) {
 
     'use strict';
 
@@ -54,9 +57,11 @@ define('io.ox/office/presentation/model/slideformatmanager', [
             // a function that checks for idle time to update slides in backgroud
             idleTimeChecker = $.noop,
             // the idle time (in ms), after that a slide formatting is triggered
-            idleTime = 2500,
-            // the left offset that is used during updating a slide
-            leftOffset = '10000px';
+            idleTime = Config.AUTOTEST ? 10 : 2500,
+            // a collector for all those slides, that need to be shifted during formatting of the active slide
+            shiftedSlides = null,
+            // a collector for slide IDs, that are waiting to inform the listeners, because dependent slides are currently formatted
+            waitingIDs = null;
 
         // base constructors --------------------------------------------------
 
@@ -97,6 +102,19 @@ define('io.ox/office/presentation/model/slideformatmanager', [
             }
         }
 
+        /**
+         * Updating the document slides belonging to a specified layout slide in that way, that
+         * the correct customized template texts are shown.
+         *
+         * @param {String} id
+         *  The ID of a (layout) slide.
+         */
+        function updateAllCustomizedTemplateTextOnSlide(id) {
+            _.each(model.getAllSlideIDsWithSpecificTargetParent(id), function (slideId) {
+                model.getDrawingStyles().handleAllEmptyPlaceHolderDrawingsOnSlide(model.getSlideById(slideId), { ignoreTemplateText: true });
+            });
+        }
+
         /**
          * Element formatting for one slide and its content.
          *
@@ -112,16 +130,22 @@ define('io.ox/office/presentation/model/slideformatmanager', [
          */
         function formatOneSlide(slide, id) {
 
-            var // making slide visible for formatting
-                visibilityChanged = model.handleContainerVisibility(slide, { makeVisible: true }),
+            if (app.isInQuit()) {
+                return $.Deferred().reject();
+            }
+
+            var // whether the visibility of the slide has changed for formatting reasons
+                visibilityChanged = false,
                 // the paragraphs in the slide
                 paragraphContainer = $(),
                 // the slide styles object
                 drawingStyles = model.getDrawingStyles(),
                 // collector for all drawings on the slide
                 allDrawings = slide.find('.drawing'),
-                // the content root node
-                contentRootNode = app.getView().getContentRootNode();
+                // whether the document slides need to be updated because of a customized template text
+                updateCustomizedTemplateTexts = false,
+                // a container for all drawings of type 'group' on the slide
+                groupDrawings = null;
 
             // updating one drawing on the slide
             function updateOneDrawing(drawing) {
@@ -139,26 +163,61 @@ define('io.ox/office/presentation/model/slideformatmanager', [
                 model.implParagraphChangedSync(paragraphs, { suppressFontSize: true });
 
                 paragraphContainer = paragraphContainer.add(paragraphs);
+
+                // marking collecting all drawings with customized template text
+                if (model.isLayoutSlideId(id) && PresentationUtils.isCustomPromptPlaceHolderDrawing(drawing)) { updateCustomizedTemplateTexts = true; }
             }
 
-            // always shifting the slide horizontally so that it is not visible during formatting
-            contentRootNode.css('overflow-x', 'hidden'); // -> avoiding horizontal scroll bar
-            slide.css('left', leftOffset);
+            // Performance: The drawing group need to be formatted after all child drawings are formatted. Setting
+            // a marker at all drawings of type 'groups' and formatting them at the end of the process, makes it
+            // possible, that the group is not updated after insertion of every child (in drawingframe.js).
+            function handleGroupNodes() {
+
+                // collecting all drawings of type 'group'
+                groupDrawings = _.filter(allDrawings, function (drawing) {
+                    return $(drawing).attr('data-type') === 'group';
+                });
+
+                if (groupDrawings.length > 0) {
+                    // setting marker at model for handled groups (performance)
+                    _.each(groupDrawings, function (oneDrawing) { $(oneDrawing).data('grouphandling', 1); });
+                    // adding the group drawings to the end of the collection
+                    allDrawings = allDrawings.get(); // converting to array
+                    allDrawings = allDrawings.concat(groupDrawings);
+                }
+            }
+
+            // attaching the slide node to the DOM, if required
+            model.appendSlideToDom(id);
+
+            // making slide visible for formatting
+            visibilityChanged = model.handleContainerVisibility(slide, { makeVisible: true });
+
+            slide.addClass('leftshift');
 
             // updating the slide ...
             model.getSlideStyles().updateElementFormatting(slide);
 
+            // appending drawings of type 'group' to the end of the drawing list, so that it is not necessary
+            // to update the complete group after each client
+            handleGroupNodes();
+
             // updating all drawings via iteration
-            return self.iterateArraySliced(allDrawings, updateOneDrawing, { infoString: 'SlideFormatManager: formatOneSlide' })
+            return self.iterateArraySliced(allDrawings, updateOneDrawing, { infoString: 'SlideFormatManager: formatOneSlide', app: app })
                 .then(function () {
                     // updating the lists also synchronously
                     model.updateLists(null, paragraphContainer);
+                    // updating the customized template texts on document slides
+                    if (updateCustomizedTemplateTexts) { updateAllCustomizedTemplateTextOnSlide(id); }
                 })
                 .always(function () {
 
+                    // removing marker for handled drawing groups (performance)
+                    _.each(groupDrawings, function (oneDrawing) { $(oneDrawing).removeData('grouphandling'); });
+
                     // shifting back the slide after formatting
-                    contentRootNode.css('overflow-x', '');
                     slide.css('left', '');
+                    slide.removeClass('leftshift');
 
                     if (visibilityChanged) {
                         // making the slide invisible again
@@ -166,6 +225,9 @@ define('io.ox/office/presentation/model/slideformatmanager', [
                         model.handleContainerVisibility(slide, { makeVisible: false });
                     }
 
+                    // let the new formatted slide stay in the DOM for some seconds
+                    model.getSlideVisibilityManager().registerOperationSlideId(id);
+
                     // this task is no longer running
                     if (runningTasks[id]) { delete runningTasks[id]; }
                 })
@@ -204,7 +266,7 @@ define('io.ox/office/presentation/model/slideformatmanager', [
             });
 
             // -> iterating asynchronously over the collected slide IDs (formatting slide(s) asynchronously)
-            return self.iterateArraySliced(newSlideIDs, function (id) { return formatOneSlide(model.getSlideById(id), id); }, { delay: 'immediate', infoString: 'SlideFormatManager: formatSlides' });
+            return self.iterateArraySliced(newSlideIDs, function (id) { return formatOneSlide(model.getSlideById(id), id); }, { delay: 'immediate', infoString: 'SlideFormatManager: formatSlides', app: app });
         }
 
         /**
@@ -213,8 +275,8 @@ define('io.ox/office/presentation/model/slideformatmanager', [
          * @returns {undefined}
          */
         function registerIdleTimeChecker() {
-            idleTimeChecker = self.createDebouncedMethod($.noop, idleSlideFormatHandler, { delay: idleTime, infoString: 'Presentation: idleSlideFormatHandler' });
-            model.getNode().on('keydown mousedown touchdown', idleTimeChecker);
+            idleTimeChecker = self.createDebouncedMethod($.noop, idleSlideFormatHandler, { delay: idleTime, infoString: 'Presentation: idleSlideFormatHandler', app: app });
+            model.getNode().on('keydown mousedown touchstart', idleTimeChecker);
         }
 
         /**
@@ -222,7 +284,7 @@ define('io.ox/office/presentation/model/slideformatmanager', [
          * can be done, if there are no more open tasks.
          */
         function deregisterIdleTimeChecker() {
-            model.getNode().off('keydown mousedown touchdown', idleTimeChecker);
+            model.getNode().off('keydown mousedown touchstart', idleTimeChecker);
             idleTimeChecker = $.noop;
         }
 
@@ -265,14 +327,15 @@ define('io.ox/office/presentation/model/slideformatmanager', [
 
                 // Trigger formatting one slide
                 slideID = getNextFormatSlideId();
+
                 // -> this must be a full set of slides
                 set = model.getSlideIdSet(slideID);
 
-                if (set.id && allUnformattedSlides[set.id]) {
+                if (set.id && allUnformattedSlides[set.id] && !runningTasks[set.id]) {
                     formatCollector = [set.id];
                 }
 
-                if (set.layoutId && allUnformattedSlides[set.layoutId]) {
+                if (set.layoutId && allUnformattedSlides[set.layoutId] && !runningTasks[set.layoutId]) {
                     if (formatCollector) {
                         formatCollector.push(set.layoutId);
                     } else {
@@ -280,7 +343,7 @@ define('io.ox/office/presentation/model/slideformatmanager', [
                     }
                 }
 
-                if (set.masterId && allUnformattedSlides[set.masterId]) {
+                if (set.masterId && allUnformattedSlides[set.masterId] && !runningTasks[set.masterId]) {
                     if (formatCollector) {
                         formatCollector.push(set.masterId);
                     } else {
@@ -293,6 +356,8 @@ define('io.ox/office/presentation/model/slideformatmanager', [
                     formatSlides(formatCollector).done(function () {
                         // informing the listeners
                         informListeners(formatCollector);
+                        // check for waiting listeners
+                        checkWaitingListeners(formatCollector); // checking, if waiting listeners can be informed
                         // triggering next slide update
                         if (self.unformattedSlideExists()) {
                             idleTimeChecker();
@@ -329,14 +394,6 @@ define('io.ox/office/presentation/model/slideformatmanager', [
          *      The id of the layout slide that will be activated.
          *  @param {String} [options.newMasterId='']
          *      The id of the master slide that will be activated.
-         *  @param {String} [options.oldSlideId='']
-         *      The id of the standard slide that will be deactivated.
-         *  @param {String} [options.oldLayoutId='']
-         *      The id of the layout slide that will be deactivated.
-         *  @param {String} [options.oldMasterId='']
-         *      The id of the master slide that will be deactivated.
-         *  @param {Boolean} [options.isMasterChange=false]
-         *      Whether only the master slide for a layout slide was changed.
          *
          * @returns {jQuery.Promise}
          *  The promise of a deferred object that will be resolved after all specified
@@ -351,13 +408,13 @@ define('io.ox/office/presentation/model/slideformatmanager', [
             var // a collector for the unformatted slides
                 formatCollector = null;
 
-            if (!self.unformattedSlideExists()) { return; }
+            if (!self.unformattedSlideExists()) { return $.when(); }
 
-            if (options.newSlideId && allUnformattedSlides[options.newSlideId]) {
+            if (options.newSlideId && allUnformattedSlides[options.newSlideId] && !runningTasks[options.newSlideId]) {
                 formatCollector = [options.newSlideId];
             }
 
-            if (options.newLayoutId && allUnformattedSlides[options.newLayoutId]) {
+            if (options.newLayoutId && allUnformattedSlides[options.newLayoutId] && !runningTasks[options.newLayoutId]) {
                 if (formatCollector) {
                     formatCollector.push(options.newLayoutId);
                 } else {
@@ -365,7 +422,7 @@ define('io.ox/office/presentation/model/slideformatmanager', [
                 }
             }
 
-            if (options.newMasterId && allUnformattedSlides[options.newMasterId]) {
+            if (options.newMasterId && allUnformattedSlides[options.newMasterId] && !runningTasks[options.newMasterId]) {
                 if (formatCollector) {
                     formatCollector.push(options.newMasterId);
                 } else {
@@ -379,8 +436,11 @@ define('io.ox/office/presentation/model/slideformatmanager', [
                 return formatSlides(formatCollector).done(function () {
                     // informing the listeners
                     informListeners(formatCollector);
+                    // check for waiting listeners
+                    checkWaitingListeners(formatCollector); // checking, if waiting listeners can be informed
                 });
             } else {
+                // ignoring that slides might be currently formatted (this has to be handled by the caller)
                 return $.when();
             }
         }
@@ -432,44 +492,116 @@ define('io.ox/office/presentation/model/slideformatmanager', [
                 var // the set of affected slides
                     set = model.getSlideIdSet(id),
                     // a collector for the unformatted slides
-                    formatCollector = null;
+                    formatCollector = null,
+                    // whether the triggering needs to be debounced
+                    waitingRequired = false,
+                    // a collector for all IDs of those slides, that are currently formatted
+                    waitForIDs = null;
 
                 if (set.id && allUnformattedSlides[set.id]) {
-                    formatCollector = [set.id];
+                    if (runningTasks[set.id]) {
+                        waitForIDs = {};
+                        waitForIDs[set.id] = 1;
+                    } else {
+                        formatCollector = [set.id];
+                    }
                 }
 
                 if (set.layoutId && allUnformattedSlides[set.layoutId]) {
-                    if (formatCollector) {
-                        formatCollector.push(set.layoutId);
+                    if (runningTasks[set.layoutId]) {
+                        waitForIDs = waitForIDs || {};
+                        waitForIDs[set.layoutId] = 1;
                     } else {
-                        formatCollector = [set.layoutId];
+                        if (formatCollector) {
+                            formatCollector.push(set.layoutId);
+                        } else {
+                            formatCollector = [set.layoutId];
+                        }
                     }
                 }
 
                 if (set.masterId && allUnformattedSlides[set.masterId]) {
-                    if (formatCollector) {
-                        formatCollector.push(set.masterId);
+                    if (runningTasks[set.masterId]) {
+                        waitForIDs = waitForIDs || {};
+                        waitForIDs[set.layoutId] = 1;
                     } else {
-                        formatCollector = [set.masterId];
+                        if (formatCollector) {
+                            formatCollector.push(set.masterId);
+                        } else {
+                            formatCollector = [set.masterId];
+                        }
                     }
                 }
 
-                // Is it necessary to inform the listener, even if all slides are already formatted?
+                // Is it necessary to inform the listener, even if all slides are already formatted -> yes
 
                 if (formatCollector) {
+                    if (waitForIDs) { // some slides are currently formatted
+                        // adding the IDs of the format collector to the 'waitForIDs' collector
+                        _.each(formatCollector, function (oneID) { waitForIDs[oneID] = 1; });
+                        informListenersLater(waitForIDs, id); // the listeners need to be informed later
+                        waitingRequired = true;
+                    }
+
                     // formatting the collected slides
                     formatSlides(formatCollector).done(function () {
-                        // informing the listeners
-                        informListeners([id]);
+                        checkWaitingListeners(formatCollector); // checking, if waiting listeners can be informed
+                        if (!waitingRequired) {
+                            informListeners([id]); // informing the listeners, that the requested slide can be used
+                        }
                     });
                 } else {
-                    // nothing to do, required slide is already formatted
-                    informListeners([id]);
+                    if (waitForIDs) {
+                        informListenersLater(waitForIDs, id); // the listeners need to be informed later
+                    } else {
+                        informListeners([id]); // informing the listeners, that the requested slide can be used
+                    }
                 }
             });
 
         }
 
+        /**
+         * Registering a slide ID for deferred information of listeners. The listeners can only be
+         * informed, if all dependent slides (saved in waitObject) are also formatted.
+         *
+         * @param {Object} waitObject
+         *  An object containing as keys all those slide IDs of those slides, that need to be formatted,
+         *  before the listeners can be informed, that the slide with the specified ID is formatted
+         *  completely.
+         *
+         * @param {String} id
+         *  The ID of that slide, that can only be used by listeners, if all dependent slides (whose
+         *  ID is saved in waitObject) are also formatted.
+         */
+        function informListenersLater(waitObject, id) {
+            waitingIDs = waitingIDs || {};
+            waitingIDs[id] = waitObject;
+        }
+
+        /**
+         * Checking, if listeners can be informed, that a specified slide can be used.
+         *
+         * @param {String[]} formattedIDs
+         *  An array containing the IDs of all new formatted slides.
+         */
+        function checkWaitingListeners(formattedIDs) {
+            if (waitingIDs) {
+                _.each(waitingIDs, function (waitIDs, id) {
+
+                    _.each(formattedIDs, function (formattedID) {
+                        delete waitIDs[formattedID];
+                    });
+
+                    if (_.isEmpty(waitIDs)) {
+                        delete waitingIDs[id];
+                        informListeners([id]); // finally the waiting listeners can be informed
+                    }
+                });
+                if (_.isEmpty(waitingIDs)) { waitingIDs = null; }
+            }
+        }
+
         /**
          * Informing the listeners, that the slide with the specified IDs are formatted.
          * This includes a check, if the model was destroyed in the meantime, because the trigger
@@ -481,7 +613,7 @@ define('io.ox/office/presentation/model/slideformatmanager', [
         function informListeners(allSlideIDs) {
             self.executeDelayed(function () {
                 if (model && !model.destroyed) { model.trigger('slidestate:formatted', allSlideIDs); }
-            }, 50, 'Presentation: Trigger slidestate:formatted');
+            }, { delay: 50, infoString: 'Presentation: Trigger slidestate:formatted', app: app });
         }
 
         // methods ------------------------------------------------------------
@@ -497,7 +629,28 @@ define('io.ox/office/presentation/model/slideformatmanager', [
         };
 
         /**
-         * Whether the slide specified by its ID is an unformatted slide.
+         * Whether all slides are formatted.
+         *
+         * @returns {Boolean}
+         *  Whether all slides are formatted.
+         */
+        this.allSlidesFormatted = function () {
+            return !self.unformattedSlideExists();
+        };
+
+        /**
+         * Whehter at least one slide is currently formatted.
+         *
+         * @returns {Boolean}
+         *  Whehter at least one slide is currently formatted.
+         */
+        this.runningTasksExist = function () {
+            return !_.isEmpty(runningTasks);
+        };
+
+        /**
+         * Whether the slide specified by its ID is an unformatted slide. It is
+         * possible, that the slide is currently formatted.
          *
          * @param {String} id
          *  The id of a slide.
@@ -509,6 +662,65 @@ define('io.ox/office/presentation/model/slideformatmanager', [
             return allUnformattedSlides && !_.isUndefined(allUnformattedSlides[id]);
         };
 
+        /**
+         * Whether the slide specified ty its ID is already formatted.
+         *
+         * @param {String} id
+         *  The id of a slide.
+         *
+         * @returns {Boolean}
+         *  Whether the slide specified by its ID is formatted.
+         */
+        this.isFormattedSlide = function (id) {
+            return !self.isUnformattedSlide(id);
+        };
+
+        /**
+         * Checks whether a specified slide is currently formatted.
+         *
+         * @param {String} id
+         *  The ID of the slide, that needs to be formatted.
+         *
+         * @returns {Boolean}
+         *  Whether the slide with the specified id is currently formatted.
+         */
+        this.isRunningTask = function (id) {
+            return runningTasks[id] === 1;
+        };
+
+        /**
+         * Whether the specified slide set is already completely formatted.
+         *
+         * @param {String[]} set
+         *  The set of slide IDs.
+         *
+         * @returns {Boolean}
+         *  Whether all the slides specified by its IDs are formatted.
+         */
+        this.isSlideSetFormatted = function (set) {
+            return _.every(set, function (id) {
+                return self.isFormattedSlide(id);
+            });
+        };
+
+        /**
+         * Whether the specified slide set is already completely formatted
+         * or the slides are currently formatted. In this case no new formatting
+         * process must be triggered.
+         *
+         * @param {String[]} set
+         *  The set of slide IDs.
+         *
+         * @returns {Boolean}
+         *  Whether all the slides specified by its IDs are already formatted
+         *  or are currently formatted.
+         */
+        this.isSlideSetCurrentlyFormatted = function (set) {
+            return _.every(set, function (id) {
+                return self.isFormattedSlide(id) || self.isRunningTask(id);
+            });
+        };
+
         /**
          * Adding additional IDs to the container of unformatted slide IDs.
          *
@@ -531,11 +743,80 @@ define('io.ox/office/presentation/model/slideformatmanager', [
             }
         };
 
+        /**
+         * Shifting a specified slide set far to the left, so that it cannot be seen by the user. This is necessary
+         * during formatting of the slide. In this case the complete set of slide IDs need to be shifted, even though
+         * some slides of it might already be completely formatted.
+         *
+         * @param {String[]} idSet
+         *  The set of slide IDs that will be shifted to the left, so that the user cannot see it.
+         */
+        this.shiftSlideSetOutOfView = function (idSet) {
+
+            if (shiftedSlides) { return; } // only one set of shifted slides is supported
+
+            _.each(idSet, function (id) {
+                model.getSlideById(id).addClass('leftshift'); // using negative left offset, so that the scroll bar is not influenced
+            });
+
+            shiftedSlides = idSet;
+        };
+
+        /**
+         * Shifting back the slides that were shifted using 'shiftSlideSetOutOfView'. This must be done, if the active
+         * slide does not need this shifting, because all slides are formatted.
+         */
+        this.shiftSlideSetIntoView = function () {
+
+            _.each(shiftedSlides, function (id) {
+                if (!self.isRunningTask(id)) { // not shifting into view, if the slide is currently formatted
+                    model.getSlideById(id).removeClass('leftshift'); // using negative left offset, so that the scroll bar is not influenced
+                }
+            });
+
+            shiftedSlides = null;
+        };
+
+        /**
+         * Whether there are some slides shifted due to formatting reasons. During a long running formatting process
+         * all three slide nodes are shifted far to the left, so that the user cannot see half formatted slides. Even
+         * if master or layout slide are completely formatted, it makes no sense to show them until the document
+         * slide is completely formatted. Therefore the array 'shiftedSlides' contains the complete collection
+         * of a slide ID set.
+         *
+         * @returns {Boolean}
+         *  Whether there are some slides shifted due to formatting reasons.
+         */
+        this.shiftedSlideExist = function () {
+            return shiftedSlides !== null;
+        };
+
+        /**
+         * Whether a slide with a specified ID is shifted due to formatting reasons. This slide can already be
+         * completely formatted, but it is shifted, because another slide of the slide ID set of the active slide
+         * is not completely formatted.
+         *
+         * @param {String} id
+         *  The slide id.
+         *
+         * @returns {Boolean}
+         *  Whether the specified slide is shifted due to formatting reasons.
+         */
+        this.isShiftedSlide = function (id) {
+            return _.contains(shiftedSlides, id);
+        };
+
         /**
          * Forcing an update of one specified slide and its layout and master slide (if required).
          * This process is especially required for formatting the first visible slide.
          *
-         * @param {String} id
+         * Important: The caller of this function has to check, if the slide with the specified
+         *            id is not currently formatted. Otherwise it might happen, that the function
+         *            'changeSlideHandler' returns a resolved promise, even though the slide is
+         *            currently formatted and this formatting has not finished yet.
+         *            Check for the caller: if (!slideFormatManager.isRunningTask(id)) { ...
+         *
+         * @param {String|String[]} id
          *  The ID of the slide, that needs to be formatted.
          *
          * @returns {jQuery.Promise}
@@ -545,9 +826,9 @@ define('io.ox/office/presentation/model/slideformatmanager', [
         this.forceSlideFormatting = function (id) {
 
             var // the set of affected slides
-                set = model.getSlideIdSet(id);
+                set = _.isString(id) ? model.getSlideIdSet(id) : id;
 
-            return changeSlideHandler(null, { newSlideId: id, newLayoutId: set.layoutId, newMasterId: set.masterId });
+            return changeSlideHandler(null, { newSlideId: set.id, newLayoutId: set.layoutId, newMasterId: set.masterId });
         };
 
         /**
@@ -580,19 +861,6 @@ define('io.ox/office/presentation/model/slideformatmanager', [
           //model.trigger('formatmanager:init');
         };
 
-        /**
-         * Checks whether a specified slide is currently formatted.
-         *
-         * @param {String} id
-         *  The ID of the slide, that needs to be formatted.
-         *
-         * @returns {Boolean}
-         *  Whether the slide with the specified id is currently formatted.
-         */
-        this.isRunningTask = function (id) {
-            return runningTasks[id] === 1;
-        };
-
         // initialization -----------------------------------------------------
 
         app.onInit(function () {
