@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -14,9 +15,9 @@
 define('io.ox/office/presentation/model/updatedocumentmixin', [
     'io.ox/office/drawinglayer/view/drawingframe',
     'io.ox/office/textframework/utils/config',
-    'io.ox/office/textframework/utils/dom',
-    'io.ox/office/textframework/utils/textutils'
-], function (DrawingFrame, Config, DOM, Utils) {
+    'io.ox/office/textframework/utils/textutils',
+    'io.ox/office/textframework/utils/dom'
+], function (DrawingFrame, Config, Utils, DOM) {
 
     'use strict';
 
@@ -117,11 +118,21 @@ define('io.ox/office/presentation/model/updatedocumentmixin', [
                 // making the slides visible
                 app.leaveBusyDuringImport();
 
-                // Setting zoom level to 'Fit to screen width'
-                app.getView().setZoomType('slide');
+                // NO autotest (means: no selenium)
+                if (!Config.AUTOTEST) {
+                    // Setting zoom level to 'Fit to screen width'
+                    app.getView().setZoomType('slide');
+                }
+
+                // Setting contenteditable 'false' to pagecontent node in IE (46752)
+                if (_.browser.IE) { DOM.getPageContentNode(pagediv).attr('contenteditable', false); }
 
                 // writing some load logging information into the console (only in debug mode)
                 dumpProfilingInformation();
+
+                // trigger event to initialize the SlidePane, before the controller updates the GUI (looks better than vice versa)
+                // -> making slidepane immediately visible, so that user sees previews of available slides
+                self.trigger('slideModel:init', { isMasterView: self.isMasterView(), activeSlideId: self.getActiveSlideId(), width: self.getSlidePaneWidth(), slideRatio: self.getSlideRatio() });
             }
 
             // setting globals
