@@ -6,16 +6,18 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
 
 define('io.ox/office/presentation/model/updatelistsmixin', [
     'io.ox/office/tk/io',
+    'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/textframework/utils/textutils',
     'io.ox/office/textframework/utils/dom'
-], function (IO, Utils, DOM) {
+], function (IO, AttributeUtils, Utils, DOM) {
 
     'use strict';
 
@@ -42,7 +44,7 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
             // whether only the current paragraph needs to be updated
             onlySingleParagraph = false,
             // the debounced list handler function
-            updateListsDebounced = self.createDebouncedMethod(registerListUpdate, updateList, { delay: 10, infoString: 'Presentation: updateLists' });
+            updateListsDebounced = self.createDebouncedMethod(registerListUpdate, updateList, { delay: 10, infoString: 'Presentation: updateLists', app: app });
 
         // private methods ----------------------------------------------------
 
@@ -118,8 +120,12 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
                 isStartValueOnLevelSet = {},
                 // list of all paragraphs in the document
                 paragraphNodes = null,
+                // whether the paragraphs are specified
+                predefinedParagraphs = !_.isUndefined(paragraphs),
                 // the deferred, whose promise will be returned
-                def = null;
+                def = null,
+                // the target chain, that is required to resolve the correct theme
+                target = null;
 
             function updateListInParagraph(para) {
 
@@ -162,7 +168,9 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
                     // the list span inside the list label node
                     listSpans = null,
                     // whether the paragraph is empty
-                    isEmptyParagraph = false;
+                    isEmptyParagraph = false,
+                    // must call more often the model
+                    docModel = app.getModel();
 
                 // helper function to count the number for the list items in numbered lists
                 // (only used for numbered list paragraphs)
@@ -235,6 +243,9 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
                 isEmptyParagraph = $(para).hasClass(DOM.PARAGRAPH_NODE_LIST_EMPTY_CLASS) || DOM.isEmptyParagraph(para);
                 if (isEmptyParagraph) {
                     $(para).addClass(DOM.PARAGRAPH_NODE_LIST_EMPTY_CLASS); // -> adding a class to the paragraph to mark it as empty
+                    if (Utils.getDomNode(self.getSelectedParagraph()) === Utils.getDomNode(para)) {
+                        $(para).addClass(DOM.PARAGRAPH_NODE_LIST_EMPTY_SELECTED_CLASS); // -> adding a class to the paragraph to mark it as empty and selected
+                    }
                 }
 
                 // resetting counter for non numbering lists
@@ -242,7 +253,7 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
 
                 if (_.isNumber(listLevel) && listLevel >= 0) {
 
-                    noListLabel = paraAttributes.bullet.type === 'none';
+                    noListLabel = paraAttributes.bullet.type ? paraAttributes.bullet.type === 'none' : true;
                     imageUrl = paraAttributes.bullet.type === 'bitmap' ? paraAttributes.bullet.imageUrl : null;
 
                     // preparing counting of list item numbers
@@ -287,20 +298,27 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
 
                         if (imageUrl) {
 
-                            var absUrl = app.getServerModuleUrl(IO.FILTER_MODULE_NAME, { action: 'getfile', get_filename: imageUrl }),
-                                imageWidth = followingTextAttributes.fontSize, // TODO
-                                image = null;
+                            var absUrl = app.getServerModuleUrl(IO.FILTER_MODULE_NAME, { action: 'getfile', get_filename: imageUrl });
+                            var image = $('<div>', { contenteditable: false });
+                            var img = $('<img>', { src: absUrl });
 
-                            image = $('<div>', { contenteditable: false })
-                            .addClass('drawing')
+                            var options = null;
+                            if (!target && AttributeUtils.isCharacterFontThemed(followingTextAttributes)) { target = docModel.getTargetChainForNode(para); }
+                            if (target) { options = { theme: docModel.getThemeCollection().getTheme('', target) }; }
+
+                            var baseLine = 0.8 * docModel.getFontCollection().getBaseLineOffset(followingTextAttributes, options);
+
+                            // fix for Bug 47859 & Bug 48025
+                            image.css('height', Utils.convertToEM(baseLine, 'px'));
+                            img.css('height', Utils.convertToEM(baseLine, 'px'));
+
+                            image.addClass('drawing')
+                            .addClass('bulletdrawing')
                             .data('url', imageUrl)
-                            .append($('<div>').addClass('content')
-                                .append($('<img>', { src: absUrl }).css('width', Utils.convertToEM(imageWidth, 'pt')))
+                            .append(
+                                $('<div>').append(img)
                             );
 
-                            self.getCharacterStyles().updateElementLineHeight(image, paraAttributes.lineHeight, followingTextAttributes);
-                            $(image).css('height', Utils.convertToEM(followingTextAttributes.fontSize, 'pt'));
-                            $(image).css('width', Utils.convertToEM(followingTextAttributes.fontSize, 'pt'));
                             numberingElement.prepend(image);
 
                         } else if (!noListLabel) {
@@ -319,10 +337,14 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
                                 if (displayFontName) { listSpans.css('font-family', self.getCssFontFamily(displayFontName)); }
                             }
 
+                            if (AttributeUtils.isColorThemed(followingTextAttributes.color) && (!target || !predefinedParagraphs)) {
+                                target = docModel.getTargetChainForNode(para); // target chain should be identical for all predefined paragraphs
+                            }
+
                             if (paraAttributes.bulletColor.followText) {
-                                listSpans.css('color', self.getCssColor(followingTextAttributes.color, 'text'));
+                                listSpans.css('color', self.getCssColor(followingTextAttributes.color, 'text', target));
                             } else {
-                                listSpans.css('color', self.getCssColor(paraAttributes.bulletColor.color, 'text'));
+                                listSpans.css('color', self.getCssColor(paraAttributes.bulletColor.color, 'text', target));
                             }
 
                             // in numbering also bold and italic are adapted from the following text span
@@ -330,9 +352,9 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
                                 listSpans.css('font-weight', $(span).css('font-weight'));
                                 listSpans.css('font-style', $(span).css('font-style'));
                             }
-                        }
 
-                        // self.getCharacterStyles().updateElementLineHeight(numberingElement, paraAttributes.lineHeight, elementAttributes.character);
+                            self.getCharacterStyles().updateElementLineHeight(listSpans, paraAttributes.lineHeight, followingTextAttributes);
+                        }
 
                         // setting distance between margin, numbering element and text (effects only the numbering element!)
                         if (!noListLabel && paraAttributes.indentFirstLine < 0) {
@@ -343,7 +365,7 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
                             numberingElement.css('margin-left', (-paraAttributes.indentLeft - paraAttributes.indentFirstLine) / 100 + 'mm');
                         }
 
-                        $(para).prepend(numberingElement);
+                        if (!noListLabel) { $(para).prepend(numberingElement); } // adding the list label
 
                     }
                 }
@@ -357,7 +379,7 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
             paragraphNodes = paragraphs ? paragraphs : self.getCurrentRootNode().find(DOM.PARAGRAPH_NODE_SELECTOR).not('.slide');
 
             if (Utils.getBooleanOption(options, 'async', false)) {
-                def = self.iterateArraySliced(paragraphNodes, updateListInParagraph, { delay: 'immediate', infoString: 'Text: updateListInParagraph' });
+                def = self.iterateArraySliced(paragraphNodes, updateListInParagraph, { delay: 'immediate', infoString: 'UpdateListMixin: updateListInParagraph', app: app });
             } else {
                 paragraphNodes.each(function () { updateListInParagraph(this); });
                 def = $.when();
