@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Miroslav Dzunic <miroslav.dzunic@open-xchange.com>
  */
@@ -19,7 +20,7 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
     'io.ox/office/tk/locale/localedata',
     'io.ox/office/textframework/view/controls',
     'gettext!io.ox/office/presentation/main',
-    'less!io.ox/office/presentation/view/dialog/insertdatedialog'
+    'less!io.ox/office/presentation/view/dialog/presentationdialogs'
 ], function (Utils, DateUtils, Forms, Dialogs, LocaleData, Controls, gt) {
 
     'use strict';
@@ -111,7 +112,7 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
             nodes.toggleClass(Forms.DISABLED_CLASS, !state);
             if (state) {
                 nodes.removeAttr('aria-disabled');
-                nodes.prop('tabindex', 1);
+                nodes.prop('tabindex', 0);
             } else {
                 nodes.attr('aria-disabled', true);
                 nodes.prop('tabindex', -1);
@@ -157,7 +158,7 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
         function initControls() {
             var dateObject = extractByType(dialogOptions, 'dt');
             var isDate = !!dateObject;
-            var isAutoDate = dateObject && dateObject.automatic || false;
+            var isAutoDate = (dateObject && dateObject.automatic) || false;
             var slideNumObject = extractByType(dialogOptions, 'sldNum');
             var isSlideNum = !!slideNumObject;
             var footerObject = extractByType(dialogOptions, 'ftr');
@@ -175,7 +176,7 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
 
             dateContainer = $('<div class="date-container">').append(autoRadio, populateFieldFormats(), fixedRadio, fixedDateTextArea);
             // depending from auto or fixed date, disable select and input fields
-            dateContainer.find('select').prop('disabled', !isDate || !isAutoDate).toggleClass('disabled', !isDate || !isAutoDate).val(dateObject && dateObject.dtType || 'datetime1');
+            dateContainer.find('select').prop('disabled', !isDate || !isAutoDate).toggleClass('disabled', !isDate || !isAutoDate).val((dateObject && dateObject.dtType) || 'datetime1');
             dateContainer.find('input').prop('disabled', !isDate || isAutoDate).toggleClass('disabled', !isDate || isAutoDate);
             if (isDate && !isAutoDate) {
                 dateContainer.find('input').val(dateObject && dateObject.dtText);
@@ -236,7 +237,7 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
                 if (Forms.isCheckedButtonNode(dateCheckbox)) {
                     if (Forms.isCheckedButtonNode(autoRadioBtn)) {
                         selectedOption = $controlArea.find('option:selected');
-                        formatIndex = selectedOption.length && selectedOption.index() + 1 || null;
+                        formatIndex = selectedOption.length ? (selectedOption.index() + 1) : null;
                         obj = { type: 'dt', automatic: true, formatIndex: formatIndex, representation: selectedOption[0].text };
                     } else {
                         obj = { type: 'dt', automatic: false, representation: dateContainer.find('input').val() };
@@ -289,8 +290,8 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
             model.setBlockKeyboardEvent(true);
 
             // us 102078426: dialogs on small devices should come up w/o keyboard,
-            // so the focus shoud not be in an input element
-            self.getOkButton().focus();
+            // so the focus should not be in an input element
+            Utils.setFocus(self.getOkButton());
         });
 
         // add additional button
@@ -301,6 +302,14 @@ define('io.ox/office/presentation/view/dialog/insertfooterdialog', [
         this.getFooter().append(applyallBtn);
         this.getOkButton().children().html(gt('Apply'));
 
+        // ensure proper button order on small devices, because base dialog makes reorder
+        if (Utils.SMALL_DEVICE) {
+            this.on('beforeshow', function () {
+                applyallBtn.parent().detach();
+                this.getFooter().children('.row').append(applyallBtn.parent());
+            });
+        }
+
         // listen on checkbox to change icon
         dateCheckbox.on('click', function () {
             Forms.checkButtonNodes(this, !Forms.isCheckedButtonNode(this), { design: 'boxed', ambiguous: false });
