@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  */
@@ -21,8 +22,9 @@ define('io.ox/office/settings/register', [
     'io.ox/office/settings/contexttemplatemodel',
     'io.ox/office/settings/view/settingslabels',
     'io.ox/office/settings/units',
-    'io.ox/office/settings/userdictionary'
-], function (ext, Manifests, IO, DriveUtils, TemplateFolders, TemplateModel, ContextTemplateModel, Labels, Units, UserDictionary) {
+    'io.ox/office/settings/userdictionary',
+    'io.ox/office/tk/utils/deferredutils'
+], function (ext, Manifests, IO, DriveUtils, TemplateFolders, TemplateModel, ContextTemplateModel, Labels, Units, UserDictionary, DeferredUtils) {
 
     'use strict';
 
@@ -41,6 +43,8 @@ define('io.ox/office/settings/register', [
             return;
         }
 
+        var self = this;
+
         inited = true;
 
         //extend the global settings with office settings
@@ -98,7 +102,7 @@ define('io.ox/office/settings/register', [
          * standard dialog button
          */
         settingsObject.appendButton = function (title, listener) {
-            var btn = $('<button type="button" class="btn btn-primary" tabindex="1">');
+            var btn = $('<button type="button" class="btn btn-primary" tabindex="0">');
             btn.text(title).on('click', listener);
             settingsNode.append(btn);
             return btn;
@@ -145,7 +149,7 @@ define('io.ox/office/settings/register', [
                 type: 'GET',
                 dataType: 'json'
             });
-            var ret = $.Deferred();
+            var ret = DeferredUtils.createDeferred(self, 'Register: checkAdmin');
             resp.done(function (answer) {
                 if (answer.data.user_id && answer.data.user_id === answer.data.context_admin) {
                     ret.resolve();
