@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  */
@@ -95,7 +96,9 @@ define('io.ox/office/settings/templatefolders', [
 
                 if (!noRemove && !readOnly) {
 
-                    var rem = $('<a href="#" tabindex="1" role="button" data-action="remove" style="right: 0;">');
+                    var rem = $('<a href="#" tabindex="0" role="button" data-action="remove" style="right: 0;">');
+                    rem.addClass('io-ox-action-link');
+
                     var icn = $('<i class="fa fa-trash-o">');
                     rem.append(icn);
                     rem.attr('title', title);
@@ -114,7 +117,7 @@ define('io.ox/office/settings/templatefolders', [
                         });
                     };
 
-                    var perm = $('<a href="#" tabindex="1" role="button" style="right: 45px; position: absolute; margin-top: -5px; padding-right: 10px;">');
+                    var perm = $('<a href="#" tabindex="0" role="button" style="right: 45px; position: absolute; margin-top: -5px; padding-right: 10px;">');
                     perm.text(Labels.PERMISSIONS_LABEL);
                     ctrl.append(perm);
                     perm.click(function (evt) {
@@ -135,10 +138,11 @@ define('io.ox/office/settings/templatefolders', [
                 title.html('<b>' + Utils.escapeHTML(folder.title) + '</b>');
                 cnt.append(title);
 
-                var link = $('<a tabindex="1" class="sectiontitle" target="_blank" style="text-align: left; display: block; max-width: 80%;" href="#"></a>');
+                var link = $('<a tabindex="0" class="sectiontitle" target="_blank" style="text-align: left; display: block; max-width: 80%;" href="#"></a>');
 
                 link.data({ folder: id });
                 link.addClass('deep-link-files');
+                link.addClass('io-ox-action-link');
 
                 var displayPath = '';
                 for (var i = 1; i < path.length - 1; i += 1) {
