@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -21,7 +22,7 @@ define('io.ox/office/spreadsheet/app/application', [
     'io.ox/office/spreadsheet/model/model',
     'io.ox/office/spreadsheet/model/presetformattable',
     'io.ox/office/spreadsheet/view/view',
-    'io.ox/office/spreadsheet/app/controller',
+    'io.ox/office/spreadsheet/controller/controller',
     'io.ox/office/spreadsheet/services/commandmixin'
 ], function (Utils, LocaleData, ErrorCode, ErrorContext, EditApplication, SheetUtils, SpreadsheetModel, PresetFormatTable, SpreadsheetView, SpreadsheetController, CommandMixin) {
 
@@ -139,21 +140,21 @@ define('io.ox/office/spreadsheet/app/application', [
         function finalizePendingDocumentChanges(options) {
 
             // commit current text of the cell in-place edit mode (without validation)
-            docView.leaveCellEditMode('auto');
+            docView.leaveCellEditMode('force');
 
             // wait for the dependency manager recalculating all dirty formulas
             options = _.extend({}, options, { volatile: false });
             var promise = docModel.getDependencyManager().recalcFormulas(options);
 
             // do not forward the rejected state of the dependency manager after a timeout
-            promise = promise.then(null, $.when);
+            promise = promise.then(null, function (cause) {
+                if (cause !== 'destroy') { return $.when(); }
+            });
 
             // send all changed view settings (after recalculating the formulas which may
             // initially set the 'document modified' flag)
             return promise.done(function () {
-                if (docView && docView.sendChangedViewAttributes) {
-                    docView.sendChangedViewAttributes();
-                }
+                docView.sendChangedViewAttributes();
             });
         }
 
