@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  */
@@ -201,7 +202,8 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
          *  The title text from the passed attribute set.
          */
         function getChartTitle(attributes) {
-            return _.isObject(attributes) ? (attributes.text.link[0] || '') : '';
+            if (_.isObject(attributes) && _.isArray(attributes.text.link)) { return attributes.text.link[0] || ''; }
+            return '';
         }
 
         /**
@@ -272,10 +274,10 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
 
                 var possSources = chart.getDataSourceInfo();
                 if (possSources.warn) {
-                    return ChartCreator.updateSeries(app, range, sheet, chart);
+                    return ChartCreator.updateSeries({ app: app, sourceRange: range, sourceSheet: sheet, chartModel: chart });
                 }
 
-                return ChartCreator.updateSeries(app, range, sheet, chart, possSources.axis);
+                return ChartCreator.updateSeries({ app: app, sourceRange: range, sourceSheet: sheet, chartModel: chart, axis: possSources.axis });
             });
         }
 
@@ -294,35 +296,13 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
 
             var chartModel = getDrawingModel('chart');
             var data = DrawingLabels.CHART_TYPE_STYLES[id];
-            var oldData = chartModel.getMergedAttributeSet(true).chart;
 
-            var oldNoAx = oldData.type.indexOf('pie') === 0 || oldData.type.indexOf('donut') === 0;
-            var noAx = data.type.indexOf('pie') === 0 || data.type.indexOf('donut') === 0;
-
-            var oldBubble = oldData.type.indexOf('bubble') === 0;
-            var bubble = data.type.indexOf('bubble') === 0;
-
-            if (oldNoAx !== noAx || oldBubble !== bubble) {
-                // special behavior for bubble & pie charts!!!
-                // fix for Bug 46917
-                var possSources = chartModel.getDataSourceInfo();
-                if (possSources.warn) {
-                    return yellChartDirection(possSources.warn);
-                }
-                return ChartCreator.updateSeries(app, possSources.range, possSources.sheet, chartModel, possSources.axis, data);
+            // fix for Bug 46917 & Bug 49738
+            var possSources = chartModel.getDataSourceInfo();
+            if (possSources.warn) {
+                return yellChartDirection(possSources.warn);
             }
-
-            return createAndApplyChartOperation(chartModel, Operations.SET_DRAWING_ATTRIBUTES, { attrs: { chart: data } }, function (generator, position) {
-                if ((data.type === 'pie2d' || data.type === 'donut2d')) {
-                    var noShape = { line: ChartCreator.getNoneShape(), axis: { label: false } };
-                    generateChartOperation(generator, chartModel, Operations.SET_CHART_AXIS_ATTRIBUTES,     position, { attrs: noShape, axis: 'x' });
-                    generateChartOperation(generator, chartModel, Operations.SET_CHART_AXIS_ATTRIBUTES,     position, { attrs: noShape, axis: 'y' });
-                    generateChartOperation(generator, chartModel, Operations.SET_CHART_GRIDLINE_ATTRIBUTES, position, { attrs: noShape, axis: 'x' });
-                    generateChartOperation(generator, chartModel, Operations.SET_CHART_GRIDLINE_ATTRIBUTES, position, { attrs: noShape, axis: 'y' });
-                    generateChartOperation(generator, chartModel, Operations.SET_CHART_TITLE_ATTRIBUTES,    position, { attrs: { text: { link: [] }, character: null }, axis: 'x' });
-                    generateChartOperation(generator, chartModel, Operations.SET_CHART_TITLE_ATTRIBUTES,    position, { attrs: { text: { link: [] }, character: null }, axis: 'y' });
-                }
-            });
+            return ChartCreator.updateSeries({ app: app, sourceRange: possSources.range, sourceSheet: possSources.sheet, chartModel: chartModel, axis: possSources.axis, chartAttrs: data, typeChanged: true });
         }
 
         function isFirstRowColEnabled(chartModel, rowCol) {
@@ -358,12 +338,16 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
 
             if (possSources.axis) { rowCol = Math.abs(rowCol - 1); }
 
+            var forceTitle;// = undefined;
+            var forceNames;// = undefined;
             if (rowCol === 1) {
-                return ChartCreator.updateSeries(app, possSources.range, possSources.sheet, chartModel, possSources.axis, undefined, value, chartModel.isNamesLabel());
+                forceNames = chartModel.isNamesLabel();
+                forceTitle = value;
             } else {
-                return ChartCreator.updateSeries(app, possSources.range, possSources.sheet, chartModel, possSources.axis, undefined, chartModel.isTitleLabel(), value);
+                forceNames = value;
+                forceTitle = chartModel.isTitleLabel();
             }
-
+            return ChartCreator.updateSeries({ app: app, sourceRange: possSources.range, sourceSheet: possSources.sheet, chartModel: chartModel, axis: possSources.axis, forceTitle: forceTitle, forceNames: forceNames });
         }
 
         function exchange(chartModel) {
@@ -371,7 +355,7 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
             if (possSources.warn) {
                 return yellChartDirection(possSources.warn);
             }
-            return ChartCreator.updateSeries(app, possSources.range, possSources.sheet, chartModel, 1 - possSources.axis, undefined, chartModel.isNamesLabel(), chartModel.isTitleLabel());
+            return ChartCreator.updateSeries({ app: app, sourceRange: possSources.range, sourceSheet: possSources.sheet, chartModel: chartModel, axis: 1 - possSources.axis, forceTitle: chartModel.isNamesLabel(), forceNames: chartModel.isTitleLabel() });
         }
 
         function addAxisDef(axisId, defs) {
