@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -25,6 +26,25 @@ define('io.ox/office/spreadsheet/model/celloperationsbuilder', [
     var AddressArray = SheetUtils.AddressArray;
     var RangeArray = SheetUtils.RangeArray;
 
+    // private global functions ===============================================
+
+    /**
+     * Returns whether the passed cell range addresses are equal, or are both
+     * falsy.
+     *
+     * @param {Range|Null} range1
+     *  The first cell range address.
+     *
+     * @param {Range|Null} range2
+     *  The second cell range address.
+     *
+     * @returns {Boolean}
+     *  Whether the passed cell range addresses are equal, or are both falsy.
+     */
+    function equalRanges(range1, range2) {
+        return (!range1 && !range2) || (range1 && range2 && range1.equals(range2));
+    }
+
     // class JSONBuffer =======================================================
 
     /**
@@ -75,7 +95,8 @@ define('io.ox/office/spreadsheet/model/celloperationsbuilder', [
             (jsonData1.e === jsonData2.e) &&
             (jsonData1.f === jsonData2.f) &&
             (jsonData1.si === jsonData2.si) &&
-            _.isEqual(jsonData1.sr, jsonData2.sr) &&
+            (jsonData1.sr === jsonData2.sr) &&
+            (jsonData1.mr === jsonData2.mr) &&
             this._builder.areEqualStyleIds(jsonData1.s, jsonData2.s);
     };
 
@@ -258,6 +279,10 @@ define('io.ox/office/spreadsheet/model/celloperationsbuilder', [
      *      The address of the first cell to generate operations for, if known.
      *      By default, address A1 will be used to be sure to include all cells
      *      in the generated operations.
+     *  @param {Address} [initOptions.skipShared=false]
+     *      Whether to skip updating the shared formulas after generating the
+     *      cell operations. Should be used by code that handles updating the
+     *      shared formulas internally.
      */
     function CellOperationsBuilder(sheetModel, generator, initOptions) {
 
@@ -267,6 +292,9 @@ define('io.ox/office/spreadsheet/model/celloperationsbuilder', [
         // the configuration for the formula grammar used in operations
         this._formulaGrammar = sheetModel.getDocModel().getFormulaGrammar('op');
 
+        // the formula parser (used to generate range strings)
+        this._formulaParser = sheetModel.getDocModel().getFormulaParser();
+
         // the cell collection this builder works on
         this._cellCollection = sheetModel.getCellCollection();
 
@@ -274,22 +302,29 @@ define('io.ox/office/spreadsheet/model/celloperationsbuilder', [
         this._generator = generator;
 
         // the JSON data for the cell operations
-        this._cellBuffer = new JSONBuffer(this);
+        this._cellBuffer = null;
 
         // the JSON data for the undo operations
-        this._undoBuffer = new JSONBuffer(this);
+        this._undoBuffer = null;
 
         // the cell address of the start cell for this builder
-        this._startAddress = Utils.getOption(initOptions, 'startAddress', Address.A1).clone();
+        this._startAddress = null;
 
         // the cell address of the first cell not yet manipulated by this builder
-        this._nextAddress = this._startAddress.clone();
+        this._nextAddress = null;
 
         // the addresses of all cells changed by this builder
-        this._changedAddresses = new AddressArray();
+        this._changedAddresses = null;
 
-        // changed shared formula IDs
-        this._sharedFormulas = new AddressArray();
+        // whether to update all shared formulas in the cell collection
+        this._refreshShared = true;
+
+        // whether shared formulas need to be updated after changing formula properties
+        this._dirtyShared = false;
+
+        // initialization -----------------------------------------------------
+
+        this._initialize(initOptions);
 
     } // class CellOperationsBuilder
 
@@ -307,12 +342,28 @@ define('io.ox/office/spreadsheet/model/celloperationsbuilder', [
      *  cell at all.
      */
     CellOperationsBuilder.isEmptyJSON = function (jsonData) {
-        return !('u' in jsonData) && !('v' in jsonData) && !('e' in jsonData) &&
-            !('f' in jsonData) && !('si' in jsonData) && !('sr' in jsonData) && !('s' in jsonData);
+        return !('u' in jsonData) && !('v' in jsonData) && !('e' in jsonData) && !('s' in jsonData) &&
+            !('f' in jsonData) && !('si' in jsonData) && !('sr' in jsonData) && !('mr' in jsonData);
     };
 
     // private methods --------------------------------------------------------
 
+    /**
+     * Initializes the properties of this instance for a new processing cycle.
+     *
+     * @param {Object} [options]
+     *  All optional parameters supported by the constructor of this class.
+     */
+    CellOperationsBuilder.prototype._initialize = function (options) {
+        this._cellBuffer = new JSONBuffer(this);
+        this._undoBuffer = new JSONBuffer(this);
+        this._startAddress = Utils.getOption(options, 'startAddress', Address.A1).clone();
+        this._nextAddress = this._startAddress.clone();
+        this._changedAddresses = new AddressArray();
+        this._refreshShared = !Utils.getBooleanOption(options, 'skipShared', false);
+        this._dirtyShared = false;
+    };
+
     /**
      * Assigns an error code as string to the 'e' operation property, otherwise
      * the passed value to the 'v' property of the passed JSON cell object, to
@@ -334,13 +385,29 @@ define('io.ox/office/spreadsheet/model/celloperationsbuilder', [
         }
     };
 
+    /**
+     * Converts the passed cell range address to its string representation as
+     * used in document operations.
+     *
+     * @param {Range} range
+     *  The cell range address to be converted.
+     *
+     * @returns {String}
+     *  The string representation of the passed cell range address.
+     */
+    CellOperationsBuilder.prototype._formatRange = function (range) {
+        return this._formulaParser.formatRange('op', range);
+    };
+
     /**
      * Appends the JSON data for a single cell to the data buffers.
      */
-    CellOperationsBuilder.prototype._createCell = function (contents, options) {
+    CellOperationsBuilder.prototype._createCell = function (contents) {
 
+        // the address of teh cell to be modified
+        var address = this._nextAddress;
         // the model of the cell to be manipulated
-        var cellModel = this._cellCollection.getCellModel(this._nextAddress);
+        var cellModel = this._cellCollection.getCellModel(address);
         // whether to delete the cell model explicitly
         var deleteCell = contents.u === true;
         // the resulting JSON contents object
@@ -348,53 +415,78 @@ define('io.ox/office/spreadsheet/model/celloperationsbuilder', [
         // the resulting JSON contents object for the undo operation
         var undoJSON = {};
 
-        // true if shared formula cell address should be collected if cell changes (value, formula or delete cell) occurred.
-        var collectSharedFormulas = Utils.getBooleanOption(options, 'collectsharedformulas', true);
-        // True if the value formula is changed or the cell will be deleted
-        var cellValueChanges = false;
+        // the original value or formula result of the cell
+        var oldValue = cellModel ? cellModel.v : null;
+        // the original formula expression of the cell
+        var oldFormula = cellModel ? cellModel.f : null;
+        // the original index of a shared formula
+        var oldSharedIndex = cellModel ? cellModel.si : null;
+        // the original bounding range of a shared formula
+        var oldSharedRange = cellModel ? cellModel.sr : null;
+        // the original bounding range of a matrix formula
+        var oldMatrixRange = cellModel ? cellModel.mr : null;
 
         // create the properties in the JSON data that will really change the cell model
         if (!deleteCell) {
 
             // copy the cell value to the JSON data (unless it does not change)
-            var oldValue = cellModel ? cellModel.v : null;
             if (('v' in contents) && (contents.v !== oldValue)) {
                 this._putValue(cellJSON, contents.v);
                 this._putValue(undoJSON, oldValue);
-                cellValueChanges = true;
             }
 
             // copy the cell formula to the JSON data (unless it does not change)
-            var oldFormula = cellModel ? cellModel.f : null;
             if (('f' in contents) && (contents.f !== oldFormula)) {
                 cellJSON.f = contents.f;
                 undoJSON.f = oldFormula;
-                cellValueChanges = true;
             }
 
-            // copy the cell shared formula id to the JSON data (unless it does not change)
-            var oldSharedFormulaID = cellModel ? cellModel.si : null;
-            if (('si' in contents) && (contents.si !== oldSharedFormulaID)) {
+            // copy the shared formula index to the JSON data (unless it does not change)
+            if (('si' in contents) && (contents.si !== oldSharedIndex)) {
                 cellJSON.si = contents.si;
-                undoJSON.si = oldSharedFormulaID;
+                undoJSON.si = oldSharedIndex;
             }
 
-            // copy the cell shared formula range to the JSON data (unless it does not change)
-            var oldSharedFormulaRange = cellModel ? cellModel.sr : null;
-            if (('sr' in contents) && ((contents.sr === null && oldSharedFormulaRange !== null) || (contents.sr !== null && oldSharedFormulaRange === null) || (contents.sr && oldSharedFormulaRange && contents.sr.differs(oldSharedFormulaRange)))) {
-                cellJSON.sr = contents.sr ? contents.sr.toJSON() : null;
-                undoJSON.sr = oldSharedFormulaRange ? oldSharedFormulaRange.toJSON() : null;
+            // copy the shared formula range to the JSON data (unless it does not change)
+            if (('sr' in contents) && !equalRanges(contents.sr, oldSharedRange)) {
+                cellJSON.sr = contents.sr ? this._formatRange(contents.sr) : null;
+                undoJSON.sr = oldSharedRange ? this._formatRange(oldSharedRange) : null;
             }
-            if ('sa' in contents) {
-                undoJSON.sa = contents.sa;
+
+            // copy the matrix formula range to the JSON data (unless it does not change)
+            if (('mr' in contents) && !equalRanges(contents.mr, oldMatrixRange)) {
+                cellJSON.mr = contents.mr ? this._formatRange(contents.mr) : null;
+                undoJSON.mr = oldMatrixRange ? this._formatRange(oldMatrixRange) : null;
             }
 
+            // add more cell properties to detach the cell from a shared formula or matrix formula
+            if (this._refreshShared && ('f' in contents)) {
+                // reset the shared index if it has not been changed explicitly
+                if ((oldSharedIndex !== null) && !('si' in contents)) {
+                    cellJSON.si = null;
+                    undoJSON.si = oldSharedIndex;
+                }
+                // reset the bounding range if the current cell is the anchor cell of the shared formula
+                if (oldSharedRange && !('sr' in contents)) {
+                    cellJSON.sr = null;
+                    undoJSON.sr = this._formatRange(oldSharedRange);
+                }
+                // reset the bounding range if the current cell is the anchor cell of the matrix formula
+                if (oldMatrixRange && !('mr' in contents)) {
+                    cellJSON.mr = null;
+                    undoJSON.mr = this._formatRange(oldMatrixRange);
+                }
+            }
+
+            // bounding ranges of shared formulas need to be updated when changing the shared index
+            if ('si' in cellJSON) { this._dirtyShared = true; }
+
             // the default column/row auto-style identifier for undefined cells, with current column/row defaults
-            var defStyleId = this._cellCollection.getDefaultStyleId(this._nextAddress);
+            var defStyleId = this._cellCollection.getDefaultStyleId(address);
             // range mode 'row:merge': ignore the row style that has been set during this operation cycle when creating the cell auto-style
             var ignoreRowStyle = contents.rangeMode === 'row:merge';
             // the identifier of the base auto-style used to create the new cell auto-style
-            var baseStyleId = cellModel ? cellModel.s : ignoreRowStyle ? this._cellCollection.getDefaultStyleId(this._nextAddress, true) : defStyleId;
+            var baseStyleId = cellModel ? cellModel.s : ignoreRowStyle ? this._cellCollection.getDefaultStyleId(address, true) : defStyleId;
             // the resulting auto-style identifier (try to get a cached identifier from a previous call)
             var newStyleId = this._generator.generateAutoStyle(baseStyleId, contents);
 
@@ -416,8 +508,9 @@ define('io.ox/office/spreadsheet/model/celloperationsbuilder', [
             deleteCell = cellModel &&
                 (('v' in contents) ? (contents.v === null) : (oldValue === null)) &&
                 (('f' in contents) ? (contents.f === null) : (oldFormula === null)) &&
-                (('si' in contents) ? (contents.si === null) : (oldSharedFormulaID === null)) &&
-                (('sr' in contents) ? (contents.sr === null) : (oldSharedFormulaRange === null)) &&
+                (('si' in cellJSON) ? (cellJSON.si === null) : (oldSharedIndex === null)) &&
+                (('sr' in cellJSON) ? (cellJSON.sr === null) : (oldSharedRange === null)) &&
+                (('mr' in cellJSON) ? (cellJSON.mr === null) : (oldMatrixRange === null)) &&
                 this.areEqualStyleIds(defStyleId, newStyleId);
 
             // the cell simply needs to be deleted on undo, if it does not exist yet and will be created
@@ -435,26 +528,19 @@ define('io.ox/office/spreadsheet/model/celloperationsbuilder', [
 
             // restore the cell value, formula, and auto-style
             undoJSON = {};
-            if (cellModel.v !== null) { this._putValue(undoJSON, cellModel.v); }
-            if (cellModel.f !== null) { undoJSON.f = cellModel.f; }
-            if (cellModel.si !== null) { undoJSON.si = cellModel.si; }
-            if (cellModel.sr !== null) { undoJSON.sr = cellModel.sr.toJSON(); }
+            if (oldValue !== null) { this._putValue(undoJSON, oldValue); }
+            if (oldFormula !== null) { undoJSON.f = oldFormula; }
+            if (oldSharedIndex !== null) { undoJSON.si = oldSharedIndex; }
+            if (oldSharedRange) { undoJSON.sr = this._formatRange(oldSharedRange); }
+            if (oldMatrixRange) { undoJSON.mr = this._formatRange(oldMatrixRange); }
             if (!this.isDefaultStyleId(cellModel.s)) { undoJSON.s = cellModel.s; }
 
-            cellValueChanges = true;
+            // update shared formula after deleting one of its cells
+            if (oldSharedIndex !== null) { this._dirtyShared = true; }
         }
 
-        // Collect the Shared Formula IDs
-        if (!deleteCell && cellValueChanges && collectSharedFormulas && cellModel && cellModel.si !== null) {
-            var sharedFormulaAddresses = this._sharedFormulas[cellModel.si];
-            if (!sharedFormulaAddresses) {
-                sharedFormulaAddresses = new AddressArray();
-                this._sharedFormulas[cellModel.si] = sharedFormulaAddresses;
-            }
-            sharedFormulaAddresses.push(cellModel.a.clone());
-        }
-
-        // whether the cell will be changed at all (method JSONBuffer.addCell() changes the JSON object in-place)
+        // whether the cell will be changed at all (store this information before calling the method
+        // JSONBuffer.addCell(), which changes/extends the JSON object in-place)
         var changed = !_.isEmpty(cellJSON);
 
         // insert the JSON objects into the data buffers, update addresses
@@ -465,15 +551,38 @@ define('io.ox/office/spreadsheet/model/celloperationsbuilder', [
     };
 
     /**
-     * Destroy the JSONBuffers and delete all properties.
+     * Generates the document operation, and the undo operation, for all cells
+     * collected by this builder instance.
+     *
+     * @param {Object} [options]
+     *  Optional parameters. Supports all options that are supported by the
+     *  public method CellOperationsBuilder.finalizeOperations().
+     *
+     * @returns {AddressArray}
+     *  The addresses of all changed cells.
      */
-    CellOperationsBuilder.prototype._reset = function () {
-        // base class will delete all instance properties
+    CellOperationsBuilder.prototype._finalize = function (options) {
+
+        // whether to generate the operation for the export filters only
+        var filter = Utils.getBooleanOption(options, 'filter', false);
+
+        // generate the undo operations
+        if (!filter && Utils.getBooleanOption(options, 'createUndo', true)) {
+            this._undoBuffer.generateOperation(this._generator, this._startAddress, { undo: true });
+        }
+
+        // generate operations for the collected cell data
+        if (Utils.getBooleanOption(options, 'createCells', true)) {
+            this._cellBuffer.generateOperation(this._generator, this._startAddress, { filter: filter });
+        }
+
+        // destroy the JSON data buffers
         this._cellBuffer.destroy();
         this._undoBuffer.destroy();
+        this._cellBuffer = this._undoBuffer = null;
 
-        // reset all properties to prevent dangling references
-        _.each(this, function (value, name, self) { delete self[name]; });
+        // return the addresses of all changed cells, for convenience
+        return this._changedAddresses;
     };
 
     // public methods ---------------------------------------------------------
@@ -546,8 +655,8 @@ define('io.ox/office/spreadsheet/model/celloperationsbuilder', [
     };
 
     /**
-     * Generates the remaining document operation, and the undo operation, for
-     * all cells collected by this builder instance, and invalidates the entire
+     * Generates the document operations, and the undo operations, for all
+     * cells collected by this builder instance, and invalidates the entire
      * builder instance.
      *
      * @param {Object} [options]
@@ -560,41 +669,32 @@ define('io.ox/office/spreadsheet/model/celloperationsbuilder', [
      *      If set to true, operations for export filters will be created
      *      (remote editor clients will ignore the operations).
      *
-     * @returns {jQuery.Promise}
-     *  A promise that will be resolved when all operations have been
-     *  finalized. The promise returns the addresses (RangeArray) of all cell ranges containing changed cells.
+     * @returns {RangeArray}
+     *  The addresses of all cell ranges containing changed cells.
      */
     CellOperationsBuilder.prototype.finalizeOperations = SheetUtils.profileMethod('CellOperationsBuilder.finalizeOperations()', function (options) {
 
-        var self = this;
-        // whether to generate the operation for the export filters only
-        var filter = Utils.getBooleanOption(options, 'filter', false);
+        // create the operations for all cells collected by this instance
+        var changedAddresses = this._finalize(options);
 
-        // generate the undo operations
-        if (!filter && Utils.getBooleanOption(options, 'createUndo', true)) {
-            this._undoBuffer.generateOperation(this._generator, this._startAddress, { undo: true });
+        // update the bounding ranges of all affected shared formulas
+        if (this._refreshShared && this._dirtyShared) {
+
+            // calculate all cell properties needed to update the cells of the shared formulas
+            var contentsArray = this._cellCollection.generateUpdateSharedFormulaContents();
+
+            // generate the document operations for all affected anchor cells
+            if (contentsArray.length > 0) {
+                this._initialize({ skipShared: true });
+                contentsArray.forEach(function (entry) {
+                    this.createCells(entry.address, entry.contents, 1);
+                }, this);
+                changedAddresses.append(this._finalize(options));
+            }
         }
 
-        // generate operations for the collected cell data
-        if (Utils.getBooleanOption(options, 'createCells', true)) {
-            this._cellBuffer.generateOperation(this._generator, this._startAddress, { filter: filter });
-        }
-
-        // return the changed cell ranges (merged from the changed cell addresses)
-        var changedRanges = RangeArray.mergeAddresses(this._changedAddresses);
-
-        var promise;
-        if (_.isEmpty(this._sharedFormulas)) {
-            promise = this._cellCollection.createResolvedPromise();
-        } else {
-            promise = this._cellCollection.generateSharedFormulaUpdateOperations(this._generator, this._sharedFormulas);
-        }
-
-        return promise.then(function () {
-            // base class will delete all instance properties
-            self._reset();
-            return changedRanges;
-        });
+        // return the addresses of all changed ranges
+        return RangeArray.mergeAddresses(changedAddresses);
     });
 
     // exports ================================================================
