@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  */
@@ -31,26 +32,19 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
      *
      * @extends AttributedModel
      */
-    var AxisModel = AttributedModel.extend({ constructor: function (chartModel, axisId, otherType) {
+    var AxisModel = AttributedModel.extend({ constructor: function (chartModel, axisId) {
 
         var self = this;
         var titleModel = null;
         var gridModel = null;
-        var zeroLine = null;
         var format = null;
 
         var dataAxis = chartModel.getModelData()['axis' + axisId.toUpperCase()];
         if (dataAxis) {
-            titleModel = new TitleModel(chartModel, axisId);
+            titleModel = new TitleModel(chartModel, axisId, dataAxis, 'title');
             gridModel = new GridlineModel(chartModel, axisId, {}, dataAxis);
 
-            var otherAxis = chartModel.getModelData()['axis' + otherType.toUpperCase()];
-            if (otherAxis.stripLines) {
-                zeroLine = otherAxis.stripLines[0];
-                if (zeroLine && !zeroLine.zero) {
-                    zeroLine = null;
-                }
-            }
+            dataAxis.labelFormatter = function (info) { return info.label || formatNumber(info.value); };
         }
 
         // base constructor ---------------------------------------------------
@@ -59,6 +53,20 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
 
         // private methods ----------------------------------------------------
 
+        function formatNumber(value) {
+            if (!chartModel) {
+                Utils.warn('no chartmodel in AxisModel.formatNumber()');
+                return;
+            }
+            var formatter = chartModel.getDocModel().getNumberFormatter();
+            var realValue = value * Math.pow(10, format.exp);
+            if (format && format.format) {
+                return formatter.formatValue(format.format, realValue);
+            } else {
+                return formatter.formatStandardNumber(realValue, 8);
+            }
+        }
+
         function isHorizontal() {
             return chartModel.getAxisIdForDrawing(axisId) === 'x';
         }
@@ -69,14 +77,11 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                 return;
             }
 
+            // fix for Bug 46910 & Bug 49574
             if (isHorizontal()) {
-                if (format && format.format) {
-                    dataAxis.labelAutoFit = false;
-                } else {
-                    dataAxis.labelAutoFit = true;
-                }
+                delete dataAxis.labelAngle;
             } else {
-                dataAxis.labelAutoFit = true;
+                dataAxis.labelAngle = 0;
             }
 
             if (axisId === 'x') {
@@ -127,7 +132,7 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
             return newMant * Math.pow(10, normalized.exp);
         }
 
-        function updateMinMax(minValue, maxValue, precision, intervalCount, xAxis, allLabels) {
+        function updateMinMax(minValue, maxValue, precision, intervalCount) {
             if (minValue < maxValue) {
                 var interval = (maxValue - minValue) / intervalCount;
                 interval = round(interval, precision - 1);
@@ -149,11 +154,18 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                         maxValue = minValue + (interval * intCount);
                     }
                 }
-                setMinMax(minValue, maxValue, interval, xAxis, allLabels);
+                setMinMax(minValue, maxValue, interval);
             }
         }
 
-        function setMinMax(min, max, interval, xAxis, allLabels) {
+        function setMinMax(min, max, interval) {
+            if (!interval || !format || !isFinite(min) || !isFinite(max)) {
+                delete dataAxis.minimum;
+                delete dataAxis.maximum;
+                delete dataAxis.interval;
+                dataAxis.stripLines = [];
+                return;
+            }
 
             if (min < 0 && format && format.format && format.format.category === 'date') { min = 0; }
 
@@ -164,32 +176,19 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
             var stripLines = dataAxis.stripLines;
             var i = 0;
 
-            if (!interval) {
-                if (stripLines.length > 1) {
-                    for (i = stripLines.length - 1; i >= 0; i -= 1) {
-                        var stripLine = stripLines[i];
-                        if (!stripLine.zero) {
-                            stripLines.splice(i, 1);
-                        }
-                    }
-                }
-                return;
-            }
-
             var index = 0;
-            var formatter = chartModel.getDocModel().getNumberFormatter();
             var steps = (dataAxis.maximum - dataAxis.minimum) / dataAxis.interval;
             var lastLine = null;
             var line = null;
 
-            for (i = 0; i <= steps; i += 1) {
+            if (chartModel.isXYType() && isHorizontal()) {
+                i = 1; // not enough space for first label
+            }
+
+            for (; i <= steps; i += 1) {
                 var value = dataAxis.minimum + i * dataAxis.interval;
 
                 line = stripLines[index];
-                if (line && line.zero) {
-                    index++;
-                    line = stripLines[index];
-                }
                 if (!line) {
                     line = {
                         value: 0,
@@ -204,31 +203,23 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                 line.label = '';
                 line.value = value;
                 line.labelPlacement = 'outside';
+                line.label = formatNumber(value);
 
-                if (allLabels || dataAxis.labelAutoFit || (index % 2)) {
-                    var realValue = value * Math.pow(10, format.exp);
-                    if (format && format.format) {
-                        line.label = formatter.formatValue(format.format, realValue);
-                    } else {
-                        line.label = formatter.formatStandardNumber(realValue, 8);
-                    }
-                    if (!line.label || (lastLine && lastLine.label === line.label)) {
-                        line.label = '';
-                        lastLine = null;
-                    } else {
-                        lastLine = line;
-                    }
-
-                    if (xAxis && lastLine && lastLine.label.length > 1) {
-                        if (value === max && i === steps) {
-                            line.label = '';
-                        } else if (value === min && !i && dataAxis.labelAngle) {
-                            line.label = '';
-                        }
-                    }
+                if (!line.label || (lastLine && lastLine.label === line.label)) {
+                    line.label = '';
+                } else {
+                    lastLine = line;
                 }
+
                 index++;
             }
+
+            // workaround for Bug 49637
+            if (!isHorizontal()) {
+                dataAxis.minimum -= dataAxis.interval * 0.001;
+                dataAxis.maximum += dataAxis.interval * 0.001;
+            }
+
             for (; index < stripLines.length; index++) {
                 line = stripLines[index];
                 line.labelFontColor = 'transparent';
@@ -250,7 +241,6 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                     });
                 });
 
-                // TODO: disable this block to reproduce Bug 46447
                 if (chartModel.isXYType()) {
                     var intervalCount = Utils.minMax(data.series.length, 2, 8);
                     var diff = maxValue - minValue;
@@ -267,9 +257,9 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                     minValue -= 0.5;
                 }
 
-                updateMinMax(minValue, maxValue, 2, 4, true, area);
+                updateMinMax(minValue, maxValue, 2, 4);
             } else {
-                setMinMax(null, null, null, true);
+                setMinMax(null, null, null);
             }
         }
 
@@ -303,15 +293,20 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
             if (stacking === 'percentStacked' || (stacking === 'stacked' && data.series.length > 1)) {
                 var first = data.series[0];
                 _.times(first.dataPoints.length, function (j) {
-                    var value = 0;
+                    var posValue = 0;
+                    var negValue = 0;
                     _.each(data.series, function (dd) {
                         var jValue = dd.dataPoints[j];
                         if (!jValue) { return; }
                         var useValue = jValue[axisId];
-                        value += useValue;
+                        if (useValue > 0) {
+                            posValue += useValue;
+                        } else if (useValue < 0) {
+                            negValue += useValue;
+                        }
                     });
-                    minValue = Math.min(minValue, value);
-                    maxValue = Math.max(maxValue, value);
+                    minValue = Math.min(minValue, negValue);
+                    maxValue = Math.max(maxValue, posValue);
                 });
             } else {
                 _.each(data.series, function (dd) {
@@ -323,14 +318,11 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                 });
             }
 
-            var ignoreMax = false;
-
             if (chartModel.isXYType()) {
                 var diff = maxValue - minValue;
                 maxValue += diff / 8;
                 minValue -= diff / 8;
             } else if (stacking === 'percentStacked') {
-                ignoreMax = true;
                 format = {
                     exp: -2,
                     format: chartModel.getDocModel().getNumberFormatter().getParsedFormat('0%', { grammarId: 'ui' })
@@ -347,7 +339,11 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                 } else {
                     // scenario 3
                     maxValue =  givenMax || 110;
-                    minValue =  givenMin || -110;
+                    if (-minValue > maxValue) {
+                        minValue =  givenMin || -110;
+                    } else {
+                        minValue =  givenMin || (-100 * ((-minValue) / maxValue));
+                    }
                 }
             } else {
                 if (maxValue >= 0 && minValue >= 0) {
@@ -378,7 +374,7 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
             }
 
             var precision = 2;
-            if (format.date) {
+            if (format && format.date) {
                 precision = 0;
             }
 
@@ -387,7 +383,7 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                 maxValue = round(maxValue, precision);
             }
 
-            updateMinMax(minValue, maxValue, precision, 8, ignoreMax);
+            updateMinMax(minValue, maxValue, precision, 8);
         }
 
         // public methods -----------------------------------------------------
@@ -408,36 +404,25 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                 dataAxis.labelFontColor = 'transparent';
                 dataAxis.labelFontSize = 1;
             }
+            dataAxis.labelPlacement = 'outside';
 
-            if (zeroLine) {
-                zeroLine.color = dataAxis.lineColor;
-                zeroLine.thickness = dataAxis.lineThickness;
-            }
-
-            var overwriteLabels = false;
             var stripLines = dataAxis.stripLines;
-            _.each(stripLines, function (stripLine) {
-                if (!stripLine.zero) {
-                    if (attrs.axis.label) {
-                        ChartStyleUtil.handleCharacterProps(chartModel, attrs.character, stripLine, 'label');
-                    } else {
-                        stripLine.labelFontColor = 'transparent';
-                        stripLine.labelFontSize = 1;
-                    }
-                    overwriteLabels = true;
-                }
-            });
+            var overwriteLabels = stripLines.length > 0;
+
             if (overwriteLabels) {
+                _.each(stripLines, function (stripLine) {
+                    stripLine.labelFontColor    = dataAxis.labelFontColor;
+                    stripLine.labelFontSize     = dataAxis.labelFontSize;
+                    stripLine.labelFontFamily   = dataAxis.labelFontFamily;
+                    stripLine.labelFontWeight   = dataAxis.labelFontWeight;
+                    stripLine.labelFontStyle    = dataAxis.labelFontStyle;
+                });
                 dataAxis.labelFontColor = 'transparent';
+
             }
 
             gridModel.refreshInfo();
-
-            var titleAtt = titleModel.getMergedAttributeSet(true);
-            dataAxis.title = titleAtt.text.link[0];
-            if (dataAxis.title) {
-                ChartStyleUtil.handleCharacterProps(chartModel, titleAtt.character, dataAxis, 'title');
-            }
+            titleModel.refreshInfo();
         };
 
         this.setFormat = function (newFormat) {
@@ -471,7 +456,7 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
 
             // restore this axis
             if (this.hasExplicitAttributes()) {
-                var properties = { axis: axisId, attrs: this.getExplicitAttributeSet(true) };
+                var properties = { axis: axisId, attrs: this.getExplicitAttributeSet(false) };
                 generator.generateDrawingOperation(Operations.SET_CHART_AXIS_ATTRIBUTES, position, properties, { undo: true });
             }
 
@@ -482,12 +467,38 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
             return this;
         };
 
+        /**
+         * Generates the operations and undo operations to update or restore
+         * the formula expressions of the source link of the axis title object.
+         *
+         * @param {SheetOperationsGenerator} generator
+         *  The operations generator to be filled with the operations.
+         *
+         * @param {Array<Number>} position
+         *  The position of the parent chart object in the sheet, as expected
+         *  by the method SheetOperationsGenerator.generateDrawingOperation().
+         *
+         * @param {Object} changeDesc
+         *  The properties describing the document change. The properties that
+         *  are expected in this descriptor depend on the change type in its
+         *  'type' property. See method TokenArray.resolveOperation() for more
+         *  details.
+         *
+         * @returns {AxisModel}
+         *  A reference to this instance.
+         */
+        this.generateUpdateFormulaOperations = function (generator, position, changeDesc) {
+            if (titleModel) { titleModel.generateUpdateFormulaOperations(generator, position, changeDesc); }
+            return this;
+        };
+
         // initialization -----------------------------------------------------
 
         this.registerDestructor(function () {
+            if (dataAxis) { delete dataAxis.labelFormatter; }
             if (gridModel) { gridModel.destroy(); }
             if (titleModel) { titleModel.destroy(); }
-            chartModel = gridModel = titleModel = null;
+            dataAxis = chartModel = gridModel = titleModel = null;
         });
 
     } }); // class AxisModel
