@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Carsten Driesner <carsten.driesner@open-xchange.com>
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
@@ -112,6 +113,8 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
 
         var docModel = sheetModel.getDocModel();
 
+        var app = docModel.getApp();
+
         var fileFormat = docModel.getApp().getFileFormat();
 
         var controllerToken = null;
@@ -119,29 +122,45 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
         var data = {
             animationEnabled: false,
             culture:  'en',
-            // zoomEnabled: true,
             bg: 'white',
             backgroundColor: 'transparent',
-            axisX: { stripLines: [], valueFormatString: ' ' },
-            axisY: { stripLines: [], valueFormatString: ' ' },
+            axisX: { stripLines: [], labelAutoFit: true },
+            axisY: { stripLines: [], labelAutoFit: true },
             axisZ: { stripLines: [] },
             creditHref: '',
             creditText: '',
             title: { text: '' },
             legend: {},
             data: [],
-            series: []
+            series: [],
+            toolTip: {
+                backgroundColor: 'black',
+                borderColor: 'black',
+                fontColor: 'white',
+                cornerRadius: 3,
+                borderThickness: 4,
+                fontStyle: 'normal',
+                contentFormatter: function (e) {
+                    var content = ' ';
+                    for (var i = 0; i < e.entries.length; i++) {
+                        if (e.entries[i].dataPoint.label) {
+                            content += e.entries[i].dataPoint.label;
+                        } else {
+                            content += e.entries[i].dataPoint.x;
+                        }
+                        content += ': ';
+                        if (e.entries[i].dataPoint.name) {
+                            content += e.entries[i].dataPoint.name;
+                        } else {
+                            content += e.entries[i].dataPoint.y;
+                        }
+                    }
+
+                    return Utils.escapeHTML(content);
+                }
+            }
         };
-        /*
-         * TODO: disabled because of a bug in canvasJS 1.8.1 beta :(
-        data.axisY.stripLines[0] = {
-            value: 0,
-            color: 'black',
-            label: '',
-            zero: true,
-            labelPlacement: 'outside'
-        };
-        */
+
         var indexLabelAttrs = {
             fontSize: 10,
             color: { type: 'auto' },
@@ -154,7 +173,7 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
         // base constructors --------------------------------------------------
 
         DrawingModel.call(this, docModel, 'chart', initAttributes, { families: 'chart fill line' });
-        DrawingModelMixin.call(this, sheetModel, cloneConstructor, generateRestoreOperations, generateFormulaOperations);
+        DrawingModelMixin.call(this, sheetModel, cloneConstructor, generateRestoreOperations, generateUpdateFormulaOperations);
 
         /**
          * this is only called by the Drawingframe to initialize the REAL CanvasJS-chart
@@ -164,13 +183,12 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
         };
 
         var axisModelMap = {
-            x: new AxisModel(this, 'x', 'y'),
-            y: new AxisModel(this, 'y', 'x'),
-            z: new AxisModel(this, 'z', 'x')
+            x: new AxisModel(this, 'x'),
+            y: new AxisModel(this, 'y'),
+            z: new AxisModel(this, 'z')
         };
 
-        var mainName = null;
-        var mainTitleModel = new TitleModel(this, 'main');
+        var mainTitleModel = new TitleModel(this, 'main', data.title, 'text');
 
         var legendModel = new LegendModel(this, {}, data.legend);
 
@@ -243,18 +261,32 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
          *  'type' property. See method TokenArray.resolveOperation() for more
          *  details.
          */
-        function generateFormulaOperations(generator, position, changeDesc) {
+        function generateUpdateFormulaOperations(generator, position, changeDesc) {
+
             // generate the change operations for the source links in all data series
-            data.series.forEach(function (seriesData, index) {
-                seriesData.model.generateFormulaOperations(generator, position, index, changeDesc);
+            // (in reverse order, to get the correct indexes when deleting entire data series)
+            Utils.iterateArray(data.series, function (seriesData, index) {
+                var generator2 = sheetModel.createOperationsGenerator();
+                seriesData.model.generateUpdateFormulaOperations(generator2, position, index, changeDesc);
+                generator.appendOperations(generator2);
+                // prepend undo operations to restore the data series (needed for correct series array index)
+                generator.prependOperations(generator2, { undo: true });
+            }, { reverse: true });
+
+            // update the source links of the axis titles
+            _.each(axisModelMap, function (axisModel) {
+                axisModel.generateUpdateFormulaOperations(generator, position, changeDesc);
             });
+
+            // update the source link of the main title
+            mainTitleModel.generateUpdateFormulaOperations(generator, position, changeDesc);
         }
 
         /**
          * Debounced version of the public method SheetChartModel.refresh()
          * with increased delay time.
          */
-        var refreshChartDebounced = this.createDebouncedMethod(_.noop, function () { self.refresh(); }, { delay: 500 });
+        var refreshChartDebounced = this.createDebouncedMethod(_.noop, innerRefresh, { delay: 500, infoString: 'SheetChartModel.refresh() for listeners', app: app });
 
         /**
          * Handles 'change:cells' events triggered by the document model (from
@@ -276,6 +308,7 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
                     seriesData.needUpdate = changed = true;
                 }
             });
+            if (mainTitleModel.rangesOverlap(ranges)) { changed = true; }
 
             if (changed) { refreshChartDebounced(); }
         }
@@ -299,6 +332,7 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
                     seriesData.needUpdate = true;
                 }
             });
+            if (mainTitleModel.rangesOverlap(range)) { changed = true; }
 
             if (changed) { refreshChartDebounced(); }
         }
@@ -425,16 +459,7 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
 
             legendModel.refreshInfo();
 
-            var mnt = mainTitleModel.getMergedAttributeSet(true);
-            data.title.text = mnt.text.link[0] || '';
-
-            // changed for Bug 46932
-            if (!data.title.text && data.series.length === 1 && 'off') {
-                data.title.text = mainName || '';
-            }
-            if (data.title.text) {
-                ChartStyleUtil.handleCharacterProps(self, mnt.character, data.title);
-            }
+            mainTitleModel.refreshInfo();
 
             refreshAxis();
 
@@ -543,23 +568,22 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
 
         function reduceBigRange(source, index, name) {
 
-            var range = data.series[index].model.getRange(name);
-            var start = range.start;
-            var end = range.end;
+            var ranges = data.series[index].model.resolveRanges(name);
+            var range = ranges ? ranges.first() : null;
+            if (!range) { return source; }
 
-            var xDist = 1 + end[0] - start[0];
-            var yDist = 1 + end[1] - start[1];
-
-            if (xDist > yDist) {
+            var cols = range.cols();
+            var rows = range.rows();
+            if (cols > rows) {
                 Utils.warn('chart with 2d ranges as "' + name + '" reduceBigRange() must be implemented!');
                 return source;
-            } else if (yDist > xDist) {
+            } else if (rows > cols) {
                 var newList = [];
                 var numberFormatter = docModel.getNumberFormatter();
-                for (var y = 0; y < yDist; y++) {
-                    var group = source[y * xDist];
-                    for (var x = 1; x < xDist; x++) {
-                        var other = source[y * xDist + x];
+                for (var row = 0; row < rows; ++row) {
+                    var group = source[row * cols];
+                    for (var col = 1; col < cols; ++col) {
+                        var other = source[row * cols + col];
                         compareFormats(group, other);
                     }
                     group.display = numberFormatter.formatValue(group.format, group.result || group.value);
@@ -609,6 +633,119 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
             data.legend.maxHeight = rect.height;
         }
 
+        function seriesAttrsToCellArray(array) {
+            var result = [];
+            if (array) {
+                array.forEach(function (entry) {
+                    var res = { display: entry };
+                    if (isFinite(entry)) {
+                        res.value = parseFloat(entry);
+                    }
+                    result.push(res);
+                });
+            }
+            return result;
+        }
+
+        /**
+         * Refreshes the source values of the data series of this chart.
+         */
+        function innerRefresh() {
+
+            // nothing to do during import of the document
+            if (!self.isImportFinished()) { return; }
+
+            var // all ranges to be querried, as array of arrays of range addresses
+                sourceRanges = null,
+                // maps series indexes and source link types to array elements in 'sourceRanges'
+                collectInfo = null;
+
+            _(data.series).each(function (seriesData, series) {
+                if (!seriesData.needUpdate) { return; }
+
+                if (!sourceRanges) {
+                    sourceRanges = [];
+                    collectInfo = [];
+                }
+
+                var info = { series: series, indexes: {} };
+
+                var tokenCount = 0;
+
+                seriesData.model.iterateTokenArrays(function (tokenArray, attrName) {
+                    tokenCount++;
+                    var entryRanges = tokenArray.resolveRangeList({ resolveNames: true });
+                    if (!entryRanges.empty()) {
+                        info.indexes[attrName] = sourceRanges.length;
+                        sourceRanges.push(entryRanges);
+                    }
+                });
+                if (tokenCount) {
+                    collectInfo.push(info);
+                } else {
+
+                    var sAttrs = seriesData.model.getExplicitAttributeSet().series;
+                    chartFormatter.update(series, seriesAttrsToCellArray(sAttrs.values), seriesAttrsToCellArray(sAttrs.title), seriesAttrsToCellArray(sAttrs.names), seriesAttrsToCellArray(sAttrs.bubbles));
+                }
+                seriesData.needUpdate = false;
+            });
+
+            if (!sourceRanges || !sourceRanges.length) {
+                if (mainTitleModel.refreshInfo()) {
+                    // fix for Bug 48095
+                    self.trigger('change:drawing', 'series');
+                } else {
+                    changeDrawing();
+                }
+                return;
+            }
+
+            if (sourceRanges.length > 0) {
+
+                // query contents of visible cells for the data series (be nice and use a time-sliced loop)
+                var allContents = [];
+                var promise = self.iterateArraySliced(sourceRanges, function (ranges) {
+                    allContents.push(docModel.getRangeContents(ranges, { blanks: true, visible: true, attributes: true, display: true, maxCount: 1000 }));
+                }, { infoString: 'ChartModel: innerRefresh', app: app });
+
+                // do not call the handler function, if the chart has been deleted in the meantime
+                self.waitForSuccess(promise, function () {
+
+                    _(collectInfo).each(function (info) {
+
+                        // returns the cell contents for the specified source link type
+                        function getCellContents(key) {
+                            return _.isNumber(info.indexes[key]) ? allContents[info.indexes[key]] : [];
+                        }
+
+                        // series values must exist
+                        var valuesSource = getCellContents('values');
+                        var titleSource = getCellContents('title');
+                        var namesSource = getCellContents('names');
+                        var bubblesSource = getCellContents('bubbles');
+
+                        if (namesSource.length && namesSource.length >= valuesSource.length * 2) {
+                            // workaround for TOO BIG ranges (2d range)
+                            namesSource = reduceBigRange(namesSource, info.series, 'names');
+                        }
+                        if (titleSource.length && titleSource.length >= valuesSource.length * 2) {
+                            // workaround for TOO BIG ranges (2d range)
+                            titleSource = reduceBigRange(titleSource, info.series, 'title');
+                        }
+                        chartFormatter.update(info.series, valuesSource, titleSource, namesSource, bubblesSource);
+
+                    });
+                    refreshAxis();
+                    self.trigger('change:drawing', 'series');
+                });
+            } else {
+                _(data.series).each(function (seriesData) {
+                    seriesData.needUpdate = false;
+                });
+                self.trigger('change:drawing', 'series');
+            }
+        }
+
         // protected methods --------------------------------------------------
 
         /**
@@ -728,7 +865,7 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
         // public methods -----------------------------------------------------
 
         this.setMainName = function (name) {
-            mainName = name;
+            mainTitleModel.setName(name);
         };
 
         /**
@@ -759,100 +896,22 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
         /**
          * Refreshes the source values of the data series of this chart.
          */
-        this.refresh = this.createDebouncedMethod(_.noop, function () {
+        this.refresh = this.createDebouncedMethod(_.noop, innerRefresh, { delay: 50, maxDelay: 250, infoString: 'SheetChartModel.refresh()', app: app });
 
-            // nothing to do during import of the document
-            if (!this.isImportFinished()) { return; }
-
-            var // all ranges to be querried, as array of arrays of range addresses
-                sourceRanges = null,
-                // maps series indexes and source link types to array elements in 'sourceRanges'
-                collectInfo = null;
-
-            _(data.series).each(function (seriesData, series) {
-                if (!seriesData.needUpdate) { return; }
-
-                if (!sourceRanges) {
-                    sourceRanges = [];
-                    collectInfo = [];
-                }
-
-                var info = { series: series, indexes: {} };
-
-                seriesData.model.iterateTokenArrays(function (tokenArray, name) {
-                    var entryRanges = tokenArray.resolveRangeList({ resolveNames: true });
-                    if (!entryRanges.empty()) {
-                        info.indexes[name] = sourceRanges.length;
-                        sourceRanges.push(entryRanges);
-                    }
-                });
-                collectInfo.push(info);
-
-                seriesData.needUpdate = false;
-            });
-
-            if (!sourceRanges) {
-                changeDrawing();
-                return;
-            }
-
-            if (sourceRanges.length > 0) {
-
-                // query contents of visible cells for the data series (be nice and use a time-sliced loop)
-                var allContents = [];
-                var promise = self.iterateArraySliced(sourceRanges, function (ranges) {
-                    allContents.push(docModel.getRangeContents(ranges, { visible: true, attributes: true, display: true, maxCount: 1000 }));
-                });
-
-                // do not call the handler function, if the chart has been deleted in the meantime
-                self.waitForSuccess(promise, function () {
-
-                    _(collectInfo).each(function (info) {
-
-                        // returns the cell contents for the specified source link type
-                        function getCellContents(key) {
-                            return _.isNumber(info.indexes[key]) ? allContents[info.indexes[key]] : [];
-                        }
-
-                        // series values must exist
-                        var valuesSource = getCellContents('values');
-                        var titleSource = getCellContents('title');
-                        var namesSource = getCellContents('names');
-                        var bubblesSource = getCellContents('bubbles');
-
-                        if (namesSource.length && namesSource.length >= valuesSource.length * 2) {
-                            // workaround for TOO BIG ranges (2d range)
-                            namesSource = reduceBigRange(namesSource, info.series, 'names');
-                        }
-                        if (titleSource.length && titleSource.length >= valuesSource.length * 2) {
-                            // workaround for TOO BIG ranges (2d range)
-                            titleSource = reduceBigRange(titleSource, info.series, 'title');
-                        }
-
-                        chartFormatter.update(info.series, valuesSource, titleSource, namesSource, bubblesSource);
-
-                    });
-                    refreshAxis();
-                    self.trigger('change:drawing', 'series');
-                });
-            } else {
-                _(data.series).each(function (seriesData) {
-                    seriesData.needUpdate = false;
-                });
-                self.trigger('change:drawing', 'series');
-            }
-        }, { delay: 50, mayDelay: 250 });
+        this.getSeriesModel = function (index) {
+            return data.series[index].model;
+        };
 
         this.getLegendModel = function () {
             return legendModel;
         };
 
-        this.getAxisModel = function (axis) {
-            return axisModelMap[axis];
+        this.getAxisModel = function (axisId) {
+            return axisModelMap[axisId];
         };
 
-        this.getTitleModel = function (type) {
-            return (type === 'main') ? mainTitleModel : this.getAxisModel(type).getTitle();
+        this.getTitleModel = function (axisId) {
+            return (axisId === 'main') ? mainTitleModel : this.getAxisModel(axisId).getTitle();
         };
 
         /**
@@ -876,8 +935,8 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
         this.iterateTokenArrays = function (callback) {
             data.series.forEach(function (seriesData) {
                 var tokens = {};
-                seriesData.model.iterateTokenArrays(function (tokenArray, name) {
-                    tokens[name] = tokenArray;
+                seriesData.model.iterateTokenArrays(function (tokenArray, attrName) {
+                    tokens[attrName] = tokenArray;
                 });
                 callback(seriesData.seriesIndex, tokens);
             });
@@ -885,21 +944,20 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
 
         function updateTokenArrays() {
             if (!controllerToken) {
-                controllerToken = new TokenArray(sheetModel, 'chart');
+                controllerToken = new TokenArray(sheetModel, 'drawing');
             }
 
-            var tmpList = {};
+            var tmpList = [];
             _.each(data.series, function (seriesData) {
                 seriesData.model.iterateTokenArrays(function (tokenArray) {
                     var formula = tokenArray.getFormula('op');
                     if (formula.length) {
-                        tmpList[formula] = true;
+                        tmpList.push(formula);
                     }
                 });
             });
 
-            var formula = _.keys(tmpList).join(',');
-            controllerToken.parseFormula('op', formula);
+            controllerToken.parseFormula('op', tmpList.join(','));
         }
 
         function refreshAxis() {
@@ -975,17 +1033,6 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
          * @returns {String|null}
          */
         this.getColorSet = function () {
-            var indiv = _(data.series).find(function (dataSeries) {
-                var at = dataSeries.model.getMergedAttributeSet(true);
-                if (at.fill.color.type !== 'auto') {
-                    return true;
-                }
-            });
-
-            if (indiv) {
-                return null;
-            }
-
             var styleId = getStyleId() - 1;
             var colorSet = styleId % 8;
             return 'cs' + colorSet;
@@ -1162,7 +1209,7 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
             var lastValues = null;
 
             _.each(data.series, function (dataSeries) {
-                dataSeries.model.iterateTokenArrays(function (tokenArray, name) {
+                dataSeries.model.iterateTokenArrays(function (tokenArray, attrName) {
                     var rangeList = tokenArray.resolveRangeList({ resolveNames: true });
                     if (rangeList.empty()) { return; }
                     var range = rangeList.first();
@@ -1172,7 +1219,7 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
                     if (!range.isSheet(sheet)) {
                         warn = 'sheets';
                     }
-                    if (name === 'values') {
+                    if (attrName === 'values') {
                         var axis = null;
                         var col = range.cols();
                         var row = range.rows();
@@ -1313,11 +1360,19 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
         this.setMarkerOnly = function (state) {
             sheetModel.createAndApplyOperations(function (generator) {
 
-                var attrs = { line: { type: state ? 'none' : 'solid' } };
-                var undoAttrs = { line: { type: state ? 'solid' : 'none' } };
+                var noneShape = { type: 'none' };
+                var solidShape = { type: 'solid' };
+
+                var attrs = {};
+                if (state) {
+                    attrs = { line: noneShape, fill: solidShape };
+                } else {
+                    attrs = { line: solidShape, fill: solidShape };
+                }
                 var position = self.getSheetPosition();
 
                 _(data.series).each(function (dataSeries, index) {
+                    var undoAttrs = dataSeries.model.getExplicitAttributeSet(false);
                     generator.generateDrawingOperation(Operations.SET_CHART_DATASERIES_ATTRIBUTES, position, { series: index, attrs: undoAttrs }, { undo: true });
                     generator.generateDrawingOperation(Operations.SET_CHART_DATASERIES_ATTRIBUTES, position, { series: index, attrs: attrs });
                 });
@@ -1350,8 +1405,8 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
             _.each(data.series, function (dataSeries) {
                 var series = {};
 
-                dataSeries.model.iterateTokenArrays(function (token, name) {
-                    series[name] = token.getFormula('op');
+                dataSeries.model.iterateTokenArrays(function (tokenArray, attrName) {
+                    series[attrName] = tokenArray.getFormula('op');
                 });
                 var nsp = dataSeries.model.getExplicitAttributeSet();
                 nsp.series = series;
@@ -1364,6 +1419,55 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
             return cloneData;
         };
 
+        this.getCanvasJSData = function () {
+            var cvsData = {
+                axis: {},
+                series: []
+            };
+            _.each(data.data, function (series) {
+                var points = [];
+                _.each(series.dataPoints, function (dataPoint) {
+                    points.push({
+                        color: dataPoint.color,
+                        label: dataPoint.label,
+                        x: dataPoint.x,
+                        y: dataPoint.y,
+                        z: dataPoint.z
+                    });
+                });
+
+                cvsData.series.push({
+                    bevelEnabled:     series.bevelEnabled,
+                    color:            series.color,
+                    fillOpacity:      series.fillOpacity,
+                    indexLabelFont:   series.indexLabelFont,
+                    legendMarkerType: series.legendMarkerType,
+                    marker:           series.marker,
+                    markerColor:      series.markerColor,
+                    name:             series.name,
+                    showInLegend:     series.showInLegend,
+                    type:             series.type,
+                    points:           points
+                });
+
+            });
+            _.each(axisModelMap, function (axisModel, axisId) {
+                var dataAxis = data['axis' + axisId.toUpperCase()];
+                cvsData.axis[axisId] = {
+                    label:     dataAxis.label,
+                    grid:      dataAxis.grid,
+                    labelFont: dataAxis.labelFont,
+                    line:      dataAxis.line,
+                    tick:      dataAxis.tick,
+                    titleFont: dataAxis.titleFont
+                };
+            });
+            cvsData.legend = data.legend.font;
+            cvsData.title = data.title.textFont;
+
+            return cvsData;
+        };
+
         // initialization -----------------------------------------------------
 
         colorHandler = new ManualColorHandler(this, data);
@@ -1375,16 +1479,6 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
         // additional processing and event handling after the document has been imported
         this.waitForImportSuccess(function (alreadyImported) {
 
-            // reparse all formulas after import is finished (formulas may refer to sheets not yet imported)
-            if (!alreadyImported) {
-                data.series.forEach(function (seriesData) { seriesData.model.refreshAfterImport(); });
-            }
-
-            // update the sheet indexes after the sheet collection has been manipulated
-            this.listenTo(docModel, 'transform:sheet', function (event, toSheet, fromSheet) {
-                data.series.forEach(function (seriesData) { seriesData.model.transformSheet(toSheet, fromSheet); });
-            });
-
             // update the chart model after changing the cell contents
             this.listenTo(docModel, 'change:cells', changeCellsHandler);
 
@@ -1402,7 +1496,7 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
                     if (sheetModel.getIndex() === docModel.getActiveSheet()) {
                         self.refresh();
                     }
-                });
+                }, { infoString: 'waitForImportSucess', app: docModel.getApp() });
             }
 
         }, this);
@@ -1443,7 +1537,7 @@ define('io.ox/office/spreadsheet/model/drawing/chartmodel', [
                 delete ds.model;
             }
 
-            self = docModel = sheetModel = mainTitleModel = legendModel = data = axisModelMap = colorHandler = chartFormatter = null;
+            self = docModel = sheetModel = mainTitleModel = legendModel = data = axisModelMap = colorHandler = chartFormatter = app = null;
         });
 
     } // class SheetChartModel
