@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -173,6 +174,7 @@ define('io.ox/office/spreadsheet/model/drawing/drawingcollection', [
 
         // the document model
         var docModel = sheetModel.getDocModel();
+        var app = docModel.getApp();
 
         // the column and row collections (size and formatting of all columns/rows)
         var colCollection = sheetModel.getColCollection();
@@ -813,7 +815,7 @@ define('io.ox/office/spreadsheet/model/drawing/drawingcollection', [
 
                 // callback may want to defer processing the following drawings
                 return result;
-            }, { delay: 'immediate' });
+            }, { delay: 'immediate', infoString: 'DrawingCollection: generateInsertDrawingOperations', app: app });
         };
 
         /**
@@ -848,7 +850,7 @@ define('io.ox/office/spreadsheet/model/drawing/drawingcollection', [
                 generator.appendOperations(generator2);
                 generator.prependOperations(generator2, { undo: true });
 
-            }, { delay: 'immediate', reverse: true });
+            }, { delay: 'immediate', reverse: true, infoString: 'DrawingCollection: generateDeleteDrawingOperations', app: app });
         };
 
         /**
@@ -874,7 +876,7 @@ define('io.ox/office/spreadsheet/model/drawing/drawingcollection', [
             return this.iterateArraySliced(positions, function (position) {
                 var drawingModel = resolveDrawingModel(position);
                 drawingModel.generateChangeOperations(generator, position, attributes);
-            }, { delay: 'immediate' });
+            }, { delay: 'immediate', infoString: 'DrawingCollection: generateChangeDrawingOperations', app: app });
         };
 
         /**
@@ -893,7 +895,7 @@ define('io.ox/office/spreadsheet/model/drawing/drawingcollection', [
         this.generateUpdateAnchorOperations = function (generator) {
             return this.iterateSliced(this.createModelIterator(), function (drawingModel, result) {
                 drawingModel.generateUpdateAnchorOperations(generator, result.position);
-            }, { delay: 'immediate' });
+            }, { delay: 'immediate', infoString: 'DrawingCollection: generateUpdateAnchorOperations', app: app });
         };
 
         /**
@@ -914,7 +916,7 @@ define('io.ox/office/spreadsheet/model/drawing/drawingcollection', [
          *  A promise that will be resolved when all operations have been
          *  generated.
          */
-        this.generateFormulaOperations = function (generator, changeDesc) {
+        this.generateUpdateFormulaOperations = function (generator, changeDesc) {
 
             // special processing needed when moving cells in a sheet (including inserting/deleting columns or rows) which may delete drawings
             if (changeDesc.type === 'moveCells') {
@@ -924,16 +926,16 @@ define('io.ox/office/spreadsheet/model/drawing/drawingcollection', [
                     var generator2 = sheetModel.createOperationsGenerator();
 
                     // generate the operations, and insert them into the passed generator
-                    drawingModel.generateFormulaOperations(generator2, result.position, changeDesc);
+                    drawingModel.generateUpdateFormulaOperations(generator2, result.position, changeDesc);
                     generator.appendOperations(generator2);
                     generator.prependOperations(generator2, { undo: true });
 
-                }, { delay: 'immediate' });
+                }, { delay: 'immediate', infoString: 'DrawingCollection: generateFormulaOperations 1', app: app });
             }
 
             return this.iterateSliced(this.createModelIterator({ deep: true }), function (drawingModel, result) {
-                drawingModel.generateFormulaOperations(generator, result.position, changeDesc);
-            }, { delay: 'immediate' });
+                drawingModel.generateUpdateFormulaOperations(generator, result.position, changeDesc);
+            }, { delay: 'immediate', infoString: 'DrawingCollection: generateFormulaOperations 2', app: app });
         };
 
         // initialization -----------------------------------------------------
@@ -941,7 +943,7 @@ define('io.ox/office/spreadsheet/model/drawing/drawingcollection', [
         // destroy all class members
         this.registerDestructor(function () {
             // drawing models are owned by the base class DrawingCollection, do not destroy them here!
-            self = docModel = sheetModel = colCollection = rowCollection = drawingModels = null;
+            self = docModel = sheetModel = colCollection = rowCollection = drawingModels = app = null;
         });
 
     } // class SheetDrawingCollection
