@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -71,15 +72,15 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
      *  operations that will delete this drawing object. An implementation must
      *  generate more undo operations to restore the complete drawing object.
      *
-     * @param {Function} [generateFormulaOperations]
+     * @param {Function} [generateUpdateFormulaOperations]
      *  A callback function that will be invoked from the own public method
-     *  DrawingModelMixin.generateFormulaOperations() while generating document
-     *  operations that involve to update the formula expressions in this
-     *  drawing object. Receives all parameters passed to the public method
-     *  mentioned before. May return an attribute set with additional
+     *  DrawingModelMixin.generateUpdateFormulaOperations() while generating
+     *  document operations that involve to update the formula expressions in
+     *  this drawing object. Receives all parameters passed to the public
+     *  method mentioned before. May return an attribute set with additional
      *  formatting attributes to be applied at this drawing object, or null.
      */
-    function DrawingModelMixin(sheetModel, cloneConstructor, generateRestoreOperations, generateFormulaOperations) {
+    function DrawingModelMixin(sheetModel, cloneConstructor, generateRestoreOperations, generateUpdateFormulaOperations) {
 
         // self reference
         var self = this;
@@ -131,8 +132,8 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
             // process all move descriptors, returning true indicates to delete the drawing
             var deleteDrawing = moveDescs.some(function (moveDesc) {
 
-                // nothing to do, if the move descriptor will not touch the drawing object
-                if (!moveDesc.coversRange(drawingRange)) { return false; }
+                // nothing to do, if the move descriptor does not cover the drawing object completely
+                if (!moveDesc.containsRange(drawingRange)) { return false; }
 
                 // whether to modify the column or row indexes of the range
                 var columns = moveDesc.columns;
@@ -346,13 +347,18 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
          */
         this.generateDeleteOperations = function (generator, position) {
 
-            // undo: create an 'insertDrawing' operation to restore the drawing model with its attributes
-            var undoProperties = { type: this.getType(), attrs: this.getExplicitAttributeSet(true) };
-            generator.generateDrawingOperation(Operations.INSERT_DRAWING, position, undoProperties, { undo: true });
+            // bug 47948: do not undo unsupported drawing types
+            var drawingType = this.getType();
+            if (drawingType !== 'undefined') {
 
-            // additional undo operations for complex drawing contents
-            if (_.isFunction(generateRestoreOperations)) {
-                generateRestoreOperations.call(this, generator, position);
+                // undo: create an 'insertDrawing' operation to restore the drawing model with its attributes
+                var undoProperties = { type: drawingType, attrs: this.getExplicitAttributeSet(true) };
+                generator.generateDrawingOperation(Operations.INSERT_DRAWING, position, undoProperties, { undo: true });
+
+                // additional undo operations for complex drawing contents
+                if (_.isFunction(generateRestoreOperations)) {
+                    generateRestoreOperations.call(this, generator, position);
+                }
             }
 
             // generate the delete operation for this drawing object
@@ -412,7 +418,7 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
          * @returns {DrawingModelMixin}
          *  A reference to this instance.
          */
-        this.generateFormulaOperations = function (generator, position, changeDesc) {
+        this.generateUpdateFormulaOperations = function (generator, position, changeDesc) {
 
             // update the position of top-level drawing objects, if cells in the own sheet will be moved
             var anchorAttrs = null;
@@ -431,8 +437,8 @@ define('io.ox/office/spreadsheet/model/drawing/drawingmodelmixin', [
             var attributeSet = null;
 
             // derived classes may generate new operations for child objects, and additional formatting attributes
-            if (_.isFunction(generateFormulaOperations)) {
-                attributeSet = generateFormulaOperations.call(this, generator, position, changeDesc);
+            if (_.isFunction(generateUpdateFormulaOperations)) {
+                attributeSet = generateUpdateFormulaOperations.call(this, generator, position, changeDesc);
             }
 
             // add the new anchor attributes to the attribute set
