@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -698,7 +699,21 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
             minParams: 3,
             maxParams: 4,
             type: 'val',
-            signature: 'val:int val:int val:int val:int'
+            signature: 'val:int val:int val:int val:int',
+            resolve: function (r, g, b, a) {
+
+                if ((r < 0) || (r > 255)) { throw ErrorCode.VALUE; }
+                if ((g < 0) || (g > 255)) { throw ErrorCode.VALUE; }
+                if ((b < 0) || (b > 255)) { throw ErrorCode.VALUE; }
+
+                if (this.isMissingOperand(3)) {
+                    a = 0;
+                } else if ((a < 0) || (a > 255)) {
+                    throw ErrorCode.VALUE;
+                }
+
+                return a * 0x1000000 + r * 0x10000 + g * 0x100 + b;
+            }
         },
 
         CONVERT: {
@@ -715,10 +730,10 @@ define('io.ox/office/spreadsheet/model/formula/funcs/conversionfuncs', [
         'CONVERT.ODF': {
             category: 'conversion',
             name: { ooxml: null, odf: 'ORG.OPENOFFICE.CONVERT' },
+            hidden: true,
             minParams: 3,
             maxParams: 3,
-            type: 'val',
-            hidden: true
+            type: 'val'
         },
 
         DEC2BIN: {
