@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -33,6 +34,10 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
     // convenience shortcuts
     var ErrorCode = SheetUtils.ErrorCode;
     var Range3D = SheetUtils.Range3D;
+    var MathUtils = FormulaUtils.Math;
+
+    // shortcuts to mathematical functions
+    var div = MathUtils.div;
 
     // class Database =========================================================
 
@@ -239,24 +244,40 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
 
     /**
      * Get the function result.
-     * @param {Range3D} range to create the database.
-     * @param {String | Number} field indicate the column wich are used for the databasefuncs.
-     *  It's the name or the index of the column.
-     * @param {Range3D} criteriaRange the range to create the criteria.
-     * @param {FormulaContext} context the formulacontext.
-     * @param {Function} resultCallback a function wich get the result array as the first parameter.
+     *
+     * @param {Range3D} range
+     *  to create the database.
+     *
+     * @param {String|Number} field
+     *  indicate the column wich are used for the databasefuncs. It's the name
+     *  or the index of the column.
+     *
+     * @param {Range3D} criteriaRange
+     *  the range to create the criteria.
+     *
+     * @param {FormulaContext} context
+     *  the formulacontext.
+     *
+     * @param {Function} resultCallback
+     *  a function wich get the result array as the first parameter.
+     *
      * @param {Object} [options]
+     *  Optional parameters:
      *  @param {Boolean} [options.resultType='array']
-     *      If 'array' add the number values to an result array,
-     *      if 'count' only count the the matched rows.
-     *  @param {Boolean} [options.onlyNumbers=true] if true the value for the result must be a Number,
-     *      otherwise all values will be added to the result
-     *  @param {Number} [options.stopOnMatchCount=0] if <=0 all values will be added to the result,
-     *      otherwise stops on the x match of the value.
-     *  @param {Number} [options.addSum=false] if true add the sum as the second parameter to the resultCallback
-     * @param {Boolean} [options.emptyFieldIsNotValid=true] true if the field value can be null, otherwise
-     *  the field must be a String or Number.
-     * @returns {Object} the return value of the resultCallback.
+     *      If 'array' add the number values to an result array, if 'count'
+     *      only count the the matched rows.
+     *  @param {Boolean} [options.onlyNumbers=true]
+     *      if true the value for the result must be a Number, otherwise all
+     *      values will be added to the result
+     *  @param {Number} [options.stopOnMatchCount=0]
+     *      if <=0 all values will be added to the result, otherwise stops on
+     *      the x match of the value.
+     *  @param {Boolean} [options.emptyFieldIsNotValid=true]
+     *      true if the field value can be null, otherwise the field must be a
+     *      String or Number.
+     *
+     * @returns {Any}
+     *  the return value of the resultCallback.
      */
     function getResult(dbRange, field, criteriaRange, context, resultCallback, options) {
 
@@ -264,7 +285,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             result = resultIsArray ? [] : 0,
             onlyNumbers = Utils.getBooleanOption(options, 'onlyNumbers', true),
             stopOnMatchCount = Utils.getNumberOption(options, 'stopOnMatchCount', 0),
-            sum = Utils.getNumberOption(options, 'addSum', false) ? null : 0,
+            sum = 0,
             emptyFieldIsNotValid = Utils.getBooleanOption(options, 'emptyFieldIsNotValid', true),
             db = new Database(dbRange, field, context, emptyFieldIsNotValid),
             criteria = new Criteria(criteriaRange, db, context),
@@ -277,12 +298,10 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             if (criteria.matchValues(rowValues)) {
                 var cellValue = rowValues[db.columnIndex];
                 if (resultIsArray && (cellValue instanceof ErrorCode)) { throw cellValue; }
-                var isNumber = _.isNumber(cellValue);
+                var isNumber = typeof cellValue === 'number';
                 if ((!onlyNumbers && cellValue !== null) || isNumber) {
 
-                    if (sum !== null && isNumber) {
-                        sum += cellValue;
-                    }
+                    if (isNumber) { sum += cellValue; }
 
                     if (resultIsArray) {
                         result.push(cellValue);
@@ -312,44 +331,13 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
      * @returns {Number} the count of cells.
      */
     function getCountResult(dbRange, field, criteriaRange, context, nonblankCells) {
-        return getResult(dbRange, field, criteriaRange, context, function (result) {
-            return result;
-        }, {
+        return getResult(dbRange, field, criteriaRange, context, _.identity, {
             resultType: 'count',
             onlyNumbers: (field !== null) && !nonblankCells,
             emptyFieldIsNotValid: false
         });
     }
 
-    /**
-     * Get the static result for the numbers.
-     *
-     * @param {String} method
-     *  The aggregation method to be implemented, either 'dev' for the standard
-     *  deviation, or 'var' for the variance.
-     *
-     * @param {Boolean} population
-     *  If set to true, calculates the standard deviation or variance based on
-     *  the entire population. If set to false, calculates the result based on
-     *  a sample.
-     *
-     * @param {Number[]} numbers to get the statistical result.
-     * @param {Number} sum the sum of the numbers.
-     * @returns {Number} the statistical result of the numbers.
-     */
-    function getStatisticalResult(method, population, numbers, sum) {
-
-        var mean = FormulaUtils.divide(sum, numbers.length),
-            result = Utils.getSum(numbers, function (number) {
-                var diff = number - mean;
-                return diff * diff;
-            }),
-            size = population ? numbers.length : (numbers.length - 1);
-
-        result = FormulaUtils.divide(result, size);
-        return (method === 'dev') ? Math.sqrt(result) : result;
-    }
-
     // exports ================================================================
 
     return {
@@ -361,9 +349,9 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             type: 'val',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
-                return getResult(dbRange, field, criteriaRange, this, function (result, sum) {
-                    return FormulaUtils.divide(sum, result.length);
-                }, { addSum: true });
+                return getResult(dbRange, field, criteriaRange, this, function (numbers, sum) {
+                    return div(sum, numbers.length);
+                });
             }
         },
 
@@ -396,10 +384,10 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             type: 'val',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
-                return getResult(dbRange, field, criteriaRange, this, function (result) {
-                    if (_.isEmpty(result)) { throw ErrorCode.VALUE; }
-                    if (result.length > 1) { throw ErrorCode.NUM; }
-                    return result[0];
+                return getResult(dbRange, field, criteriaRange, this, function (values) {
+                    if (values.length === 0) { throw ErrorCode.VALUE; }
+                    if (values.length > 1) { throw ErrorCode.NUM; }
+                    return values[0];
                 }, { onlyNumbers: false });
             }
         },
@@ -411,13 +399,8 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             type: 'val',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
-                return getResult(dbRange, field, criteriaRange, this, function (result) {
-
-                    if (_.isEmpty(result)) {
-                        return 0;
-                    }
-
-                    return _.max(result);
+                return getResult(dbRange, field, criteriaRange, this, function (numbers) {
+                    return (numbers.length === 0) ? 0 : _.max(numbers);
                 });
             }
         },
@@ -429,12 +412,8 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             type: 'val',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
-                return getResult(dbRange, field, criteriaRange, this, function (result) {
-
-                    if (_.isEmpty(result)) {
-                        return 0;
-                    }
-                    return _.min(result);
+                return getResult(dbRange, field, criteriaRange, this, function (numbers) {
+                    return (numbers.length === 0) ? 0 : _.min(numbers);
                 });
             }
         },
@@ -446,14 +425,8 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             type: 'val',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
-                return getResult(dbRange, field, criteriaRange, this, function (result) {
-
-                    if (_.isEmpty(result)) {
-                        return 0;
-                    }
-                    return _.reduce(result, function (memo, num) {
-                        return memo * num;
-                    }, 1);
+                return getResult(dbRange, field, criteriaRange, this, function (numbers) {
+                    return (numbers.length === 0) ? 0 : MathUtils.product(numbers);
                 });
             }
         },
@@ -465,11 +438,9 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             type: 'val',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
-                return getResult(dbRange, field, criteriaRange, this, function (result, sum) {
-
-                    return getStatisticalResult('dev', false, result, sum);
-                },
-                    { addSum: true });
+                return getResult(dbRange, field, criteriaRange, this, function (numbers, sum) {
+                    return MathUtils.variance(numbers, sum, 'dev', false);
+                });
             }
         },
 
@@ -480,10 +451,9 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             type: 'val',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
-                return getResult(dbRange, field, criteriaRange, this, function (result, sum) {
-                    return getStatisticalResult('dev', true, result, sum);
-                },
-                    { addSum: true });
+                return getResult(dbRange, field, criteriaRange, this, function (numbers, sum) {
+                    return MathUtils.variance(numbers, sum, 'dev', true);
+                });
             }
         },
 
@@ -494,10 +464,9 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             type: 'val',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
-                return getResult(dbRange, field, criteriaRange, this, function (result, sum) {
+                return getResult(dbRange, field, criteriaRange, this, function (numbers, sum) {
                     return sum;
-                },
-                    { addSum: true });
+                });
             }
         },
 
@@ -508,12 +477,9 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             type: 'val',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
-
-                return getResult(dbRange, field, criteriaRange, this, function (result, sum) {
-
-                    return getStatisticalResult('var', false, result, sum);
-                },
-                    { addSum: true });
+                return getResult(dbRange, field, criteriaRange, this, function (numbers, sum) {
+                    return MathUtils.variance(numbers, sum, 'var', false);
+                });
             }
         },
 
@@ -524,11 +490,9 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             type: 'val',
             signature: 'ref:single val ref:single',
             resolve: function (dbRange, field, criteriaRange) {
-                return getResult(dbRange, field, criteriaRange, this, function (result, sum) {
-
-                    return getStatisticalResult('var', true, result, sum);
-                },
-                    { addSum: true });
+                return getResult(dbRange, field, criteriaRange, this, function (numbers, sum) {
+                    return MathUtils.variance(numbers, sum, 'var', true);
+                });
             }
         }
     };
