@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Oliver Specht <oliver.specht@open-xchange.com>
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
@@ -330,7 +331,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/datetimefuncs', [
 
     function parseDateTime(context, text) {
         var result = context.numberFormatter.parseFormattedValue(text);
-        var parsedFormat = context.numberFormatter.getParsedFormat(result.id);
+        var parsedFormat = context.numberFormatter.getParsedFormat(result.format);
         if (parsedFormat.isAnyDateTime()) {
             return result.value;
         }
