@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Oliver Specht <oliver.specht@open-xchange.com>
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
@@ -29,11 +30,8 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
      *
      *************************************************************************/
 
-    // maximum number of iterations to prevent endless loops etc.
-    var MAX_ITERATIONS = 50000;
-
-    // minimum difference between iteration steps
-    var EPSILON = 1e-15;
+    // convenience shortcuts
+    var MathUtils = FormulaUtils.Math;
 
     // mathematical constants
     var PI = Math.PI;
@@ -51,6 +49,12 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
     var sin = Math.sin;
     var cos = Math.cos;
 
+    // maximum number of iterations to prevent endless loops etc.
+    var MAX_ITERATIONS = 50000;
+
+    // minimum difference between iteration steps
+    var EPSILON = 1e-15;
+
     // private global functions ===============================================
 
     function besselI(value, order) {
@@ -565,10 +569,10 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
                     // equal values always result in zero (do not calculate erf(a) explicitly)
                     if (a === b) { return 0; }
                     // no second parameter: calculate erf(a)
-                    var erf_a = FormulaUtils.erf(a);
+                    var erf_a = MathUtils.erf(a);
                     if (!_.isNumber(b)) { return erf_a; }
                     // absolute value of parameters are equal: do not calculate erf(b)
-                    return (a === -b) ? (-2 * erf_a) : (FormulaUtils.erf(b) - erf_a);
+                    return (a === -b) ? (-2 * erf_a) : (MathUtils.erf(b) - erf_a);
                 }
 
                 return {
@@ -590,7 +594,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
             maxParams: 1,
             type: 'val',
             signature: 'val:num',
-            resolve: FormulaUtils.erf
+            resolve: MathUtils.erf
         },
 
         ERFC: {
@@ -603,9 +607,9 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
                 ooxml: function (a) {
                     // legacy ERFC() function: negative numbers result in #NUM! error
                     if (a < 0) { throw ErrorCode.NUM; }
-                    return FormulaUtils.erfc(a);
+                    return MathUtils.erfc(a);
                 },
-                odf: FormulaUtils.erfc
+                odf: MathUtils.erfc
             }
         },
 
@@ -616,7 +620,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/engineeringfuncs', [
             maxParams: 1,
             type: 'val',
             signature: 'val:num',
-            resolve: FormulaUtils.erfc
+            resolve: MathUtils.erfc
         },
 
         GESTEP: {
