@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -28,14 +29,18 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
      *
      *************************************************************************/
 
+    // convenience shortcuts
+    var MathUtils = FormulaUtils.Math;
+
     // shortcuts to mathematical functions
     var floor = Math.floor;
     var ceil = Math.ceil;
+    var isZero = MathUtils.isZero;
+    var div = MathUtils.div;
     var pow = Math.pow;
-    var pow10 = FormulaUtils.pow10;
+    var pow10 = MathUtils.pow10;
     var log = Math.log;
-    var log10 = FormulaUtils.log10;
-    var isZero = FormulaUtils.isZero;
+    var log10 = MathUtils.log10;
 
     // standard options for date parameter iterators (method FormulaContext.iterateNumbers())
     var RCONVERT_ALL_SKIP_EMPTY = { // id: RRR0
@@ -756,10 +761,10 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             maxParams: 4,
             type: 'val',
             signature: 'val:day val:day val:int val:int',
-            resolve: function (settlement, maturity, frequency, mode) {
+            resolve: function (settlement, maturity, frequency/*, mode*/) {
                 if (settlement >= maturity) { throw ErrorCode.NUM; }
                 ensureFrequency(frequency);
-                mode = getModeFromParam(mode);
+                //mode = getModeFromParam(mode);
 
                 return getCoupncd.call(this, settlement, maturity, frequency);
             }
@@ -786,10 +791,10 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
             maxParams: 4,
             type: 'val',
             signature: 'val:day val:day val:int val:int',
-            resolve: function (settlement, maturity, frequency, mode) {
+            resolve: function (settlement, maturity, frequency/*, mode*/) {
                 if (settlement >= maturity) { throw ErrorCode.NUM; }
                 ensureFrequency(frequency);
-                mode = getModeFromParam(mode);
+                //mode = getModeFromParam(mode);
 
                 return getCouppcd(settlement, maturity, frequency);
             }
@@ -1179,9 +1184,9 @@ define('io.ox/office/spreadsheet/model/formula/funcs/financialfuncs', [
                     fPow_invest /= fRate1_invest;
                 }, IRR_ITERATOR_OPTIONS);
 
-                var fResult = -FormulaUtils.divide(fNPV_reinvest, fNPV_invest);
+                var fResult = -div(fNPV_reinvest, fNPV_invest);
                 fResult *= pow(fRate1_reinvest, count - 1);
-                fResult = pow(fResult, FormulaUtils.divide(1, count - 1));
+                fResult = pow(fResult, div(1, count - 1));
                 return fResult - 1;
             }
         },
