@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -28,6 +29,9 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
      *
      *************************************************************************/
 
+    // convenience shortcuts
+    var MathUtils = FormulaUtils.Math;
+
     // mathematical constants
     var PI = Math.PI;
     var PI_2 = PI / 2;
@@ -37,15 +41,20 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
     var floor = Math.floor;
     var ceil = Math.ceil;
     var round = Math.round;
+    var trunc = MathUtils.trunc;
     var abs = Math.abs;
-    var pow10 = FormulaUtils.pow10;
+    var div = MathUtils.div;
+    var pow10 = MathUtils.pow10;
     var sqrt = Math.sqrt;
     var exp = Math.exp;
     var log = Math.log;
-    var log10 = FormulaUtils.log10;
+    var log10 = MathUtils.log10;
     var sin = Math.sin;
+    var sinh = MathUtils.sinh;
     var cos = Math.cos;
+    var cosh = MathUtils.cosh;
     var tan = Math.tan;
+    var tanh = MathUtils.tanh;
     var atan = Math.atan;
 
     // standard options for numeric parameter iterators (method FormulaContext.iterateNumbers())
@@ -147,7 +156,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             maxParams: 1,
             type: 'val',
             signature: 'val:num',
-            resolve: FormulaUtils.acosh
+            resolve: MathUtils.acosh
         },
 
         ACOT: {
@@ -169,7 +178,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             maxParams: 1,
             type: 'val',
             signature: 'val:num',
-            resolve: FormulaUtils.acoth
+            resolve: MathUtils.acoth
         },
 
         AGGREGATE: {
@@ -182,44 +191,50 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             resolve: (function () {
 
                 // all function implementations used by the AGGREGATE function
-                var AGGREGATE_FUNCTIONS = [
-                    StatUtils.groupAverage,
-                    StatUtils.groupCount,
-                    StatUtils.groupCountA,
-                    StatUtils.groupMax,
-                    StatUtils.groupMin,
-                    StatUtils.groupProduct,
-                    StatUtils.groupStdDevS,
-                    StatUtils.groupStdDevP,
-                    StatUtils.groupSum,
-                    StatUtils.groupVarS,
-                    StatUtils.groupVarP,
-                    StatUtils.groupMedian,
-                    StatUtils.groupModeSngl,
-                    StatUtils.groupLarge,
-                    StatUtils.groupSmall,
-                    StatUtils.groupPercentileInc,
-                    StatUtils.groupQuartileInc,
-                    StatUtils.groupPercentileExc,
-                    StatUtils.groupQuartileExc
+                var AGGREGATE_FUNCTIONS_INFO = [
+                    { func: StatUtils.groupAverage,       type: 'any' },
+                    { func: StatUtils.groupCount,         type: 'any' },
+                    { func: StatUtils.groupCountA,        type: 'any' },
+                    { func: StatUtils.groupMax,           type: 'any' },
+                    { func: StatUtils.groupMin,           type: 'any' },
+                    { func: StatUtils.groupProduct,       type: 'any' },
+                    { func: StatUtils.groupStdDevS,       type: 'any' },
+                    { func: StatUtils.groupStdDevP,       type: 'any' },
+                    { func: StatUtils.groupSum,           type: 'any' },
+                    { func: StatUtils.groupVarS,          type: 'any' },
+                    { func: StatUtils.groupVarP,          type: 'any' },
+                    { func: StatUtils.groupMedian,        type: 'any' },
+                    { func: StatUtils.groupModeSngl,      type: 'any' },
+                    { func: StatUtils.groupLarge,         type: 'val:int' },
+                    { func: StatUtils.groupSmall,         type: 'val:int' },
+                    { func: StatUtils.groupPercentileInc, type: 'val:num' },
+                    { func: StatUtils.groupQuartileInc,   type: 'val:int' },
+                    { func: StatUtils.groupPercentileExc, type: 'val:num' },
+                    { func: StatUtils.groupQuartileExc,   type: 'val:int' }
                 ];
 
                 // the implementation of the AGGREGATE function
                 return function (func, flags) {
 
                     // get the function implementation (one-based to zero-based index!)
-                    var funcImpl = AGGREGATE_FUNCTIONS[func - 1];
-                    if (!funcImpl) { throw ErrorCode.VALUE; }
+                    var funcInfo = AGGREGATE_FUNCTIONS_INFO[func - 1];
+                    if (!funcInfo) { throw ErrorCode.VALUE; }
 
                     // initialize the options according to the passed flags:
                     var options = {};
                     // bit 0: whether to visit visible rows only (hidden columns will always be visited!)
-                    if (flags & 1) { options.visible = 'rows'; }
+                    if (flags & 1) { options.skipHiddenRows = true; }
                     // bit 1: whether to skip error codes in source data (by default, they will be thrown immediately)
                     if (flags & 2) { options.skipErrors = true; }
 
-                    // invoke the function implementation with the remaining operands
-                    return funcImpl(this, this.getOperands(2), options);
+                    // 'any' functions: invoke the function implementation with the remaining operands
+                    if (funcInfo.type === 'any') {
+                        return funcInfo.func(this, this.getOperands(2), options);
+                    }
+
+                    // parameter count of functions with numeric fourth parameter (e.g. LARGE/SMALL) are restricted
+                    if (this.getOperandCount() !== 4) { throw ErrorCode.VALUE; }
+                    return funcInfo.func(this, this.getOperand(2), this.getOperand(3, funcInfo.type), options);
                 };
             }())
         },
@@ -239,7 +254,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             maxParams: 1,
             type: 'val',
             signature: 'val:num',
-            resolve: FormulaUtils.asinh
+            resolve: MathUtils.asinh
         },
 
         ATAN: {
@@ -257,7 +272,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             maxParams: 2,
             type: 'val',
             signature: 'val:num val:num',
-            resolve: FormulaUtils.arctan2 // parameter order is (x,y), Math.atan2 expects (y,x)
+            resolve: MathUtils.atan2 // parameter order is (x,y), Math.atan2 expects (y,x)
         },
 
         ATANH: {
@@ -266,7 +281,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             maxParams: 1,
             type: 'val',
             signature: 'val:num',
-            resolve: FormulaUtils.atanh
+            resolve: MathUtils.atanh
         },
 
         CEILING: {
@@ -346,7 +361,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             maxParams: 2,
             type: 'val',
             signature: 'val:int val:int',
-            resolve: FormulaUtils.binomial
+            resolve: MathUtils.binomial
         },
 
         COMBINA: {
@@ -357,7 +372,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             type: 'val',
             signature: 'val:int val:int',
             resolve: function (number1, number2) {
-                return FormulaUtils.binomial(number1 + number2 - 1, number2);
+                return MathUtils.binomial(number1 + number2 - 1, number2);
             }
         },
 
@@ -376,7 +391,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             maxParams: 1,
             type: 'val',
             signature: 'val:num',
-            resolve: FormulaUtils.cosh
+            resolve: cosh
         },
 
         COT: {
@@ -387,7 +402,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             type: 'val',
             signature: 'val:num',
             resolve: function (number) {
-                return FormulaUtils.divide(1, tan(number));
+                return div(1, tan(number));
             }
         },
 
@@ -399,7 +414,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             type: 'val',
             signature: 'val:num',
             resolve: function (number) {
-                return FormulaUtils.divide(1, FormulaUtils.tanh(number));
+                return div(1, tanh(number));
             }
         },
 
@@ -411,7 +426,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             type: 'val',
             signature: 'val:num',
             resolve: function (number) {
-                return FormulaUtils.divide(1, sin(number));
+                return div(1, sin(number));
             }
         },
 
@@ -423,7 +438,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             type: 'val',
             signature: 'val:num',
             resolve: function (number) {
-                return FormulaUtils.divide(2 * exp(-number), 1 - exp(-2 * number));
+                return div(2 * exp(-number), 1 - exp(-2 * number));
             }
         },
 
@@ -465,7 +480,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             maxParams: 1,
             type: 'val',
             signature: 'val:int',
-            resolve: FormulaUtils.factorial
+            resolve: MathUtils.factorial
         },
 
         FACTDOUBLE: {
@@ -555,7 +570,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             type: 'val',
-            signature: 'any',
+            signature: 'any|mat:pass',
             resolve: (function () {
 
                 // returns the GCD of the result and the new number
@@ -606,7 +621,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             type: 'val',
-            signature: 'any',
+            signature: 'any|mat:pass',
             resolve: (function () {
 
                 // updates the LCM in the passed result according to the passed number
@@ -668,7 +683,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             maxParams: 2,
             type: 'val',
             signature: 'val:num val:num',
-            resolve: FormulaUtils.modulo
+            resolve: MathUtils.mod
         },
 
         MROUND: {
@@ -684,7 +699,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             type: 'val',
-            signature: 'any',
+            signature: 'any|mat:pass',
             resolve: (function () {
 
                 // round down all numbers to integers
@@ -696,9 +711,9 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
                 function finalize(numbers, sum) {
                     if (numbers.length === 0) { throw ErrorCode.VALUE; }
                     var denom = numbers.reduce(function (accu, number) {
-                        return accu * FormulaUtils.factorial(number);
+                        return accu * MathUtils.factorial(number);
                     }, 1);
-                    return FormulaUtils.factorial(sum) / denom;
+                    return MathUtils.factorial(sum) / denom;
                 }
 
                 // the implementation of the MULTINOMIAL function
@@ -755,14 +770,14 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             maxParams: 2,
             type: 'val',
             signature: 'val:num val:num',
-            resolve: FormulaUtils.POWER
+            resolve: MathUtils.POW
         },
 
         PRODUCT: {
             category: 'math',
             minParams: 1,
             type: 'val',
-            signature: 'any',
+            signature: 'any|mat:pass',
             resolve: function () { return StatUtils.groupProduct(this, arguments); }
         },
 
@@ -773,7 +788,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             type: 'val',
             signature: 'val:num val:num',
             resolve: function (number1, number2) {
-                return FormulaUtils.trunc(FormulaUtils.divide(number1, number2));
+                return trunc(div(number1, number2));
             }
         },
 
@@ -860,7 +875,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             type: 'val',
             signature: 'val:num',
             resolve: function (number) {
-                return FormulaUtils.divide(1, cos(number));
+                return div(1, cos(number));
             }
         },
 
@@ -872,7 +887,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             type: 'val',
             signature: 'val:num',
             resolve: function (number) {
-                return FormulaUtils.divide(2 * exp(-number), 1 + exp(-2 * number));
+                return div(2 * exp(-number), 1 + exp(-2 * number));
             }
         },
 
@@ -881,7 +896,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             minParams: 4,
             maxParams: 4,
             type: 'val',
-            signature: 'val:num val:num val:num any',
+            signature: 'val:num val:num val:num any|mat:pass',
             resolve: (function () {
 
                 var AGGREGATE_OPTIONS = {
@@ -933,7 +948,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             maxParams: 1,
             type: 'val',
             signature: 'val:num',
-            resolve: FormulaUtils.sinh
+            resolve: sinh
         },
 
         SQRT: {
@@ -961,7 +976,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             minParams: 2,
             type: 'val',
             recalc: 'always', // function result depends on hidden state of rows
-            signature: 'val:int any',
+            signature: 'val:int any|mat:pass',
             resolve: (function () {
 
                 // all function implementations used by the SUBTOTAL function
@@ -987,9 +1002,13 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
                     var funcImpl = SUBTOTAL_FUNCTIONS[func % 100 - 1];
                     if (!funcImpl) { throw ErrorCode.VALUE; }
 
-                    // function indexes above 100 are used to skip hidden rows
-                    var options = (func >= 100) ? { visible: 'rows' } : null;
-                    return funcImpl(this, this.getOperands(1), options);
+                    // Function indexes above 100 are used to skip manually hidden rows.
+                    // Bug 49375: If a filter is active (auto-filter or table), ALL hidden rows will
+                    // ALWAYS be skipped (not only filtered rows, but also all manually hidden rows).
+                    return funcImpl(this, this.getOperands(1), {
+                        skipHiddenRows: func >= 100,
+                        skipFilteredRows: true
+                    });
                 };
             }())
         },
@@ -998,7 +1017,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             category: 'math',
             minParams: 1,
             type: 'val',
-            signature: 'any',
+            signature: 'any|mat:pass',
             resolve: function () {
                 return StatUtils.groupSum(this, arguments, { collectFormats: true });
             }
@@ -1009,8 +1028,10 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             minParams: 2,
             maxParams: 3,
             type: 'val',
-            signature: 'ref val:any ref',
-            resolve: FormulaUtils.implementFilterAggregation(0, FormulaUtils.add, _.identity)
+            signature: 'ref:val val:any ref:val',
+            resolve: function () {
+                return this.aggregateFilteredCells('single', 0, MathUtils.add);
+            }
         },
 
         SUMIFS: {
@@ -1018,15 +1039,17 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             minParams: 3,
             repeatParams: 2,
             type: 'val',
-            signature: 'ref ref val:any',
-            resolve: FormulaUtils.implementParallelFilterAggregation(0, FormulaUtils.add, _.identity)
+            signature: 'ref:val ref:val val:any',
+            resolve: function () {
+                return this.aggregateFilteredCells('multi', 0, MathUtils.add);
+            }
         },
 
         SUMSQ: {
             category: 'math',
             minParams: 1,
             type: 'val',
-            signature: 'any',
+            signature: 'any|mat:pass',
             resolve: function () {
                 function aggregate(result, number) { return result + number * number; }
                 return this.aggregateNumbers(arguments, 0, aggregate, _.identity, SKIP_MAT_SKIP_REF_SKIP_EMPTY);
@@ -1048,7 +1071,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
             maxParams: 1,
             type: 'val',
             signature: 'val:num',
-            resolve: FormulaUtils.tanh
+            resolve: tanh
         },
 
         TRUNC: {
@@ -1065,7 +1088,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/mathfuncs', [
                 // default value for missing digits
                 digits = digits || 0;
                 // simpler implementation for integer truncation
-                if (digits === 0) { return FormulaUtils.trunc(number); }
+                if (digits === 0) { return trunc(number); }
 
                 // absolute number
                 var absNum = abs(number);
