@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -15,11 +16,8 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
     'io.ox/office/tk/utils/iteratorutils',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/formulautils',
-    'io.ox/office/spreadsheet/model/formula/tokenarray',
-    'io.ox/office/spreadsheet/model/formula/utils/cellref',
-    'io.ox/office/spreadsheet/model/formula/utils/sheetref',
-    'io.ox/office/spreadsheet/model/formula/utils/matrix'
-], function (IteratorUtils, SheetUtils, FormulaUtils, TokenArray, CellRef, SheetRef, Matrix) {
+    'io.ox/office/spreadsheet/model/formula/tokenarray'
+], function (IteratorUtils, SheetUtils, FormulaUtils, TokenArray) {
 
     'use strict';
 
@@ -43,8 +41,12 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
 
     // convenience shortcuts
     var ErrorCode = SheetUtils.ErrorCode;
+    var Address = SheetUtils.Address;
     var Range3D = SheetUtils.Range3D;
     var Range3DArray = SheetUtils.Range3DArray;
+    var Matrix = FormulaUtils.Matrix;
+    var CellRef = FormulaUtils.CellRef;
+    var SheetRef = FormulaUtils.SheetRef;
 
     // private global variables ===============================================
 
@@ -80,7 +82,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
     }
 
     /**
-     * @returns {Number} order and {Operand} op
+     * @returns {Number} order and {Boolean} anyString
      *  1  is ascending
      *  -1 is descending
      *  0  is no order
@@ -88,11 +90,9 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
     function getOrderType(context, operand) {
         var order = null;
         var last = null;
+        var anyString = false;
 
-        var resultArray = [];
-        var iterator = context.createScalarIterator(operand);
-
-        IteratorUtils.some(iterator, function (value) {
+        IteratorUtils.some(context.createScalarIterator(operand), function (value) {
             if (last !== null) {
                 var subOrder = context.compareScalars(last, value);
                 if (order === null) {
@@ -102,27 +102,22 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
                     return true;
                 }
             }
-            resultArray.push(value);
             last = value;
+            if (_.isString(value)) { anyString = true; }
         });
+        return {
+            anyString: anyString,
+            order: -order
+        };
+    }
 
-        if (order === null) {
-            return { op: operand, type: 1 };
-        }
-
-        if (order === 0) {
-            return { op: operand, type: 0 };
-        }
-
-        if (order === -1) { resultArray.reverse(); }
-        var mat = new Matrix([resultArray]);
-        var op = context.createOperand(mat);
-        return { op: op, type: -order };
+    function getTypeId(value) {
+        return _.isNumber(value) ? 1 : _.isString(value) ? 2 : _.isBoolean(value) ? 3 : (value instanceof ErrorCode) ? 4 : 0;
     }
 
     function searchInOperand(context, lookup, inexact, searchOperand, resultOperand) {
 
-        if (resultOperand.isValue()) { throw ErrorCode.NA; }
+        if (resultOperand.isScalar()) { throw ErrorCode.NA; }
 
         var index = searchIndexInOperand(context, lookup, inexact, searchOperand);
         var res = null;
@@ -138,11 +133,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
 
     }
 
-    function searchIndexInOperand(context, lookup, inexact, operand, matchSearch) {
-
-        function getTypeId(value) {
-            return _.isNumber(value) ? 1 : _.isString(value) ? 2 : _.isBoolean(value) ? 3 : (value instanceof ErrorCode) ? 4 : 0;
-        }
+    function searchIndexInOperand(context, lookup, inexact, operand) {
 
         if (_.isUndefined(inexact)) { inexact = true; }
         if (_.isUndefined(lookup) || _.isNull(lookup)) { throw ErrorCode.VALUE; }
@@ -185,17 +176,77 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
 
         if (!_.isNaN(resultIndex)) { return resultIndex; }
 
-        if (!_.isNaN(lastIndex)) {
-            if (matchSearch) {
-                return lastIndex;
-            } else if (inexact && getTypeId(last) === lookupType && context.compareScalars(last, lookup) < 0) {
-                return lastIndex;
-            }
+        if (!_.isNaN(lastIndex) && inexact && getTypeId(last) === lookupType && context.compareScalars(last, lookup) < 0) {
+            return lastIndex;
         }
 
         throw ErrorCode.NA;
     }
 
+    function searchMatchInOperand(context, lookup, operand, order) {
+
+        if (_.isUndefined(lookup) || _.isNull(lookup)) { throw ErrorCode.VALUE; }
+
+        var inexact = order !== 0;
+
+        var regex = null;
+        if (!inexact && _.isString(lookup)) { regex = context.convertPatternToRegExp(lookup, true); }
+
+        var lookupType = getTypeId(lookup);
+        var last = null;
+        var lastIndex = null;
+        var resultIndex = Number.NaN;
+        var anyString = false;
+        var iterator = context.createScalarIterator(operand, SEARCHOPERANDOPTIONS);
+
+        IteratorUtils.some(iterator, function (value, result) {
+            if (value === null) { return; }
+
+            var index = result.offset;
+
+            last = value;
+            lastIndex = index;
+
+            var currentType = getTypeId(value);
+
+            if (currentType === 2) { anyString = true; }
+
+            if (currentType !== lookupType) { return; }
+
+            var compare = context.compareScalars(value, lookup);
+            if (compare === 0) {
+                resultIndex = index;
+                return true;
+            }
+
+            if (inexact) {
+                if (order === 1) {
+                    if (compare > 0) {
+                        if (index < 1) { throw ErrorCode.NA; }
+                        resultIndex = index - 1;
+                        return true;
+                    }
+                } else if (order === -1) {
+                    if (compare < 0) {
+                        if (index < 1) { throw ErrorCode.NA; }
+                        resultIndex = index - 1;
+                        return true;
+                    }
+                }
+            }
+            if (regex && regex.test(value)) {
+                resultIndex = index;
+                return true;
+            }
+        });
+
+        if (!_.isNaN(resultIndex)) { return resultIndex; }
+
+        if (!_.isNaN(lastIndex) && getTypeId(last) === lookupType && anyString) { return lastIndex; }
+
+        throw ErrorCode.NA;
+    }
+
     // exports ================================================================
 
     return {
@@ -218,16 +269,49 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
                     throw ErrorCode.VALUE;
                 }
 
-                // default for missing or empty A1 style (always defaults to TRUE)
+                // default for missing or empty A1 style (default value is TRUE)
                 if (this.isMissingOrEmptyOperand(3)) {
                     a1Style = true;
                 }
 
-                // initialize and validate the cell reference structure
+                // initialize the cell reference structure
                 var cellRef = new CellRef(0, 0, (absMode % 2) > 0, absMode <= 2);
-                cellRef.col = (a1Style || cellRef.absCol) ? (col - 1) : col;
-                cellRef.row = (a1Style || cellRef.absRow) ? (row - 1) : row;
-                this.checkCellRef(cellRef, !a1Style);
+                var refAddress = new Address(0, 0);
+
+                // get the effective column index (convert column offset in R1C1 notation to real column index)
+                if (a1Style || cellRef.absCol) {
+                    // absolute column index, or any column index in A1 notation (one-based)
+                    cellRef.col = col - 1;
+                } else if (col < 0) {
+                    // negative column offset in R1C1 notation, e.g. R1C[-16383]
+                    // (adjust reference address to be able to create large negative offsets)
+                    var maxCol = this.docModel.getMaxCol();
+                    cellRef.col = maxCol + col;
+                    refAddress[0] = maxCol;
+                } else {
+                    // positive column offset in R1C1 notation, e.g. R1C[16383]
+                    cellRef.col = col;
+                    refAddress[0] = 0;
+                }
+
+                // get the effective row index (convert row offset in R1C1 notation to real row index)
+                if (a1Style || cellRef.absRow) {
+                    // absolute row index, or any row index in A1 notation (one-based)
+                    cellRef.row = row - 1;
+                } else if (row < 0) {
+                    // negative row offset in R1C1 notation, e.g. R[-1048575]C1
+                    // (adjust reference address to be able to create large negative offsets)
+                    var maxRow = this.docModel.getMaxRow();
+                    cellRef.row = maxRow + row;
+                    refAddress[1] = maxRow;
+                } else {
+                    // positive row offset in R1C1 notation, e.g. R[1048575]C1
+                    cellRef.row = row;
+                    refAddress[1] = 0;
+                }
+
+                // validate the effective cell reference structure
+                this.checkCellRef(cellRef);
 
                 // start with encoded sheet name (enclosed in apostrophes if needed)
                 // (not for missing or empty parameter, but for explicit empty string)
@@ -243,7 +327,8 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
                 }
 
                 // append the range address in A1 or R1C1 style
-                return result + this.formulaGrammar.formatReference(this.docModel, null, null, cellRef, null, !a1Style);
+                var formulaGrammar = this.docModel.getFormulaGrammar('ui!' + (a1Style ? 'a1' : 'rc'));
+                return result + formulaGrammar.formatReference(this.docModel, refAddress, null, null, cellRef, null);
             }
         },
 
@@ -275,11 +360,20 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             type: 'val',
             signature: 'ref:single|deps:skip',
             resolve: function (range) {
-                // use reference address, if parameter is missing
-                var address = range ? range.start : this.getRefAddress();
+                // create a matrix with all column indexes in matrix context with explicit range
+                if (range && (this.getContextType() === 'mat')) {
+                    FormulaUtils.ensureMatrixDim(1, range.cols());
+                    return Matrix.generate(1, range.cols(), function (row, col) {
+                        return range.start[0] + col + 1;
+                    });
+                }
+                // use target reference address, if parameter is missing
+                var address = range ? this.getMatrixAddress(range) : this.getTargetAddress();
                 // function returns one-based column index
                 return address[0] + 1;
-            }
+            },
+            // result depends on reference address (behaves like a relative reference), if parameter is missing
+            relColRef: function (count) { return count === 0; }
         },
 
         COLUMNS: {
@@ -289,14 +383,14 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             type: 'val',
             signature: 'any|deps:skip',
             resolve: function (operand) {
+                var value = operand.getRawValue();
                 switch (operand.getType()) {
                     case 'val':
-                        var value = operand.getValue();
                         return (value instanceof ErrorCode) ? value : 1;
                     case 'mat':
-                        return operand.getMatrix().cols();
+                        return value.cols();
                     case 'ref':
-                        return this.convertToRange(operand.getRanges()).cols();
+                        return this.convertToRange(value).cols();
                     default:
                         FormulaUtils.throwInternal('ReferenceFuncs.COLUMNS.resolve(): unknown operand type');
                 }
@@ -319,8 +413,12 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
                 // TODO: resolve self-reference while entering a cell or shared formula
 
                 // getCellFormula() returns null for blank cells, and simple value cells
-                var formula = this.getCellFormula(range.sheet1, address);
-                return (formula === null) ? ErrorCode.NA : ('=' + formula);
+                var result = this.getCellFormula(range.sheet1, address);
+                if (!result) { throw ErrorCode.NA; }
+
+                // special handling for matrix formulas
+                var formula = '=' + result.formula;
+                return result.matrix ? ('{' + formula + '}') : formula;
             }
         },
 
@@ -340,7 +438,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             signature: 'val any val:int val:bool',
             resolve: function (lookup, searchOperand, rowIndexParam, inexact) {
                 var rowIndex = rowIndexParam - 1;
-                var dim = searchOperand.getDimensions();
+                var dim = searchOperand.getDimension({ errorCode: ErrorCode.VALUE }); // #VALUE! thrown for complex references
 
                 if (rowIndex < 0) { throw ErrorCode.VALUE; }
                 if (rowIndex >= dim.rows) { throw ErrorCode.REF; }
@@ -357,16 +455,17 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             maxParams: 4,
             type: 'any',
             recalc: 'always',
-            signature: 'any|deps:skip val:int val:int val:int',
+            signature: 'any|deps:skip val:int|mat:pass val:int|mat:pass val:int|mat:pass',
             resolve: function (source, row, col, area) {
                 if (source.isMatrix() && !_.isUndefined(area)) { throw ErrorCode.REF; }
 
+                if (_.isUndefined(row)) { row = 1; }
                 if (_.isUndefined(area)) { area = 1; }
                 if (_.isUndefined(col)) { col = 1; }
 
                 row--; col--; area--;
 
-                if (source.isValue()) { throw ErrorCode.VALUE; }
+                if (source.isScalar()) { throw ErrorCode.VALUE; }
 
                 var value = source.getRawValue();
                 if (value instanceof Range3DArray) {
@@ -374,18 +473,25 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
                     value = value[area];
                     source = this.createOperand(value);
                 }
-                var dim = source.getDimensions();
+                var dim = source.getDimension({ errorCode: ErrorCode.VALUE }); // #VALUE! thrown for complex references
 
-                if (col < 0 || col >= dim.cols)  { throw ErrorCode.REF; }
+                var cols = 1;
+                if (col === -1) {
+                    cols = dim.cols;
+                    col = 0;
+                } else {
+                    if (col < 0 || col >= dim.cols)  { throw ErrorCode.REF; }
+                }
 
-                var result = null;
+                var rows = 1;
                 if (row === -1) {
-                    result = splitOperand(this, source, [{ col: col, cols: 1, row: 0, rows: value.rows() }]);
+                    rows = dim.rows;
+                    row = 0;
                 } else {
                     if (row < 0 || row >= dim.rows)  { throw ErrorCode.REF; }
-
-                    result = splitOperand(this, source, [{ col: col, cols: 1, row: row, rows: 1 }]);
                 }
+
+                var result = splitOperand(this, source, [{ col: col, cols: cols, row: row, rows: rows }]);
                 result = result[0].getRawValue();
                 if (result instanceof Range3DArray && result.length === 1) {
                     result = result[0];
@@ -402,14 +508,18 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             recalc: 'always',
             signature: 'val:str val:bool',
             resolve: function (refText, a1Style) {
-                // default for missing or empty A1 style is true!
-                a1Style = a1Style || this.isMissingOrEmptyOperand(1);
 
-                var sheetModel = this.docModel.getSheetModel(this.getRefSheet());
+                // default for missing or empty A1 style (default value is TRUE)
+                if (this.isMissingOrEmptyOperand(1)) {
+                    a1Style = true;
+                }
+
+                var sheetModel = this.getRefSheetModel();
                 var tokenArray = new TokenArray(sheetModel, 'custom');
-                var refAddress = this.getRefAddress();
+                var grammarId = 'ui!' + (a1Style ? 'a1' : 'rc');
+                var refAddress = this.getTargetAddress();
 
-                tokenArray.parseFormula('ui', refText, { refAddress: refAddress });
+                tokenArray.parseFormula(grammarId, refText, { refAddress: refAddress });
 
                 var ranges = tokenArray.resolveRangeList({ resolveNames: true, refAddress: refAddress, targetAddress: refAddress });
                 if (ranges.length !== 1) { throw ErrorCode.REF; }
@@ -427,7 +537,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             resolve: function (lookup, searchOperand, resultOperand) {
 
                 if (this.isMissingOrEmptyOperand(2)) {
-                    var dim = searchOperand.getDimensions();
+                    var dim = searchOperand.getDimension({ errorCode: ErrorCode.VALUE }); // #VALUE! thrown for complex references
                     var ops = [];
                     if (dim.rows < dim.cols) {
                         ops = splitOperand(this, searchOperand, [{ col: 0, cols: dim.cols, row: 0, rows: 1 }, { col: 0, cols: dim.cols, row: dim.rows - 1, rows: 1 }]);
@@ -438,8 +548,8 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
                     return searchInOperand(this, lookup, undefined, ops[0], ops[1]);
                 } else {
                     if (resultOperand.isReference()) {
-                        var sDim = searchOperand.getDimensions();
-                        var rDim = resultOperand.getDimensions();
+                        var sDim = searchOperand.getDimension({ errorCode: ErrorCode.VALUE }); // #VALUE! thrown for complex references
+                        var rDim = resultOperand.getDimension({ errorCode: ErrorCode.VALUE }); // #VALUE! thrown for complex references
                         var resultRange = null;
 
                         if (rDim.cols < sDim.cols) {
@@ -462,10 +572,10 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             minParams: 2,
             maxParams: 3,
             type: 'val',
-            signature: 'val any val:int',
+            signature: 'val any|mat:pass val:int',
             resolve: function (lookup, searchOperand, order) {
 
-                var dim = searchOperand.getDimensions();
+                var dim = searchOperand.getDimension({ errorCode: ErrorCode.VALUE }); // #VALUE! thrown for complex references
 
                 if (Math.min(dim.rows, dim.cols) !== 1) { throw ErrorCode.NA; }
 
@@ -474,19 +584,15 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
                 if (order !== 0) {
                     var orderType = getOrderType(this, searchOperand);
 
-                    if (order !== 1 && order !== orderType.type) { throw ErrorCode.NA; }
-
-                    searchOperand = orderType.op;
-                }
-                try {
-                    return searchIndexInOperand(this, lookup, false, searchOperand, order === 1) + 1;
-                } catch (e) {
-                    if (order === 1 && e === ErrorCode.NA) {
-                        return searchIndexInOperand(this, lookup, true, searchOperand, order === 1) + 1;
-                    } else {
-                        throw e;
+                    if (order !== orderType.order) {
+                        if (orderType.anyString) {
+                            order = 0;
+                        } else {
+                            throw ErrorCode.NA;
+                        }
                     }
                 }
+                return searchMatchInOperand(this, lookup, searchOperand, order) + 1;
             }
         },
 
@@ -500,7 +606,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             resolve: function (ranges, rows, cols, height, width) {
 
                 // reference must contain a single range address
-                var range = this.convertToRange(ranges, { valueError: true });
+                var range = this.convertToRange(ranges, { errorCode: ErrorCode.VALUE });
 
                 // apply offset
                 range.start[0] += cols;
@@ -525,11 +631,20 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             type: 'val',
             signature: 'ref:single|deps:skip',
             resolve: function (range) {
-                // use reference address, if parameter is missing
-                var address = range ? range.start : this.getRefAddress();
+                // create a matrix with all row indexes in matrix context with explicit range
+                if (range && (this.getContextType() === 'mat')) {
+                    FormulaUtils.ensureMatrixDim(range.rows(), 1);
+                    return Matrix.generate(range.rows(), 1, function (row) {
+                        return range.start[1] + row + 1;
+                    });
+                }
+                // use target reference address, if parameter is missing
+                var address = range ? this.getMatrixAddress(range) : this.getTargetAddress();
                 // function returns one-based row index
                 return address[1] + 1;
-            }
+            },
+            // result depends on reference address (behaves like a relative reference), if parameter is missing
+            relRowRef: function (count) { return count === 0; }
         },
 
         ROWS: {
@@ -539,14 +654,14 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             type: 'val',
             signature: 'any|deps:skip',
             resolve: function (operand) {
+                var value = operand.getRawValue();
                 switch (operand.getType()) {
                     case 'val':
-                        var value = operand.getValue();
                         return (value instanceof ErrorCode) ? value : 1;
                     case 'mat':
-                        return operand.getMatrix().rows();
+                        return value.rows();
                     case 'ref':
-                        return this.convertToRange(operand.getRanges()).rows();
+                        return this.convertToRange(value).rows();
                     default:
                         FormulaUtils.throwInternal('ReferenceFuncs.ROWS.resolve(): unknown operand type');
                 }
@@ -559,21 +674,23 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             minParams: 0,
             maxParams: 1,
             type: 'val',
-            recalc: 'always',
+            recalc: 'always', // function result depends on index of a sheet (refresh on moving sheet)
             signature: 'any|deps:skip', // string (sheet name) or reference
             resolve: function (operand) {
 
                 // use reference sheet, if parameter is missing
                 if (!operand) { return this.getRefSheet() + 1; }
 
+                var value = operand.getRawValue();
+
                 // use sheet index of a reference
                 if (operand.isReference()) {
-                    return this.convertToRange(operand.getRanges()).sheet1 + 1;
+                    return this.convertToRange(value).sheet1 + 1;
                 }
 
-                // convert values to strings (sheet name may look like a number or Boolean)
-                if (operand.isValue()) {
-                    var sheet = this.docModel.getSheetIndex(this.convertToString(operand.getValue()));
+                // convert values to strings (sheet name may look like a number or boolean)
+                if (operand.isScalar()) {
+                    var sheet = this.docModel.getSheetIndex(this.convertToString(value));
                     return (sheet < 0) ? ErrorCode.NA : (sheet + 1);
                 }
 
@@ -588,7 +705,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             minParams: 0,
             maxParams: 1,
             type: 'val',
-            recalc: 'always',
+            recalc: 'always', // function result depends on indexes of sheets (refresh on moving sheet)
             signature: 'ref:multi|deps:skip',
             resolve: function (range) {
                 // return total number of sheets in document, if parameter is missing
@@ -633,7 +750,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             signature: 'val any val:int val:bool',
             resolve: function (lookup, searchOperand, colIndexParam, inexact) {
                 var colIndex = colIndexParam - 1;
-                var dim = searchOperand.getDimensions();
+                var dim = searchOperand.getDimension({ errorCode: ErrorCode.VALUE }); // #VALUE! thrown for complex references
 
                 if (colIndex < 0) { throw ErrorCode.VALUE; }
                 if (colIndex >= dim.cols) { throw ErrorCode.REF; }
