@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -29,8 +30,12 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
      *
      *************************************************************************/
 
+    // convenience shortcuts
+    var MathUtils = FormulaUtils.Math;
+    var Scalar = FormulaUtils.Scalar;
+
     // shortcuts to mathematical functions
-    var pow10 = FormulaUtils.pow10;
+    var pow10 = MathUtils.pow10;
 
     // private global functions ===============================================
 
@@ -207,7 +212,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             name: { ooxml: '_xlfn.CONCAT', odf: null },
             minParams: 1,
             type: 'val',
-            signature: 'any',
+            signature: 'any|mat:pass',
             resolve: function () {
                 // the aggregation function (throws early, if the string length exceeds the limit)
                 function aggregate(str1, str2) { return this.concatStrings(str1, str2); }
@@ -649,10 +654,13 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             minParams: 2,
             maxParams: 2,
             type: 'val',
+            recalc: 'once', // result depends on GUI language
             signature: 'val:num val:str',
             resolve: function (number, formatText) {
                 var parsedFormat = this.numberFormatter.getParsedFormat(formatText, { grammarId: 'ui' });
-                return this.numberFormatter.formatValue(parsedFormat, number);
+                var result = this.numberFormatter.formatValue(parsedFormat, number);
+                if (result === null) { throw ErrorCode.VALUE; }
+                return result;
             }
         },
 
@@ -661,7 +669,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             name: { ooxml: '_xlfn.TEXTJOIN', odf: null },
             minParams: 3,
             type: 'val',
-            signature: 'val:str val:bool any',
+            signature: 'val:str val:bool any|mat:pass',
             resolve: function (delimiter, skipEmpty) {
 
                 // offset of the last visited string
@@ -755,10 +763,10 @@ define('io.ox/office/spreadsheet/model/formula/funcs/textfuncs', [
             signature: 'val',
             resolve: function (value) {
                 // text can be converted to number, but boolean values will result in #VALUE!
-                switch (FormulaUtils.getScalarType(value)) {
-                    case FormulaUtils.ScalarType.NUMBER: return value;
-                    case FormulaUtils.ScalarType.STRING: return this.convertToNumber(value);
-                    case FormulaUtils.ScalarType.NULL:   return 0; // reference to empty cell
+                switch (Scalar.getType(value)) {
+                    case Scalar.Type.NUMBER: return value;
+                    case Scalar.Type.STRING: return this.convertToNumber(value);
+                    case Scalar.Type.NULL:   return 0; // reference to empty cell
                 }
                 throw ErrorCode.VALUE;
             }
