@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -36,7 +37,7 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
     var RAW_EN_RESOURCE_DATA = null;
 
     // the native prefix characters for R1C1 reference notation
-    var NATIVE_R1C1_PREFIX_CHARS = 'RC';
+    var NATIVE_RC_PREFIX_CHARS = 'RC';
 
     // maps the keys of error codes to their native names used in file format
     var NATIVE_ERROR_NAMES = {
@@ -318,6 +319,11 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
         // create a clone for deleting entries (needed to detect missing descriptors)
         localNames = _.clone(localNames);
 
+        // returns an optional boolean-or-function property (converts true to a function returning true)
+        function getBoolOrFuncProperty(properties, name) {
+            return Utils.getFunctionOption(properties, name, Utils.getBooleanOption(properties, name, false) ? _.constant(true) : null);
+        }
+
         // process all raw descriptor objects
         var collection = DescriptorCollection.create(implementationMap, function (implementation, key) {
 
@@ -360,9 +366,11 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
             // convert category list to a set
             descriptor.category = Utils.makeSet(Utils.getTokenListOption(properties, 'category', []));
 
-            // add the hidden flag, and recalculation mode
+            // add the hidden flag, recalculation mode, and reference mode flags
             descriptor.hidden = Utils.getBooleanOption(properties, 'hidden', false);
             descriptor.recalc = Utils.getStringOption(properties, 'recalc', null);
+            descriptor.relColRef = getBoolOrFuncProperty(properties, 'relColRef');
+            descriptor.relRowRef = getBoolOrFuncProperty(properties, 'relRowRef');
 
             // copy parameter counts
             descriptor.minParams = properties.minParams;
@@ -384,14 +392,19 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
                 var baseType = typeSpec.split(':')[0];
                 // source dependency behavior
                 var depSpec = null;
+                // special behavior for matrix context
+                var matSpec = 'none';
 
                 // process the additional options
                 for (var index = 1; index < tokens.length; index += 1) {
                     var option = tokens[index].split(':');
-                    if (option[0] === 'deps') { depSpec = option[1]; }
+                    switch (option[0]) {
+                        case 'deps': depSpec = option[1]; break;
+                        case 'mat':  matSpec = option[1]; break;
+                    }
                 }
 
-                return { typeSpec: typeSpec, baseType: baseType, depSpec: depSpec };
+                return { typeSpec: typeSpec, baseType: baseType, depSpec: depSpec, matSpec: matSpec };
             });
 
             // copy the resolver (callback function, or resource key, the latter will be resolved later)
@@ -735,8 +748,8 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
          *  The prefix characters used in R1C1 references (a string with two
          *  characters, first the row prefix, then the column prefix).
          */
-        this.getR1C1PrefixChars = function (localized) {
-            return localized ? localPrefixChars : NATIVE_R1C1_PREFIX_CHARS;
+        this.getRCPrefixChars = function (localized) {
+            return localized ? localPrefixChars : NATIVE_RC_PREFIX_CHARS;
         };
 
         /**
@@ -891,7 +904,7 @@ define.async('io.ox/office/spreadsheet/model/formula/parser/formularesource', [
         functionCollection = createCollection(FUNCTION_IMPL_MAP, fileFormat, rawResourceData.functions);
 
         // the R1C1 prefix characters (ODF does not translate these characters in the UI)
-        localPrefixChars = (fileFormat === 'odf') ? NATIVE_R1C1_PREFIX_CHARS : Utils.getStringOption(rawResourceData, 'RC', 'RC').toUpperCase();
+        localPrefixChars = (fileFormat === 'odf') ? NATIVE_RC_PREFIX_CHARS : Utils.getStringOption(rawResourceData, 'RC', 'RC').toUpperCase();
 
         // process each entry in the function help map (build system ensures valid data)
         _.each(rawResourceData.help, function (rawHelpEntry, funcKey) {
