@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -14,10 +15,8 @@
 define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
     'io.ox/office/tk/utils',
     'io.ox/office/spreadsheet/utils/sheetutils',
-    'io.ox/office/spreadsheet/model/formula/formulautils',
-    'io.ox/office/spreadsheet/model/formula/utils/sheetref',
-    'io.ox/office/spreadsheet/model/formula/utils/cellref'
-], function (Utils, SheetUtils, FormulaUtils, SheetRef, CellRef) {
+    'io.ox/office/spreadsheet/model/formula/formulautils'
+], function (Utils, SheetUtils, FormulaUtils) {
 
     'use strict';
 
@@ -27,18 +26,13 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
     var Address = SheetUtils.Address;
     var Range = SheetUtils.Range;
     var Range3D = SheetUtils.Range3D;
+    var RangeArray = SheetUtils.RangeArray;
     var IntervalArray = SheetUtils.IntervalArray;
     var Range3DArray = SheetUtils.Range3DArray;
-
-    // private global functions ===============================================
-
-    /**
-     * Returns whether the passed value is an existing sheet reference that
-     * represents a reference error.
-     */
-    function isSheetError(sheetRef) {
-        return _.isObject(sheetRef) && !sheetRef.valid();
-    }
+    var MoveDescriptor = SheetUtils.MoveDescriptor;
+    var Scalar = FormulaUtils.Scalar;
+    var CellRef = FormulaUtils.CellRef;
+    var SheetRef = FormulaUtils.SheetRef;
 
     // class BaseToken ========================================================
 
@@ -193,16 +187,28 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
 
     /**
      * Derived classes may overwrite this method to generate a new text
-     * representation of this token, after cell ranges have been moved in a
+     * representation of this token, before cell ranges will be moved in a
      * specific sheet of the spreadsheet document.
      *
-     * @returns {Object|Null}
+     * @returns {String|Null}
      *  The new text representation of this token, if available.
      */
     BaseToken.prototype.resolveMovedCells = function (/*formulaGrammar, sheet, moveDescs, options*/) {
         return null;
     };
 
+    /**
+     * Derived classes may overwrite this method to generate a new text
+     * representation of this token, after cell ranges have been cut and pasted
+     * in a specific sheet of the spreadsheet document.
+     *
+     * @returns {String|Null}
+     *  The new text representation of this token, if available.
+     */
+    BaseToken.prototype.resolveCutPasteCells = function (/*formulaGrammar, sourceRange, targetRange, options*/) {
+        return null;
+    };
+
     // class FixedToken =======================================================
 
     /**
@@ -460,7 +466,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      * Generates the text representation for debug logging.
      */
     LiteralToken.prototype.debugText = function () {
-        return FormulaUtils.valueToString(this._value);
+        return Scalar.toString(this._value);
     };
 
     // class MatrixToken ======================================================
@@ -548,10 +554,11 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
     // public methods ---------------------------------------------------------
 
     /**
-     * Returns the native name of the function, as passed to the constructor.
+     * Returns the unique resource key of the function, as passed to the
+     * constructor.
      *
      * @returns {String}
-     *  The native name of the function.
+     *  The unique resource key of the function.
      */
     FunctionToken.prototype.getValue = function () {
         return this._value;
@@ -684,7 +691,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *  Whether this token contains a sheet reference.
      */
     SheetRefToken.prototype.hasSheetRef = function () {
-        return _.isObject(this._sheet1Ref);
+        return !!this._sheet1Ref;
     };
 
     /**
@@ -695,7 +702,8 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *  Whether a sheet reference of this token is invalid.
      */
     SheetRefToken.prototype.hasSheetError = function () {
-        return isSheetError(this._sheet1Ref) || isSheetError(this._sheet2Ref);
+        // sheet error: sheet reference must exist and must be invalid
+        return (!!this._sheet1Ref && !this._sheet1Ref.valid()) || (!!this._sheet2Ref && !this._sheet2Ref.valid());
     };
 
     /**
@@ -721,9 +729,9 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      * @returns {Boolean}
      *  Whether the token has been changed.
      */
-    SheetRefToken.prototype.transformSheet = function (toSheet, fromSheet) {
-        var changed1 = _.isObject(this._sheet1Ref) && this._sheet1Ref.transform(toSheet, fromSheet);
-        var changed2 = _.isObject(this._sheet2Ref) && this._sheet2Ref.transform(toSheet, fromSheet);
+    SheetRefToken.prototype.transformSheet = function (fromSheet, toSheet) {
+        var changed1 = _.isObject(this._sheet1Ref) && this._sheet1Ref.transform(fromSheet, toSheet);
+        var changed2 = _.isObject(this._sheet2Ref) && this._sheet2Ref.transform(fromSheet, toSheet);
         return changed1 || changed2;
     };
 
@@ -889,6 +897,18 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
 
     // private methods --------------------------------------------------------
 
+    /**
+     * Returns whether this reference token contains relative column or row
+     * references only.
+     *
+     * @param {Boolean} columns
+     *  Whether to check the column references (true), or the row references
+     *  (false).
+     *
+     * @returns {Boolean}
+     *  Whether this reference token contains relative column or row references
+     *  only.
+     */
     ReferenceToken.prototype._isSingleRelative = function (columns) {
         // absolute index in first cell reference: this reference cannot be relative
         if (this._cell1Ref.isAbs(columns)) { return false; }
@@ -1110,10 +1130,53 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
         }, this);
     };
 
+    /**
+     * Returns whether this reference token contains at least one relative
+     * column reference, e.g. the C in C$4:$D$5.
+     *
+     * @returns {Boolean}
+     *  Whether this reference token contains at least one relative column
+     *  reference.
+     */
+    ReferenceToken.prototype.hasRelCol = function () {
+
+        // reference errors (missing first cell reference) cannot be relative
+        if (!this._cell1Ref) { return false; }
+
+        // immediately return if the first cell reference contains a relative column
+        if (!this._cell1Ref.absCol) { return true; }
+
+        // otherwise check the column reference of the second cell reference if existing
+        return !!this._cell2Ref && !this._cell2Ref.absCol;
+    };
+
+    /**
+     * Returns whether this reference token contains at least one relative row
+     * reference, e.g. the 4 in $C4:$D$5.
+     *
+     * @returns {Boolean}
+     *  Whether this reference token contains at least one relative row
+     *  reference.
+     */
+    ReferenceToken.prototype.hasRelRow = function () {
+
+        // reference errors (missing first cell reference) cannot be relative
+        if (!this._cell1Ref) { return false; }
+
+        // immediately return if the first cell reference contains a relative row
+        if (!this._cell1Ref.absRow) { return true; }
+
+        // otherwise check the row reference of the second cell reference if existing
+        return !!this._cell2Ref && !this._cell2Ref.absRow;
+    };
+
     /**
      * Changes the current cell range of this token, keeps all absolute flags
      * and sheet references intact.
      *
+     * @param {Range} range
+     *  The new position of this reference token.
+     *
      * @returns {Boolean}
      *  Whether the token has been changed.
      */
@@ -1152,12 +1215,21 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
     /**
      * Relocates this reference token to a new cell position.
      *
+     * @param {Address} refAddress
+     *  The source address to relocate the reference token from.
+     *
+     * @param {Address} targetAddress
+     *  The target address to relocate the reference token to.
+     *
+     * @param {Boolean} wrapReferences
+     *  Whether to wrap the addresses at the sheet boundaries.
+     *
      * @returns {Boolean}
      *  Whether the token has been changed.
      */
     ReferenceToken.prototype.relocateRange = function (refAddress, targetAddress, wrapReferences) {
 
-        // do not touch tokens representing a reference error
+        // do not touch tokens representing a reference error (missing first cell reference)
         if (!this._cell1Ref || refAddress.equals(targetAddress)) { return false; }
 
         // relocate first cell reference, bail out immediately on error
@@ -1193,7 +1265,8 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
     ReferenceToken.prototype.getText = function (formulaGrammar, options) {
         var sheetRefs = this._resolveSheetRefs(options);
         var cellRefs = this._resolveCellRefs(options);
-        return formulaGrammar.formatReference(this._docModel, sheetRefs.s1, sheetRefs.s2, cellRefs.r1, cellRefs.r2);
+        var targetAddress = Utils.getOption(options, 'targetAddress', Address.A1);
+        return formulaGrammar.formatReference(this._docModel, targetAddress, sheetRefs.s1, sheetRefs.s2, cellRefs.r1, cellRefs.r2);
     };
 
     /**
@@ -1209,8 +1282,8 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
     // 'virtual' methods ------------------------------------------------------
 
     /**
-     * Resolves the new text representation of this token, after cell ranges
-     * have been moved in a specific sheet of the spreadsheet document.
+     * Resolves the new text representation of this token, before cell ranges
+     * will be moved in a specific sheet of the spreadsheet document.
      *
      * @param {FormulaGrammar} formulaGrammar
      *  The formula grammar containing specific settings for formula tokens.
@@ -1225,14 +1298,9 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      * @param {Object} [options]
      *  Optional parameters. Will be passed to the method getRange3D().
      *
-     * @returns {Object|Null}
-     *  Null, if the string representation of the moved cell reference does not
-     *  change; otherwise a result descriptor with the following properties:
-     *  - {String} text
-     *      The string representation of the moved cell reference.
-     *  - {Boolean} refError
-     *      Whether this cell reference is valid, but will be deleted (will
-     *      result in a #REF! error code).
+     * @returns {String|Null}
+     *  The string representation of the moved cell reference, if it has been
+     *  changed; otherwise null.
      */
     ReferenceToken.prototype.resolveMovedCells = function (formulaGrammar, sheet, moveDescs, options) {
 
@@ -1266,7 +1334,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
                 }
 
                 // transform only the start address of the range, if the end address is frozen
-                if (isFrozen2) {
+                if (isFrozen2 && this._cell2Ref) {
                     var startAddress = moveDesc.transformAddress(newRange.start);
                     return (newRange = startAddress ? Range.createFromAddresses(startAddress, newRange.end) : null);
                 }
@@ -1281,11 +1349,156 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
         // create copies of the cell references that will be modified to generate the text representation
         var cell1Ref = newRange && CellRef.create(newRange.start, this._cell1Ref.absCol, this._cell1Ref.absRow);
         var cell2Ref = newRange && this._cell2Ref && CellRef.create(newRange.end, this._cell2Ref.absCol, this._cell2Ref.absRow);
+        var targetAddress = Utils.getOption(options, 'targetAddress', Address.A1);
+        return formulaGrammar.formatReference(this._docModel, targetAddress, this._sheet1Ref, this._sheet2Ref, cell1Ref, cell2Ref);
+    };
 
-        return {
-            text: formulaGrammar.formatReference(this._docModel, this._sheet1Ref, this._sheet2Ref, cell1Ref, cell2Ref),
-            refError: !cell1Ref && !cell2Ref
-        };
+    /**
+     * Resolves the new text representation of this token, after cell ranges
+     * have been cut/paste in a specific sheet of the spreadsheet document.
+     *
+     * @param {FormulaGrammar} formulaGrammar
+     *  The formula grammar containing specific settings for formula tokens.
+     *
+     * @param {Range} sourceRange
+     *  The range from which the content was cutted off.
+     *
+     * @param {Range} targetRange
+     *  The range to whom the content will be pasted.
+     *
+     * @param {Object} [options]
+     *  Optional parameters. Will be passed to the method getRange3D() amongst
+     *  other things.
+     *
+     * @returns {String|Null}
+     *  Null, if the string representation of the pasted cell reference does
+     *  not change; otherwise the new string representation of the pasted cell
+     *  reference.
+     */
+    ReferenceToken.prototype.resolveCutPasteCells = function (formulaGrammar, sourceRange, targetRange, options) {
+        // the original range, with sheet indexes
+        var sheet       = options.sheet,
+
+            bothExists  = (this._cell1Ref && this._cell2Ref),
+
+            oldRange3d  = this.getRange3D(options),
+            sameCol     = (sourceRange.start[0] === targetRange.start[0]),
+            sameRow     = (sourceRange.start[1] === targetRange.start[1]),
+            columns     = sameCol ? true : sameRow ? false : null,
+            forward     = sourceRange.start.get(!columns) < targetRange.start.get(!columns),
+            oldRange    = oldRange3d.toRange(),
+            overlaps    = oldRange.overlaps(targetRange),
+
+            newRange    = null,
+            cell1Ref    = null,
+            cell2Ref    = null;
+
+        // nothing to do, if this token represents a reference error, or points
+        // to another sheet or a sheet range, or sheet reference is invalid
+        if (!oldRange3d || !oldRange3d.isSheet(sheet)) { return null; }
+
+        if (
+            (bothExists && sourceRange.contains(Range.create(this._cell1Ref.col, this._cell1Ref.row, this._cell2Ref.col, this._cell2Ref.row)))
+            ||
+            (!bothExists && this._cell1Ref && sourceRange.containsAddress(new Address(this._cell1Ref.col, this._cell1Ref.row)))
+        ) {
+            var backupCell1Ref = (this._cell1Ref) ? this._cell1Ref.clone() : null,
+                backupCell2Ref = (this._cell2Ref) ? this._cell2Ref.clone() : null;
+
+            this.relocateRange(sourceRange.start, targetRange.start, false);
+            cell1Ref = (this._cell1Ref) ? this._cell1Ref.clone() : null;
+            cell2Ref = (this._cell2Ref) ? this._cell2Ref.clone() : null;
+
+            this._cell1Ref = backupCell1Ref;
+            this._cell2Ref = backupCell2Ref;
+
+            return formulaGrammar.formatReference(this._docModel, targetRange.start, this._sheet1Ref, this._sheet2Ref, cell1Ref, cell2Ref);
+
+        // one end (top, right, bottom or left) completly covered by sourceRange
+        } else if (bothExists && this._cell1Ref.getIndex(columns) >= sourceRange.start.get(columns) && this._cell2Ref.getIndex(columns) <= sourceRange.end.get(columns)) {
+
+            if (!sameCol && !sameRow) { return null; }
+
+            var oldRangeArray       = new RangeArray(oldRange),
+                sourceRangeArray    = new RangeArray(sourceRange),
+                // current indexes
+                col1            = this._cell1Ref.col,
+                row1            = this._cell1Ref.row,
+                col2            = this._cell2Ref.col,
+                row2            = this._cell2Ref.row;
+
+            var newRefRange     = oldRangeArray.difference(sourceRange).first(), // oldRange without sourceRange
+                cuttedRefRange  = sourceRangeArray.intersect(oldRange).first(),
+
+                startCutted     = null,
+                endCutted       = null,
+                startPasted     = null,
+                endPasted       = null,
+
+                xOffset         = null,
+                yOffset         = null,
+                xOver           = null,
+                yOver           = null;
+
+            if (!cuttedRefRange) { return null; }
+
+            startCutted     = (sourceRange.contains((columns ? oldRange.headerRow() : oldRange.leadingCol())));
+            endCutted       = (sourceRange.contains((columns ? oldRange.footerRow() : oldRange.trailingCol())));
+            startPasted     = (targetRange.contains((columns ? oldRange.headerRow() : oldRange.leadingCol())));
+            endPasted       = (targetRange.contains((columns ? oldRange.footerRow() : oldRange.trailingCol())));
+
+            xOffset         = cuttedRefRange.start.get(true) - sourceRange.start.get(true);
+            yOffset         = cuttedRefRange.start.get(false) - sourceRange.start.get(false);
+            xOver           = (sourceRange.size(true) - xOffset - cuttedRefRange.size(true));
+            yOver           = (sourceRange.size(false) - yOffset - cuttedRefRange.size(false));
+
+            if (startCutted) {
+                if (endPasted) {
+                    col1 = newRefRange.start.get(true);
+                    row1 = newRefRange.start.get(false);
+
+                    col2 = targetRange.start.get(true) + xOffset + cuttedRefRange.size(true) - 1;
+                    row2 = targetRange.start.get(false) + yOffset + cuttedRefRange.size(false) - 1;
+
+                } else if (overlaps || !forward) {
+                    col1 = (xOffset > 0 || !forward) ? targetRange.start.get(true) + xOffset : newRefRange.start.get(true);
+                    row1 = (yOffset > 0 || !forward) ? targetRange.start.get(false) + yOffset : newRefRange.start.get(false);
+
+                    col2 = Math.max(cuttedRefRange.size(true), newRefRange.end.get(true));
+                    row2 = Math.max(cuttedRefRange.size(false), newRefRange.end.get(false));
+                }
+
+            } else if (endCutted) {
+                if (startPasted) {
+                    col1 = Math.min(newRefRange.start.get(true), targetRange.start.get(true) + xOffset);
+                    row1 = Math.min(newRefRange.start.get(false), targetRange.start.get(false) + yOffset);
+
+                    col2 = (xOver > 0 && forward) ? targetRange.start.get(true) + xOffset + cuttedRefRange.size(true) - 1 : newRefRange.end.get(true);
+                    row2 = (yOver > 0 && forward) ? targetRange.start.get(false) + yOffset + cuttedRefRange.size(false) - 1 : newRefRange.end.get(false);
+
+                } else if (overlaps || forward) {
+                    col1 = Math.min(newRefRange.start.get(true), targetRange.start.get(true) + xOffset);
+                    row1 = Math.min(newRefRange.start.get(false), targetRange.start.get(false) + yOffset);
+
+                    col2 = (xOver > 0 || forward) ? targetRange.start.get(true) + xOffset + cuttedRefRange.size(true) - 1 : newRefRange.end.get(true);
+                    row2 = (yOver > 0 || forward) ? targetRange.start.get(false) + yOffset + cuttedRefRange.size(false) - 1 : newRefRange.end.get(false);
+                }
+            }
+
+            // create new range from calculated values
+            newRange = Range.create(col1, row1, col2, row2);
+
+            // nothing changes, if the transformed range equals the original range
+            if (newRange && newRange.equals(oldRange)) { return null; }
+
+            // create copies of the cell references that will be modified to generate the text representation
+            cell1Ref = newRange && CellRef.create(newRange.start, this._cell1Ref.absCol, this._cell1Ref.absRow);
+            cell2Ref = newRange && this._cell2Ref && CellRef.create(newRange.end, this._cell2Ref.absCol, this._cell2Ref.absRow);
+
+            return formulaGrammar.formatReference(this._docModel, targetRange.start, this._sheet1Ref, this._sheet2Ref, cell1Ref, cell2Ref);
+        }
+
+        return null;
     };
 
     // class NameToken ========================================================
@@ -1569,7 +1782,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
      *
      * @param {Object} [initOptions]
      *  Optional parameters:
-     *  @param {String} [initOptionsoptions.regionKey]
+     *  @param {String} [initOptions.regionKey]
      *      The resource key of a table region. If omitted, the default region
      *      'DATA' will be referred by the token. Additionally, the combined
      *      regions 'HEADER,DATA' and 'DATA,TOTALS' will be accepted.
@@ -1636,7 +1849,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
         if (!tableModel) { return null; }
 
         // resolve the table region (nothing to return, if no table region is available);
-        var regionKey = this._regionKey || 'DATA';
+        var regionKey = this.getRegionKey();
         // special handling for the 'ThisRow' region, if no target address is given (do not result in error)
         var ignoreRowRef = !targetAddress && (regionKey === 'ROW');
         var regionRange = ignoreRowRef ? tableModel.getRange() : tableModel.getRegionRange(regionKey, targetAddress);
@@ -1680,6 +1893,28 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
         return this._tableName;
     };
 
+    /**
+     * The resource key of the table region contained in this table token.
+     *
+     * @returns {String}
+     *  The resource key of a single table region, or one of the combined
+     *  regions 'HEADER,DATA' or 'DATA,TOTALS'.
+     */
+    TableToken.prototype.getRegionKey = function () {
+        return this._regionKey || 'DATA';
+    };
+
+    /**
+     * Returns whether this token extracts a specific column, or a range of
+     * columns from the table range, e.g. when using Table[Column1].
+     *
+     * @returns {Boolean}
+     *  Whether this token extracts specific columns from the table range.
+     */
+    TableToken.prototype.hasColumnRange = function () {
+        return !!this._col1Name;
+    };
+
     /**
      * Returns the model of the table range referred by this token.
      *
@@ -1875,26 +2110,47 @@ define('io.ox/office/spreadsheet/model/formula/parser/tokens', [
     };
 
     /**
-     * Resolves the new text representation of this token, after cell ranges
-     * have been moved in a specific sheet of the spreadsheet document.
+     * Resolves the new text representation of this token, before cell ranges
+     * will be moved in a specific sheet of the spreadsheet document.
      *
      * @param {FormulaGrammar} formulaGrammar
      *  The formula grammar containing specific settings for formula tokens.
      *
-     * @returns {Object|Null}
-     *  Null, if the string representation of the moved cell reference does not
-     *  change; otherwise a result descriptor with the following properties:
-     *  - {String} text
-     *      The string representation of the moved table reference.
-     *  - {Boolean} refError
-     *      Whether this cell reference is valid, but will be deleted (will
-     *      result in a #REF! error code).
+     * @param {Number} sheet
+     *  The zero-based index of the sheet containing the moved cell ranges.
+     *
+     * @param {Array<MoveDescriptor>} moveDescs
+     *  An array of move descriptors created while generating the move document
+     *  operations.
+     *
+     * @returns {String|Null}
+     *  The string representation of the moved cell reference, if it has been
+     *  changed; otherwise null.
      */
-    TableToken.prototype.resolveMovedCells = function (formulaGrammar) {
+    TableToken.prototype.resolveMovedCells = function (formulaGrammar, sheet, moveDescs) {
 
-        // return simple #REF! error, if the target range cannot be resolved anymore, e.g. due to deleted table column
-        var result = this._resolveRangeData(null);
-        return result ? null : { text: formulaGrammar.getErrorName(ErrorCode.REF), refError: true };
+        // return simple #REF! error, if the table token is invalid
+        var rangeData = this._resolveRangeData(null);
+        if (!rangeData) { return formulaGrammar.getErrorName(ErrorCode.REF); }
+
+        // table ranges located on another sheet will not be affected
+        if (sheet !== rangeData.tableModel.getSheetModel().getIndex()) { return null; }
+
+        // transform the resulting range; return #REF!, if the range will be deleted
+        var origRange = rangeData.tableRange;
+        if (!MoveDescriptor.transformRange(origRange, moveDescs)) {
+            return formulaGrammar.getErrorName(ErrorCode.REF);
+        }
+
+        // if the table token refers to columns, invalidate it if the start or the end
+        // column will be deleted (even if some inner columns remain available)
+        if (this.hasColumnRange()) {
+            var col1Range = MoveDescriptor.transformRange(origRange.leadingCol(), moveDescs);
+            var col2Range = MoveDescriptor.transformRange(origRange.trailingCol(), moveDescs);
+            if (!col1Range || !col2Range) { return formulaGrammar.getErrorName(ErrorCode.REF); }
+        }
+
+        return null;
     };
 
     // static class Tokens ====================================================
