@@ -6,19 +6,19 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/spreadsheet/model/formula/tokenarray', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/container/simplemap',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/formulautils',
-    'io.ox/office/spreadsheet/model/formula/utils/sheetref',
-    'io.ox/office/spreadsheet/model/formula/utils/cellref',
     'io.ox/office/spreadsheet/model/formula/parser/tokens'
-], function (Utils, SheetUtils, FormulaUtils, SheetRef, CellRef, Tokens) {
+], function (Utils, SimpleMap, SheetUtils, FormulaUtils, Tokens) {
 
     'use strict';
 
@@ -26,9 +26,10 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
     var Address = SheetUtils.Address;
     var RangeArray = SheetUtils.RangeArray;
     var Range3DArray = SheetUtils.Range3DArray;
+    var CellRef = FormulaUtils.CellRef;
+    var SheetRef = FormulaUtils.SheetRef;
     var SeparatorToken = Tokens.SeparatorToken;
     var ParenthesisToken = Tokens.ParenthesisToken;
-    var SheetRefToken = Tokens.SheetRefToken;
     var ReferenceToken = Tokens.ReferenceToken;
     var NameToken = Tokens.NameToken;
 
@@ -60,8 +61,9 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *      conditional formatting range.
      *  - 'validation': The token array represents the condition value of a
      *      data validation range.
-     *  - 'chart': The token array represents the source link of a data series
-     *      in a chart object.
+     *  - 'drawing': The token array represents the source link in a drawing
+     *      object (e.g. data series source in a chart object, or a linked text
+     *      box).
      *  - 'custom': A custom token array without special behavior.
      */
     function TokenArray(parentModel, tokenType) {
@@ -76,7 +78,7 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
         // the array of all formula tokens
         this._allTokens = [];
         // the formula tokens with sheet references
-        this._sheetTokens = [];
+        this._sheet3dTokens = [];
         // the formula reference tokens
         this._refTokens = [];
         // the formula tokens with defined names
@@ -95,8 +97,13 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
 
         // cached compiler token tree
         this._compileDesc = null;
+        // cached formula results, mapped by reference and target addresses
+        this._resultCache = null;
+
         // whether this token array is currently interpreted, to prevent recursion
-        this._interpreting = false;
+        // (flag set by target addresses, the same token array may be used for different
+        // formula cells, e.g. in shared formulas)
+        this._interpreting = new SimpleMap();
 
     } // class TokenArray
 
@@ -112,7 +119,7 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      */
     TokenArray.prototype._registerToken = function (token) {
         this._tokenTypeSet[token.getType()] = true;
-        if (token instanceof SheetRefToken) { this._sheetTokens.push(token); }
+        if (token.hasSheetRef && token.hasSheetRef()) { this._sheet3dTokens.push(token); }
         if (token instanceof ReferenceToken) { this._refTokens.push(token); }
         if (token instanceof NameToken) { this._nameTokens.push(token); }
     };
@@ -121,10 +128,19 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      * Invokes all registered change callback handlers.
      */
     TokenArray.prototype._invokeChangeHandlers = function (token, index) {
-        if (!this._changeHandlers) { return; }
-        this._changeHandlers.forEach(function (changeHandler) {
-            changeHandler.call(this, token, index);
-        }, this);
+
+        // clear compiler tree (changed reference tokens may result in different tree)
+        this._compileDesc = null;
+
+        // clear all cached formula results if a single token in this instance has been changed
+        this.clearResultCache();
+
+        // invoke all registered change handlers
+        if (this._changeHandlers) {
+            this._changeHandlers.forEach(function (changeHandler) {
+                changeHandler.call(this, token, index);
+            }, this);
+        }
     };
 
     /**
@@ -133,7 +149,8 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *
      * @param {String} grammarId
      *  The identifier of the formula grammar to be used to generate the
-     *  formula expressions. See class FormulaGrammar for details.
+     *  formula expressions. See SpreadsheetDocument.getFormulaGrammar() for
+     *  more details.
      *
      * @param {Function} callback
      *  A callback function that receives a token from this token array, and
@@ -192,9 +209,10 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      * the own reference sheet index as option 'refSheet' if available.
      */
     TokenArray.prototype._extendWithOwnOptions = function (options) {
-        return _.extend({}, options, {
+        return _.extend({
+            wrapReferences: this._wrapReferences
+        }, options, {
             refSheet: this._resolveRefSheet(options),
-            wrapReferences: this._wrapReferences,
             detectCircular: this._detectCircular,
             unqualifiedTables: this._unqualifiedTables
         });
@@ -212,6 +230,45 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
         return this._docModel.getFormulaCompiler().compileTokens(tokens);
     };
 
+    /**
+     * Returns whether this token array is currently being interpreted for the
+     * specified target address.
+     *
+     * @param {Address} targetAddress
+     *  The address of the target cell.
+     *
+     * @returns {Boolean}
+     *  Whether this token array is currently being interpreted for the
+     *  specified target address.
+     */
+    TokenArray.prototype._isInterpreting = function (targetAddress) {
+        return this._interpreting.has(targetAddress.key());
+    };
+
+    /**
+     * Sets the 'interpreting' state for the specified target address, invokes
+     * the specified callback function, and removes the 'interpreting' state
+     * afterwards.
+     *
+     * @param {Address} targetAddress
+     *  The address of the target cell to be locked for interpreting state.
+     *
+     * @param {Function} callback
+     *  The callback function to be invoked with locked interpreting state.
+     *
+     * @returns {Any}
+     *  The return value of the callback function.
+     */
+    TokenArray.prototype._lockInterpreting = function (targetAddress, callback) {
+        var addressKey = targetAddress.key();
+        try {
+            this._interpreting.insert(addressKey, true);
+            return callback.call(this);
+        } finally {
+            this._interpreting.remove(addressKey);
+        }
+    };
+
     // public methods ---------------------------------------------------------
 
     /**
@@ -262,13 +319,27 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
         return this.hasToken('ref') || this.hasToken('name') || this.hasToken('table');
     };
 
+    /**
+     * Returns whether this token array contains any tokens with existing sheet
+     * reference (references such as Sheet1!A1, or sheet-local defined names
+     * such as Sheet1!name).
+     *
+     * @returns {Boolean}
+     *  Whether this token array contains any any tokens with existing sheet
+     *  reference.
+     */
+    TokenArray.prototype.hasSheet3dTokens = function () {
+        return this._sheet3dTokens.length > 0;
+    };
+
     /**
      * Returns the text representation of the formula represented by this token
      * array.
      *
      * @param {String} grammarId
      *  The identifier of the formula grammar to be used to generate the
-     *  formula expression. See class FormulaGrammar for details.
+     *  formula expression. See SpreadsheetDocument.getFormulaGrammar() for
+     *  more details.
      *
      * @param {Object} [options]
      *  Optional parameters:
@@ -286,6 +357,10 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *      expression will be modified, as if the token array has been
      *      relocated according to these two addresses (without actually
      *      modifying the token array).
+     *  @param {Boolean} [options.wrapReferences]
+     *      If specified, the internal 'wrap references' state that has been
+     *      set according to the formula type passed to the constructor will be
+     *      overridden.
      *
      * @returns {String}
      *  The string representation of the formula.
@@ -370,19 +445,25 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *  @param {Boolean} [options.resolveNames=false]
      *      If set to true, will return the range addresses referred by all
      *      defined names contained in this token array.
+     *  @param {Boolean} [options.wrapReferences]
+     *      If specified, the internal 'wrap references' state that has been
+     *      set according to the formula type passed to the constructor will be
+     *      overridden.
      *
      * @returns {Range3DArray}
-     *  The addresses of the resulting cell ranges, including their sheet
-     *  indexes. If the formula cannot be resolved successfully to a range
-     *  list, this method returns an empty array.
+     *  The addresses of the resulting cell ranges with their sheet indexes. If
+     *  the formula cannot be resolved successfully to a range list, this
+     *  method returns an empty array.
      */
     TokenArray.prototype.resolveRangeList = function (options) {
 
+        // the target address of the cell this formula is interpreted for
+        var targetAddress = Utils.getOption(options, 'targetAddress', Address.A1);
         // the resulting range addresses
         var resultRanges = new Range3DArray();
 
         // prevent recursive processing of the token array, e.g. in defined name
-        if (this._interpreting) { return resultRanges; }
+        if (this._isInterpreting(targetAddress)) { return resultRanges; }
 
         // whether to resolve defined name tokens
         var resolveNames = Utils.getBooleanOption(options, 'resolveNames', false);
@@ -390,9 +471,6 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
         var hasTokens = resolveNames ? this.hasRefTokens() : this.hasToken('ref');
         if (!hasTokens) { return resultRanges; }
 
-        // the target address (needed to resolve addresses in table ranges)
-        var targetAddress = Utils.getOption(options, 'targetAddress', Address.A1);
-
         // add more options (refSheet and wrapReferences)
         options = this._extendWithOwnOptions(options);
 
@@ -424,9 +502,9 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
                     newOptions.refAddress = Address.A1;
 
                     // prevent recursive invocation of this token array via other defined names
-                    this._interpreting = true;
-                    var ranges = nameModel.getTokenArray().resolveRangeList(newOptions);
-                    this._interpreting = false;
+                    var ranges = this._lockInterpreting(targetAddress, function () {
+                        return nameModel.getTokenArray().resolveRangeList(newOptions);
+                    });
                     if (ranges.empty()) { return false; }
 
                     // append the new ranges to the result
@@ -488,6 +566,10 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *  @param {Boolean} [options.resolveNames=false]
      *      If set to true, will return the range addresses referred by all
      *      defined names and table ranges contained in this token array.
+     *  @param {Boolean} [options.wrapReferences]
+     *      If specified, the internal 'wrap references' state that has been
+     *      set according to the formula type passed to the constructor will be
+     *      overridden.
      *
      * @returns {Array<Object>}
      *  The addresses of all cell ranges contained in this token array with
@@ -513,12 +595,14 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      */
     TokenArray.prototype.extractRanges = function (options) {
 
+        // the target address
+        var targetAddress = Utils.getOption(options, 'targetAddress', Address.A1);
         // descriptors for the resulting ranges, with the additional 'circular' property
         var rangeInfos = [];
         rangeInfos.circular = false;
 
         // prevent recursive processing of the token array in defined names
-        if (this._interpreting) {
+        if (this._isInterpreting(targetAddress)) {
             rangeInfos.circular = true;
             return rangeInfos;
         }
@@ -529,9 +613,6 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
         var hasTokens = resolveNames ? this.hasRefTokens() : this.hasToken('ref');
         if (!hasTokens) { return rangeInfos; }
 
-        // the target address (needed to resolve addresses in table ranges)
-        var targetAddress = Utils.getOption(options, 'targetAddress', Address.A1);
-
         // add more options (refSheet and wrapReferences)
         options = this._extendWithOwnOptions(options);
 
@@ -554,9 +635,9 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
                     newOptions.refAddress = Address.A1;
 
                     // prevent recursive invocation of this token array via other defined names
-                    this._interpreting = true;
-                    var nameRangeInfos = nameModel.getTokenArray().extractRanges(newOptions);
-                    this._interpreting = false;
+                    var nameRangeInfos = this._lockInterpreting(targetAddress, function () {
+                        return nameModel.getTokenArray().extractRanges(newOptions);
+                    });
 
                     // insert the range descriptors with adjusted properties
                     nameRangeInfos.forEach(function (rangeInfo) {
@@ -585,7 +666,8 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *
      * @param {String} grammarId
      *  The identifier of the formula grammar to be used to generate the
-     *  formula expressions. See class FormulaGrammar for details.
+     *  formula expressions. See SpreadsheetDocument.getFormulaGrammar() for
+     *  more details.
      *
      * @param {Object} changeDesc
      *  The properties describing the document change. The properties that are
@@ -603,9 +685,11 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *          references containing the renamed sheet will be updated.
      *      - 'relabelName': The label of a defined name has been changed. The
      *          formula expressions will be updated to use the new label.
-     *      - 'moveCells': Cells have been moved in a sheet. This includes
+     *      - 'moveCells': Cells will be moved in a sheet. This includes
      *          inserting or deleting some columns or rows. All affected cell
      *          references will be updated.
+     *      - 'cutPaste': Cut cells have been pasted within a sheet. This
+     *          includes recalculation of all dependent references.
      *  - {Number|Null} changeDesc.sheet
      *      The zero-based index of the sheet that will be changed. This
      *      property is used by all document operation types: The index of the
@@ -634,20 +718,19 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *      The current text representation of this token array.
      *  - {String} new
      *      The transformed text representation of this token array.
-     *  - {Boolean} error
-     *      Whether the a cell reference has been replaced with a #REF! error.
-     *      This property will be inserted for change type 'moveCells' only.
      */
     TokenArray.prototype.resolveOperation = function (grammarId, changeDesc) {
 
         // the effective reference sheet of this token array
         var refSheet = this._resolveRefSheet();
+        // additional options for the token methods
+        var options = null;
 
         switch (changeDesc.type) {
 
             case 'deleteSheet':
                 // if the formula does not contain any sheet or table references, nothing will change
-                if ((this._sheetTokens.length === 0) && !this.hasToken('table')) { return null; }
+                if ((this._sheet3dTokens.length === 0) && !this.hasToken('table')) { return null; }
 
                 // collect the old and new text representation of the formula
                 return this._resolveChangedFormula(grammarId, function (token, config) {
@@ -656,7 +739,7 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
 
             case 'renameSheet':
                 // if the formula does not contain any sheet or table references, nothing will change
-                if ((this._sheetTokens.length === 0) && !this.hasToken('table')) { return null; }
+                if ((this._sheet3dTokens.length === 0) && !this.hasToken('table')) { return null; }
 
                 // collect the old and new text representation of the formula
                 return this._resolveChangedFormula(grammarId, function (token, config) {
@@ -677,22 +760,28 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
                 if (!this.hasToken('ref') && !this.hasToken('table')) { return null; }
 
                 // create options for the method BaseToken.resolveMovedCells()
-                var options = { refSheet: refSheet, freezeRelRefs: this._freezeRelRefs };
+                options = { refSheet: refSheet, freezeRelRefs: this._freezeRelRefs };
                 if (changeDesc.relocate) {
                     options.refAddress = changeDesc.relocate.from;
                     options.targetAddress = changeDesc.relocate.to;
                 }
 
                 // collect the old and new text representation of the formula
-                var refError = false;
-                var moveResult = this._resolveChangedFormula(grammarId, function (token, config) {
-                    var result = token.resolveMovedCells(config, changeDesc.sheet, changeDesc.moveDescs, options);
-                    if (!result) { return null; }
-                    refError = refError || result.refError;
-                    return result.text;
+                return this._resolveChangedFormula(grammarId, function (token, config) {
+                    return token.resolveMovedCells(config, changeDesc.sheet, changeDesc.moveDescs, options);
+                });
+
+            case 'cutPaste':
+                // if the formula does not contain any reference tokens, nothing will change
+                if (!this.hasToken('ref') && !this.hasToken('table')) { return null; }
+
+                // create options for the method BaseToken.resolveCutPasteCells()
+                options = { refSheet: refSheet, sheet: changeDesc.sourceSheet };
+
+                // collect the old and new text representation of the formula
+                return this._resolveChangedFormula(grammarId, function (token, config) {
+                    return token.resolveCutPasteCells(config, changeDesc.sourceRange, changeDesc.targetRange, options);
                 });
-                if (moveResult) { moveResult.error = refError; }
-                return moveResult;
         }
 
         Utils.error('TokenArray.resolveOperation(): unknown operation type "' + changeDesc.type + '"');
@@ -760,12 +849,11 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
 
         // collect all existing token types in a flag set
         this._refTokens = [];
-        this._sheetTokens = [];
+        this._sheet3dTokens = [];
         this._tokenTypeSet = {};
         this._allTokens.forEach(this._registerToken, this);
 
         // reset other properties, notify change handlers
-        this._compileDesc = null;
         this._invokeChangeHandlers(null);
         return this;
     };
@@ -788,7 +876,8 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *
      * @param {String} grammarId
      *  The identifier of the formula grammar to be used to parse the passed
-     *  formula expression. See class FormulaGrammar for details.
+     *  formula expression. See SpreadsheetDocument.getFormulaGrammar() for
+     *  more details.
      *
      * @param {String} formula
      *  The formula expression to be parsed, without the leading equality sign.
@@ -846,9 +935,11 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
         // reparse formula if it contains a bad token, otherwise refresh all sheet tokens
         if (this.hasToken('bad'))  {
             this.parseFormula('op', this.getFormula('op'), options);
-        } else {
-            this._sheetTokens.forEach(function (token) { token.refreshSheets(); });
+        } else if (this._sheet3dTokens.length > 0) {
+            this._sheet3dTokens.forEach(function (token) { token.refreshSheets(); });
+            // the compiler tree may contain an 'unexpected' error due to missing sheets while importing
             this._compileDesc = null;
+            this.clearResultCache();
         }
 
         return this;
@@ -908,11 +999,45 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
     TokenArray.prototype.appendToken = function (token) {
         this._allTokens.push(token);
         this._registerToken(token);
-        this._compileDesc = null;
         this._invokeChangeHandlers(token, this._allTokens.length - 1);
         return this;
     };
 
+    /**
+     * Appends a new reference token to this token array, that will be built
+     * from the passed cell address, and invokes the registered change callback
+     * handlers for the new token.
+     *
+     * @param {Address} address
+     *  The address of the cell to be added as reference token to this token
+     *  array.
+     *
+     * @param {Object} [options]
+     *  Optional parameters:
+     *  @param {Number} [options.abs=false]
+     *      If set to true, the column and row reference will be marked as
+     *      absolute (leading dollar signs).
+     *  @param {Number} [options.sheet]
+     *      The zero-based index of the sheet the reference token will point
+     *      to. If omitted, no sheet reference will be inserted into the
+     *      reference token (sheet-local reference).
+     *
+     * @returns {TokenArray}
+     *  A reference to this instance.
+     */
+    TokenArray.prototype.appendAddress = function (address, options) {
+
+        // the cell references
+        var abs = Utils.getBooleanOption(options, 'abs', false);
+        var cellRef = CellRef.create(address, abs, abs);
+
+        // the sheet reference
+        var sheet = Utils.getIntegerOption(options, 'sheet');
+        var sheetRef = (typeof sheet === 'number') ? new SheetRef(sheet, true) : null;
+
+        return this.appendToken(new ReferenceToken(this._docModel, cellRef, null, sheetRef));
+    };
+
     /**
      * Appends a new reference token to this token array, that will be built
      * from the passed cell range address, and invokes the registered change
@@ -1038,18 +1163,18 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      * change callback handlers, after a sheet has been inserted into, deleted
      * from, or moved in the document.
      *
-     * @param {Number|Null} toSheet
-     *  The zero-based index of the inserted sheet, or the new position of a
-     *  moved sheet, or null for a deleted sheet.
-     *
      * @param {Number|Null} fromSheet
      *  The zero-based index of the deleted sheet, or the old position of a
      *  moved sheet, or null for an inserted sheet.
      *
+     * @param {Number|Null} toSheet
+     *  The zero-based index of the inserted sheet, or the new position of a
+     *  moved sheet, or null for a deleted sheet.
+     *
      * @returns {Boolean}
      *  Whether any token in this token array has been changed.
      */
-    TokenArray.prototype.transformSheet = function (toSheet, fromSheet) {
+    TokenArray.prototype.transformSheet = function (fromSheet, toSheet) {
 
         // nothing to do, if the sheet indexes are equal
         if (toSheet === fromSheet) { return false; }
@@ -1058,8 +1183,8 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
         var changed = false;
 
         // relocate all sheet tokens, and collect changed state (no early exit!)
-        this._sheetTokens.forEach(function (token) {
-            if (token.transformSheet(toSheet, fromSheet)) { changed = true; }
+        this._sheet3dTokens.forEach(function (token) {
+            if (token.transformSheet(fromSheet, toSheet)) { changed = true; }
         }, this);
 
         // invoke all change handlers
@@ -1074,7 +1199,7 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      * tree structure. See class FormulaCompiler for details.
      *
      * @returns {Object}
-     *  The result descriptor of the compilation process. See description of
+     *  The result descriptor of the compiled token tree. See description of
      *  the method FormulaCompiler.compileTokens() for details.
      */
     TokenArray.prototype.compileFormula = function () {
@@ -1114,12 +1239,17 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *      these ranges will be forwarded to the name token of the parent
      *      formula expression, in order to decide how to proceed with these
      *      ranges.
-     *  - {Object} names
+     *  - {Object<String,NameModel>} names
      *      A map with the models of all defined names, mapped by their UIDs.
-     *  - {Object} missingNames
+     *  - {Object<String,TableModel>} tables
+     *      A map with the models of all table ranges, mapped by their UIDs.
+     *  - {Object<String,Boolean>} missingNames
      *      A flag set with the map keys of all missing defined names (as
      *      object keys) occurring in the formula expression, or in any
      *      existing defined name referred by the formula.
+     *  - {Object<String,Boolean>} missingFuncs
+     *      A flag set with the resource keys of all unimplemented functions
+     *      that occur in the formula.
      *  - {String|Null} recalc
      *      The recalculation mode: Either 'always' or 'once', if at least one
      *      function in the formula contains the respective recalculation mode
@@ -1132,23 +1262,30 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
     TokenArray.prototype.getDependencies = function (refAddress, depTarget, options) {
 
         // the result descriptor object
-        var deps = { depRanges: new Range3DArray(), rootRanges: new Range3DArray(), names: {}, missingNames: {}, recalc: null, circular: false };
+        var deps = { depRanges: new Range3DArray(), rootRanges: new Range3DArray(), names: {}, tables: {}, missingNames: {}, missingFuncs: {}, recalc: null, circular: false };
 
         // compile the infix tokens to a token tree (early exit, if this token array is invalid)
         var compileDesc = this.compileFormula();
         if (compileDesc.error) { return deps; }
 
-        // prevent recursive processing of the token array, e.g. in defined name
-        if (this._interpreting) { deps.circular = true; return deps; }
+        // a single target address for cell formulas (and others, e.g. formatting rules in range mode); otherwise null (!)
+        var targetAddress = (depTarget instanceof Address) ? depTarget : null;
 
+        // prevent recursive processing of the token array, e.g. in defined name
+        if (this._isInterpreting(targetAddress || refAddress)) {
+            deps.circular = true;
+            return deps;
+        }
+
+        // insert the resource keys of all missing functions
+        _.extend(deps.missingFuncs, compileDesc.missingFuncs);
         // insert the recalculation mode of the root node into the result
         deps.recalc = compileDesc.root.recalc;
 
         // add more options (refSheet and wrapReferences)
         options = this._extendWithOwnOptions(options);
 
-        // a single target address for cell formulas (and others, e.g. formatting rules in range mode)
-        var targetAddress = (depTarget instanceof Address) ? depTarget : null;
+        // options to resolve the range addresses from reference tokens
         var addressOptions = targetAddress ? _.extend({}, options, { refAddress: refAddress, targetAddress: targetAddress }) : null;
 
         // array of target ranges for other formulas, e.g. formatting rules
@@ -1182,16 +1319,18 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
                 }
 
                 // prevent recursive invocation of this token array via other defined names
-                this._interpreting = true;
-                // defined names will always be evaluated relative to cell A1
-                var nameDeps = nameModel.getTokenArray().getDependencies(Address.A1, depTarget, options);
-                this._interpreting = false;
+                var nameDeps = this._lockInterpreting(targetAddress || refAddress, function () {
+                    // defined names will always be evaluated relative to cell A1
+                    return nameModel.getTokenArray().getDependencies(Address.A1, depTarget, options);
+                });
 
                 // add all dependencies of the defined name to the own result
                 deps.depRanges.append(nameDeps.depRanges);
                 deps.names[nameModel.getUid()] = nameModel;
                 _.extend(deps.names, nameDeps.names);
+                _.extend(deps.tables, nameDeps.tables);
                 _.extend(deps.missingNames, nameDeps.missingNames);
+                _.extend(deps.missingFuncs, nameDeps.missingFuncs);
                 deps.recalc = FormulaUtils.getRecalcMode(deps.recalc, nameDeps.recalc);
                 deps.circular = deps.circular || nameDeps.circular;
 
@@ -1201,6 +1340,9 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
 
             // table token: resolve the target range inside the table
             if (token.isType('table')) {
+                var tableModel = token.resolveTableModel();
+                if (!tableModel) { return null; }
+                deps.tables[tableModel.getUid()] = tableModel;
                 var tableRange = token.getRange3D(targetAddress);
                 return tableRange ? new Range3DArray(tableRange) : null;
             }
@@ -1255,10 +1397,18 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *      The target reference address used to relocate reference tokens with
      *      relative column/row components. If omitted, cell A1 will be used as
      *      target reference cell.
-     *  @param {Address} [options.recalcDirty=false]
+     *  @param {Range} [options.matrixRange]
+     *      The entire bounding range of a matrix formula. Used if the passed
+     *      context type is 'mat'. If omitted, a 1x1 matrix formula is assumed.
+     *  @param {Boolean} [options.recalcDirty=false]
      *      If set to true, all dirty cell formulas referred by the reference
      *      tokens of this token array will be recalculated recursively using
      *      the dependency manager of the document.
+     *  @param {Boolean} [options.cacheResult=false]
+     *      If set to true, this instance will use an internal cache for the
+     *      formula results, and will return the cached results upon next
+     *      invocations of this method. The results will be cached separately
+     *      by reference address and target address.
      *
      * @returns {Object}
      *  The result descriptor for the formula. See description of the method
@@ -1273,21 +1423,72 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
 
         // check compiler result
         if (compileDesc.error) {
-            return formulaInterpreter.createErrorResult(compileDesc.error);
+            return formulaInterpreter.createErrorResult(contextType, compileDesc.error);
         }
 
+        // the target address
+        var targetAddress = Utils.getOption(options, 'targetAddress', Address.A1);
+
         // prevent recursive interpretation
-        if (this._interpreting) {
-            return formulaInterpreter.createResult(FormulaUtils.CIRCULAR_ERROR);
+        if (this._isInterpreting(targetAddress)) {
+            return formulaInterpreter.createWarnResult(contextType, FormulaUtils.CIRCULAR_ERROR);
+        }
+
+        // extend the passed options with more internal options
+        options = this._extendWithOwnOptions(options);
+
+        // get or create the result cache (do not cache results of volatile formulas)
+        var cacheActive = options.cacheResult && (compileDesc.root.recalc !== 'always');
+        var resultCache = cacheActive ? (this._resultCache || (this._resultCache = new SimpleMap())) : null;
+
+        // Create the cache key. Depending on the existence of relative column or row references
+        // in the token array, the cache can be optimized according to the reference and target
+        // address. Without relative column (or row) references, the column A (or the row 1
+        // respectively) will be used as cache key for all reference and target addresses.
+        //
+        // Example: The formula expression =SUM($C1:$E4) will always be evaluated for columns C:E
+        // regardless of the reference and target addresses. Therefore, the formula result will
+        // be cached with column A as cache key, in order to resolve the cached result for any
+        // reference and target address.
+        //
+        var cacheKey = (function () {
+            if (!resultCache) { return null; }
+            // defined names may always contain relative column/row references
+            var hasNames = this.hasToken('name');
+            // if the formula does not contain relative column references, store all results at column A
+            var relColRef = hasNames || compileDesc.root.relColRef;
+            var refCol = (relColRef && options.refAddress) ? options.refAddress[0] : 0;
+            var targetCol = relColRef ? targetAddress[0] : 0;
+            // if the formula does not contain relative row references, store all results at row 1
+            var relRowRef = hasNames || compileDesc.root.relRowRef;
+            var refRow = (relRowRef && options.refAddress) ? options.refAddress[1] : 0;
+            var targetRow = relRowRef ? targetAddress[1] : 0;
+            // create the cache key from reference and target address
+            return Address.key(refCol, refRow) + ':' + Address.key(targetCol, targetRow);
+        }.call(this));
+
+        // invokes the formula interpreter to calculate the actual result of the formula
+        function interpretTokens() {
+            return formulaInterpreter.interpretTokens(contextType, compileDesc.root, options);
         }
 
         // interpret the formula with extended options
-        try {
-            this._interpreting = true;
-            return formulaInterpreter.interpretTokens(contextType, compileDesc.root, this._extendWithOwnOptions(options));
-        } finally {
-            this._interpreting = false;
-        }
+        return this._lockInterpreting(targetAddress, function () {
+            return resultCache ? resultCache.getOrCreate(cacheKey, interpretTokens) : interpretTokens();
+        });
+    };
+
+    /**
+     * Clears all cached formula results. Formula results will be cached when
+     * passing the option 'cacheResult' to the method
+     * TokenArray.interpretFormula() of this class.
+     *
+     * @returns {TokenArray}
+     *  A reference to this instance.
+     */
+    TokenArray.prototype.clearResultCache = function () {
+        this._resultCache = null;
+        return this;
     };
 
     // exports ================================================================
