@@ -6,24 +6,26 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Michael Nimz <michael.nimz@open-xchange.com>
  */
 
 define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/arraytemplate',
+    'io.ox/office/tk/container/typedarray',
     'io.ox/office/tk/object/timermixin',
     'io.ox/office/baseframework/model/modelobject',
     'io.ox/office/spreadsheet/utils/operations',
     'io.ox/office/spreadsheet/utils/sheetutils'
-], function (Utils, ArrayTemplate, TimerMixin, ModelObject, Operations, SheetUtils) {
+], function (Utils, TypedArray, TimerMixin, ModelObject, Operations, SheetUtils) {
 
     'use strict';
 
     var RangeArray = SheetUtils.RangeArray;
     var Range = SheetUtils.Range;
+    var MoveDescriptor = SheetUtils.MoveDescriptor;
 
     // class HyperlinkModel ===================================================
 
@@ -63,7 +65,7 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
      *
      * @constructor
      */
-    var HyperlinkModelArray = ArrayTemplate.create(HyperlinkModel);
+    var HyperlinkModelArray = TypedArray.create(HyperlinkModel);
 
     // class HyperlinkCollection ==============================================
 
@@ -88,6 +90,8 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
         // all hyperlink ranges
         var linkModels = new HyperlinkModelArray();
 
+        var app = sheetModel.getApp();
+
         // base constructor ---------------------------------------------------
 
         ModelObject.call(this, sheetModel.getDocModel());
@@ -175,12 +179,8 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
          *  The transformed hyperlink range if available, otherwise null.
          */
         function transformHyperlinkRange(range, moveDescs, reverse) {
-            Utils.iterateArray(moveDescs, function (moveDesc) {
-                // transform the passed range without expanding the end of the range
-                range = moveDesc.transformRange(range, { reverse: reverse });
-                if (!range) { return Utils.BREAK; }
-            }, { reverse: reverse });
-            return range;
+            // transform the passed range without expanding the end of the range
+            return MoveDescriptor.transformRange(range, moveDescs, { reverse: reverse });
         }
 
         /**
@@ -382,7 +382,7 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
                     // add new hyperlink
                     generateInsertHyperlinkOperation(generator, range, url);
                 }
-            }, { delay: 'immediate' });
+            }, { delay: 'immediate', infoString: 'HyperlinkCollection: generateHyperlinkOperations', app: app });
         };
 
         /**
@@ -467,7 +467,7 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
                         }
                     }
                 }
-            }, { delay: 'immediate' });
+            }, { delay: 'immediate', infoString: 'HyperlinkCollection: generateAutoFillOperations 1', app: app });
 
             // Next Step: Create new ajar Hyperlink(s)
             promise = promise.then(function () {
@@ -488,14 +488,14 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
                     linkRange.setEnd(row_i_end, false);
 
                     return sheetModel.getCellCollection().generateFillOperations(generator, linkRange, { url: linkModel.url });
-                }, { delay: 'immediate' });
+                }, { delay: 'immediate', infoString: 'HyperlinkCollection: generateAutoFillOperations 2', app: app });
             });
 
             // add new (independent) single hyperlink(s)
             promise = promise.then(function () {
                 return self.iterateArraySliced(singleHyperlinks, function (linkModel) {
                     return sheetModel.getCellCollection().generateFillOperations(generator, linkModel.range, { url: linkModel.url });
-                }, { delay: 'immediate' });
+                }, { delay: 'immediate', infoString: 'HyperlinkCollection: generateAutoFillOperations 3', app: app });
             });
 
             return promise;
@@ -531,13 +531,13 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
                 if (!restoredRange || restoredRange.differs(linkModel.range)) {
                     restoreLinks.push(linkModel);
                 }
-            }, { delay: 'immediate' });
+            }, { delay: 'immediate', infoString: 'HyperlinkCollection: generateMoveCellsOperations 1', app: app });
 
             // add all hyperlinks to the undo generator that need to be restored
             promise = promise.then(function () {
                 return self.iterateArraySliced(restoreLinks, function (linkModel) {
                     generateRestoreHyperlinkOperation(generator, linkModel);
-                }, { delay: 'immediate' });
+                }, { delay: 'immediate', infoString: 'HyperlinkCollection: generateMoveCellsOperations 2', app: app });
             });
 
             return promise;
@@ -575,7 +575,7 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
                 }
 
                 return self.generateHyperlinkOperations(generator, range, url);
-            }, { delay: 'immediate' });
+            }, { delay: 'immediate', infoString: 'HyperlinkCollection: generateMergeCellsOperations', app: app });
         };
 
         // initialization -----------------------------------------------------
@@ -585,7 +585,7 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            self = linkModels = null;
+            self = linkModels = app = null;
         });
 
     } // class HyperlinkCollection
