@@ -6,21 +6,20 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/spreadsheet/model/mergecollection', [
-    'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/iteratorutils',
-    'io.ox/office/tk/utils/simplemap',
+    'io.ox/office/tk/container/simplemap',
     'io.ox/office/tk/object/timermixin',
     'io.ox/office/baseframework/model/modelobject',
     'io.ox/office/spreadsheet/utils/operations',
     'io.ox/office/spreadsheet/utils/sheetutils'
-], function (Utils, IteratorUtils, SimpleMap, TimerMixin, ModelObject, Operations, SheetUtils) {
+], function (SimpleMap, TimerMixin, ModelObject, Operations, SheetUtils) {
 
     'use strict';
 
@@ -29,6 +28,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
     var Range = SheetUtils.Range;
     var RangeArray = SheetUtils.RangeArray;
     var RangeSet = SheetUtils.RangeSet;
+    var MoveDescriptor = SheetUtils.MoveDescriptor;
 
     // class MergeCollection ==================================================
 
@@ -74,6 +74,9 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
         // all merged ranges, mapped by key of their start addresses
         var mergedRangeMap = new SimpleMap();
 
+        // the spreadsheet app
+        var app = docModel.getApp();
+
         // base constructor ---------------------------------------------------
 
         ModelObject.call(this, docModel);
@@ -130,23 +133,19 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
         }
 
         /**
-         * Generates the 'mergeCells' operation needed to merge the specified
-         * cell ranges. The number of generated operations will be minimized by
-         * grouping consecutive single column ranges and single row ranges into
-         * merge operations with merge type 'horizontal' or 'vertical'.
+         * Generates the 'mergeCells' operation needed to restore the specified
+         * merged cell ranges. The number of generated operations will be
+         * minimized by grouping consecutive single column ranges and single
+         * row ranges into merge operations with merge type 'horizontal' or
+         * 'vertical'.
          *
          * @param {SheetOperationsGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {RangeArray} ranges
-         *  An array of cell range addresses.
-         *
-         * @param {Object} [options]
-         *  Optional parameters passed to the operations generator which can be
-         *  used to decide whether to append or prepend operations, or whether
-         *  to generate undo operation.
+         *  An array of addresses of merged cell ranges.
          */
-        function generateMergeOperations(generator, ranges, options) {
+        function generateRestoreOperations(generator, ranges) {
 
             // generate 'vertical' or 'horizontal' merge operations for single-column/single-row ranges
             function collectAndGenerateOperations(singleRanges, columns) {
@@ -175,7 +174,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
 
                     // create one operation for all adjacent merged ranges
                     var compoundRange = columns ? range1.colRange(0, count) : range1.rowRange(0, count);
-                    generator.generateRangeOperation(Operations.MERGE_CELLS, compoundRange, { type: (count > 1) ? mergeType : 'merge' }, options);
+                    generator.generateRangeOperation(Operations.MERGE_CELLS, compoundRange, { type: (count > 1) ? mergeType : 'merge' }, { undo: true });
                 }
             }
 
@@ -197,7 +196,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
             // generate undo operations for two-dimensional ranges directly
             if (rangeGroups.range) {
                 rangeGroups.range.forEach(function (range) {
-                    generator.generateRangeOperation(Operations.MERGE_CELLS, range, { type: 'merge' }, options);
+                    generator.generateRangeOperation(Operations.MERGE_CELLS, range, { type: 'merge' }, { undo: true });
                 });
             }
         }
@@ -234,10 +233,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
         function transformMergedRange(mergedRange, moveDescs, reverse) {
 
             // transform the passed range without expanding the end of the range
-            Utils.iterateArray(moveDescs, function (moveDesc) {
-                mergedRange = moveDesc.transformRange(mergedRange, { reverse: reverse });
-                if (!mergedRange) { return Utils.BREAK; }
-            }, { reverse: reverse });
+            mergedRange = MoveDescriptor.transformRange(mergedRange, moveDescs, { reverse: reverse });
 
             // skip merged ranges that have been shrunken to a single cell
             return (mergedRange && !mergedRange.single()) ? mergedRange : null;
@@ -319,7 +315,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
             // the range covered by the operation
             var range = context.getRange();
             // the method how to merge/unmerge the operation range
-            var type = context.getEnum('type', /^(merge|horizontal|vertical|unmerge)$/);
+            var type = context.getOptEnum('type', /^(merge|horizontal|vertical|unmerge)$/, 'merge');
             // all merged ranges deleted from the collection
             var removedRanges = new RangeArray();
             // all merged ranges added to the collection
@@ -750,28 +746,6 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
          */
         this.generateMergeCellsOperations = function (generator, ranges, type) {
 
-            // creates col or row ranges in case of merging 'horizontal' or 'vertical'
-            function createColRowRanges(ranges, type) {
-                var horizontal = (type === 'horizontal'),
-                    collection = horizontal ? sheetModel.getRowCollection() : sheetModel.getColCollection(),
-                    newRanges  = new RangeArray();
-
-                ranges.forEach(function (ran) {
-                    var interval = (horizontal) ? ran.rowInterval() : ran.colInterval();
-
-                    IteratorUtils.forEach(collection.createIterator(interval), function (desc) {
-                        var start_col = horizontal ? ran.start[0] : desc.index,
-                            start_row = horizontal ? desc.index : ran.start[1],
-                            end_col   = horizontal ? ran.end[0] : desc.index,
-                            end_row   = horizontal ? desc.index : ran.end[1];
-
-                        newRanges.push(Range.create(start_col, start_row, end_col, end_row));
-                    });
-                });
-
-                return newRanges;
-            }
-
             // the cell collection of the sheet
             var cellCollection = sheetModel.getCellCollection();
             // whether to merge single columns in the passed ranges
@@ -789,10 +763,6 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
                 return horizontal ? range.singleCol() : vertical ? range.singleRow() : range.single();
             });
 
-            if (horizontal || vertical) {
-                ranges = createColRowRanges(ranges, type);
-            }
-
             // nothing to do without ranges
             if (ranges.empty()) { return $.when(); }
 
@@ -865,7 +835,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
                 // (will become undefined, if no more merged ranges of this collection are left)
                 remainingRanges = rangeGroups.remaining;
 
-            }, { delay: 'immediate' });
+            }, { delay: 'immediate', infoString: 'MergeCollection.generateMergeCellsOperations', app: app });
 
             // generate the hyperlink operations
             promise = promise.then(function () {
@@ -879,7 +849,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
 
             // add all merged ranges to the undo generator that need to be restored
             return promise.then(function () {
-                generateMergeOperations(generator, restoreRanges, { undo: true });
+                generateRestoreOperations(generator, restoreRanges);
             });
         };
 
@@ -913,18 +883,18 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
                 if (!restoredRange || restoredRange.differs(mergedRange)) {
                     restoreRanges.push(mergedRange);
                 }
-            }, { delay: 'immediate' });
+            }, { delay: 'immediate', infoString: 'MergeCellCollection.generateMoveCellsOperations', app: app });
 
             // add all merged ranges to the undo generator that need to be restored
             return promise.done(function () {
-                generateMergeOperations(generator, restoreRanges, { undo: true });
+                generateRestoreOperations(generator, restoreRanges);
             });
         };
 
         /**
          *
          */
-        this.generateAutoFillOperations = SheetUtils.profileAsyncMethod('ColRowCollection.generateAutoFillOperations()', function (generator, sourceRange, targetRange, columns, reverse) {
+        this.generateAutoFillOperations = SheetUtils.profileAsyncMethod('MergeCollection.generateAutoFillOperations()', function (generator, sourceRange, targetRange, columns, reverse) {
 
             function prepareNewMergedRanges(baseRange) {
                 var newMergedRange = baseRange.clone(),
@@ -972,7 +942,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            self = docModel = sheetModel = mergedRangeSet = mergedRangeMap = null;
+            self = docModel = sheetModel = mergedRangeSet = mergedRangeMap = app = null;
         });
 
     } // class MergeCollection
