@@ -6,20 +6,22 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/spreadsheet/model/modelattributesmixin', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/container/simplemap',
     'io.ox/office/editframework/utils/color',
     'io.ox/office/editframework/utils/border',
     'io.ox/office/drawinglayer/model/drawingstylecollection',
     'io.ox/office/spreadsheet/model/cellstylecollection',
     'io.ox/office/spreadsheet/model/tablestylecollection',
     'io.ox/office/spreadsheet/model/cellautostylecollection'
-], function (Utils, Color, Border, DrawingStyleCollection, CellStyleCollection, TableStyleCollection, CellAutoStyleCollection) {
+], function (Utils, SimpleMap, Color, Border, DrawingStyleCollection, CellStyleCollection, TableStyleCollection, CellAutoStyleCollection) {
 
     'use strict';
 
@@ -43,6 +45,12 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
          */
         calcOnLoad: { def: false },
 
+        /**
+         * The null date (the date represented by the serial value 0) of the
+         * workbook. Must be a date in ISO format YYYY-MM-DD.
+         */
+        nullDate: { def: '1899-12-30' },
+
         // view attributes
 
         /**
@@ -250,9 +258,11 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
         visible: { def: true, resize: true },
 
         /**
-         * The width of the column, in 1/100 mm.
+         * The width of the column, in number of digits of default document
+         * font (OOXML), or in 1/100 mm (ODF). The actual default column width
+         * will be set dynamically per sheet.
          */
-        width: { def: 2000, resize: true },
+        width: { def: 0, resize: true },
 
         /**
          * Specifies whether the width of the column has been set or changed in
@@ -271,9 +281,10 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
         visible: { def: true, resize: true },
 
         /**
-         * The height of the row, in 1/100 mm.
+         * The height of the row, in points (OOXML), or in 1/100 mm (ODF). The
+         * actual default row height will be set dynamically per sheet.
          */
-        height: { def: 500, resize: true },
+        height: { def: 0, resize: true },
 
         /**
          * Specifies whether the height of the row has been set or changed in
@@ -297,6 +308,23 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
         filtered: { def: false, resize: true }
     };
 
+    // definitions for column/row grouping attributes -------------------------
+
+    var GROUP_ATTRIBUTE_DEFINITIONS = {
+
+        /**
+         * Specifies the grouping level of the column or row.
+         */
+        level: { def: 0 },
+
+        /**
+         * Specifies whether the affected column/row groups are collapsed. Will
+         * be a boolean value in OOXML documents, but an integral bit set in
+         * ODF documents!
+         */
+        collapse: { def: false }
+    };
+
     // definitions for sheet attributes ---------------------------------------
 
     var SHEET_ATTRIBUTE_DEFINITIONS = {
@@ -318,6 +346,18 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
          */
         baseColWidth: { def: 8 },
 
+        /**
+         * Whether the total columns of all column groups in the sheet are
+         * located before the groups.
+         */
+        colTotalBefore: { def: false },
+
+        /**
+         * Whether the total rows of all row groups in the sheet are located
+         * before the groups.
+         */
+        rowTotalBefore: { def: false },
+
         // view attributes
 
         /**
@@ -435,6 +475,30 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
          */
         footerRow: { def: false, scope: 'element' },
 
+        /**
+         * Whether to show special formatting for the cells in the first table
+         * column, according to the current table style sheet.
+         */
+        firstCol: { def: false, scope: 'element' },
+
+        /**
+         * Whether to show special formatting for the cells in the last table
+         * column, according to the current table style sheet.
+         */
+        lastCol: { def: false, scope: 'element' },
+
+        /**
+         * Whether to show alternating row formatting for the data cells,
+         * according to the current table style sheet.
+         */
+        bandsHor: { def: false, scope: 'element' },
+
+        /**
+         * Whether to show alternating column formatting for the data cells,
+         * according to the current table style sheet.
+         */
+        bandsVert: { def: false, scope: 'element' },
+
         /**
          * Whether the table can be filtered (this flag does not mean that the
          * table has actual filter rules applied, but the GUI may provide
@@ -696,12 +760,46 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
      */
     function ModelAttributesMixin() {
 
+        // self reference
+        var self = this;
+
+        // special behavior for OOXML files
+        var ooxml = this.getApp().isOOXML();
+
+        // the font collection of the document
+        var fontCollection = this.getFontCollection();
+
         // the style sheet collection for cells, columns, and rows
         var cellStyles = null;
 
         // the auto-style collection for cells, columns, and rows
         var cellAutoStyles = null;
 
+        // cache for default digit width, mapped by different zoom factors
+        var digitWidthCache = new SimpleMap();
+
+        // the conversion factor for column widths (1 operation unit to 1/100 mm, initialized lazily)
+        var colWidthFactor = null;
+
+        // the conversion factor for row heights (1 operation unit to 1/100 mm, initialized lazily)
+        var rowHeightFactor = null;
+
+        // the maximum column width in 1/100 mm (initialized lazily)
+        var maxColWidthHmm = null;
+
+        // the maximum wow height in 1/100 mm (initialized lazily)
+        var maxRowHeightHmm = null;
+
+        // private methods ----------------------------------------------------
+
+        function getColWidthFactor() {
+            return colWidthFactor || (colWidthFactor = ooxml ? (100 * Utils.convertLength(self.getDefaultDigitWidth(1), 'px', 'mm')) : 1);
+        }
+
+        function getRowHeightFactor() {
+            return rowHeightFactor || (rowHeightFactor = ooxml ? (100 * Utils.convertLength(1, 'pt', 'mm')) : 1);
+        }
+
         // public methods -----------------------------------------------------
 
         /**
@@ -725,34 +823,127 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
         };
 
         /**
-         * Returns the default column width for all undefined columns in a
-         * sheet, according to the font settings in the current default cell
-         * style, and the passed base column width.
+         * Returns the maximum width of the digits in the font of the current
+         * default cell style, according to the passed zoom factor.
          *
-         * @param {Number} baseWidth
-         *  The base column width, as number of zero digits.
+         * @param {Number} zoom
+         *  The zoom factor to be applied to the default font.
          *
          * @returns {Number}
-         *  The default column width for all undefined columns, in 1/100 mm.
+         *  The maximum width of the digits in the font of the current default
+         *  cell style, in pixels.
          */
-        this.getDefaultColWidthHmm = function (baseWidth) {
+        this.getDefaultDigitWidth = function (zoom) {
+            return digitWidthCache.getOrCreate(Math.round(zoom * 100), function () {
 
-            // attributes of the default cell style (NOT the default auto-style!)
-            var charAttributes = cellStyles.getDefaultStyleAttributeSet().character;
+                // attributes of the default cell style (NOT the default auto-style!)
+                var charAttributes = cellStyles.getDefaultStyleAttributeSet().character;
 
-            // the maximum pixel width of any of the digits of the default font
-            var maxDigitWidth = this.getFontCollection().getDigitWidths(charAttributes).maxWidth;
+                // the maximum pixel width of any of the digits of the default font
+                return fontCollection.getDigitWidths(charAttributes, { zoom: zoom }).maxWidth;
+            });
+        };
 
-            // the resulting column width, calculated from baseWidth and the actual digit width
-            var colWidth = maxDigitWidth * baseWidth + 5;
-            return Utils.convertLengthToHmm(colWidth, 'px');
+        /**
+         * Converts the passed column width from 1/100 of millimeters to
+         * operation units according to the file format of the edited document.
+         *
+         * @param {Number} colWidthHmm
+         *  A column width in 1/100 of millimeters.
+         *
+         * @returns {Number}
+         *  The column width in operation units.
+         */
+        this.convertColWidthToUnit = function (colWidthHmm) {
+            var colWidth = colWidthHmm / getColWidthFactor();
+            return ooxml ? Utils.round(colWidth, 0.01) : colWidth;
+        };
+
+        /**
+         * Converts the passed column width from operation units according to
+         * the file format of the edited document to 1/100 of millimeters.
+         *
+         * @param {Number} colWidth
+         *  A column width in operation units.
+         *
+         * @returns {Number}
+         *  The column width in 1/100 of millimeters.
+         */
+        this.convertColWidthFromUnit = function (colWidth) {
+            return Math.ceil(colWidth * getColWidthFactor());
+        };
+
+        /**
+         * Converts the passed row height from 1/100 of millimeters to
+         * operation units according to the file format of the edited document.
+         *
+         * @param {Number} rowHeightHmm
+         *  A row height in 1/100 of millimeters.
+         *
+         * @returns {Number}
+         *  The row height in operation units.
+         */
+        this.convertRowHeightToUnit = function (rowHeightHmm) {
+            var rowHeight = rowHeightHmm / getRowHeightFactor();
+            return ooxml ? Utils.round(rowHeight, 0.25) : rowHeight;
+        };
+
+        /**
+         * Converts the passed row height from operation units according to the
+         * file format of the edited document to 1/100 of millimeters.
+         *
+         * @param {Number} rowHeight
+         *  A row height in operation units.
+         *
+         * @returns {Number}
+         *  The row height in 1/100 of millimeters.
+         */
+        this.convertRowHeightFromUnit = function (rowHeight) {
+            return Math.ceil(rowHeight * getRowHeightFactor());
+        };
+
+        /**
+         * Returns the maximum width for columns, as supported by the file
+         * format of the edited document.
+         *
+         * @returns {Number}
+         *  The maximum width for columns.
+         */
+        this.getMaxColWidthHmm = function () {
+            return maxColWidthHmm || (maxColWidthHmm = ooxml ? this.convertColWidthFromUnit(255) : 100000);
+        };
+
+        /**
+         * Returns the maximum height for rows, as supported by the file format
+         * of the edited document.
+         *
+         * @returns {Number}
+         *  The maximum height for rows.
+         */
+        this.getMaxRowHeightHmm = function () {
+            return maxRowHeightHmm || (maxRowHeightHmm = ooxml ? this.convertRowHeightFromUnit(409.5) : 100000);
+        };
+
+        /**
+         * Returns the maximum width for columns or the maximum height for
+         * rows, as supported by the file format of the edited document.
+         *
+         * @param {Boolean} columns
+         *  Whether to the maximum column width (true), or the maximum row
+         *  height (false).
+         *
+         * @returns {Number}
+         *  The maximum width for columns, or the maximum height for rows.
+         */
+        this.getMaxColRowSizeHmm = function (columns) {
+            return columns ? this.getMaxColWidthHmm() : this.getMaxRowHeightHmm();
         };
 
         /**
          * Calculates the row height in 1/100 of millimeters to be used for the
          * passed character attributes. The row height is about 10% larger than
          * the normal line height for the passed font settings, as returned
-         * e.g. by the method FontMetrics.getNormalLineHeight().
+         * e.g. by the method Font.getNormalLineHeight().
          *
          * @param {Object} charAttributes
          *  Character formatting attributes influencing the line height, as
@@ -764,7 +955,7 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
         this.getRowHeightHmm = function (charAttributes) {
 
             // the normal line height according to the font settings
-            var lineHeight = this.getFontCollection().getNormalLineHeight(charAttributes);
+            var lineHeight = fontCollection.getNormalLineHeight(charAttributes);
 
             // use at least 125% of the font size, to compensate for browsers
             // reporting very small line heights (especially Chrome)
@@ -794,42 +985,42 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
             return Utils.convertHmmToLength(this.getRowHeightHmm(charAttributes) * zoom, 'px', 1);
         };
 
-        /**
-         * Returns the default row height for all undefined rows in a sheet,
-         * according to the font settings in the current default cell style.
-         *
-         * @returns {Number}
-         *  The default row height for all undefined rows, in 1/100 mm.
-         */
-        this.getDefaultRowHeightHmm = function () {
-            return this.getRowHeightHmm(cellStyles.getDefaultStyleAttributeSet().character);
-        };
-
         // initialization -----------------------------------------------------
 
-        this.registerAttributeDefinitions('document', DOCUMENT_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('character', CHARACTER_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('cell', CELL_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('apply', APPLY_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('column', COLUMN_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('row', ROW_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('sheet', SHEET_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('table', TABLE_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('filter', TABLE_FILTER_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('sort', TABLE_SORT_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('validation', VALIDATION_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('rule', FORMAT_RULE_ATTRIBUTE_DEFINITIONS)
-            .registerAttributeDefinitions('drawing', DRAWING_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributeDefinitions('document', DOCUMENT_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributeDefinitions('character', CHARACTER_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributeDefinitions('cell', CELL_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributeDefinitions('apply', APPLY_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributeDefinitions('column', COLUMN_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributeDefinitions('row', ROW_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributeDefinitions('group', GROUP_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributeDefinitions('sheet', SHEET_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributeDefinitions('table', TABLE_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributeDefinitions('filter', TABLE_FILTER_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributeDefinitions('sort', TABLE_SORT_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributeDefinitions('validation', VALIDATION_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributeDefinitions('rule', FORMAT_RULE_ATTRIBUTE_DEFINITIONS);
+        this.registerAttributeDefinitions('drawing', DRAWING_ATTRIBUTE_DEFINITIONS);
 
-        this.addStyleCollection(cellStyles = new CellStyleCollection(this))
-            .addStyleCollection(new TableStyleCollection(this))
-            .addStyleCollection(new DrawingStyleCollection(this));
+        this.addStyleCollection(cellStyles = new CellStyleCollection(this));
+        this.addStyleCollection(new TableStyleCollection(this));
+        this.addStyleCollection(new DrawingStyleCollection(this));
 
         this.addAutoStyleCollection(cellAutoStyles = new CellAutoStyleCollection(this));
 
+        // OOXML: listen to changes of the default style sheet, invalidate cached font measures for column width
+        if (ooxml) {
+            this.listenTo(cellStyles, 'triggered', function (event, styleId) {
+                if (styleId === cellStyles.getDefaultStyleId()) {
+                    digitWidthCache.clear();
+                    colWidthFactor = maxColWidthHmm = null;
+                }
+            });
+        }
+
         // destroy class members on destruction
         this.registerDestructor(function () {
-            cellStyles = cellAutoStyles = null;
+            self = fontCollection = cellStyles = cellAutoStyles = null;
         });
 
     } // class ModelAttributesMixin
