@@ -6,14 +6,15 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/spreadsheet/model/namecollection', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/simplemap',
+    'io.ox/office/tk/container/simplemap',
     'io.ox/office/tk/object/timermixin',
     'io.ox/office/baseframework/model/modelobject',
     'io.ox/office/spreadsheet/utils/operations',
@@ -232,7 +233,8 @@ define('io.ox/office/spreadsheet/model/namecollection', [
          *
          * @param {String} grammarId
          *  The identifier of the formula grammar to be used to generate the
-         *  formula expression. See class FormulaGrammar for details.
+         *  formula expression. See SpreadsheetDocument.getFormulaGrammar() for
+         *  more details.
          *
          * @param {Address} [targetAddress]
          *  The target address to relocate the formula expression to. If
@@ -252,7 +254,8 @@ define('io.ox/office/spreadsheet/model/namecollection', [
          *
          * @param {String} grammarId
          *  The identifier of the formula grammar to be used to generate the
-         *  formula expression. See class FormulaGrammar for details.
+         *  formula expression. See SpreadsheetDocument.getFormulaGrammar() for
+         *  more details.
          *
          * @returns {String}
          *  The formula expression of the reference address of this name model.
@@ -290,7 +293,7 @@ define('io.ox/office/spreadsheet/model/namecollection', [
          * @returns {NameModel}
          *  A reference to this instance.
          */
-        this.generateFormulaOperations = function (generator, changeDesc) {
+        this.generateUpdateFormulaOperations = function (generator, changeDesc) {
 
             // the properties for the change operation, and the undo operation
             var properties = {};
@@ -393,6 +396,9 @@ define('io.ox/office/spreadsheet/model/namecollection', [
         // the document model
         var docModel = parentModel.getDocModel();
 
+        // the spreadsheet app
+        var app = docModel.getApp();
+
         // the sheet model, if this collection is part of a worksheet
         var sheetModel = (parentModel === docModel) ? null : parentModel;
 
@@ -950,17 +956,17 @@ define('io.ox/office/spreadsheet/model/namecollection', [
             var changeDesc = { type: 'relabelName', sheet: sheetModel ? sheetModel.getIndex() : null, oldLabel: label, newLabel: newLabel };
 
             // update the formulas of all globally defined names
-            var promise = docModel.getNameCollection().generateFormulaOperations(generator, changeDesc);
+            var promise = docModel.getNameCollection().generateUpdateFormulaOperations(generator, changeDesc);
 
             // update the formula expressions for all sheet collections in the document
             promise = promise.then(function () {
                 return docModel.generateOperationsForAllSheets(generator, function (sheetModel) {
                     return Utils.invokeChainedAsync(
-                        function () { return sheetModel.getCellCollection().generateFormulaOperations(generator, changeDesc); },
-                        function () { return sheetModel.getNameCollection().generateFormulaOperations(generator, changeDesc); },
-                        function () { return sheetModel.getValidationCollection().generateFormulaOperations(generator, changeDesc); },
-                        function () { return sheetModel.getCondFormatCollection().generateFormulaOperations(generator, changeDesc); },
-                        function () { return sheetModel.getDrawingCollection().generateFormulaOperations(generator, changeDesc); }
+                        function () { return sheetModel.getCellCollection().generateUpdateFormulaOperations(generator, changeDesc); },
+                        function () { return sheetModel.getNameCollection().generateUpdateFormulaOperations(generator, changeDesc); },
+                        function () { return sheetModel.getValidationCollection().generateUpdateFormulaOperations(generator, changeDesc); },
+                        function () { return sheetModel.getCondFormatCollection().generateUpdateFormulaOperations(generator, changeDesc); },
+                        function () { return sheetModel.getDrawingCollection().generateUpdateFormulaOperations(generator, changeDesc); }
                     );
                 });
             });
@@ -985,10 +991,10 @@ define('io.ox/office/spreadsheet/model/namecollection', [
          *  A promise that will be resolved when all operations have been
          *  generated.
          */
-        this.generateFormulaOperations = function (generator, changeDesc) {
+        this.generateUpdateFormulaOperations = function (generator, changeDesc) {
             return this.iterateSliced(nameModelMap.iterator(), function (nameModel) {
-                nameModel.generateFormulaOperations(generator, changeDesc);
-            }, { delay: 'immediate' });
+                nameModel.generateUpdateFormulaOperations(generator, changeDesc);
+            }, { delay: 'immediate', infoString: 'NameCollection: generateFormulaOperations', app: app });
         };
 
         // initialization -----------------------------------------------------
@@ -1004,9 +1010,9 @@ define('io.ox/office/spreadsheet/model/namecollection', [
             }
 
             // update the sheet indexes after the sheet collection has been manipulated
-            this.listenTo(docModel, 'transform:sheet', function (event, toSheet, fromSheet) {
+            this.listenTo(docModel, 'transform:sheet', function (event, fromSheet, toSheet) {
                 nameModelMap.forEach(function (nameModel) {
-                    nameModel.getTokenArray().transformSheet(toSheet, fromSheet);
+                    nameModel.getTokenArray().transformSheet(fromSheet, toSheet);
                 });
             });
 
@@ -1015,7 +1021,7 @@ define('io.ox/office/spreadsheet/model/namecollection', [
         // destroy all class members on destruction
         this.registerDestructor(function () {
             nameModelMap.forEach(function (nameModel) { nameModel.destroy(); });
-            self = parentModel = docModel = sheetModel = nameModelMap = null;
+            self = parentModel = docModel = sheetModel = nameModelMap = app = null;
         });
 
     } // class NameCollection
