@@ -6,14 +6,15 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define.async('io.ox/office/spreadsheet/model/numberformatter', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/simplemap',
+    'io.ox/office/tk/container/simplemap',
     'io.ox/office/tk/locale/localedata',
     'io.ox/office/tk/locale/parser',
     'io.ox/office/tk/locale/formatter',
@@ -21,14 +22,18 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
     'io.ox/office/spreadsheet/utils/operations',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/presetformattable',
-    'io.ox/office/spreadsheet/model/formula/formulautils',
-    'io.ox/office/spreadsheet/model/formula/utils/complex'
-], function (Utils, SimpleMap, LocaleData, Parser, Formatter, AppObjectMixin, Operations, SheetUtils, PresetFormatTable, FormulaUtils, Complex) {
+    'io.ox/office/spreadsheet/model/formula/formulautils'
+], function (Utils, SimpleMap, LocaleData, Parser, Formatter, AppObjectMixin, Operations, SheetUtils, PresetFormatTable, FormulaUtils) {
 
     'use strict';
 
     // convenience shortcuts
     var ErrorCode = SheetUtils.ErrorCode;
+    var MathUtils = FormulaUtils.Math;
+    var Complex = FormulaUtils.Complex;
+
+    // shortcuts to mathematical functions
+    var isZero = MathUtils.isZero;
 
     // identifiers of predefined formats that can be overridden by user-defined formats
     var REPLACEABLE_FORMAT_ID_SET = Utils.makeSet(PresetFormatTable.CURRENCY_FORMAT_IDS);
@@ -192,9 +197,20 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
         // predefined number formats, as arrays mapped by categories
         var predefFormatsMap = new SimpleMap();
 
+        // the format code of the standard number format
+        var standardCode = presetTable.getFormatCode(PresetFormatTable.GENERAL_ID);
+
+        // the parsed standard number format
+        var standardFormat = Parser.parseFormatCode(fileFormat, 'op', standardCode);
+
         // base constructors --------------------------------------------------
 
-        Formatter.call(this, { negativeDates: fileFormat === 'odf', generalLength: SheetUtils.MAX_LENGTH_STANDARD_CELL });
+        Formatter.call(this, {
+            nullDate: Date.UTC(1899, 11, 30),
+            negativeDates: fileFormat === 'odf',
+            leapYearBug: fileFormat === 'ooxml',
+            generalLength: SheetUtils.MAX_LENGTH_STANDARD_CELL
+        });
         AppObjectMixin.call(this, docModel.getApp());
 
         // private methods ----------------------------------------------------
@@ -273,6 +289,7 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
         }
 
         function generateCurrencyFormatCode(symbol, options) {
+            /*
             var withDec         = '0.00',
                 withoutDec      = '0',
                 withGroup       = '#,##',
@@ -286,6 +303,12 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
             if (!options.leading) { formatCode += ' ' + symbolCode; }
 
             return formatCode;
+            */
+
+            // bug #49613: now simply get the predefined-codes until ...
+            //             TODO: we cleaned up this whole piece of code
+            var preDefined = self.getPredefinedFormats('currency');
+            return (options.dec) ? preDefined[3].formatCodes[0] : preDefined[2].formatCodes[0];
         }
 
         // protected methods --------------------------------------------------
@@ -427,6 +450,16 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
             return presetTable.getFormatCode(formatId);
         };
 
+        /**
+         * Returns the format code for the standard number format.
+         *
+         * @returns {String}
+         *  The format code for the standard number format.
+         */
+        this.getStandardCode = function () {
+            return standardCode;
+        };
+
         /**
          * Returns a currency format code for the native currency of the
          * current UI language.
@@ -482,6 +515,26 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
             return presetTable.getFormatCode(formatId);
         };
 
+        /**
+         * Returns the predefined number formats for a specific number format
+         * category.
+         *
+         * @param {String} category
+         *  The identifier of a number format category.
+         *
+         * @returns {Array<Object>|Null}
+         *  An array of descriptor objects for all predefined number formats
+         *  for the specified category; or null if no number formats exist.
+         *  Each descriptor in the array contains the following properties:
+         *  - {ParsedFormat} parsedFormat
+         *      The parsed number format.
+         *  - {Array<String>} formatCodes
+         *      All format codes that are considered to represent the current
+         *      predefined number format.
+         *  - {Number|String} previewValue
+         *      The recommended value to be used to represent the number format
+         *      in the GUI.
+         */
         this.getPredefinedFormats = function (category) {
             return predefFormatsMap.get(category, null);
         };
@@ -503,7 +556,7 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
             if (predefFormats) { return predefFormats[0].parsedFormat.formatCode; }
 
             // return the format code for standard category
-            return (category === 'standard') ? presetTable.getFormatCode(PresetFormatTable.GENERAL_ID) : null;
+            return (category === 'standard') ? standardCode : null;
         };
 
         /**
@@ -558,6 +611,17 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
             return ((presetId !== null) && !formatTable.has(presetId)) ? presetId : null;
         };
 
+        /**
+         * Returns the parsed number format descriptor for the standard number
+         * format.
+         *
+         * @returns {ParsedFormat}
+         *  The parsed number format descriptor for the standard number format.
+         */
+        this.getStandardFormat = function () {
+            return standardFormat;
+        };
+
         /**
          * Returns the parsed number format descriptor for the specified number
          * format.
@@ -578,7 +642,7 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
         this.getParsedFormat = function (format, options) {
             var grammarId = Utils.getStringOption(options, 'grammarId', 'op');
             var formatCode = this.resolveFormatCode(format);
-            return (formatCode !== null) ? Parser.parseFormatCode(fileFormat, grammarId, formatCode) : this.getParsedFormat(0);
+            return (formatCode !== null) ? Parser.parseFormatCode(fileFormat, grammarId, formatCode) : standardFormat;
         };
 
         /**
@@ -602,7 +666,7 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
             }
 
             Utils.error('NumberFormatter.parseAttributesFormat(): cannot resolve attributes');
-            return this.getParsedFormat(0);
+            return standardFormat;
         };
 
         /**
@@ -948,7 +1012,7 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
             }
 
             // the resulting value must be a finite floating-point number
-            return (_.isNumber(value) && isFinite(value)) ? (floor ? Math.floor(value) : value) : null;
+            return ((typeof value === 'number') && isFinite(value)) ? (floor ? Math.floor(value) : value) : null;
         };
 
         /**
@@ -1018,7 +1082,7 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
             }
 
             // convert numbers and booleans to strings
-            if (_.isNumber(value) && isFinite(value)) {
+            if ((typeof value === 'number') && isFinite(value)) {
                 value = this.formatStandardNumber(value, maxLength);
             } else if (_.isBoolean(value)) {
                 value = formulaGrammar.getBooleanName(value); // always localized
@@ -1057,8 +1121,8 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
             }
 
             // convert numbers and strings to booleans
-            if (_.isNumber(value) && isFinite(value)) {
-                value = !FormulaUtils.isZero(value);
+            if ((typeof value === 'number') && isFinite(value)) {
+                value = !isZero(value);
             } else if (_.isString(value)) {
                 // always localized, returns null on failure
                 value = formulaGrammar.getBooleanValue(value);
@@ -1119,10 +1183,10 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
 
                 // ODF: do not create any additional operations, always use the number format property,
                 // but add the preset format identifiers for further usage in the export filters
+                // bug 49610: clear the 'formatId' attribute for user-defined format codes
                 case 'odf':
-                    if ((formatId !== null) && (formatId < PresetFormatTable.FIRST_USER_FORMAT_ID)) {
-                        cellAttrs.formatId = formatId;
-                    }
+                    var isPredef = (formatId !== null) && (formatId < PresetFormatTable.FIRST_USER_FORMAT_ID);
+                    cellAttrs.formatId = isPredef ? formatId : null;
                     break;
             }
 
@@ -1236,10 +1300,10 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
             createDateTimeEntry(true);
 
             // create all entries for percentages
-            createPercentEntry(false, false);
-            createPercentEntry(false, true);
             createPercentEntry(true,  false);
             createPercentEntry(true,  true);
+            createPercentEntry(false, false);
+            createPercentEntry(false, true);
 
             // create all entries for scientific numbers
             createScientificEntry(true);
@@ -1254,9 +1318,18 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
             createEntry('@', '@');
         }());
 
+        // change the null date via document operation
+        this.listenTo(docModel, 'change:attributes', function (event, newAttrs) {
+            var matches = /^(\d{4})-(\d{2})-(\d{2})$/.exec(newAttrs.nullDate);
+            if (matches) {
+                var nullDate = Date.UTC(parseInt(matches[1], 10), parseInt(matches[2], 10) - 1, parseInt(matches[3], 10));
+                self.configure({ nullDate: nullDate });
+            }
+        });
+
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            docModel = formulaGrammar = null;
+            self = docModel = formulaGrammar = null;
             presetTable = formatTable = reverseTable = null;
         });
 
