@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -16,6 +17,7 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
     'io.ox/office/tk/object/timermixin',
     'io.ox/office/editframework/utils/color',
     'io.ox/office/editframework/model/attributedmodel',
+    'io.ox/office/editframework/model/viewattributesmixin',
     'io.ox/office/spreadsheet/utils/operations',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/utils/paneutils',
@@ -28,9 +30,8 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
     'io.ox/office/spreadsheet/model/tablecollection',
     'io.ox/office/spreadsheet/model/validationcollection',
     'io.ox/office/spreadsheet/model/condformatcollection',
-    'io.ox/office/spreadsheet/model/drawing/drawingcollection',
-    'io.ox/office/spreadsheet/model/viewsettingsmixin'
-], function (Utils, TimerMixin, Color, AttributedModel, Operations, SheetUtils, PaneUtils, SheetSelection, NameCollection, ColRowCollection, MergeCollection, CellCollection, HyperlinkCollection, TableCollection, ValidationCollection, CondFormatCollection, SheetDrawingCollection, ViewSettingsMixin) {
+    'io.ox/office/spreadsheet/model/drawing/drawingcollection'
+], function (Utils, TimerMixin, Color, AttributedModel, ViewAttributesMixin, Operations, SheetUtils, PaneUtils, SheetSelection, NameCollection, ColRowCollection, MergeCollection, CellCollection, HyperlinkCollection, TableCollection, ValidationCollection, CondFormatCollection, SheetDrawingCollection) {
 
     'use strict';
 
@@ -40,6 +41,9 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
     var Range = SheetUtils.Range;
     var RangeArray = SheetUtils.RangeArray;
 
+    // additional fixed zoom factor depending on platform type
+    var ZOOM_ADJUST_FACTOR = Utils.TOUCH ? 1.25 : 1;
+
     // definitions for sheet view attributes
     var SHEET_VIEW_ATTRIBUTES = {
 
@@ -301,7 +305,7 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
      *
      * @extends AttributedModel
      * @extends TimerMixin
-     * @extends ViewSettingsMixin
+     * @extends ViewAttributesMixin
      *
      * @param {SpreadsheetModel} docModel
      *  The spreadsheet document model containing this sheet.
@@ -327,6 +331,9 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
         // self reference
         var self = this;
 
+        // the collection of all cell style sheets
+        var cellStyles = docModel.getCellStyles();
+
         // the collection of defined names in this sheet
         var nameCollection = null;
 
@@ -355,14 +362,31 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
         // the collection of drawing objects contained in this sheet
         var drawingCollection = null;
 
+        // the effective zoom factor, according to the 'zoom' attribute, and platform type
+        var effectiveZoom = 0;
+
+        // the effective horizontal cell text padding, according to zoom factor
+        var effectivePadding = 0;
+
         // base constructor ---------------------------------------------------
 
         AttributedModel.call(this, docModel, initialAttrs, { trigger: 'always', families: 'sheet column row' });
         TimerMixin.call(this);
-        ViewSettingsMixin.call(this, SHEET_VIEW_ATTRIBUTES);
+        ViewAttributesMixin.call(this, SHEET_VIEW_ATTRIBUTES, { changeHandler: changeViewAttributesHandler });
 
         // private methods ----------------------------------------------------
 
+        /**
+         * Updates internal settings according to the current effective sheet
+         * zoom factor.
+         */
+        function changeViewAttributesHandler(changedAttributes) {
+            if ('zoom' in changedAttributes) {
+                effectiveZoom = changedAttributes.zoom * ZOOM_ADJUST_FACTOR;
+                effectivePadding = SheetUtils.getTextPadding(effectiveZoom);
+            }
+        }
+
         /**
          * Expands all ranges but entire column/row ranges to the merged ranges
          * in the sheet.
@@ -814,7 +838,7 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
          *  The converted length in 1/100 of millimeters.
          */
         this.convertPixelToHmm = function (length) {
-            return Utils.convertLengthToHmm(length / this.getEffectiveZoom(), 'px');
+            return Utils.convertLengthToHmm(length / effectiveZoom, 'px');
         };
 
         /**
@@ -828,7 +852,82 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
          *  The converted length in pixels.
          */
         this.convertHmmToPixel = function (length) {
-            return Utils.convertHmmToLength(length * this.getEffectiveZoom(), 'px', 1);
+            return Utils.convertHmmToLength(length * effectiveZoom, 'px', 1);
+        };
+
+        /**
+         * Returns the maximum width of the digits in the font of the current
+         * default cell style.
+         *
+         * @returns {Number}
+         *  The maximum width of the digits in the font of the current default
+         *  cell style, in pixels.
+         */
+        this.getDefaultDigitWidth = function () {
+            return docModel.getDefaultDigitWidth(effectiveZoom);
+        };
+
+        /**
+         * Returns the base width for all undefined columns in this sheet,
+         * according to the font settings in the current default cell style,
+         * the base column width of the sheet, and the current effective zoom
+         * factor.
+         *
+         * @returns {Number}
+         *  The base width for all undefined columns, in pixels.
+         */
+        this.getBaseColWidth = function () {
+
+            // the base column width (in number of digits) to be used for undefined columns
+            var baseWidth = this.getMergedAttributeSet(true).sheet.baseColWidth;
+
+            // convert to pixels, add standard padding to the resulting column width
+            return Math.ceil(this.getDefaultDigitWidth() * baseWidth + effectivePadding);
+        };
+
+        /**
+         * Returns the base width for all undefined columns in this sheet,
+         * according to the font settings in the current default cell style,
+         * and the base column width of the sheet.
+         *
+         * @returns {Number}
+         *  The base width for all undefined columns, in 1/100 mm.
+         */
+        this.getBaseColWidthHmm = function () {
+            return this.convertPixelToHmm(this.getBaseColWidth());
+        };
+
+        /**
+         * Returns the base height for all undefined rows in this sheet,
+         * according to the font settings in the current default cell style,
+         * and the current effective zoom factor.
+         *
+         * @returns {Number}
+         *  The base height for all undefined rows, in pixels.
+         */
+        this.getBaseRowHeight = function () {
+
+            // the character attributes of the default cell style sheet
+            var charAttrs = cellStyles.getDefaultStyleAttributeSet().character;
+
+            // resolve the resulting row height from the default character attributes
+            return docModel.getRowHeight(charAttrs, effectiveZoom);
+        };
+
+        /**
+         * Returns the base height for all undefined rows in this sheet,
+         * according to the font settings in the current default cell style.
+         *
+         * @returns {Number}
+         *  The base height for all undefined rows, in 1/100 mm.
+         */
+        this.getBaseRowHeightHmm = function () {
+
+            // the character attributes of the default cell style sheet
+            var charAttrs = cellStyles.getDefaultStyleAttributeSet().character;
+
+            // resolve the resulting row height from the default character attributes
+            return docModel.getRowHeightHmm(charAttrs);
         };
 
         /**
@@ -861,10 +960,10 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
          */
         this.getRangeRectangle = function (range) {
 
-            var // the position and size of the column interval
-                colPosition = colCollection.getIntervalPosition(range.colInterval()),
-                // the position and size of the row interval
-                rowPosition = rowCollection.getIntervalPosition(range.rowInterval());
+            // the position and size of the column interval
+            var colPosition = colCollection.getIntervalPosition(range.colInterval());
+            // the position and size of the row interval
+            var rowPosition = rowCollection.getIntervalPosition(range.rowInterval());
 
             return getRectangle(colPosition, rowPosition);
         };
@@ -1451,8 +1550,7 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
          *  The effective zoom factor for this sheet.
          */
         this.getEffectiveZoom = function () {
-            var zoom = this.getViewAttribute('zoom');
-            return Utils.TOUCHDEVICE ? (zoom * 1.25) : zoom;
+            return effectiveZoom;
         };
 
         /**
@@ -1464,8 +1562,7 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
          *  The effective horizontal cell content padding, in pixels.
          */
         this.getEffectiveTextPadding = function () {
-            // 2 pixels in 100% zoom, round up early
-            return Math.floor(2 * this.getEffectiveZoom() + 0.75);
+            return effectivePadding;
         };
 
         /**
@@ -1765,6 +1862,34 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
             return $.when();
         };
 
+        /**
+         * Generates the operations and undo operations to update or restore
+         * the formulas of all cells, defined names, data validations,
+         * formatting rules, and drawing objects in this sheet.
+         *
+         * @param {SheetOperationsGenerator} generator
+         *  The operations generator to be filled with the operations.
+         *
+         * @param {Object} changeDesc
+         *  The properties describing the document change. The properties that
+         *  are expected in this descriptor depend on the change type in its
+         *  'type' property. See method TokenArray.resolveOperation() for more
+         *  details.
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved when all operations have been
+         *  generated.
+         */
+        this.generateUpdateFormulaOperations = function (generator, changeDesc) {
+            return Utils.invokeChainedAsync(
+                function () { return cellCollection.generateUpdateFormulaOperations(generator, changeDesc); },
+                function () { return nameCollection.generateUpdateFormulaOperations(generator, changeDesc); },
+                function () { return validationCollection.generateUpdateFormulaOperations(generator, changeDesc); },
+                function () { return condFormatCollection.generateUpdateFormulaOperations(generator, changeDesc); },
+                function () { return drawingCollection.generateUpdateFormulaOperations(generator, changeDesc); }
+            );
+        };
+
         // initialization -----------------------------------------------------
 
         // create the collection instances (constructors want to access public methods of this sheet model)
@@ -1823,7 +1948,7 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
             colCollection.destroy();
             rowCollection.destroy();
             nameCollection.destroy();
-            self = docModel = null;
+            self = docModel = cellStyles = null;
             nameCollection = colCollection = rowCollection = mergeCollection = cellCollection = hyperlinkCollection = null;
             tableCollection = validationCollection = condFormatCollection = drawingCollection = null;
         });
