@@ -6,15 +6,16 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/spreadsheet/model/tablecollection', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/simplemap',
     'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/container/simplemap',
     'io.ox/office/tk/object/timermixin',
     'io.ox/office/baseframework/model/modelobject',
     'io.ox/office/editframework/model/attributedmodel',
@@ -23,7 +24,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
     'io.ox/office/spreadsheet/utils/scalarset',
     'io.ox/office/spreadsheet/model/cellvaluecache',
     'io.ox/office/spreadsheet/model/celloperationsbuilder'
-], function (Utils, SimpleMap, IteratorUtils, TimerMixin, ModelObject, AttributedModel, Operations, SheetUtils, ScalarSet, CellValueCache, CellOperationsBuilder) {
+], function (Utils, IteratorUtils, SimpleMap, TimerMixin, ModelObject, AttributedModel, Operations, SheetUtils, ScalarSet, CellValueCache, CellOperationsBuilder) {
 
     'use strict';
 
@@ -181,6 +182,9 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
         // the spreadsheet document model
         var docModel = sheetModel.getDocModel();
 
+        // the spreadsheet app
+        var app = docModel.getApp();
+
         // the cell collection used to resolve header labels etc.
         var cellCollection = sheetModel.getCellCollection();
 
@@ -238,7 +242,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
 
                 // collect the column names from all string cells
                 IteratorUtils.forEach(iterator, function (address) {
-                    var value = cellCollection.getCellValue(address);
+                    var value = cellCollection.getValue(address);
                     if (typeof value === 'string') {
                         columnIndexMap.insert(SheetUtils.getTableKey(value), address[0] - firstCol);
                     }
@@ -317,7 +321,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
 
             // silently remove filter rules from all filtered column models, when
             // table is not active anymore (sorting settings remain valid though)
-            if (!self.isFilterActive()) {
+            if (!self.isFilterEnabled()) {
                 columnModelMap.forEach(function (entry, key) {
                     // remove filter settings from the column
                     entry.columnModel.setAttributes({ filter: { type: 'none' } }, { notify: 'never' });
@@ -515,17 +519,30 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
         };
 
         /**
-         * Returns whether filtering in this table range is activated. This
-         * does not necessarily mean that a row has actually been hidden by the
-         * filter rules.
+         * Returns whether filtering in this table range is enabled. This does
+         * not necessarily mean that any column contains active filter rules.
          *
          * @returns {Boolean}
-         *  Whether filtering in this table range is activated.
+         *  Whether filtering in this table range is enabled.
          */
-        this.isFilterActive = function () {
+        this.isFilterEnabled = function () {
             return this.getMergedAttributeSet(true).table.filtered;
         };
 
+        /**
+         * Returns whether this table model contains at least one column with
+         * active filter rules.
+         *
+         * @returns {Boolean}
+         *  Whether this table model contains at least one column with active
+         *  filter rules.
+         */
+        this.isFiltered = function () {
+            return this.isFilterEnabled() && columnModelMap.some(function (entry) {
+                return entry.columnModel.isFiltered();
+            });
+        };
+
         /**
          * Returns the address of the header row of this table.
          *
@@ -666,34 +683,49 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
         };
 
         /**
-         * Returns whether the selected rows can be deleted from the sheet,
-         * according to the position of this table. The header row of the table
-         * cannot be deleted (except for auto-filters), and at least one data
-         * row must remain in the table.
+         * Returns whether the move operations represented by the passed move
+         * descriptor can be applied with this table. The table cannot be moved
+         * partly, the header row of the table cannot be deleted (unless it is
+         * the auto-filter), and at least one data row must remain in the
+         * table.
          *
-         * @param {IntervalArray|Interval} intervals
-         *  The row intervals intended to be deleted from the sheet.
+         * @param {Array<MoveDescriptor>} moveDescs
+         *  An array of move descriptors representing the move operation to be
+         *  applied.
          *
          * @returns {Boolean}
-         *  Whether the selected rows can be deleted from the sheet.
+         *  Whether the move operations can be applied.
          */
-        this.canDeleteRows = function (intervals) {
+        this.canMoveCells = function (moveDescs) {
 
-            // any row in an auto-filter can be deleted
-            if (this.isAutoFilter()) { return true; }
+            return moveDescs.every(function (moveDesc) {
 
-            // header rows cannot be deleted
-            if (this.hasHeaderRow() && intervals.containsIndex(tableRange.start[1])) {
-                return false;
-            }
+                // the part of the table range that will be moved somehow
+                var moveRange = tableRange.intersect(moveDesc.dirtyRange);
+                if (!moveRange) { return true; }
 
-            // at least one data row must remain in the table
-            var dataRange = this.getDataRange();
-            if (dataRange && IntervalArray.get(dataRange.rowInterval()).difference(intervals).empty()) {
-                return false;
-            }
+                // it is not possible to move parts of the table (e.g. only the lower part to the right etc.)
+                var tableInterval = tableRange.interval(!moveDesc.columns);
+                var moveInterval = moveRange.interval(!moveDesc.columns);
+                if (tableInterval.differs(moveInterval)) { return false; }
 
-            return true;
+                // entire columns/rows can be inserted, entire columns can be deleted,
+                // all rows in an auto-filter can be deleted
+                if (moveDesc.insert || moveDesc.columns || this.isAutoFilter()) { return true; }
+
+                // the entire table can be deleted
+                if (!moveDesc.transformRange(tableRange)) { return true; }
+
+                // the header row cannot be deleted while keeping other parts of the table
+                var headerRange = this.getHeaderRange();
+                if (headerRange && !moveDesc.transformRange(headerRange)) { return false; }
+
+                // at least one data row must remain in the table
+                var dataRange = this.getDataRange();
+                if (dataRange && !moveDesc.transformRange(dataRange)) { return false; }
+
+                return true;
+            }, this);
         };
 
         /**
@@ -740,17 +772,15 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
         this.transformRange = function (moveDesc) {
 
             // process move descriptors that cover the table range completely in move direction
-            if (!moveDesc.coversRange(tableRange)) { return true; }
-
-            // first column index of the old table range
-            var startCol = tableRange.start[0];
+            if (!moveDesc.containsRange(tableRange)) { return true; }
 
             // preprocessing when deleting rows in the table range
             if (!moveDesc.insert && !moveDesc.columns) {
 
                 // bug 36226: delete tables whose header row has been deleted
                 // bug 39869: deleting header rows prevented by UI except for auto-filter
-                if (this.hasHeaderRow() && moveDesc.deleteIntervals.containsIndex(tableRange.start[1])) {
+                var headerRange = this.getHeaderRange();
+                if (headerRange && !moveDesc.transformRange(headerRange)) {
                     return false;
                 }
             }
@@ -763,6 +793,9 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             // delete or remap all affected column models
             if (moveDesc.columns) {
 
+                // first column index of the old table range
+                var startCol = tableRange.start[0];
+
                 // create a new model map to prevent interfering with existing map entries
                 var newColumnModelMap = new SimpleMap();
                 columnModelMap.forEach(function (entry) {
@@ -901,7 +934,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             var dataRanges = RangeArray.createFromRowIntervals(rowIntervals, dataRange.start[0]);
 
             // fetch the cell contents from the cell collection
-            return cellCollection.getRangeContents(dataRanges, { display: true, compressed: true });
+            return cellCollection.getRangeContents(dataRanges, { blanks: true, covered: true, display: true, compressed: true });
         };
 
         /**
@@ -943,7 +976,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
          *  Whether this table contains any columns with active settings.
          */
         this.isRefreshable = function () {
-            return this.isFilterActive() && columnModelMap.some(function (entry) {
+            return this.isFilterEnabled() && columnModelMap.some(function (entry) {
                 return entry.columnModel.isRefreshable();
             });
         };
@@ -1015,7 +1048,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             var visibleIntervals = new IntervalArray(new Interval(0, dataRowInterval.size() - 1));
 
             // collect the column indexes of all filtered columns
-            if (this.isFilterActive()) {
+            if (this.isFilterEnabled()) {
                 columnModelMap.forEach(function (entry) {
                     if (entry.columnModel.isFiltered() && !(entry.tableCol in skipColsSet)) {
                         filterCols.push(entry.tableCol);
@@ -1066,7 +1099,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
                     // the number of remaining cell to process for the current cell data object
                     var remainingCells = cellData.count;
                     // whether the current cell data results in visible rows (the filter matches)
-                    var visible = _.isString(cellData.display) && matcher(cellData.value, cellData.display);
+                    var visible = matcher(cellData.value, cellData.display);
                     // the current row interval
                     var visibleInterval = null;
                     // number of cells that can be processed for the current row interval
@@ -1096,7 +1129,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
 
                 // use the resulting filtered row intervals for the next filtered column
                 visibleIntervals = newIntervals;
-            });
+            }, { infoString: 'TableModel.queryFilterResult', app: app });
 
             // return a promise that resolves with the row intervals
             return promise.then(function () { return visibleIntervals; });
@@ -1294,7 +1327,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
         this.generateMoveCellsOperations = function (generator, moveDescs) {
 
             // find the move descriptor that manipulates this table (only one move descriptor can cover the table range)
-            var moveDesc = _.find(moveDescs, function (moveDesc) { return moveDesc.coversRange(tableRange); });
+            var moveDesc = _.find(moveDescs, function (moveDesc) { return moveDesc.containsRange(tableRange); });
             if (!moveDesc) { return $.when(); }
 
             // whether the move descriptor deletes rows
@@ -1348,7 +1381,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             var promise = this.iterateSliced(deletedColumnMap.iterator(), function (entry) {
                 var colProperties = { col: entry.tableCol, attrs: entry.columnModel.getExplicitAttributeSet(true) };
                 generator.generateTableOperation(Operations.CHANGE_TABLE_COLUMN, tableName, colProperties, { undo: true });
-            }, { delay: 'immediate' });
+            }, { delay: 'immediate', infoString: 'TableModel.generateMoveCellsOperations', app: app });
 
             // refresh the visible/hidden rows (deleted filter settings will cause to show hidden rows)
             return promise.then(function () {
@@ -1379,7 +1412,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             var labelArray = [], labelSet = {};
             var iterator = cellCollection.createAddressIterator(headerRange, { covered: true });
             IteratorUtils.forEach(iterator, function (address) {
-                var label = cellCollection.getCellValue(address);
+                var label = cellCollection.getValue(address);
                 var key = (typeof label === 'string') ? SheetUtils.getTableKey(label) : null;
                 if (key && !(key in labelSet)) {
                     labelArray.push(label);
@@ -1443,7 +1476,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             defColumnModel.destroy();
             headerCache.destroy();
             self = docModel = sheetModel = null;
-            columnModelMap = defColumnModel = headerCache = null;
+            columnModelMap = defColumnModel = headerCache = app = null;
         });
 
     } }); // class TableModel
@@ -1498,9 +1531,15 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
         // the document model instance
         var docModel = sheetModel.getDocModel();
 
+        // the spreadsheet app
+        var app = docModel.getApp();
+
         // all table models, mapped by upper-case table name
         var tableModelMap = new SimpleMap();
 
+        // special behaviour for OOXML files
+        var ooxml = docModel.getApp().isOOXML();
+
         // base constructor ---------------------------------------------------
 
         ModelObject.call(this, docModel);
@@ -1698,7 +1737,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
 
             // check that the cell range does not cover another table
             var tableRange = context.getRange();
-            context.ensure(!rangeCoversAnyTable(tableRange), 'range covers another table');
+            if (ooxml) { context.ensure(!rangeCoversAnyTable(tableRange), 'range covers another table'); }
 
             // create and insert the new table model, notify listeners
             modelData.model = new TableModel(sheetModel, modelData.name, tableRange, context.getOptObj('attrs'));
@@ -1737,7 +1776,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             var tableRange = context.getOptRange();
             if (tableRange) {
                 // check that the cell range does not cover another table
-                context.ensure(!rangeCoversAnyTable(tableRange, tableModel), 'range covers another table');
+                if (ooxml) { context.ensure(!rangeCoversAnyTable(tableRange, tableModel), 'range covers another table'); }
                 // set the new ranges at the table model
                 tableModel.setRange(tableRange);
             }
@@ -1791,8 +1830,8 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
          *
          * @param {String} tableName
          *  The name of the table. The empty string addresses the anonymous
-         *  table range used to store filter settings for the standard auto
-         *  filter of the sheet.
+         *  table range used to store filter settings for the standard
+         *  auto-filter of the sheet.
          *
          * @returns {TableModel|Null}
          *  The model of the table with the specified name; or null, if no
@@ -1802,6 +1841,29 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             return tableModelMap.get(SheetUtils.getTableKey(tableName), null);
         };
 
+        /**
+         * Returns the model of the table representing the auto-filter range.
+         *
+         * @returns {TableModel|Null}
+         *  The model of the table representing the auto-filter range; or null,
+         *  if this collection does not contain an auto-filter.
+         */
+        this.getAutoFilter = function () {
+            return tableModelMap.get('', null);
+        };
+
+        /**
+         * Creates an iterator that visits the models of all table ranges in
+         * this collection.
+         *
+         * @returns {Object}
+         *  An iterator object with the method next(). The result object of the
+         *  iterator will contain the model of a table range as value.
+         */
+        this.createModelIterator = function () {
+            return tableModelMap.iterator();
+        };
+
         /**
          * Returns all table models in this collection as plain array.
          *
@@ -1852,8 +1914,8 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
          *  Optional parameters:
          *  @param {Boolean} [options.active=false]
          *      If set to true, the result returned by this method will be
-         *      restricted to tables with activated filters/sorting (see method
-         *      TableModel.isFilterActive() for details).
+         *      restricted to tables with enabled filters/sorting (see method
+         *      TableModel.isFilterEnabled() for details).
          *
          * @returns {Array<TableModel>}
          *  The models of all tables overlapping with the specified cell range.
@@ -1864,25 +1926,41 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             var active = Utils.getBooleanOption(options, 'active', false);
 
             return tableModelMap.filter(function (tableModel) {
-                return tableModel.overlapsRange(range) && (!active || tableModel.isFilterActive());
+                return tableModel.overlapsRange(range) && (!active || tableModel.isFilterEnabled());
             });
         };
 
         /**
-         * Returns whether the selected rows can be deleted from the sheet,
-         * according to the position of the tables in this collection. The
-         * header rows of all tables but the auto-filter cannot be deleted, and
-         * at least one data row must remain in each table.
-         *
-         * @param {IntervalArray|Interval} intervals
-         *  The row intervals intended to be deleted from the sheet.
+         * Returns whether this collection contains at least one table model
+         * with active filter rules.
          *
          * @returns {Boolean}
-         *  Whether the selected rows can be deleted from the sheet.
+         *  Whether this collection contains at least one table model with
+         *  active filter rules.
          */
-        this.canDeleteRows = function (intervals) {
+        this.hasFilteredTables = function () {
+            return tableModelMap.some(function (tableModel) {
+                return tableModel.isFiltered();
+            });
+        };
+
+        /**
+         * Returns whether the move operations represented by the passed move
+         * descriptor can be applied with the tables in this collection. The
+         * tables cannot be moved partly, the header rows of all tables but the
+         * auto-filter cannot be deleted, and at least one data row must remain
+         * in each table.
+         *
+         * @param {Array<MoveDescriptor>} moveDescs
+         *  An array of move descriptors representing the move operation to be
+         *  applied.
+         *
+         * @returns {Boolean}
+         *  Whether the move operations can be applied.
+         */
+        this.canMoveCells = function (moveDescs) {
             return tableModelMap.every(function (tableModel) {
-                return tableModel.canDeleteRows(intervals);
+                return tableModel.canMoveCells(moveDescs);
             });
         };
 
@@ -1925,7 +2003,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             if (this.findTables(range).length > 0) { return SheetUtils.makeRejected('table:overlap'); }
 
             // 'real' tables must not contain merged cells (neither in header, footer, nor data rows)
-            var promise = autoFilter ? this.createResolvedPromise() : sheetModel.getCellCollection().generateMergeCellsOperations(generator, range, 'unmerge');
+            var promise = autoFilter ? this.createResolvedPromise(null) : sheetModel.getCellCollection().generateMergeCellsOperations(generator, range, 'unmerge');
 
             // create all operations and undo operations for the new table
             return promise.then(function () {
@@ -1948,7 +2026,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
                             // no undo operations necessary (the table will be deleted completely on undo)
                             generator.generateTableOperation(Operations.CHANGE_TABLE_COLUMN, tableName, { col: col - range.start[0], attrs: { filter: { hideMergedButton: true } } });
                         }
-                    }, { delay: 'immediate' });
+                    }, { delay: 'immediate', infoString: 'TableCollection.generateInsertTableOperations', app: app });
                 }
             });
         };
@@ -1972,7 +2050,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
         this.generateMoveCellsOperations = function (generator, moveDescs) {
             return this.iterateSliced(tableModelMap.iterator(), function (tableModel) {
                 tableModel.generateMoveCellsOperations(generator, moveDescs);
-            }, { delay: 'immediate' });
+            }, { delay: 'immediate', infoString: 'TableCollection.generateMoveCellsOperations', app: app });
         };
 
         /**
@@ -1993,17 +2071,19 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             var addresses = new AddressArray();
             var promise = this.iterateSliced(tableModelMap.iterator(), function (tableModel) {
                 addresses.append(tableModel.createMissingHeaderLabels());
-            }, { delay: 'immediate' });
+            }, { delay: 'immediate', infoString: 'TableCollection.generateMissingHeaderLabelOperations', app: app });
 
             // create a cell operation for all header label cells
-            return promise.then(function () {
+            promise.done(function () {
                 if (addresses.empty()) { return; }
-                var builder = new CellOperationsBuilder(sheetModel, generator);
+                var operationsBuilder = new CellOperationsBuilder(sheetModel, generator);
                 addresses.sort().forEach(function (address) {
-                    builder.createCells(address, { v: address.label }, 1);
+                    operationsBuilder.createCells(address, { v: address.label }, 1);
                 });
-                return builder.finalizeOperations({ createUndo: false });
+                operationsBuilder.finalizeOperations({ createUndo: false });
             });
+
+            return promise;
         };
 
         // initialization -----------------------------------------------------
@@ -2017,7 +2097,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
         // destroy all class members
         this.registerDestructor(function () {
             tableModelMap.forEach(function (tableModel) { tableModel.destroy(); });
-            self = docModel = sheetModel = tableModelMap = null;
+            self = docModel = sheetModel = tableModelMap = app = null;
         });
 
     } // class TableCollection
