@@ -6,22 +6,22 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/spreadsheet/model/validationcollection', [
-    'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/simplemap',
-    'io.ox/office/tk/utils/arraytemplate',
+    'io.ox/office/tk/container/simplemap',
+    'io.ox/office/tk/container/typedarray',
     'io.ox/office/tk/object/timermixin',
     'io.ox/office/baseframework/model/modelobject',
     'io.ox/office/editframework/model/attributedmodel',
     'io.ox/office/spreadsheet/utils/operations',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/tokenarray'
-], function (Utils, SimpleMap, ArrayTemplate, TimerMixin, ModelObject, AttributedModel, Operations, SheetUtils, TokenArray) {
+], function (SimpleMap, TypedArray, TimerMixin, ModelObject, AttributedModel, Operations, SheetUtils, TokenArray) {
 
     'use strict';
 
@@ -29,6 +29,7 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
     var Address = SheetUtils.Address;
     var RangeSet = SheetUtils.RangeSet;
     var Range3DArray = SheetUtils.Range3DArray;
+    var MoveDescriptor = SheetUtils.MoveDescriptor;
 
     // private global functions ===============================================
 
@@ -51,14 +52,8 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
      *  The transformed target ranges.
      */
     function transformTargetRanges(targetRanges, moveDescs, reverse) {
-
         // transform the passed ranges, expand the end of the range when inserting cells
-        Utils.iterateArray(moveDescs, function (moveDesc) {
-            targetRanges = moveDesc.transformRanges(targetRanges, { expandEnd: true, reverse: reverse });
-            if (targetRanges.empty()) { return Utils.BREAK; }
-        }, { reverse: reverse });
-
-        return targetRanges;
+        return MoveDescriptor.transformRanges(targetRanges, moveDescs, { expandEnd: true, reverse: reverse });
     }
 
     // class ValidationModel ==================================================
@@ -238,7 +233,7 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
                     // get the cell range addresses contained in the first token array
                     var result = tokenArrayMap.get('value1').interpretFormula('ref', { refAddress: refAddress, targetAddress: targetAddress });
                     // collect all cell values and display strings, restrict to 1000 entries
-                    return (result.value instanceof Range3DArray) ? docModel.getRangeContents(result.value, { display: true, maxCount: 1000 }) : [];
+                    return (result.value instanceof Range3DArray) ? docModel.getRangeContents(result.value, { blanks: true, display: true, maxCount: 1000 }) : [];
             }
 
             // default (wrong validation type)
@@ -271,8 +266,8 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
          * @returns {ValidationModel}
          *  A reference to this instance.
          */
-        this.transformSheet = function (toSheet, fromSheet) {
-            tokenArrayMap.forEach(function (tokenArray) { tokenArray.transformSheet(toSheet, fromSheet); });
+        this.transformSheet = function (fromSheet, toSheet) {
+            tokenArrayMap.forEach(function (tokenArray) { tokenArray.transformSheet(fromSheet, toSheet); });
             return this;
         };
 
@@ -298,7 +293,7 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
          * @returns {ValidationModel}
          *  A reference to this instance.
          */
-        this.generateFormulaOperations = function (generator, index, changeDesc) {
+        this.generateUpdateFormulaOperations = function (generator, index, changeDesc) {
 
             // whether to restore the target ranges (if they cannot be restored implicitly)
             var restoreTargetRanges = false;
@@ -380,7 +375,7 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
 
     // class ValidationModelArray =============================================
 
-    var ValidationModelArray = ArrayTemplate.create(ValidationModel);
+    var ValidationModelArray = TypedArray.create(ValidationModel);
 
     // class ValidationCollection =============================================
 
@@ -402,6 +397,8 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
         // the spreadsheet document model
         var docModel = sheetModel.getDocModel();
 
+        var app = docModel.getApp();
+
         // all model instances with validation settings, as array (in operation order)
         var valModels = new ValidationModelArray();
 
@@ -632,6 +629,20 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
 
         // public methods -----------------------------------------------------
 
+        /**
+         * Returns the validation model with the specified index.
+         *
+         * @param {Number} index
+         *  The array index of a validation model.
+         *
+         * @returns {ValidationModel|Null}
+         *  The validation model with the specified index; or null, if there is
+         *  no model with the given index.
+         */
+        this.getValidationModel = function (index) {
+            return valModels[index] || null;
+        };
+
         /**
          * Creates an iterator that visits the models of all data validations
          * in this collection.
@@ -709,10 +720,10 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
          *  A promise that will be resolved when all operations have been
          *  generated.
          */
-        this.generateFormulaOperations = function (generator, changeDesc) {
+        this.generateUpdateFormulaOperations = function (generator, changeDesc) {
             return this.iterateArraySliced(valModels, function (valModel, index) {
-                valModel.generateFormulaOperations(generator, index, changeDesc);
-            }, { delay: 'immediate' });
+                valModel.generateUpdateFormulaOperations(generator, index, changeDesc);
+            }, { delay: 'immediate', infoString: 'ValidationCollection: generateFormulaOperations', app: app });
         };
 
         // initialization -----------------------------------------------------
@@ -728,9 +739,9 @@ define('io.ox/office/spreadsheet/model/validationcollection', [
             }
 
             // update the sheet indexes after the sheet collection has been manipulated
-            this.listenTo(docModel, 'transform:sheet', function (event, toSheet, fromSheet) {
+            this.listenTo(docModel, 'transform:sheet', function (event, fromSheet, toSheet) {
                 valModels.forEach(function (valModel) {
-                    valModel.transformSheet(toSheet, fromSheet);
+                    valModel.transformSheet(fromSheet, toSheet);
                 });
             });
 
