@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  */
@@ -61,9 +62,10 @@ define('io.ox/office/spreadsheet/services/commandmixin', [
          * @returns {jQuery.Promise}
          *  A promise that resolves after setting the optimal column widths.
          */
-        function setOptimalColumnWidthForSheet(sheet) {
+        function setOptimalColumnWidthForSheet(sheetModel) {
 
             var promise = null;
+            var sheet = sheetModel.getIndex();
 
             if (docView.getActiveSheet() === sheet) {
                 promise = setOptimalColumnWidth();
@@ -87,9 +89,7 @@ define('io.ox/office/spreadsheet/services/commandmixin', [
             var activeSheet = docView.getActiveSheet();
 
             var sheetIt = docModel.createSheetIterator({ types: 'worksheet' });
-            var promise = docModel.iterateSliced(sheetIt, function (sheetModel, result) {
-                return setOptimalColumnWidthForSheet(result.sheet);
-            });
+            var promise = docModel.iterateSliced(sheetIt, setOptimalColumnWidthForSheet, { infoString: 'CommandMixin: setOptimalColumnWidthForDocument', app: self });
 
             return promise.done(function () {
                 docView.setActiveSheet(activeSheet);
@@ -97,14 +97,8 @@ define('io.ox/office/spreadsheet/services/commandmixin', [
         }
 
         function init() {
-
-            var promise = $.when();
-
-            if (self.getLaunchOption('autoWidth')) {
-                promise = promise.then(setOptimalColumnWidthForDocument);
-            }
-
-            if (promise.state() === 'pending') {
+            var promise = self.getLaunchOption('autoWidth') ? setOptimalColumnWidthForDocument() : null;
+            if (promise && (promise.state() === 'pending')) {
                 docView.enterBusy({ delay: 0, immediate: true });
                 docView.waitForAny(promise, function () { docView.leaveBusy(); });
             }
@@ -119,7 +113,7 @@ define('io.ox/office/spreadsheet/services/commandmixin', [
 
         this.waitForImportSuccess(function () {
             docView.one('change:usedarea', function () {
-                self.executeDelayed(init, { delay: 1000 });
+                self.executeDelayed(init, { delay: 1000, infoString: 'CommandMixin: waitForImportSuccess', app: self });
             });
         });
 
