@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Mario Schroeder <mario.schroeder@open-xchange.com>
  */
@@ -125,7 +126,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
                 // replace double backslash the text &#92;&#92;
                 .replace(/\\\\/g, '&#92;&#92;')
                 // replace double quote, Euro symbol, double quote with the text &#92;&#8364; as work around for IE problems with the double quote
-                .replace(/"€"/g, '&#92;&#8364;');
+                .replace(/"\u20ac"/g, '&#92;&#8364;');
 
         } else {
             // use UTF-8 representation
@@ -391,8 +392,8 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
             // cleanup current styles from old border-attributes
             currentStyles = currentStyles.split('border-' + side.toLowerCase() + ':none;').join('');
 
-            var adr             = (side === 'Top' || side === 'Left') ? range.start : range.end,
-                styleId         = cellCollection.getCellStyleId(adr);
+            var adr     = (side === 'Top' || side === 'Left') ? range.start : range.end,
+                styleId = cellCollection.getStyleId(adr);
 
             if (autoStyles.isDefaultStyleId(styleId)) {
                 return currentStyles;
@@ -908,20 +909,20 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
      * @returns {String}
      *  The resulting HTML mark-up of the <table> element.
      */
-    Clipboard.getHtmlMarkupFromRange = function (sheetModel, range, clientClipboardId) {
+    Clipboard.getHtmlMarkupFromRange = function (sheetModel, range, clientClipboardId, options) {
 
         function getOxCellData(adr) {
             var // cell model
                 cellModel = cellCollection.getCellModel(adr),
                 // style id
-                styleId = cellCollection.getCellStyleId(adr),
+                styleId = cellCollection.getStyleId(adr),
                 // the merged attribute set of the cell
                 attributeSet = autoStyles.isDefaultStyleId(styleId) ? null : autoStyles.getMergedAttributeSet(styleId),
                 // data
                 oxCellData = {};
 
             // handle formula
-            var opFormula = cellCollection.getCellFormula(adr, 'op');
+            var opFormula = cellCollection.getFormula(adr, 'op:ooxml');
             if (opFormula) {
                 oxCellData.formula = opFormula;
             }
@@ -940,45 +941,6 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
             return oxCellData;
         }
 
-        function getCondFormats(range) {
-            var startCol = range.start[0],
-                startRow = range.start[1],
-                returnRulesArray = [];
-
-            // iterate over each single rule which were overlapped by the selected range
-            _.each(condFormatCollection.getRules(range), function (rule) {
-                var newTargetRanges = [];
-
-                // calculate the intersection range
-                _.each(rule.getTargetRanges(), function (tRange) {
-                    var intersectionRange = range.intersect(tRange);
-
-                    if (intersectionRange) {
-                        // calculate the relative reference
-                        intersectionRange.moveBoth((startCol * -1), true);
-                        intersectionRange.moveBoth((startRow * -1), false);
-
-                        newTargetRanges.push(intersectionRange);
-                    }
-                });
-
-                // if we have new target ranges, add the rule
-                if (newTargetRanges.length > 0) {
-                    var ruleId  = rule.getRuleId(),
-                        model   = condFormatCollection.getRuleModel(ruleId),
-                        ruleType = docModel.getApp().isODF() ? '' : ruleId.charAt(0);
-
-                    returnRulesArray.push({
-                        targetRanges: newTargetRanges,
-                        attr: model.getExplicitAttributes(),
-                        ruleType: ruleType
-                    });
-                }
-            });
-
-            return (returnRulesArray.length > 0) ? returnRulesArray : null;
-        }
-
         var // the document model
             docModel = sheetModel.getDocModel(),
             // the collection of auto-styles
@@ -987,12 +949,8 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
             formulaGrammar = docModel.getFormulaGrammar('op'),
             // the cell collection of the passed sheet
             cellCollection = sheetModel.getCellCollection(),
-            // the conditional formats collection of the passed sheet
-            condFormatCollection = sheetModel.getCondFormatCollection(),
             // the merged ranges covering the passed range
             mergedRanges = sheetModel.getMergeCollection().getMergedRanges(range),
-            // the conditional formattings covering the passed range
-            condFormats = getCondFormats(range),
             // the formula parser
             tokenArray = new TokenArray(sheetModel, 'cell'),
             // the col, the range starts with
@@ -1002,27 +960,55 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
             // the current table row
             row = range.start[1],
             // the tableMarkup string
-            tableMarkup = '';
-
-        // NEW conditional Format code for copy & paste
-        //      console.log('USE condFormats:', condFormats);
-        //      _.each(condFormats, function (cF) {
-        //          console.log('     ', cF.targetRanges.toString(), cF.attr);
-        //      });
+            tableMarkup = '',
+            // whether it is a cut event (or a copy)
+            cut = Utils.getBooleanOption(options, 'cut', false),
+            // the collection of cell-styles
+            cellStyles = docModel.getCellStyles();
 
         tableMarkup += '<html ' + EXCEL_NAMESPACES + '>' + HTML_HEADER;
         tableMarkup += '<body><table id="ox-clipboard-data"';
 
-        if (condFormats) {
-            tableMarkup += ' data-ox-condFormats="' + Utils.escapeHTML(JSON.stringify(condFormats)) + '"';
-        }
-
         if (clientClipboardId) {
             tableMarkup += ' data-ox-clipboard-id="' + clientClipboardId + '"';
         }
 
+        tableMarkup += ' data-ox-clipboard-type="' + (cut ? 'cut' : 'copy') + '"';
         tableMarkup += ' data-app-guid="' + docModel.getApp().getGlobalUid() + '"';
-        tableMarkup += ' data-range-start="' + range.start[0] +  ';' + range.start[1] + '"';
+        tableMarkup += ' data-range="' + range.toString() + '"';
+        tableMarkup += ' data-sheet="' + docModel.getActiveSheet() + '"';
+
+        // the conditional formattings covering the passed range
+        var ruleModels = sheetModel.getCondFormatCollection().findRules(range);
+        var condFormats = ruleModels.reduce(function (resultArray, ruleModel) {
+
+            // calculate the intersection ranges
+            var targetRanges = ruleModel.getTargetRanges().intersect(range);
+            if (!targetRanges.empty()) {
+
+                // relocate the target ranges to cell A1
+                targetRanges.forEach(function (targetRange) {
+                    targetRange.moveBoth(-startCol, true);
+                    targetRange.moveBoth(-startRow, false);
+                });
+                var attrs = ruleModel.getExplicitAttributeSet().rule;
+                if (attrs.attrs && attrs.attrs.styleId) {
+                    attrs.attrs = cellStyles.getStyleAttributeSet(attrs.attrs.styleId);
+                }
+                // add an entry for the rule to the result array
+                resultArray.push({
+                    id: ruleModel.getRuleId(),
+                    ranges: targetRanges,
+                    attrs: attrs
+                });
+            }
+
+            return resultArray;
+        }, []);
+        if (condFormats.length > 0) {
+            tableMarkup += ' data-ox-cond-formats="' + Utils.escapeHTML(JSON.stringify(condFormats)) + '"';
+        }
+
         tableMarkup += '>';
         tableMarkup += '<tbody><tr>';
 
@@ -1053,7 +1039,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
                 // the complete cell model (value, formula, style), may be null
                 var cellModel = cellCollection.getCellModel(address);
                 // the auto-style identifier
-                var styleId = cellCollection.getCellStyleId(address);
+                var styleId = cellCollection.getStyleId(address);
                 // the merged attribute set of the cell
                 var attributeSet = autoStyles.isDefaultStyleId(styleId) ? null : autoStyles.getMergedAttributeSet(styleId);
                 // the merged attribute set of existing cells with custom formatting
@@ -1110,9 +1096,10 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
                 var oxCellData = getOxCellData(address);
 
                 if (oxCellData.formula) {
-                    // relocate all formulas relative to A1
                     tokenArray.parseFormula('op', oxCellData.formula, { refAddress: range.start });
-                    var enFormula = tokenArray.getFormula('en', { refAddress: range.start, targetAddress: Address.A1 });
+
+                    var enFormula = tokenArray.getFormula('en');
+
                     Utils.log('external clipboard - formula - range:', range, ', original: ', oxCellData.formula, ', relocated: ', enFormula);
 
                     tableMarkup += ' x:fmla="' + Utils.escapeHTML(enFormula) + '"';
@@ -1132,7 +1119,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
                     });
                 }
 
-                tableMarkup += ' ox-cell-data="' + Utils.escapeHTML(JSON.stringify(oxCellData)) + '"';
+                tableMarkup += ' data-ox-cell-data="' + Utils.escapeHTML(JSON.stringify(oxCellData)) + '"';
 
                 // add HTML attributes
                 tableMarkup += getHtmlCellStyles(docModel, attributeSet);
@@ -1179,7 +1166,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
             } else if (address[1] > range.start[1]) {
                 resultText += '\r\n';
             }
-            resultText += cellCollection.getCellDisplayString(address) || '';
+            resultText += cellCollection.getDisplayString(address) || '';
         });
 
         return resultText;
@@ -1288,8 +1275,6 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
             contents = [],
             // an array of ranges of merged cells
             mergedRanges = new RangeArray(),
-            // an array of conditional format objects
-            preparedCondFormats = [],
             // the row nodes
             rows,
             // the number of columns
@@ -1300,6 +1285,8 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
             targetStart = docView.getSelection().activeRange().start,
             // start address of the clipboard range
             sourceStart = null,
+            sourceRange = null,
+            sourceSheet = null,
             // copy from the same document
             sameDoc = false,
             // copy from (other) ox-spreadsheet
@@ -1307,7 +1294,9 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
             // stores the last forumla
             lastFormula = null,
             // stores all found merged ranges
-            foundMergedRanges = {};
+            foundMergedRanges = {},
+            // whether it is a cut-event (or a copy)
+            cut = false;
 
         // Bug 35126: Excel sends CSS rules containing fractional border widths, e.g.
         // 'border-top: .5pt solid ...' which will be translated to 0px borders in Chrome.
@@ -1348,21 +1337,23 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
         // merge in the character and cell attributes of the HTML table
         tableAttrData = extractElementAttributes(docModel, tableAttrData, table);
 
-        if (table.attr('data-app-guid') === docModel.getApp().getGlobalUid()) {
-            // copy from same document
-            sameDoc = true;
-            sourceStart = table.attr('data-range-start');
-        }
+        // copy from same document
+        sameDoc = (table.attr('data-app-guid') === docModel.getApp().getGlobalUid());
 
         // copy from ox-spreadsheet
-        if (table.attr('data-app-guid')) { intern = true; }
+        if (table.attr('data-range')) {
+            sourceRange = Range.parse(table.attr('data-range'));
+            sourceStart = sourceRange.start;
+        }
+        if (table.attr('data-sheet')) {
+            sourceSheet = parseInt(table.attr('data-sheet'), 10);
+        }
+        if (table.attr('data-ox-clipboard-type') === 'cut') {   cut         = true;                           }
+        if (table.attr('data-app-guid')) {                      intern      = true;                           }
 
-        if (sourceStart) {
-            sourceStart = sourceStart.split(';');
-        } else {
-            sourceStart = [0, 0];
+        if (!sourceStart) {
+            sourceStart = new Address(0, 0);
         }
-        sourceStart = new Address(sourceStart[0], sourceStart[1]);
 
         // make sure that table header, body and footer are in the correct order
         rows = _.union(table.find('thead tr').get(), table.find('tbody tr').get(), table.find('tfoot tr').get());
@@ -1417,7 +1408,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
                         // look for Calc cell value
                         cellValue = cell.attr('sdval');
                         if (_.isString(cellValue) && cellValue.length > 0) {
-                            cellValue = parseFloat(cellValue, 10);
+                            cellValue = parseFloat(cellValue);
                         }
                         if (!_.isNumber(cellValue) || _.isNaN(cellValue)) {
                             cellValue = cell.text();
@@ -1444,28 +1435,19 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
                         }
                     }
 
-                    var oxCellData = isMergedCell ? foundMergedRanges['col' + colId + '_row' + rowId] : cell.attr('ox-cell-data');
+                    var oxCellData = isMergedCell ? foundMergedRanges['col' + colId + '_row' + rowId] : cell.attr('data-ox-cell-data');
                     if (oxCellData) {
                         oxCellData = isMergedCell ? oxCellData : JSON.parse(oxCellData);
 
                         if (oxCellData.formula) {
-                            if (sameDoc) {
-                                //internal clipboard
-                                tokenArray.parseFormula('op', oxCellData.formula);
-                                cellData.f = tokenArray.getFormula('op', { refAddress: sourceStart, targetAddress: targetStart });
-                                lastFormula = cellData.f;
-
+                            tokenArray.parseFormula('op:ooxml', oxCellData.formula, { refAddress: sourceStart });
+                            //internal clipboard
+                            if (cut) {
+                                cellData.f = tokenArray.getFormula('op');
                             } else {
-                                //external clipboard but also spreadsheet
-                                var relocated = cell.attr('formula');
-                                if (relocated) {
-                                    tokenArray.parseFormula('op', relocated);
-                                    cellData.f = tokenArray.getFormula('op', { refAddress: sourceStart, targetAddress: targetStart });
-                                    lastFormula = cellData.f;
-                                } else {
-                                    cellData.f = oxCellData.value;
-                                }
+                                cellData.f = tokenArray.getFormula('op', { refAddress: sourceStart, targetAddress: targetStart });
                             }
+                            lastFormula = cellData.f;
                         }
 
                         cellData.v = oxCellData ? oxCellData.value : null;
@@ -1475,6 +1457,10 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
                             cellData.s = oxCellData.styleId;
                             cellData.a = null;
 
+                        } else if (intern) {
+                            cellData.a = oxCellData.explicit;
+                            cellData.s = '';
+
                         } else {
                             cellAttrData = _.copy(tableAttrData, true);
                             cellData.a = cellAttrData.attrs ? cellAttrData.attrs : {};
@@ -1535,30 +1521,52 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
             }
         }
 
-        if (intern && table.attr('data-ox-condFormats')) {
-            var condFormats = JSON.parse(table.attr('data-ox-condFormats'));
-            _.each(condFormats, function (cFormat) {
-                var currentFormatObject = {
-                    attrs: cFormat.attr,
-                    ruleType: cFormat.ruleType,
-                    targetRanges: []
-                };
+        var condFormats = (function () {
+            var condFormatsStr = intern ? table.attr('data-ox-cond-formats') : null;
+            if ((typeof condFormatsStr === 'string') && condFormatsStr) {
+                try {
+                    var condFormats = JSON.parse(condFormatsStr);
+                    return _.isArray(condFormats) ? condFormats : [];
+                } catch (ex) {
+                    Utils.exception(ex);
+                }
+            }
+            return [];
+        }());
 
-                // relocate the ranges of the formattings
-                _.each(cFormat.targetRanges, function (originTRange) {
-                    var tRange = Range.createFromAddresses(originTRange.start, originTRange.end);
-                    tRange.moveBoth(targetStart[0], true);
-                    tRange.moveBoth(targetStart[1], false);
-                    currentFormatObject.targetRanges.push(tRange);
-                });
+        condFormats = condFormats.filter(function (condFormat) {
 
-                preparedCondFormats.push(currentFormatObject);
+            // parse the JSON data to a range array
+            if (!_.isObject(condFormat)) { return false; }
+            var ranges = docModel.createRangeArray(condFormat.ranges);
+            if (!ranges) { return false; }
+
+            if (condFormat.attrs && condFormat.attrs.attrs && condFormat.attrs.attrs.styleId) {
+                if (docModel.getApp().isOOXML() || !sameDoc) {
+                    delete condFormat.attrs.attrs.styleId;
+                } else {
+                    // set the style Id if it is the copy document and if it is not OOXML
+                    condFormat.attrs.attrs = { styleId: condFormat.attrs.attrs.styleId };
+                }
+            }
+
+            // relocate the ranges to the target address
+            condFormat.ranges = RangeArray.map(ranges, function (range) {
+                return docModel.getCroppedMovedRange(range, targetStart[0], targetStart[1]);
             });
-        }
+            return !condFormat.ranges.empty();
+        });
 
-        if (preparedCondFormats.length === 0) { preparedCondFormats = null; }
-
-        return { contents: contents, mergedRanges: mergedRanges, condFormats: preparedCondFormats, intern: intern };
+        return {
+            contents:       contents,
+            mergedRanges:   mergedRanges,
+            condFormats:    (condFormats.length > 0) ? condFormats : null,
+            intern:         intern,
+            sameDoc:        sameDoc,
+            cut:            cut,
+            sourceRange:    sourceRange,
+            sourceSheet:    sourceSheet
+        };
     };
 
     /**
