@@ -6,16 +6,17 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/spreadsheet/utils/intervalarray', [
     'io.ox/office/tk/utils/iteratorutils',
-    'io.ox/office/tk/utils/arraytemplate',
+    'io.ox/office/tk/container/typedarray',
     'io.ox/office/spreadsheet/utils/interval'
-], function (IteratorUtils, ArrayTemplate, Interval) {
+], function (IteratorUtils, TypedArray, Interval) {
 
     'use strict';
 
@@ -29,7 +30,7 @@ define('io.ox/office/spreadsheet/utils/intervalarray', [
      *
      * @extends Array
      */
-    var IntervalArray = ArrayTemplate.create(Interval);
+    var IntervalArray = TypedArray.create(Interval);
 
     // static methods ---------------------------------------------------------
 
@@ -168,6 +169,8 @@ define('io.ox/office/spreadsheet/utils/intervalarray', [
                 return false;
             case 2:
                 return this[0].overlaps(this[1]);
+            case 3:
+                return this[0].overlaps(this[1]) || this[0].overlaps(this[2]) || this[1].overlaps(this[2]);
         }
 
         // work on a sorted clone for performance (check adjacent array elements)
