@@ -6,20 +6,24 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/spreadsheet/utils/intervalset', [
-    'io.ox/office/tk/utils/simplemap',
-    'io.ox/office/tk/utils/sortedarray',
+    'io.ox/office/tk/container/basemap',
+    'io.ox/office/tk/container/sortedarray',
     'io.ox/office/spreadsheet/utils/interval',
     'io.ox/office/spreadsheet/utils/intervalarray'
-], function (SimpleMap, SortedArray, Interval, IntervalArray) {
+], function (BaseMap, SortedArray, Interval, IntervalArray) {
 
     'use strict';
 
+    // convenience shortcuts
+    var MapProto = BaseMap.prototype;
+
     var ZEROS = '000000000';
 
     // private global functions ===============================================
@@ -359,15 +363,18 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
      * have the same start end end index).
      *
      * @constructor
+     *
+     * @extends BaseMap
      */
-    function IntervalSet() {
+    var IntervalSet = BaseMap.extend({ constructor: function () {
+
+        // base constructor (stores all intervals by their keys, for fast direct access)
+        BaseMap.call(this);
 
         // the centered interval tree storing all intervals
         this._tree = null;
-        // a map that stores all intervals by their keys, for fast direct access
-        this._map = new SimpleMap();
 
-    } // class IntervalSet
+    } }); // class IntervalSet
 
     // public methods ---------------------------------------------------------
 
@@ -388,8 +395,8 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
      *  A reference to this instance.
      */
     IntervalSet.prototype.clear = function () {
+        MapProto.clear.call(this);
         this._tree = null;
-        this._map.clear();
         return this;
     };
 
@@ -436,12 +443,12 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
                 var callback = _.isFunction(deep) ? deep : _.noop;
                 clone._tree = this._tree.clone(function (newInterval, oldInterval) {
                     callback.call(context, newInterval, oldInterval);
-                    clone._map.insert(newInterval.key(), newInterval);
+                    MapProto.insert.call(clone, newInterval.key(), newInterval);
                 });
             } else {
                 // shallow mode: simple clones of the tree, and the map
+                MapProto._init.call(clone, this);
                 clone._tree = this._tree.clone();
-                clone._map = this._map.clone();
             }
         }
 
@@ -460,7 +467,7 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
      *  passed interval.
      */
     IntervalSet.prototype.has = function (interval) {
-        return this._map.has(interval.key());
+        return MapProto.has.call(this, interval.key());
     };
 
     /**
@@ -475,7 +482,7 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
      *  as the passed interval; otherwise null.
      */
     IntervalSet.prototype.get = function (interval) {
-        return this._map.get(interval.key(), null);
+        return MapProto.get.call(this, interval.key(), null);
     };
 
     /**
@@ -536,43 +543,6 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
         return this._tree ? this._tree.findIntervals(interval) : new IntervalArray();
     };
 
-    /**
-     * Invokes the passed callback for each index interval in this set.
-     *
-     * @param {Function} callback
-     *  The callback function to be invoked for each index interval. Receives
-     *  the current interval as first parameter, and its map key as second
-     *  parameter.
-     *
-     * @param {Object} [context]
-     *  The calling context for the callback function.
-     *
-     * @returns {IntervalSet}
-     *  A reference to this instance.
-     */
-    IntervalSet.prototype.forEach = function (callback, context) {
-        this._map.forEach(callback, context);
-        return this;
-    };
-
-    /**
-     * Creates an iterator for all index intervals in this set.
-     *
-     * @returns {Object}
-     *  An iterator object that implements the standard EcmaScript iterator
-     *  protocol, i.e. it provides the method next() that returns a result
-     *  object with the following properties:
-     *  - {Boolean} done
-     *      If set to true, the index intervals have been visited completely.
-     *      No more elements are available; this result object does not contain
-     *      any other properties!
-     *  - {Interval} value
-     *      The index interval currently visited.
-     */
-    IntervalSet.prototype.iterator = function () {
-        return this._map.iterator();
-    };
-
     /**
      * Inserts a new index interval into this set.
      *
@@ -655,7 +625,7 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
 
         // add the interval to the tree, and the map
         interval = this._tree.insert(interval, replace);
-        return this._map.insert(interval.key(), interval);
+        return MapProto.insert.call(this, interval.key(), interval);
     };
 
     /**
@@ -671,7 +641,7 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
     IntervalSet.prototype.remove = function (interval) {
 
         // remove the inerval from the map (early exit, if the inetrval does not exist)
-        interval = this._map.remove(interval.key());
+        interval = MapProto.remove.call(this, interval.key(), null);
         if (!interval) { return null; }
 
         // remove the interval from the tree, and shrink the tree, if one subtree and the sorted arrays are empty
