@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -402,6 +403,21 @@ define('io.ox/office/spreadsheet/utils/range', [
         return this.start.equals(this.end);
     };
 
+    /**
+     * Returns whether the size (width AND height) of this range address is
+     * equal to the size of the passed range address.
+     *
+     * @param {Range} range
+     *  The range address to be checked.
+     *
+     * @returns {Boolean}
+     *  Whether this range address has the same size as the passed range
+     *  address.
+     */
+    Range.prototype.equalSize = function (range) {
+        return (this.cols() === range.cols()) && (this.rows() === range.rows());
+    };
+
     /**
      * Returns whether this cell range address starts at the specified cell
      * address.
@@ -643,14 +659,14 @@ define('io.ox/office/spreadsheet/utils/range', [
      * Returns the address of the specified columns or rows in this cell range
      * address.
      *
-     * @param {Number} index
-     *  The relative column/row index (the value zero will return the address
-     *  of the leading column or top row in this range).
-     *
      * @param {Boolean} columns
      *  Whether to return a column range (true), or a row range (false) of this
      *  cell range address.
      *
+     * @param {Number} index
+     *  The relative column/row index (the value zero will return the address
+     *  of the leading column or top row in this range).
+     *
      * @param {Number} [count=1]
      *  The number of columns or rows covered by the resulting range.
      *
