@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -82,26 +83,11 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
 
     // constants --------------------------------------------------------------
 
-    // TODO: get maximum size of columns/rows from somewhere
-    /**
-     * Maximum width of columns, in 1/100 millimeters.
-     *
-     * @constant
-     */
-    SheetUtils.MAX_COLUMN_WIDTH = 20000;
-
-    // TODO: get maximum size of columns/rows from somewhere
-    /**
-     * Maximum height of rows, in 1/100 millimeters.
-     *
-     * @constant
-     */
-    SheetUtils.MAX_ROW_HEIGHT = 20000;
-
     /**
      * Maximum length of a defined name.
      *
      * @constant
+     * @type Number
      */
     SheetUtils.MAX_NAME_LENGTH = 255;
 
@@ -110,6 +96,7 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      * auto-fill operation.
      *
      * @constant
+     * @type Number
      */
     SheetUtils.MAX_FILL_CELL_COUNT = 20000;
 
@@ -118,6 +105,7 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      * auto-fill operation.
      *
      * @constant
+     * @type Number
      */
     SheetUtils.MAX_AUTOFILL_COL_ROW_COUNT = 100;
 
@@ -125,6 +113,7 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      * Maximum number of merged ranges to be created with a single operation.
      *
      * @constant
+     * @type Number
      */
     SheetUtils.MAX_MERGED_RANGES_COUNT = 1000;
 
@@ -132,6 +121,7 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      * The maximum number of cells to be filled when unmerging a range.
      *
      * @constant
+     * @type Number
      */
     SheetUtils.MAX_UNMERGE_CELL_COUNT = 5000;
 
@@ -139,6 +129,7 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      * The maximum number of columns to be changed with one row operation.
      *
      * @constant
+     * @type Number
      */
     SheetUtils.MAX_CHANGE_COLS_COUNT = 5000;
 
@@ -146,6 +137,7 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      * The maximum number of rows to be changed with one row operation.
      *
      * @constant
+     * @type Number
      */
     SheetUtils.MAX_CHANGE_ROWS_COUNT = 5000;
 
@@ -153,6 +145,7 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      * The maximum number of columns/rows that can be sorted.
      *
      * @constant
+     * @type Number
      */
     SheetUtils.MAX_SORT_LINES_COUNT = 5000;
 
@@ -161,6 +154,7 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      * with the standard number format (in cells).
      *
      * @constant
+     * @type Number
      */
     SheetUtils.MAX_LENGTH_STANDARD_CELL = 11;
 
@@ -169,6 +163,7 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      * with the standard number format (in cell edit mode).
      *
      * @constant
+     * @type Number
      */
     SheetUtils.MAX_LENGTH_STANDARD_EDIT = 21;
 
@@ -178,6 +173,7 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      * converting numbers to strings for functions expecting strings).
      *
      * @constant
+     * @type Number
      */
     SheetUtils.MAX_LENGTH_STANDARD_FORMULA = 20;
 
@@ -187,6 +183,7 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      * bottom borders of a cell overlay each other.
      *
      * @constant
+     * @type Number
      */
     SheetUtils.MIN_CELL_SIZE = 5;
 
@@ -194,6 +191,7 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      * Minimum allowed zoom factor in the spreadsheet view.
      *
      * @constant
+     * @type Number
      */
     SheetUtils.MIN_ZOOM = 0.5;
 
@@ -201,6 +199,7 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      * Maximum allowed zoom factor in the spreadsheet view.
      *
      * @constant
+     * @type Number
      */
     SheetUtils.MAX_ZOOM = 8;
 
@@ -208,6 +207,7 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      * Whether multi-selection (multiple ranges at the same time) is supported.
      *
      * @constant
+     * @type Boolean
      */
     SheetUtils.MULTI_SELECTION = !Utils.TOUCHDEVICE;
 
@@ -501,6 +501,38 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
         return BORDER_ATTRIBUTE_NAMES[SheetUtils.getInnerBorderKey(columns)];
     };
 
+    /**
+     * Returns the effective horizontal padding between cell grid lines and the
+     * text contents of the cell, according to the passed zoom factor.
+     *
+     * @param {Number} zoom
+     *  The zoom factor to calculate the cell content padding for.
+     *
+     * @returns {Number}
+     *  The effective horizontal cell content padding, in pixels.
+     */
+    SheetUtils.getTextPadding = function (zoom) {
+        // 2 pixels padding for 100% zoom, rounded up early
+        return Math.floor(2 * zoom + 0.75);
+    };
+
+    /**
+     * Returns the total size of all horizontal padding occupied in a cell that
+     * cannot be used for the cell contents, according to the passed zoom
+     * factor. This value includes the text padding (twice, for left and right
+     * border), and additional space needed for the grid lines.
+     *
+     * @param {Number} zoom
+     *  The zoom factor to calculate the cell content padding for.
+     *
+     * @returns {Number}
+     *  The total size of the horizontal cell content padding, in pixels.
+     */
+    SheetUtils.getTotalCellPadding = function (zoom) {
+        // padding at left and right cell border, and 1 pixel for the grid line
+        return 2 * SheetUtils.getTextPadding(zoom) + 1;
+    };
+
     /**
      * Returns whether the passed split mode identifier includes the dynamic
      * split mode. Returns also true, if the split mode is 'frozenSplit', i.e.
