@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  */
@@ -357,7 +358,7 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
         );
 
         // first array element of the result is an array with the contents of the three cells
-        var res = docModel.getRangeContents(ranges, { attributes: true, display: true });
+        var res = docModel.getRangeContents(ranges, { blanks: true, attributes: true, display: true });
         var bottomCell = res[0];
         var rightCell = res[1];
         var startCell = res[2];
@@ -494,43 +495,58 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
 
     /**
      *
-     * @param {Range} range
-     *  whole start to end area of the new series
+     * @param {Object} options
+     *  @param {Range} [options.range]
+     *      whole start to end area of the new series
      *
-     * @param {Number} sheet
+     *  @param {Number} [options.sheet]
      *
-     * @param {ChartModel} chartModel
-     *  is used for the position and id in the document and as fallback for chart-type-checks
+     *  @param {ChartModel} [options.chartModel]
+     *      is used for the position and id in the document and as fallback for chart-type-checks
      *
-     * @param {String} axis
-     *  series direction
+     *  @param {String} [options.axis]
+     *      series direction
      *
-     * @param {Object} chartAttrs
-     *  is used for changing other attributes of the chart and for the type info (bubble or not)
+     *  @param {Object} [options.chartAttrs]
+     *      is used for changing other attributes of the chart and for the type info (bubble or not)
      *
-     * @param {Boolean} forceTitle
-     *  is set, it overwrites the internal logic for title data
+     *  @param {Boolean} [options.forceTitle]
+     *      is set, it overwrites the internal logic for title data
      *
-     * @param {Boolean} forceNames
-     *  is set, it overwrites the internal logic for names data
+     *  @param {Boolean} [options.forceNames]
+     *      is set, it overwrites the internal logic for names data
      *
      * @returns {jQuery.Promise}
      *  A promise that will be resolved after the chart has been changed
      *  successfully, or that will be rejected on any error.
      */
-    ChartCreator.updateSeries = function (app, sourceRange, sourceSheet, chartModel, axis, chartAttrs, forceTitle, forceNames) {
+    ChartCreator.updateSeries = function (options) {
+
+        var app         = Utils.getOption(options, 'app');
+        var sourceRange = Utils.getOption(options, 'sourceRange');
+        var sourceSheet = Utils.getOption(options, 'sourceSheet');
+        var chartModel  = Utils.getOption(options, 'chartModel');
+        var axis        = Utils.getOption(options, 'axis');
+        var chartAttrs  = Utils.getOption(options, 'chartAttrs');
+        var forceTitle  = Utils.getOption(options, 'forceTitle');
+        var forceNames  = Utils.getOption(options, 'forceNames');
+        var typeChanged = Utils.getOption(options, 'typeChanged');
 
         if (!chartAttrs) {
             var mergedAttributes = chartModel.getMergedAttributeSet(true);
             //CURVED is a workaround, filter has not all the information it needs!
             chartAttrs = {
                 type: mergedAttributes.chart.type,
+                stacking: mergedAttributes.chart.stacking,
                 curved: mergedAttributes.chart.curved
             };
         }
 
-        var docModel = app.getModel(),
-            docView = app.getView();
+        var clonedData = chartModel.getCloneData();
+        var undoAttrs = chartModel.getUndoAttributeSet({ chart: chartAttrs });
+
+        var docModel = app.getModel();
+        var docView = app.getView();
 
         var promise = getContentForRange(docModel, docView, sourceRange, sourceSheet, axis, forceTitle, forceNames);
 
@@ -542,29 +558,28 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
             }
             var position = chartModel.getSheetPosition();
             var lineAttrs = null;
-            if (chartModel.isMarkerOnly()) {
+            if (!typeChanged && chartModel.isMarkerOnly()) {
                 lineAttrs = NONE_SHAPE;
             }
 
             return chartModel.getSheetModel().createAndApplyOperations(function (generator) {
 
-                var clonedData = chartModel.getCloneData(),
-                    oldCount = chartModel.getSeriesCount(),
-                    seriesCount = generateSeriesOperations(docModel, sourceRange, sourceSheet, generator, position, data.cells, axis, chartAttrs, lineAttrs);
+                var oldCount = chartModel.getSeriesCount();
+                var seriesCount = generateSeriesOperations(docModel, sourceRange, sourceSheet, generator, position, data.cells, axis, chartAttrs, lineAttrs);
 
                 _.times(oldCount, function () {
                     generator.generateDrawingOperation(Operations.DELETE_CHART_DATASERIES, position, { series: seriesCount });
                 });
 
                 // UNDO ---
-                generator.generateDrawingOperation(Operations.SET_DRAWING_ATTRIBUTES, position, { attrs: clonedData.attrs }, { undo: true });
+                generator.generateDrawingOperation(Operations.SET_DRAWING_ATTRIBUTES, position, { attrs: undoAttrs }, { undo: true });
 
                 _.each(clonedData.series, function (obj, index) {
                     generator.generateDrawingOperation(Operations.INSERT_CHART_DATASERIES, position, { series: index, attrs: obj }, { undo: true });
                 });
 
                 _.times(seriesCount, function () {
-                    generator.generateDrawingOperation(Operations.DELETE_CHART_DATASERIES, position, { series: clonedData.series.length }, { undo: true });
+                    generator.generateDrawingOperation(Operations.DELETE_CHART_DATASERIES, position, { series: oldCount }, { undo: true });
                 });
 
                 // callback MUST return a promise
@@ -578,7 +593,7 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
     ChartCreator.generateOperationsFromModelData = function (app, generator, position, chartModelData) {
         var chartAttrs = {
             chart: chartModelData.attrs.chart,
-            fill: chartModelData.attrs.chart,
+            fill: chartModelData.attrs.fill,
             line: chartModelData.attrs.line
         };
         var axes = chartModelData.axes;
