@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -387,7 +388,7 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
         function dndTrackingEndHandler() {
 
             // leave cell edit mode before manipulating the sheet order
-            if (isValidDndTargetIndex() && docView.leaveCellEditMode('auto', { validate: true })) {
+            if (isValidDndTargetIndex() && docView.leaveCellEditMode()) {
 
                 // adjust drop position, if target position follows source position
                 if (dndStartIndex < dndTargetIndex) { dndTargetIndex -= 1; }
@@ -445,7 +446,7 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
 
             // explicitly notify listeners, needed for reliable layout
             self.trigger('change:sheets');
-        });
+        }, { infoString: 'ActiveSheetGroup: fillList', app: docView.getApp() });
 
         // methods ------------------------------------------------------------
 
