@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -75,7 +76,7 @@ define('io.ox/office/spreadsheet/view/control/activesheetlist', [
                     tooltip: _.noI18n(sheetName)
                 });
             });
-        });
+        }, { infoString: 'ActiveSheetList: fillList', app: docView.getApp() });
 
         // initialization -----------------------------------------------------
 
