@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -21,6 +22,9 @@ define('io.ox/office/spreadsheet/view/control/discretefiltergroup', [
 
     'use strict';
 
+    // convenience shortcuts
+    var Scalar = FormulaUtils.Scalar;
+
     //#. Represents a list entry in spreadsheet data filters that selects all blank (empty) cells in a column
     var BLANK_CELLS_LABEL = gt.pgettext('filter', 'Blank cells');
 
@@ -39,8 +43,8 @@ define('io.ox/office/spreadsheet/view/control/discretefiltergroup', [
      */
     function DiscreteFilterGroup(docView) {
 
-        var // self reference
-            self = this;
+        // self reference
+        var self = this;
 
         // base constructor ---------------------------------------------------
 
@@ -60,8 +64,8 @@ define('io.ox/office/spreadsheet/view/control/discretefiltergroup', [
          * entries of this control.
          */
         function sortComparator(sortIndex1, sortIndex2) {
-            var result = FormulaUtils.compareScalars(sortIndex1.value, sortIndex2.value, { nullMode: 'less' });
-            return (result === 0) ? FormulaUtils.compareStrings(sortIndex1.display, sortIndex2.display) : result;
+            var result = Scalar.compare(sortIndex1.value, sortIndex2.value, { nullMode: 'less' });
+            return (result === 0) ? Scalar.compareStrings(sortIndex1.display, sortIndex2.display) : result;
         }
 
         // public methods -----------------------------------------------------
@@ -116,7 +120,7 @@ define('io.ox/office/spreadsheet/view/control/discretefiltergroup', [
 
                     // the label displayed in the list entry (preserve case)
                     // bug 36264: trim space characters but no other whitespace
-                    var label = _.isString(cellData.display) ? cellData.display.replace(/^ +| +$/g, '') : '#######';
+                    var label = cellData.display.replace(/^ +| +$/g, '');
                     // the key used to detect duplicates
                     var key = isODF ? cellData.value : label.toLowerCase();
 
