@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Michael Nimz <michael.nimz@open-xchange.com>
  */
@@ -47,7 +48,9 @@ define('io.ox/office/spreadsheet/view/control/sortmenubutton', [
             icon: 'fa-sort-alpha-asc',
             tooltip: /*#. spreadsheet sorting: button tooltip for sorting */ gt.pgettext('sort', 'Sorting')
         }, initOptions, {
-            value: { order: 'toggle' },
+            value: function () {
+                return { orderRules: [{ orderBy: 'toggle' }] };
+            },
             updateCaptionMode: 'icon'
         }));
 
@@ -56,8 +59,16 @@ define('io.ox/office/spreadsheet/view/control/sortmenubutton', [
         /**
          * Updates the icon according to the sort state.
          */
-        function updateHandler() {
-            switch (docView.getSortState()) {
+        function updateHandler(sortState) {
+
+            var rules = sortState.orderRules,
+                state = 'ascending';
+
+            if (rules.length > 0 && rules[0].orderBy) {
+                state = rules[0].orderBy;
+            }
+
+            switch (state) {
                 case 'ascending':
                     self.setIcon('fa-sort-alpha-asc');
                     break;
@@ -73,8 +84,8 @@ define('io.ox/office/spreadsheet/view/control/sortmenubutton', [
         // initialization -----------------------------------------------------
 
         // create all drop-down menu items
-        this.addGroup('cell/sort', new Button({ icon: 'fa-sort-alpha-asc', label: /*#. sort ascending */ gt.pgettext('sort', 'Ascending'), tooltip: gt.pgettext('sort', 'Sort from smallest to largest value'), value: { order: 'ascending' } }))
-            .addGroup('cell/sort', new Button({ icon: 'fa-sort-alpha-desc', label: /*#. sort descending */ gt.pgettext('sort', 'Descending'), tooltip: gt.pgettext('sort', 'Sort from largest to smallest value'), value: { order: 'descending' } }))
+        this.addGroup('cell/sort', new Button({ icon: 'fa-sort-alpha-asc', label: /*#. sort ascending */ gt.pgettext('sort', 'Ascending'), tooltip: gt.pgettext('sort', 'Sort from smallest to largest value'), value: { orderRules: [{ orderBy: 'ascending' }] } }))
+            .addGroup('cell/sort', new Button({ icon: 'fa-sort-alpha-desc', label: /*#. sort descending */ gt.pgettext('sort', 'Descending'), tooltip: gt.pgettext('sort', 'Sort from largest to smallest value'), value: { orderRules: [{ orderBy: 'descending' }] } }))
             .addSeparator()
             .addGroup('cell/sort/menu', new Button({ label: /*#. sorting: label of the button opening a menu with custom sort options */ gt.pgettext('sort', 'Custom'), tooltip: /*#. tooltip for custom sort button */ gt.pgettext('sort', 'Settings for sorting') }));
 
