@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -89,13 +90,13 @@ define('io.ox/office/spreadsheet/view/controls', [
      *
      * @extends UnitField
      */
-    SpreadsheetControls.ColRowSizeField = EditControls.UnitField.extend({ constructor: function (columns) {
+    SpreadsheetControls.ColRowSizeField = EditControls.UnitField.extend({ constructor: function (docView, columns) {
 
         EditControls.UnitField.call(this, {
             width: 70,
             tooltip: columns ? gt('Column width') : gt('Row height'),
             min: 0,
-            max: columns ? SheetUtils.MAX_COLUMN_WIDTH : SheetUtils.MAX_ROW_HEIGHT,
+            max: docView.getDocModel().getMaxColRowSizeHmm(columns),
             smallerVersion: { hide: true }
         });
 
@@ -158,6 +159,31 @@ define('io.ox/office/spreadsheet/view/controls', [
 
     } }); // class FrozenSplitCheckBox
 
+    // class FormulaLabel =====================================================
+
+    /**
+     * A dynamic label that shows the formula expression of the active cell.
+     *
+     * @constructor
+     *
+     * @extends DynamicLabel
+     */
+    SpreadsheetControls.FormulaLabel = EditControls.DynamicLabel.extend({ constructor: function () {
+
+        EditControls.DynamicLabel.call(this, {
+            classes: 'formula-text',
+            captionResolver: captionResolver,
+            setToolTip: true
+        });
+
+        function captionResolver(tokenDesc) {
+            if (!tokenDesc) { return null; }
+            var formula = '=' + tokenDesc.formula;
+            return tokenDesc.matrixRange ? ('{' + formula + '}') : formula;
+        }
+
+    } }); // class FormulaLabel
+
     // exports ================================================================
 
     return SpreadsheetControls;
