@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Kai Ahrens <kai.ahrens@open-xchange.com>
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
@@ -25,7 +26,7 @@ define('io.ox/office/spreadsheet/view/dialog/functiondialog', [
     'use strict';
 
     // dialog width according to device type
-    var DIALOG_WIDTH = ox.mobile ? 320 : 540;
+    var DIALOG_WIDTH = (Utils.SMALL_DEVICE && Utils.isPortrait()) ? 320 : 540;
 
     // special drop-down list entry value for 'show all functions'
     var CATEGORY_ALL = '__all__';
@@ -78,6 +79,9 @@ define('io.ox/office/spreadsheet/view/dialog/functiondialog', [
      */
     var FunctionDialog = Dialogs.ModalDialog.extend({ constructor: function (docView, text) {
 
+        // self-referecne
+        var self = this;
+
         // the document model
         var docModel = docView.getDocModel();
 
@@ -103,6 +107,16 @@ define('io.ox/office/spreadsheet/view/dialog/functiondialog', [
 
         // private methods ----------------------------------------------------
 
+        // set some classes to style the Dialog (especially for the different mobile-devices)
+        function functionDialogOrientation() {
+            self.getBody().toggleClass('portrait', Utils.isPortrait());
+            self.getBody().toggleClass('landscape', Utils.isLandscape());
+            self.getBody().toggleClass('mobile', Utils.SMALL_DEVICE);
+
+            var sel = self.getBody().find('select[name="functions"]').first();
+            sel.attr('size', (Utils.SMALL_DEVICE) ? 4 : 13);
+        }
+
         /**
          * Returns the fully formatted syntax string for the passed function
          * help descriptor.
@@ -256,7 +270,7 @@ define('io.ox/office/spreadsheet/view/dialog/functiondialog', [
 
             if (!_.browser.iOS) {
                 // the anchor element used to open the drop-down menu
-                jqMenuAnchor = $('<a href="#" tabindex="1" aria-haspopup="true" data-toggle="dropdown">');
+                jqMenuAnchor = $('<a href="#" tabindex="0" aria-haspopup="true" data-toggle="dropdown">');
                 jqMenuAnchor.text(ALL_FUNCTIONS_LABEL);
 
                 // the drop-down list attached to the anchor element
@@ -298,13 +312,13 @@ define('io.ox/office/spreadsheet/view/dialog/functiondialog', [
 
                     jqMenuAnchor.text(jqClicked.text());
                     updateFunctionList(category);
-                    _.defer(function () { functionSelectNode.focus(); });
+                    _.defer(function () { Utils.setFocus(functionSelectNode); });
                 });
             } else {
                 jqCategoriesCtl = $(Forms.createSelectBoxMarkup(categories, {
                     name: 'Categories',
                     classes: 'control functions categories',
-                    size: ox.mobile ? 4 : 1
+                    size: (Utils.SMALL_DEVICE && Utils.isLandscape()) ? 4 : 1
                 }));
 
                 categorySelectNode = jqCategoriesCtl.find('select');
@@ -333,7 +347,7 @@ define('io.ox/office/spreadsheet/view/dialog/functiondialog', [
                 name: 'Functions',
                 label: PICK_FUNCTION_LABEL,
                 classes: 'control functions',
-                size: ox.mobile ? 4 : 13
+                size: (Utils.SMALL_DEVICE) ? 4 : 13
             }));
 
             // shortcut to the function list <select> elements
@@ -362,7 +376,7 @@ define('io.ox/office/spreadsheet/view/dialog/functiondialog', [
          *  the function selected in the dialog; or that will be rejected when
          *  canceling the dialog.
          */
-        this.show = _.wrap(this.show, function (show) {
+        self.show = _.wrap(self.show, function (show) {
             return show.call(this).then(function () {
                 var funcName = functionSelectNode.val();
                 return funcName ? funcName : $.Deferred().reject();
@@ -372,12 +386,14 @@ define('io.ox/office/spreadsheet/view/dialog/functiondialog', [
         // initialization -----------------------------------------------------
 
         // close dialog when losing edit rights
-        docView.closeDialogOnReadOnlyMode(this);
+        docView.closeDialogOnReadOnlyMode(self);
 
         // initialize the body element of the dialog
-        this.getBody()
+        self.getBody()
             .addClass('io-ox-office-spreadsheet-function-dialog')
-            .toggleClass('mobile', !!ox.mobile)
+            .toggleClass('portrait', Utils.isPortrait())
+            .toggleClass('landscape', Utils.isLandscape())
+            .toggleClass('mobile', Utils.SMALL_DEVICE)
             .append(controlRootNode, descRootNode);
 
         // create the contents of the dialog
@@ -394,21 +410,27 @@ define('io.ox/office/spreadsheet/view/dialog/functiondialog', [
             updateFunctionDescription(text);
         }
 
+        // set listener for orientation-change
+        $(window).on('orientationchange', functionDialogOrientation);
+
         // set initial control focus
-        this.on('show', function () {
+        self.on('show', function () {
 
             // us 102078426: dialogs on small devices should come up w/o keyboard,
             // so the focus should not be in an input element
             if (Utils.SMALL_DEVICE) {
-                this.getOkButton().focus();
+                Utils.setFocus(self.getOkButton());
             } else {
-                functionSelectNode.focus();
+                Utils.setFocus(functionSelectNode);
             }
 
         });
 
         // clean up after closing
-        this.on('close', function () {
+        self.on('close', function () {
+            // unsubscribe listener for orientation-change
+            $(window).off('orientationchange', functionDialogOrientation);
+
             docView = docModel = formulaResource = functionCollection = null;
             controlRootNode = descRootNode = functionSelectNode = categorySelectNode = null;
         });
