@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  */
@@ -46,13 +47,13 @@ define('io.ox/office/spreadsheet/view/dialog/sheetorderdialog', [
 
             upButton = $.button({ click: upButtonClickHandler })
                     .addClass('btn')
-                    .attr('tabindex', 1)
+                    .attr('tabindex', 0)
                     .css({ marginTop: '-3px', marginBottom: '5px', display: 'block' })
                     .append(Forms.createIconMarkup('fa-arrow-up')),
 
             downButton = $.button({ data: { dir: 1 }, click: downButtonClickHandler })
                     .addClass('btn')
-                    .attr('tabindex', 1)
+                    .attr('tabindex', 0)
                     .css('display', 'block')
                     .append(Forms.createIconMarkup('fa-arrow-down')),
 
@@ -60,7 +61,7 @@ define('io.ox/office/spreadsheet/view/dialog/sheetorderdialog', [
 
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDialog.call(this, { title: gt('Reorder sheets') });
+        Dialogs.ModalDialog.call(this, { title: gt('Reorder sheets'), width: 298 });
         var self = this;
 
         // private functions --------------------------------------------------
@@ -112,7 +113,7 @@ define('io.ox/office/spreadsheet/view/dialog/sheetorderdialog', [
             if (currentChosen.prev('*').length > 0) {
                 upButton.removeClass('disabled');
                 upButton.css({ pointerEvents: 'auto' });
-                upButton.attr('tabindex', 1);
+                upButton.attr('tabindex', 0);
             } else {
                 upButton.addClass('disabled');
                 upButton.css({ pointerEvents: 'none' });
@@ -122,7 +123,7 @@ define('io.ox/office/spreadsheet/view/dialog/sheetorderdialog', [
             if (currentChosen.next('*').length > 0) {
                 downButton.removeClass('disabled');
                 downButton.css({ pointerEvents: 'auto' });
-                downButton.attr('tabindex', 1);
+                downButton.attr('tabindex', 0);
             } else {
                 downButton.addClass('disabled');
                 downButton.css({ pointerEvents: 'none' });
@@ -145,7 +146,7 @@ define('io.ox/office/spreadsheet/view/dialog/sheetorderdialog', [
                 button = upDown ? currentChosen.prev('*') : currentChosen.next('*');
             }
             button.click();
-            currentChosen.focus();
+            Utils.setFocus(currentChosen);
         }
 
         /**
@@ -193,7 +194,7 @@ define('io.ox/office/spreadsheet/view/dialog/sheetorderdialog', [
             if (!docView.isSheetTypeSupported(sheetModel.getType())) { return; }
 
             var sheetName = _.noI18n(Utils.escapeHTML(result.name));
-            var button = $('<button class="btn" data-index="' + result.sheet + '" title="' + sheetName + '" tabindex="1" role="button">' + sheetName + '</button>');
+            var button = $('<button class="btn" data-index="' + result.sheet + '" title="' + sheetName + '" tabindex="0" role="button">' + sheetName + '</button>');
 
             button.on('click', selectButton);
             if (result.sheet === currentSheet) {
@@ -214,7 +215,7 @@ define('io.ox/office/spreadsheet/view/dialog/sheetorderdialog', [
             checkButtonsActive();
 
             // workaround for Bug 46874
-            self.getOkButton().focus();
+            Utils.setFocus(self.getOkButton());
         });
 
     } }); // class SheetOrderDialog
