@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -890,7 +891,7 @@ define('io.ox/office/spreadsheet/view/headerpane', [
 
             return this;
 
-        }, function () { updateScrollAreaSize(scrollPos); }, { delay: 500 });
+        }, function () { updateScrollAreaSize(scrollPos); }, { delay: 500, infoString: 'HeaderPane: scrollTo', app: docView.getApp() });
 
         /**
          * Changes the scroll position of this header pane relative to the
