@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -259,7 +260,7 @@ define('io.ox/office/spreadsheet/view/labels', [
     };
 
     /**
-     * Standard options for 'filter function'.
+     * Standard options for 'Toggle table filter' buttons.
      *
      * @constant
      */
@@ -270,7 +271,7 @@ define('io.ox/office/spreadsheet/view/labels', [
     };
 
     /**
-     * Standard options for 'sort function'.
+     * Standard options for 'Custom sort' buttons.
      *
      * @constant
      */
@@ -280,7 +281,7 @@ define('io.ox/office/spreadsheet/view/labels', [
     };
 
     /**
-     * Standard options for 'clean function'.
+     * Standard options for 'Clear contents' buttons.
      *
      * @constant
      */
@@ -384,6 +385,9 @@ define('io.ox/office/spreadsheet/view/labels', [
      *
      * @param {Number} col
      *  The zero-based column index to be converted to a column label.
+     *
+     * @returns {String}
+     *  The label for the specified column.
      */
     SpreadsheetLabels.getColLabel = function (col) {
         return (
@@ -399,6 +403,9 @@ define('io.ox/office/spreadsheet/view/labels', [
      *
      * @param {Number} row
      *  The zero-based row index to be converted to a row label.
+     *
+     * @returns {String}
+     *  The label for the specified row.
      */
     SpreadsheetLabels.getRowLabel = function (row) {
         return (
@@ -408,6 +415,23 @@ define('io.ox/office/spreadsheet/view/labels', [
             gt('Row %1$s', _.noI18n(Address.stringifyRow(row))));
     };
 
+    /**
+     * Returns the name of the passed column or row together with the word
+     * 'Column' or 'Row' respectively, e.g. 'Column A', or 'Row 1'.
+     *
+     * @param {Number} index
+     *  The zero-based column or row index to be converted to a label.
+     *
+     * @param {Boolean} columns
+     *  Whether to return a column label (true), or a row label (false).
+     *
+     * @returns {String}
+     *  The label for the specified column or row.
+     */
+    SpreadsheetLabels.getColRowLabel = function (index, columns) {
+        return columns ? SpreadsheetLabels.getColLabel(index) : SpreadsheetLabels.getRowLabel(index);
+    };
+
     /**
      * Returns the localized name of the specified function category.
      *
