@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -15,7 +16,6 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/keycodes',
     'io.ox/office/tk/forms',
-    'io.ox/office/tk/utils/dateutils',
     'io.ox/office/tk/utils/iteratorutils',
     'io.ox/office/tk/utils/tracking',
     'io.ox/office/tk/popup/tooltip',
@@ -27,12 +27,11 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
     'io.ox/office/spreadsheet/model/formula/tokenarray',
     'io.ox/office/spreadsheet/view/popup/signaturetooltip',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, KeyCodes, Forms, DateUtils, IteratorUtils, Tracking, ToolTip, ListMenu, Color, AttributeUtils, SheetUtils, SheetSelection, TokenArray, SignatureToolTip, gt) {
+], function (Utils, KeyCodes, Forms, IteratorUtils, Tracking, ToolTip, ListMenu, Color, AttributeUtils, SheetUtils, SheetSelection, TokenArray, SignatureToolTip, gt) {
 
     'use strict';
 
     // convenience shortcuts
-    var ErrorCode = SheetUtils.ErrorCode;
     var Range = SheetUtils.Range;
 
     // key codes of all keys used to navigate in text area, or in the sheet (quick edit mode)
@@ -64,15 +63,10 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
         var docModel = this.getDocModel();
         var undoManager = docModel.getUndoManager();
         var fontCollection = docModel.getFontCollection();
-        var numberFormatter = docModel.getNumberFormatter();
         var formulaResource = docModel.getFormulaResource();
         var formulaGrammar = docModel.getFormulaGrammar('ui');
         var formulaParser = docModel.getFormulaParser();
-
-        // the preferred date format for cell edit mode
-        var DATE_FORMAT = numberFormatter.getPresetCode(14);
-        // the preferred time format for cell edit mode
-        var TIME_FORMAT = numberFormatter.getTimeCode({ seconds: true });
+        var app = docModel.getApp();
 
         // the underlay node containing highlighting for formulas
         var textUnderlayNode = $('<div class="underlay">');
@@ -133,8 +127,6 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
         var formulaOffset = 0;
         // unique identifier of the current range highlighting mode for formulas
         var highlightUid = null;
-        // whether a matrix formula is currently edited
-        var matrixFormula = false;
         // whether to show auto-completion list for a function or defined name
         var funcAutoComplete = false;
         // token descriptor for function/name auto-completion
@@ -148,89 +140,6 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
 
         // private methods ----------------------------------------------------
 
-        /**
-         * Returns the initial text for the in-place cell edit mode. Returns
-         * the formula expression for formula cells, otherwise the cell value
-         * formatted with an appropriate default number format.
-         *
-         * @returns {String}
-         *  The initial text for the in-place cell edit mode.
-         */
-        function getTextForCellEditMode() {
-
-            // formulas: hide formula if the cell contains the hidden attribute
-            var formula = cellCollection.getCellFormula(editAddress, 'ui');
-            if (_.isString(formula)) {
-                var cellAttrs = cellCollection.getCellAttributeSet(editAddress).cell;
-                return (self.isSheetLocked() && cellAttrs.hidden) ? '' : ('=' + formula);
-            }
-
-            // the result value of the cell to be formatted
-            var value = cellCollection.getCellValue(editAddress);
-
-            // strings: use plain unformatted string for editing (bug 34421: add an apostrophe if necessary)
-            if (_.isString(value) && (value.length > 0)) {
-                return ((/^['=]/).test(value) || !_.isString(numberFormatter.parseValue(value))) ? ('\'' + value) : value;
-            }
-
-            // booleans: use plain boolean literal for editing
-            if (_.isBoolean(value)) {
-                return formulaGrammar.getBooleanName(value);
-            }
-
-            // error codes: use plain error code literal for editing
-            if (value instanceof ErrorCode) {
-                return formulaGrammar.getErrorName(value);
-            }
-
-            // numbers: use appropriate number representation according to number format category
-            if (_.isNumber(value) && isFinite(value)) {
-
-                // the resulting formatted value
-                var formatted = null;
-
-                // process different format categories
-                var category = cellCollection.getCellParsedFormat(editAddress).category;
-                switch (category) {
-
-                    // percent: multiply by 100, add percent sign without whitespace
-                    case 'percent':
-                        value *= 100; // may become infinite
-                        formatted = (isFinite(value) ? numberFormatter.formatStandardNumber(value, SheetUtils.MAX_LENGTH_STANDARD_EDIT) : '') + '%';
-                        break;
-
-                    // automatically show date and/or time, according to the number
-                    case 'date':
-                    case 'time':
-                    case 'datetime':
-
-                        // number of milliseconds
-                        var milliSecs = Math.round(value * DateUtils.MSEC_PER_DAY);
-                        // number of days
-                        var date = Math.floor(milliSecs / DateUtils.MSEC_PER_DAY);
-                        // number of milliseconds in the day
-                        var time = Math.floor(milliSecs % DateUtils.MSEC_PER_DAY);
-                        // whether to add the date and time part to the result
-                        var showDate = (category !== 'time') || (date !== 0);
-                        var showTime = (category !== 'date') || (time !== 0);
-                        // the resulting format code
-                        var formatCode = (showDate ? DATE_FORMAT : '') + ((showDate && showTime) ? ' ' : '') + (showTime ? TIME_FORMAT : '');
-                        // the parsed number format
-                        var parsedFormat = numberFormatter.getParsedFormat(formatCode);
-
-                        // the resulting formatted value (may be null for invalid dates)
-                        formatted = numberFormatter.formatValue(parsedFormat, value);
-                        break;
-                }
-
-                // use standard number format for all other format codes
-                return _.isString(formatted) ? formatted : numberFormatter.formatStandardNumber(value, SheetUtils.MAX_LENGTH_STANDARD_EDIT);
-            }
-
-            // empty cells
-            return '';
-        }
-
         /**
          * Applies a transformation to the passed color, and returns the CSS
          * color value.
@@ -258,14 +167,14 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
         function updateTextAreaStyle() {
 
             // get cell attributes, and overwrite them with current edit attributes
-            cellAttributeSet = docModel.extendAttributes(cellCollection.getCellAttributeSet(editAddress), editAttributeSet, { clone: true });
+            cellAttributeSet = docModel.extendAttributes(cellCollection.getAttributeSet(editAddress), editAttributeSet, { clone: true });
 
             // receive font settings, text line height, and text orientation
             var zoom = sheetModel.getEffectiveZoom();
-            fontDesc = fontCollection.getFont(cellAttributeSet.character, zoom);
+            fontDesc = fontCollection.getFont(cellAttributeSet.character, { zoom: zoom });
             fontDesc.fontSize = Utils.minMax(fontDesc.fontSize, 6, 48);
             lineHeight = docModel.getRowHeight(cellAttributeSet.character, zoom);
-            var orientation = cellCollection.getCellTextOrientation(editAddress);
+            var orientation = cellCollection.getTextOrientation(editAddress);
 
             // set CSS attributes according to formatting of active cell
             textAreaContainer.children().css({
@@ -276,7 +185,7 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
                 fontWeight: fontDesc.bold ? 'bold' : 'normal',
                 fontStyle: fontDesc.italic ? 'italic' : 'normal',
                 textDecoration: docModel.getCssTextDecoration(cellAttributeSet.character),
-                textAlign: (cellCollection.isAnyFormulaCell(editAddress) && (cellAttributeSet.cell.alignHor === 'auto')) ? 'left' : orientation.cssTextAlign
+                textAlign: (cellCollection.isFormulaCell(editAddress) && (cellAttributeSet.cell.alignHor === 'auto')) ? 'left' : orientation.cssTextAlign
             }).attr('dir', orientation.textDir);
 
             // set cell text color and fill color to the appropriate nodes
@@ -331,7 +240,7 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
                 // the visible area of this grid pane
                 var visiblePosition = null;
                 // whether the text in the cell wraps automatically
-                var isWrapped = _.isString(cellCollection.getCellValue(editAddress)) && SheetUtils.hasWrappingAttributes(cellAttributeSet);
+                var isWrapped = _.isString(cellCollection.getValue(editAddress)) && SheetUtils.hasWrappingAttributes(cellAttributeSet);
                 // the effective horizontal CSS text alignment
                 var textAlign = textAreaNode.css('text-align');
                 // round up width to multiples of the line height
@@ -458,7 +367,7 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
             }
 
             // return the debounced method updateTextAreaPosition()
-            return self.createDebouncedMethod(directCallback, deferredCallback, { delay: 250, maxDelay: 500 });
+            return self.createDebouncedMethod(directCallback, deferredCallback, { delay: 250, maxDelay: 500, infoString: 'CellEditMixin: updateTextAreaPosition', app: app });
         }());
 
         /**
@@ -839,7 +748,7 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
             self.executeDelayed(function () {
                 // fail-safe check that cell edit mode is still active
                 if (editActive) { updateTextAreaPopups(); }
-            });
+            }, { infoString: 'CelleditMixin: updateTextAreaAfterSelection', app: app });
         }
 
         /**
@@ -966,7 +875,7 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
             }
 
             // return the debounced method updateTokenArray()
-            return self.createDebouncedMethod(directCallback, deferredCallback, { delay: 100, maxDelay: 300 });
+            return self.createDebouncedMethod(directCallback, deferredCallback, { delay: 100, maxDelay: 300, infoString: 'CellEditMixin: updateTextAreaPosition', app: app });
         }());
 
         /**
@@ -1049,7 +958,7 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
 
             // get new text and new cursor position
             var newText = itemValue.name;
-            var newStart = funcAutoTokenDesc.start + newText.length + 1;
+            var newStart = funcAutoTokenDesc.start + newText.length + formulaOffset;
 
             // insert parentheses after function name (unless the existing token is
             // a function token which means it already has an opening parenthesis)
@@ -1065,7 +974,7 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
 
             // insert the new text into the formula string, prevent showing the
             // auo-completion pop-up list immediately again (important for defined names)
-            newText = Utils.replaceSubString(textAreaNode.val(), funcAutoTokenDesc.start + 1, funcAutoTokenDesc.end + 1, newText);
+            newText = Utils.replaceSubString(textAreaNode.val(), funcAutoTokenDesc.start + formulaOffset, funcAutoTokenDesc.end + formulaOffset, newText);
             setTextAreaContents(newText, { start: newStart, suppressAutoComplete: true });
             saveUndoState({ update: true });
         }
@@ -1215,7 +1124,7 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
 
             // ENTER without modifier keys (but ignoring SHIFT): set value, move cell down/up
             if (KeyCodes.matchKeyCode(event, 'ENTER', { shift: null })) {
-                if (self.leaveCellEditMode('cell', { validate: true })) {
+                if (self.leaveCellEditMode()) {
                     return; // let key event bubble up to move the cell cursor
                 }
                 return false;
@@ -1223,7 +1132,7 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
 
             // ENTER with CTRL or META key: fill value to all cells (no SHIFT), or insert matrix formula (SHIFT)
             if (KeyCodes.matchKeyCode(event, 'ENTER', { shift: null, ctrlOrMeta: true })) {
-                self.leaveCellEditMode(event.shiftKey ? 'matrix' : 'fill', { validate: true });
+                self.leaveCellEditMode(event.shiftKey ? 'matrix' : 'fill');
                 // do not let key event bubble up (no change of selection)
                 return false;
             }
@@ -1242,7 +1151,7 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
 
             // TAB key without modifier keys (but ignoring SHIFT): set value, move cell to next/previous cell
             if (KeyCodes.matchKeyCode(event, 'TAB', { shift: null })) {
-                if (self.leaveCellEditMode('cell', { validate: true })) {
+                if (self.leaveCellEditMode()) {
                     return; // let key event bubble up to move the cell cursor
                 }
                 return false;
@@ -1325,7 +1234,7 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
             self.executeDelayed(function () {
                 textSelection = Forms.getInputSelection(textAreaNode);
                 funcAutoComplete = textSelection.start === textSelection.end;
-            });
+            }, { infoString: 'CelleditMixin.textAreaInputHandler()', app: app });
 
             // forget last active cell range selected in the sheet (formulas with cell references)
             resetActiveCellSelection();
@@ -1341,7 +1250,7 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
                     var boundRange = Range.create(editAddress[0], Math.max(0, editAddress[1] - 256), editAddress[0], Math.min(docModel.getMaxRow(), editAddress[1] + 256));
                     var cellIt = cellCollection.createLinearAddressIterator(editAddress, 'up down', { type: 'value', boundRange: boundRange, skipStart: true });
                     IteratorUtils.forEach(cellIt, function (address) {
-                        var value = cellCollection.getCellValue(address);
+                        var value = cellCollection.getValue(address);
                         if ((typeof value === 'string') && (value.length > 0)) {
                             typeAheadEntries.push({ text: value, dist: Math.abs(editAddress[1] - address[1]) });
                         }
@@ -1417,14 +1326,14 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
                         self.executeDelayed(function () {
                             if (editActive && textAreaListMenu.hasFocus()) {
                                 ignoreFocusEvent = true;
-                                textAreaNode.focus();
+                                Utils.setFocus(textAreaNode);
                                 // IE sends focus event deferred
-                                self.executeDelayed(function () { ignoreFocusEvent = false; });
+                                self.executeDelayed(function () { ignoreFocusEvent = false; }, { infoString: 'CelleditMixin: updateTextAreaAfterSelection.editActive', app: app });
                             } else {
                                 textAreaContainer.removeClass(Forms.FOCUSED_CLASS);
                                 if (!stickyAutoComplete) { hideTextAreaPopups(); }
                             }
-                        });
+                        }, { infoString: 'CelleditMixin: textAreaFocusHandler.blur', app: app });
                         break;
                 }
             };
@@ -1623,19 +1532,24 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
             // (tool and tab) are visible, nor the editable cell. Root cause is the soft-keyboard.
             // However, scroll back to 0,0 and everything is fine. (Delay of 1000 necessary for iOS)
             if (Utils.TOUCHDEVICE) {
-                this.executeDelayed(function () { window.scrollTo(0, 0); }, 1000);
+                this.executeDelayed(function () { window.scrollTo(0, 0); }, { delay: 1000, infoString: 'CelleditMixin: enterCellEditMode:Touch', app: app });
             }
 
+            // bug 47129: wait for a running document action (e.g. change multiple cells very quickly)
+            var promise = docModel.waitForActionsProcessed();
+
             // the active cell must not be locked
-            return this.ensureUnlockedActiveCell({ lockTables: 'header' }).then(function () {
+            promise = promise.then(function () {
+                return self.ensureUnlockedActiveCell({ lockTables: 'header' });
+            });
+
+            // finally, start the cell edit mode
+            promise = promise.then(function () {
 
                 // initial state of quick edit mode and other settings
                 editActive = true;
                 setQuickEditMode(Utils.getBooleanOption(options, 'quick', false));
 
-                // TODO: matrix formula support
-                matrixFormula = false;
-
                 // type-ahead suggestions will be collected on first access
                 typeAheadEntries = null;
 
@@ -1659,7 +1573,7 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
                 editGridPane.on('change:scrollpos', gridPaneScrollHandler);
 
                 // get the formatted edit string
-                originalText = getTextForCellEditMode();
+                originalText = cellCollection.getEditString(editAddress);
                 textUnderlayNode.empty();
 
                 // set initial contents, position, size, and selection of the text area
@@ -1690,6 +1604,9 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
                 // notify listeners
                 self.trigger('celledit:enter');
             });
+
+            // show warning alert if necessary
+            return this.yellOnFailure(promise);
         };
 
         /**
@@ -1731,11 +1648,12 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
         };
 
         /**
-         * Leaves in-place cell edit mode, and optionally commits the current
-         * text. If the current text is a formula expression, it will be
-         * validated before committing.
+         * Leaves in-place cell edit mode, and commits the current text. If the
+         * current text is a formula expression, it will be validated before
+         * committing. If the formula syntax is invalid, a notification alert
+         * will be shown, and the cell edit mode will not be left.
          *
-         * @param {String} commitMode
+         * @param {String} [commitMode='cell']
          *  Specifies how to leave the cell edit mode. The following values are
          *  supported:
          *  - 'cell': The current value will be committed to the active cell of
@@ -1744,106 +1662,137 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
          *      selection.
          *  - 'matrix': The current value will be inserted as matrix formula
          *      into the selected cell range.
-         *  - 'auto': Preserves the current formula type of the cell: either
-         *      'cell' or 'matrix'.
-         *
-         * @param {Object} [options]
-         *  Optional parameters:
-         *  @param {Boolean} [options.validate=false]
-         *      If set to true, a formula expression will be velidated. If it
-         *      is invalid, a notification alert will be shown, and the cell
-         *      edit mode will not be left.
+         *  - 'force': Similar to 'cell', but does not remain in cell edit mode
+         *      if the formula expression is invalid. Instead, the edit text
+         *      will be ignored, and nothing will be changed in the edit cell.
          *
          * @returns {Boolean}
          *  Whether the cell edit mode has actually been left. Returns false,
-         *  if the option 'validate' have been set to true, and the current
-         *  formula expression is invalid.
+         *  if the current formula expression is invalid (and the commit mode
+         *  has NOT been set to 'force'), and thus the cell edit mode remains
+         *  active.
          */
-        this.leaveCellEditMode = function (commitMode, options) {
+        this.leaveCellEditMode = function (commitMode) {
+
+            // shows an alert notification, and keeps the cell edit mode activated
+            function keepEditMode(msgCode) {
+                self.yellMessage(msgCode);
+                setQuickEditMode(false);
+                return false;
+            }
 
             // nothing to do, if in-place edit mode is not active
             if (!editActive) { return true; }
 
-            // check validity of commit mode (e.g. disallow 'cell' in matrix formulas)
-            switch (commitMode) {
-                case 'cell':
-                case 'fill':
-                    if (matrixFormula) {
-                        // TODO: define behavior (update entire matrix automatically?)
-                        self.yellMessage('formula:matrix');
-                        setQuickEditMode(false);
-                        return false;
-                    }
-                    break;
-                case 'matrix':
-                    // TODO: check that selection matches range of matrix formula
-                    break;
-                case 'auto':
-                    commitMode = matrixFormula ? 'matrix' : 'cell';
-                    break;
-                default:
-                    Utils.error('CellEditMixin.leaveCellEditMode(): unknown commit mode: ' + commitMode);
-                    commitMode = null;
-            }
-
-            // do nothing else, if the document does not have edit rights anymore
-            if (!docModel.getEditMode() || !commitMode) {
+            // ignore edit mode, if the document does not have edit rights anymore
+            if (!docModel.getEditMode()) {
                 this.cancelCellEditMode();
                 return true;
             }
 
+            // default commit mode is 'cell' (change the active cell only)
+            commitMode = commitMode || 'cell';
+
+            // bounding range of an existing matrix formula covering the active cell
+            var matrixRange = cellCollection.getMatrixRange(editAddress);
+            // whether to update an existing matrix (prevent auto-expansion of 1x1 matrixes)
+            var updateMatrix = matrixRange !== null;
+            // fill the active range of the selection with a new matrix formula (ignore multi-selection)
+            if (!matrixRange) { matrixRange = this.getActiveRange(); }
+
             // the new cell text
             var editText = textAreaNode.val();
             // parse the entered text: convert to other data types, or interpret the formula
-            // TODO: get value/matrix result depending on commit mode
-            var contents = cellCollection.parseCellValue(editText, editAddress);
-            // whether to validate the formula
-            var validate = Utils.getBooleanOption(options, 'validate', false);
+            var contents = cellCollection.parseCellValue(editText, (commitMode === 'matrix') ? 'mat' : 'val', editAddress, matrixRange);
+            // whether to create a formula cell
+            var createFormula = contents.f && contents.result;
+            // whether the formula expression is invalid (do not create document operations)
+            var syntaxError = createFormula && (contents.result.type === 'error');
 
             // keep edit mode active, if an error has been found in the formula structure
-            if (validate && contents.result && (contents.result.type === 'error')) {
-                self.yellMessage('formula:invalid');
-                setQuickEditMode(false);
-                return false;
+            // (unless leaving the edit mode has been forced by caller)
+            if (syntaxError && (commitMode !== 'force')) { return keepEditMode('formula:invalid'); }
+
+            // if matrix edit mode has been left without a formula expression, behave like normal fill mode
+            if (!createFormula && (commitMode === 'matrix')) { commitMode = 'fill'; }
+
+            // special checks to keep the edit mode active, for different commit modes
+            switch (commitMode) {
+
+                // fail, if single-cell edit wants to change a matrix formula
+                case 'cell':
+                    if (updateMatrix && !matrixRange.single()) {
+                        return keepEditMode('formula:matrix:change');
+                    }
+                    break;
+
+                // fail, if fill mode wants to change parts of a matrix formula
+                case 'fill':
+                    if (cellCollection.rangesOverlapAnyMatrix(this.getSelectedRanges(), { partial: true })) {
+                        return keepEditMode('formula:matrix:change');
+                    }
+                    break;
+
+                // fail, if another matrix formula overlapping with the active cell would be changed
+                case 'matrix':
+                    if (!updateMatrix && cellCollection.rangesOverlapAnyMatrix(matrixRange, { partial: true })) {
+                        return keepEditMode('formula:matrix:change');
+                    }
+                    break;
             }
 
             // deinitialize cell edit mode
             this.cancelCellEditMode();
 
-            // add auto-wrapping attribute, if the text contains an explicit line break
-            if (editText.indexOf('\n') >= 0) {
+            // nothing more to do with formula syntax error or when editing a matrix, if leaving edit mode is forced
+            if ((commitMode === 'force') && (syntaxError || updateMatrix)) { return true; }
+
+            // add auto-wrapping attribute, if the text contains an explicit line break (except for formulas)
+            if (!contents.f && (editText.indexOf('\n') >= 0)) {
                 AttributeUtils.insertAttribute(editAttributeSet, 'cell', 'wrapText', true);
             }
 
-            // add hyperlink specific attributes
-            if (contents.url) {
-                AttributeUtils.insertAttribute(editAttributeSet, 'character', 'underline', true);
-                AttributeUtils.insertAttribute(editAttributeSet, 'character', 'color', docModel.createJSONColor(Color.HYPERLINK, 'text'));
-            }
+            // extract the hyperlink URL (will be generated separately to get an own undo action)
+            var url = contents.url;
+            delete contents.url;
 
             // performance: do not pass empty attributes object (prevent useless object processing)
             if (!_.isEmpty(editAttributeSet)) {
                 contents.a = contents.a ? docModel.extendAttributes(contents.a, editAttributeSet) : editAttributeSet;
             }
 
+            // do not commit anything if the document edit mode is gone
+            if (!docModel.getEditMode()) { return true; }
+
             // send current value to document model after returning to selection mode
-            switch (docModel.getEditMode() ? commitMode : 'discard') {
-                case 'cell':
-                    // single cell mode: do not send operations if text and formatting did not change
-                    if ((originalText !== editText) || contents.a) {
-                        this.setCellContents(contents);
-                    }
-                    break;
+            var promise = null;
+            switch (commitMode) {
                 case 'fill':
-                    // fill mode: always fill all cells in the selection
-                    this.fillRangeContents(contents);
+                    promise = this.fillRangeContents(contents);
                     break;
                 case 'matrix':
-                    // TODO: matrix formulas
-                    Utils.warn('CellEditMixin.leaveCellEditMode(): matrix formulas not implemented');
+                    promise = this.setMatrixContents(contents);
                     break;
+                default: // 'cell' and 'force'
+                    // single cell mode: do not send operations if neither text nor formatting changes
+                    // (especially: do not replace shared formula cell with simple formula cell)
+                    // (but allow to change a single-cell matrix formula to a simple cell formula)
+                    if ((originalText !== editText) || contents.a || updateMatrix) {
+                        commitMode = 'cell';
+                        promise = this.setCellContents(contents);
+                    }
             }
 
+            // create the hyperlink in a separate step, in order to get an own undo action
+            if (url && promise) {
+                promise.done(function () {
+                    self.insertHyperlink(url, { activeCell: commitMode === 'cell', createStyles: true });
+                });
+            }
+
+            // nothing to do (cell not changed): hide previously shown alert box (bug 47936)
+            if (!promise) { this.hideYell(); }
+
             return true;
         };
 
@@ -2001,7 +1950,7 @@ define('io.ox/office/spreadsheet/view/mixin/celleditmixin', [
             textAreaListItemToolTip.destroy();
 
             self = docModel = undoManager = fontCollection = null;
-            numberFormatter = formulaResource = formulaGrammar = formulaParser = null;
+            formulaResource = formulaGrammar = formulaParser = null;
             textAreaContainer = textAreaNode = textUnderlayNode = null;
             signatureToolTip = textAreaListMenu = textAreaListItemToolTip = null;
             undoStack = null;
