@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
@@ -17,14 +18,15 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
     'io.ox/office/tk/utils/tracking',
     'io.ox/office/drawinglayer/view/drawingframe',
     'io.ox/office/spreadsheet/utils/sheetutils',
-    'io.ox/office/spreadsheet/utils/paneutils'
+    'io.ox/office/spreadsheet/utils/paneutils',
+    'io.ox/core/tk/nodetouch' // activates $.enableTouch() function, not used otherwise (keep at end of list)
 ], function (Utils, Tracking, DrawingFrame, SheetUtils, PaneUtils) {
 
     'use strict';
 
-    var // convenience shortcuts
-        Address = SheetUtils.Address,
-        Range = SheetUtils.Range;
+    // convenience shortcuts
+    var Address = SheetUtils.Address;
+    var Range = SheetUtils.Range;
 
     // mix-in class GridTrackingMixin =========================================
 
@@ -44,6 +46,7 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
         var docView = this.getDocView();
         var docModel = docView.getDocModel();
 
+        var app = docModel.getApp();
         // the root node of all rendering layers
         var layerRootNode = this.getLayerRootNode();
 
@@ -1077,7 +1080,7 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
                             DrawingFrame.toggleTracking(drawingFrame, true);
                         }
 
-                        if (_.isNumber(shiftX) && _.isNumber(shiftY) && (shiftX !== 0) || (shiftY !== 0)) {
+                        if (_.isNumber(shiftX) && _.isNumber(shiftY) && ((shiftX !== 0) || (shiftY !== 0))) {
                             if (!doResize) {
                                 // moving the drawing(s)
                                 if (isMultiSelection) {
@@ -1209,6 +1212,155 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
             };
         }()); // end of drawingTrackingHandler() local scope
 
+        var pinchHandler = (function () {
+
+            var startDistance;
+            var transformScale;
+            var originX;
+            var originY;
+            var originOffsetX;
+            var originOffsetY;
+            var translateX;
+            var translateY;
+            var visibleRectangle;
+            var scrollArea;
+            var lastPhase;
+            var scale;
+
+            function minMaxTransformScale(scale) {
+                var currentZoomFactor = getZoom();
+                var zoomFactor = scale * currentZoomFactor;
+                zoomFactor = Utils.minMax(zoomFactor, SheetUtils.MIN_ZOOM, SheetUtils.MAX_ZOOM);
+                return zoomFactor / currentZoomFactor;
+            }
+
+            function roundTransformScale(scale) {
+                var currentZoomFactor = getZoom();
+                var zoomFactor = scale * currentZoomFactor;
+                zoomFactor = Utils.round(zoomFactor, 0.05);
+                return zoomFactor / currentZoomFactor;
+            }
+
+            function reset(scrollArea) {
+                Utils.setCssAttributeWithPrefixes(scrollArea, 'transform', '');
+                Utils.setCssAttributeWithPrefixes(scrollArea, 'transform-origin', '');
+
+                startDistance = null;
+                transformScale = null;
+                originX = null;
+                originY = null;
+                originOffsetX = null;
+                originOffsetY = null;
+                translateX = null;
+                translateY = null;
+                visibleRectangle = null;
+                scrollArea = null;
+                lastPhase = null;
+                scale = null;
+            }
+
+            function getZoom() {
+                return docView.getSheetViewAttribute('zoom');
+            }
+
+            function calcOffset(translate, scale, refSize, refMin) {
+                var newRefSize = refSize / scale;
+                var newRefMin = (refSize - newRefSize) * 0.5;
+                var offset = refMin + newRefMin - (translate * scale);
+                return offset;
+            }
+
+            return self.createDebouncedAnimationFrameMethod(function (phase, event, distance, midPoint) {
+                // workaround for IOS
+                if (phase === 'cancel' && lastPhase === 'move') { phase = 'end'; }
+
+                scrollArea = layerRootNode.parent();
+                lastPhase = phase;
+
+                switch (phase) {
+                    case 'start':
+                        event.preventDefault();
+                        startDistance = distance;
+                        originX = midPoint.x;
+                        originY = midPoint.y;
+
+                        var offset = scrollArea.offset();
+                        originOffsetX = originX - offset.left;
+                        originOffsetY = originY - offset.top;
+
+                        //default values, if no move event is triggered before end event
+                        translateX = 0;
+                        translateY = 0;
+                        transformScale = 1;
+
+                        visibleRectangle = docView.getActiveGridPane().getVisibleRectangle();
+
+                        break;
+                    case 'move':
+                        event.preventDefault();
+                        transformScale = distance / startDistance;
+                        transformScale = Utils.minMax(transformScale, 0.5, 2.0);
+                        transformScale = minMaxTransformScale(transformScale);
+                        translateX = midPoint.x - originX;
+                        translateY = midPoint.y - originY;
+                        break;
+                    case 'end':
+                        event.preventDefault();
+
+                        scale = roundTransformScale(transformScale);
+                        var zoom = getZoom();
+                        //round a second time because of imprecise float stuff
+                        var zoomFactor = Utils.round(scale * zoom, 0.05);
+
+                        if (zoomFactor < 0.1) {
+                            //should never be here :)
+                            Utils.error('pinch to zoom is broken scale: ' + scale + ' transformScale: ' + transformScale + ' zoom: ' + zoom);
+                            return;
+                        }
+
+                        var sheetModel = docView.getSheetModel();
+                        var colCollection = sheetModel.getColCollection();
+                        var rowCollection = sheetModel.getRowCollection();
+
+                        var attributes = {};
+
+                        var offsetX = calcOffset(translateX, scale, visibleRectangle.width, visibleRectangle.left);
+                        var offsetY = calcOffset(translateY, scale, visibleRectangle.height, visibleRectangle.top);
+
+                        attributes.anchorRight = colCollection.getScrollAnchorByOffset(offsetX, { pixel: true });
+                        attributes.anchorBottom = rowCollection.getScrollAnchorByOffset(offsetY, { pixel: true });
+                        attributes.zoom = zoomFactor;
+
+                        docView.setSheetViewAttributes(attributes);
+                        break;
+                    case 'cancel':
+
+                        break;
+                    default:
+                        break;
+                }
+            }, function () {
+                switch (lastPhase) {
+                    case 'start':
+                        Utils.setCssAttributeWithPrefixes(scrollArea, 'transform-origin', originOffsetX + 'px ' + originOffsetY + 'px');
+                        Utils.setCssAttributeWithPrefixes(scrollArea, 'transform', 'translate3d(0px, 0px, 0) scale(1)');
+                        break;
+                    case 'move':
+                        //if move phase comes to fast, start phase is skip, so we set origin always (because we use 3 event types in one event)
+                        Utils.setCssAttributeWithPrefixes(scrollArea, 'transform-origin', originOffsetX + 'px ' + originOffsetY + 'px');
+
+                        Utils.setCssAttributeWithPrefixes(scrollArea, 'transform', 'translate3d(' + translateX + 'px, ' + translateY + 'px, 0) scale(' + transformScale + ')');
+                        break;
+                    case 'end':
+                    case 'cancel':
+                        reset(scrollArea);
+                        break;
+                    default:
+                        break;
+                }
+            });
+        }());
+
         // --------------------------------------------------------------------
 
         /**
@@ -1318,7 +1470,7 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
             // Workaround for Firefox, it sends 'focusout' events after the old
             // selection DOM node that has been clicked is removed (the 'focusout'
             // event causes canceling the tracking sometimes).
-            self.executeDelayed(function () { self.grabFocus(); });
+            self.executeDelayed(function () { self.grabFocus(); }, { infoString: 'GridTrackingMixin: trackingStartHandler', app: app });
         }
 
         /**
@@ -1341,8 +1493,12 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
 
         layerRootNode.on('dblclick dragenter dragexit dragover dragleave', false);
 
+        layerRootNode.enableTouch({ pinchHandler: pinchHandler });
+
         // destroy all class members on destruction
         this.registerDestructor(function () {
+            layerRootNode.disableTouch();
+
             self = docModel = docView = layerRootNode = null;
         });
 
