@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -18,8 +19,9 @@ define('io.ox/office/spreadsheet/view/mixin/selectionmixin', [
     'io.ox/office/tk/utils/iteratorutils',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/utils/paneutils',
-    'io.ox/office/spreadsheet/utils/sheetselection'
-], function (Utils, KeyCodes, Forms, IteratorUtils, SheetUtils, PaneUtils, SheetSelection) {
+    'io.ox/office/spreadsheet/utils/sheetselection',
+    'io.ox/office/tk/utils/deferredutils'
+], function (Utils, KeyCodes, Forms, IteratorUtils, SheetUtils, PaneUtils, SheetSelection, DeferredUtils) {
 
     'use strict';
 
@@ -43,8 +45,8 @@ define('io.ox/office/spreadsheet/view/mixin/selectionmixin', [
         var self = this;
 
         // the spreadsheet document model
-        var docModel = this.getDocModel();
-
+        var docModel = this.getDocModel(),
+            app = docModel.getApp();
         // callback handlers to override cell selection behavior
         var getCellSelectionHandler = null;
         var setCellSelectionHandler = null;
@@ -778,7 +780,7 @@ define('io.ox/office/spreadsheet/view/mixin/selectionmixin', [
 
             // When traversing unlocked cells in a locked sheet, and the new cell is locked, the next unlocked
             // cell in the selection must be searched now.
-            if (unlockedCells && !cellCollection.getCellAttributeSet(address).cell.unlocked) {
+            if (unlockedCells && !cellCollection.getAttributeSet(address).cell.unlocked) {
 
                 // Use the cell collection to search for the next cell with unlocked flag.
                 var desc = cellCollection.findCellWithAttributes(selection.ranges, { cell: { unlocked: true } }, {
@@ -1052,7 +1054,7 @@ define('io.ox/office/spreadsheet/view/mixin/selectionmixin', [
                 if (Forms.containsFocus(appPaneNode)) { return $.when(); }
 
                 // the deferred object that will be resolved after the focus has returned into the application pane
-                var def = $.Deferred();
+                var def = DeferredUtils.createDeferred(app, 'SelectionMixin: listenToWithFocus');
 
                 // let the focus event bubble up, then resolve the deferred object
                 function focusHandler() {
@@ -1081,7 +1083,7 @@ define('io.ox/office/spreadsheet/view/mixin/selectionmixin', [
                 return waitForViewFocus().always(function () {
                     handler.apply(context, args);
                 });
-            });
+            }, { infoString: 'SelectionMixin: waitForViewFocus', app: app });
 
             // the actual listenToWithFocus() method
             function listenToWithFocus(source, type, handler) {
@@ -1179,7 +1181,7 @@ define('io.ox/office/spreadsheet/view/mixin/selectionmixin', [
 
             // create a new deferred object representing the custom selection mode
             customSelectionId = id;
-            customSelectionDef = $.Deferred();
+            customSelectionDef = DeferredUtils.createDeferred(app, 'SelectionMixin: enterCustomSelectionMode', 'background-proc');
 
             // set the initial selection
             this.setSheetViewAttribute('activeSelection', Utils.getObjectOption(options, 'selection', null));
@@ -1433,7 +1435,7 @@ define('io.ox/office/spreadsheet/view/mixin/selectionmixin', [
             if (!_.isFunction(setCellSelectionHandler) || (setCellSelectionHandler.call(this, selection) !== true)) {
 
                 // leave cell in-place edit mode before changing the selection
-                if (this.leaveCellEditMode('auto', { validate: true })) {
+                if (this.leaveCellEditMode()) {
                     setSheetSelection(selection);
                 }
             }
@@ -1665,9 +1667,7 @@ define('io.ox/office/spreadsheet/view/mixin/selectionmixin', [
         this.setDrawingSelection = function (positions) {
 
             // first, leave cell in-place edit mode
-            if (!this.leaveCellEditMode('auto', { validate: true })) {
-                return this;
-            }
+            if (!this.leaveCellEditMode()) { return this; }
 
             // the current selection to be modified (keep cell selection as it is)
             var selection = this.getSelection();
@@ -1698,9 +1698,7 @@ define('io.ox/office/spreadsheet/view/mixin/selectionmixin', [
         this.selectDrawing = function (position, options) {
 
             // first, leave cell in-place edit mode
-            if (!this.leaveCellEditMode('auto', { validate: true })) {
-                return this;
-            }
+            if (!this.leaveCellEditMode()) { return this; }
 
             // the current selection to be modified (keep cell selection as it is)
             var selection = this.getSelection();
