@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -36,8 +37,8 @@ define('io.ox/office/spreadsheet/view/popup/validationlistmenu', [
      */
     function ValidationListMenu(docView) {
 
-        var // self reference
-            self = this;
+        // self reference
+        var self = this;
 
         // base constructor ---------------------------------------------------
 
@@ -90,8 +91,7 @@ define('io.ox/office/spreadsheet/view/popup/validationlistmenu', [
             // insert the data into the list
             this.clearContents();
             contentsList.forEach(function (entry) {
-                var display = _.isString(entry.display) ? entry.display : '#######';
-                this.createItemNode(entry, { label: _.noI18n(display) });
+                this.createItemNode(entry, { label: _.noI18n(entry.display) });
             }, this);
             return $.when();
         };
