@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -15,7 +16,7 @@ define('io.ox/office/spreadsheet/view/render/drawingrenderer', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/forms',
     'io.ox/office/tk/utils/iteratorutils',
-    'io.ox/office/tk/utils/simplemap',
+    'io.ox/office/tk/container/simplemap',
     'io.ox/office/tk/object/triggerobject',
     'io.ox/office/tk/object/timermixin',
     'io.ox/office/drawinglayer/view/drawingframe',
@@ -43,9 +44,10 @@ define('io.ox/office/spreadsheet/view/render/drawingrenderer', [
         // self reference
         var self = this;
 
-        // the spreadsheet model and view
+        // the spreadsheet model, view and app
         var docView = gridPane.getDocView();
         var docModel = docView.getDocModel();
+        var app = docView.getApp();
 
         // the layer node containing all drawing frames
         var drawingLayerNode = gridPane.createLayerNode('drawing-layer');
@@ -139,7 +141,7 @@ define('io.ox/office/spreadsheet/view/render/drawingrenderer', [
                 // remove processed drawing models from the 'pendingModelMap' object
                 pendingModelMap.remove(result.key);
 
-            }, { delay: _.isNumber(refreshDelay) ? refreshDelay : 200, interval: 200 });
+            }, { delay: _.isNumber(refreshDelay) ? refreshDelay : 200, interval: 200, infoString: 'DrawingRenderer.refreshDrawingFramesDelayed()', app: app });
 
             // try to restart the timer in case new dirty objects have been registered in the meantime
             refreshTimer.done(function () {
@@ -393,6 +395,10 @@ define('io.ox/office/spreadsheet/view/render/drawingrenderer', [
             return drawingFrame || $();
         };
 
+        this.getRendererPromise = function () {
+            return refreshTimer;
+        };
+
         // initialization -----------------------------------------------------
 
         // update grid pane when document edit mode changes
@@ -409,8 +415,8 @@ define('io.ox/office/spreadsheet/view/render/drawingrenderer', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            docView.getApp().destroyImageNodes(drawingLayerNode);
-            self = gridPane = docModel = docView = null;
+            app.destroyImageNodes(drawingLayerNode);
+            self = gridPane = docModel = docView = app = null;
             drawingLayerNode = drawingFrameMap = pendingModelMap = refreshTimer = null;
         });
 
