@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
@@ -46,9 +47,10 @@ define('io.ox/office/spreadsheet/view/render/highlightrenderer', [
         var // self reference
             self = this,
 
-            // the spreadsheet model and view
+            // the spreadsheet model, view and app
             docView = gridPane.getDocView(),
             docModel = docView.getDocModel(),
+            app = docView.getApp(),
 
             // the range highlight layer (container for the highlighted ranges of formulas)
             highlightLayerNode = gridPane.createLayerNode('highlight-layer'),
@@ -170,7 +172,7 @@ define('io.ox/office/spreadsheet/view/render/highlightrenderer', [
                 if (!animationTimer) {
                     animationTimer = self.repeatDelayed(function (index) {
                         activeRangeLayerNode.attr('data-frame', index % 6);
-                    }, 100);
+                    }, { delay: 100, infoString: 'HighlightRenderer: renderActiveSelection', app: app, priority: 'background-proc' });
                 }
             } else if (animationTimer) {
                 animationTimer.abort();
