@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -14,7 +15,7 @@
 define('io.ox/office/spreadsheet/view/render/rendercache', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/iteratorutils',
-    'io.ox/office/tk/utils/simplemap',
+    'io.ox/office/tk/container/simplemap',
     'io.ox/office/tk/object/triggerobject',
     'io.ox/office/tk/object/timermixin',
     'io.ox/office/spreadsheet/utils/sheetutils',
@@ -66,6 +67,9 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
         // the spreadsheet model and its containers
         var docModel = docView.getDocModel();
 
+        // the spreadsheet app
+        var app = docView.getApp();
+
         // the cache for all auto style descriptors
         var styleCache = new AutoStyleCache(docView);
 
@@ -93,6 +97,12 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
         // all pending cell ranges to be updated in the rendering matrix
         var dirtyRanges = new RangeArray();
 
+        // all pending cell ranges currently updated in an asynchronous loop
+        var pendingRanges = new RangeArray();
+
+        // timer for the current asynchronous update cycle
+        var updateTimer = null;
+
         // special behavior for ODF files
         var odf = docModel.getApp().isODF();
 
@@ -466,6 +476,13 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
             });
         }
 
+        function abortUpdateCycle() {
+            if (updateTimer) {
+                updateTimer.abort();
+                updateTimer = null;
+            }
+        }
+
         /**
          * Registers the specified cell ranges as 'dirty', which will include
          * them in the next update cycle.
@@ -482,7 +499,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
             }
 
             // deferred callback: updates all dirty cell elements in the rendering matrix
-            var updateMatrix = RenderUtils.profileMethod('RenderCache.registerDirtyRanges(): (2) update rendering matrix', function () {
+            var updateMatrix = RenderUtils.profileAsyncMethod('RenderCache.registerDirtyRanges(): (2) update rendering matrix', function () {
 
                 // the model of the active sheet
                 var sheetModel = docView.getSheetModel();
@@ -520,7 +537,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                     // explicit attributes of conditional formatting to be rendered over the auto-style of the cell
                     var attributeSet = condFormatResult ? condFormatResult.attributeSet : null;
                     // an alternative auto-style identifier for outer borders in merged ranges (use current address not shifted to merged origin!)
-                    var borderStyleId = (!expandMergedBorders && element.isMergedBorder()) ? cellCollection.getCellStyleId(element.address) : null;
+                    var borderStyleId = (!expandMergedBorders && element.isMergedBorder()) ? cellCollection.getStyleId(element.address) : null;
                     // the auto-style identifier of the source cell (resolve default style for undefined cells with conditional formatting)
                     var styleId = (baseStyleId !== null) ? baseStyleId : (attributeSet || _.isString(borderStyleId)) ? cellCollection.getDefaultStyleId(address) : null;
                     // the rendering style descriptor; or null for undefined cells without any special settings
@@ -563,11 +580,11 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                     if (!address) { return null; }
 
                     // skip non-text cells
-                    var value = cellCollection.getCellValue(address);
+                    var value = cellCollection.getValue(address);
                     if (typeof value !== 'string') { return null; }
 
                     // skip existing cells without overflowing text
-                    var attrSet = cellCollection.getCellAttributeSet(address);
+                    var attrSet = cellCollection.getAttributeSet(address);
                     return SheetUtils.hasWrappingAttributes(attrSet) ? null : address;
                 }
 
@@ -611,20 +628,34 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                     updateRanges.push(overflowRange);
                 }
 
+                // abort the current asynchronous update cycle (this restores 'dirtyRanges' and 'pendingRanges')
+                abortUpdateCycle();
+
+                // copy of the dirty ranges, for asynchronous registration of new dirty ranges, timer abort, etc.
+                pendingRanges = dirtyRanges.merge();
+                dirtyRanges.clear();
+
                 // reduce update ranges to bounding row intervals (but do not reduce to bounding
                 // column intervals, original ranges are needed for updating overflowing text cells)
-                dirtyRanges = dirtyRanges.merge();
                 rowHeader.intervals.forEach(function (interval) {
-                    updateRanges.append(dirtyRanges.intersect(docModel.makeRowRange(interval)));
+                    updateRanges.append(pendingRanges.intersect(docModel.makeRowRange(interval)));
                 });
 
                 // merge the ranges to be updated, and shrink them to visible areas
                 updateRanges = sheetModel.mergeAndShrinkRanges(updateRanges);
                 RenderUtils.withLogging(function () { RenderUtils.log('update ranges: ' + updateRanges); });
 
-                // update all existing matrix elements
-                var outerMergeDescs = RenderUtils.takeTime('update matrix elements', function () {
+                // collect all existing matrix elements
+                var updateElements = [];
+                var outerMergeDescs = RenderUtils.takeTime('collect matrix elements', function () {
                     return iterateCellsInRanges(updateRanges, function (element) {
+                        updateElements.push(element);
+                    });
+                });
+
+                // update all existing matrix elements
+                updateTimer = RenderUtils.takeAsyncTime('update matrix elements', function () {
+                    return self.iterateArraySliced(updateElements, function (element) {
 
                         // whether the cell element was blank before
                         var oldBlank = element.blank;
@@ -660,18 +691,18 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                         if (oldBlank !== newBlank) {
                             neighborElementMap.insert(element.key, element);
                         }
-                    });
+                    }, { delay: 'immediate', infoString: 'Rendercache.updatetimer 1', app: app });
                 });
 
                 // update origin cells of outer merged ranges overlapping the dirty ranges
-                RenderUtils.takeTime('update origins of merged range', function () {
-                    outerMergeDescs.forEach(function (mergeDesc) {
+                updateTimer = updateTimer.then(RenderUtils.profileAsyncMethod('update origins of merged range', function () {
+                    return self.iterateArraySliced(outerMergeDescs, function (mergeDesc) {
                         updateCellElement(mergeDesc.element);
-                    });
-                });
+                    }, { delay: 'immediate', infoString: 'Rendercache.updatetimer 2', app: app });
+                }));
 
                 // update clipping rectangles of cells with overflowing text (restrict to content cells and merged ranges)
-                RenderUtils.takeTime('update text clipping rectangles', function () {
+                updateTimer = updateTimer.then(RenderUtils.profileAsyncMethod('update text clipping rectangles', function () {
 
                     // find adjacent cells with overflowing text (left/right of changed cells)
                     neighborElementMap.forEach(function (element) {
@@ -680,7 +711,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                     });
 
                     // update clipping rectangles of all registered cells
-                    overflowElementMap.forEach(function (overflowEntry) {
+                    return self.iterateSliced(overflowElementMap.iterator(), function (overflowEntry) {
 
                         // the matrix cell element to be updated
                         var element = overflowEntry.element;
@@ -729,16 +760,26 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                         if (overflowL || overflowR) {
                             addOverflowRange(element.address, overflowL, overflowR);
                         }
-                    });
-                });
-
-                // reset settings for dirty ranges for next update cycle
-                dirtyRanges.clear();
+                    }, { delay: 'immediate', infoString: 'Rendercache.updatetimer 3', app: app });
+                }));
 
                 // notify rendering listeners
-                if (!updateRanges.empty()) {
-                    self.trigger('update:matrix', updateRanges);
-                }
+                updateTimer.done(function () {
+                    pendingRanges.clear();
+                    if (!updateRanges.empty()) {
+                        self.trigger('update:matrix', updateRanges.merge());
+                    }
+                });
+
+                // restore dirty ranges, if the update cycle will be aborted
+                updateTimer.fail(function (cause) {
+                    if (cause === 'abort') {
+                        dirtyRanges.append(pendingRanges);
+                        pendingRanges.clear();
+                    }
+                });
+
+                return updateTimer; // needed by Logger.profileAsyncMethod()
             });
 
             // the actual method RenderCache.registerDirtyRanges() to be returned from the local scope
@@ -1019,7 +1060,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
          *  overlapping with the passed cell range.
          */
         this.hasDirtyRanges = function (range) {
-            return dirtyRanges.overlaps(range);
+            return dirtyRanges.overlaps(range) || pendingRanges.overlaps(range);
         };
 
         /**
@@ -1096,7 +1137,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
             rowHeader.intervals = rowCollection.mergeAndShrinkIntervals(rowHeader.boundaries.pluck('interval'));
 
             // calculate the new bounding ranges for all combinations of column/row intervals
-            _.each(PaneUtils.ALL_PANE_POSITIONS, function (panePos) {
+            PaneUtils.ALL_PANE_POSITIONS.forEach(function (panePos) {
 
                 // column/row side identifier
                 var colPaneSide = PaneUtils.getColPaneSide(panePos);
@@ -1154,6 +1195,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
 
             } else {
                 // no more bounding ranges available: reset all pending dirty ranges immediately
+                abortUpdateCycle();
                 mergedRangeSet.clear();
                 dirtyRanges.clear();
             }
@@ -1179,7 +1221,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
         // destroy all class members on destruction
         this.registerDestructor(function () {
             styleCache.destroy();
-            self = docView = docModel = null;
+            self = docView = docModel = app = null;
             styleCache = cellMatrix = colHeader = rowHeader = null;
             boundaryMap = boundRanges = totalRange = null;
             mergedRangeSet = dirtyRanges = null;
