@@ -6,21 +6,22 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/spreadsheet/view/render/renderutils', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/simplemap',
-    'io.ox/office/tk/utils/sortedarray',
     'io.ox/office/tk/utils/logger',
+    'io.ox/office/tk/container/simplemap',
+    'io.ox/office/tk/container/sortedarray',
     'io.ox/office/tk/render/path',
     'io.ox/office/editframework/utils/color',
     'io.ox/office/editframework/utils/border',
     'io.ox/office/spreadsheet/utils/sheetutils'
-], function (Utils, SimpleMap, SortedArray, Logger, Path, Color, Border, SheetUtils) {
+], function (Utils, Logger, SimpleMap, SortedArray, Path, Color, Border, SheetUtils) {
 
     'use strict';
 
@@ -298,7 +299,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         });
 
         // scaled font attributes according to current sheet zoom factor
-        this.font = docModel.getFontCollection().getFont(charAttrs, sheetZoom);
+        this.font = docModel.getFontCollection().getFont(charAttrs, { zoom: sheetZoom });
 
         // scaled height of a single text line, in pixels (effective height of an empty cell)
         this.rowHeight = docModel.getRowHeight(charAttrs, sheetZoom);
@@ -811,6 +812,9 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
      * @property {MatrixCellElement|Null} b
      *  The next cell element below in the rendering matrix.
      *
+     * @property {CellModel|Null} model
+     *  The model of the cell covered by this matrix element.
+     *
      * @property {Boolean} blank
      *  Whether the cell represented by this matrix element is blank. Will only
      *  be true for undefined or blank cells, but not for non-blank cells
@@ -867,14 +871,17 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         this.t = t;
         this.b = b;
 
-        // the blank cell flag
+        // the cell model, and the blank cell flag
+        this.model = null;
         this.blank = true;
 
         // descriptor of the merged range containing this cell (instance of MergeDescriptor)
         this.merged = null;
 
-        // text descriptor, and other rendering properties
+        // text descriptor
         this.text = null;
+
+        // other rendering properties
         this.renderProps = null;
 
         // update the references in the header elements
@@ -934,7 +941,8 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         // update background/border formatting
         MatrixElement.prototype.update.call(this, styleDesc, skipBorders);
 
-        // set the blank cell flag
+        // set the cell model, and the blank cell flag
+        this.model = cellModel;
         this.blank = !cellModel || cellModel.isBlank();
 
         // ensure that the merge descriptor refers to the correct matrix element; it may change e.g. when the
@@ -954,10 +962,10 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         this.renderProps = renderProps;
 
         // Do not render cells covered by merged ranges, or undefined cells (missing cell model). Conditional
-        // formatting data bars may specify to hide the cell display text. Reformat the display string, if the
-        // number format of the auto-style has been overridden (e.g. via conditional formatting).
+        // formatting (data bars or icon sets) may specify to hide the cell display text. Reformat the display
+        // string, if the number format of the auto-style has been overridden (e.g. via conditional formatting).
         var display = null;
-        if (covered || !cellModel || cellModel.isBlank() || (renderProps && renderProps.dataBar && !renderProps.dataBar.showValue)) {
+        if (covered || this.blank || (renderProps && (renderProps.showValue === false))) {
             display = '';
         } else if (styleDesc && styleDesc.formatChanged) {
             display = numberFormatter.formatValue(styleDesc.format, cellModel.v);
@@ -986,13 +994,14 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         // effective text orientation (alignment and writing direction)
         var textOrient = SheetUtils.getTextOrientation(cellModel.v, attributes.cell.alignHor, display);
         // the inner horizontal padding for text in cells (according to current zoom)
-        var textPadding = sheetModel.getEffectiveTextPadding();
+        var paddingLeft = (renderProps && renderProps.iconSet) ? rowHeight : sheetModel.getEffectiveTextPadding();
+        var paddingRight = sheetModel.getEffectiveTextPadding();
         // the available width for the cell text (without left/right padding)
-        var availableWidth = Math.max(2, innerRect.width - 2 * textPadding);
+        var availableWidth = Math.max(2, innerRect.width - paddingLeft - paddingRight);
         // resolved and scaled font settings
         var font = styleDesc.font;
         // the effective number format section, according to cell value (treat booleans like strings)
-        var section = styleDesc.format.getSection(_.isBoolean(cellModel.v) ? '' : cellModel.v);
+        var section = styleDesc.format.getSection(cellModel.isBoolean() ? '' : cellModel.v);
         // position of the font base line in the text lines (according to effective row height)
         var baseLineOffset = font.getBaseLineOffset(rowHeight);
         // resulting width of text contents (maximum width of text lines)
@@ -1060,19 +1069,17 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
                 // calculate width of the text that overflows from the cell (merged ranges always clip at cell boundaries)
                 if (!this.merged && (availableWidth < totalWidth)) {
 
-                    // the total size of the text that overflows from the cell
-                    var overflowWidth = Math.ceil(totalWidth + textPadding - innerRect.width);
-
                     // store width of text overflowing from the cell area, according to alignment
                     switch (textOrient.baseBoxAlign) {
                         case 'left':
-                            overflowR = overflowWidth;
+                            overflowR = Math.ceil(paddingLeft + totalWidth - innerRect.width);
                             break;
                         case 'center':
-                            overflowL = overflowR = Math.ceil(overflowWidth / 2);
+                            overflowL = Math.max(0, Math.ceil((totalWidth - innerRect.width - paddingLeft + paddingRight) / 2));
+                            overflowR = Math.max(0, Math.ceil((totalWidth - innerRect.width + paddingLeft - paddingRight) / 2));
                             break;
                         case 'right':
-                            overflowL = overflowWidth;
+                            overflowL = Math.ceil(totalWidth + paddingRight - innerRect.width);
                             break;
                     }
                 }
@@ -1089,7 +1096,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
             if (display && section && (section.category === 'standard') && cellModel.isNumber()) {
 
                 // number formatter returns null, if no valid display string can be found for the available width (e.g. cell too narrow)
-                var formatResult = numberFormatter.formatStandardNumberToWidth(cellModel.v, SheetUtils.MAX_LENGTH_STANDARD_CELL, font, availableWidth);
+                var formatResult = numberFormatter.formatStandardNumberToWidth(cellModel.v, SheetUtils.MAX_LENGTH_STANDARD_CELL, font, availableWidth + 1);
 
                 // store the new display string, and the resulting text width
                 display = formatResult ? formatResult.text : null;
@@ -1155,14 +1162,14 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
             // calculate horizontal text position according to alignment
             switch (textOrient.baseBoxAlign) {
                 case 'center':
-                    lineDesc.x = innerRect.left + (innerRect.width - lineDesc.width) / 2;
+                    lineDesc.x = innerRect.left + paddingLeft + (availableWidth - lineDesc.width) / 2;
                     break;
                 case 'right':
-                    lineDesc.x = innerRect.left + innerRect.width - textPadding - lineDesc.width;
+                    lineDesc.x = innerRect.left + innerRect.width - paddingRight - lineDesc.width;
                     break;
                 default:
                     // left alignment, and fall-back for unknown alignments
-                    lineDesc.x = innerRect.left + textPadding;
+                    lineDesc.x = innerRect.left + paddingLeft;
             }
 
             // calculate vertical text position
