@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
@@ -27,15 +28,15 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
     // convenience shortcuts
     var Range = SheetUtils.Range;
 
-    // FIX the IE/EDGE render bug. Bug 41205 - (EDGE) - last row - navigate via tab key:=> rendering problem
-    var ie_spreadsheet_render_helper = $('<div id="ie_spreadsheet_render_helper" style="position: absolute">');
+    // bug 41205: IE/Edge: navigating via tab key in last row results in rendering errors
+    var renderHelperNode = $('<div id="io-ox-office-spreadsheet-ie-render-helper" style="position:absolute;">');
 
     // private global functions ===============================================
 
-    var setIERenderHelper = _.browser.IE ? function () {
-        ie_spreadsheet_render_helper.remove();
+    var setIERenderHelperNode = _.browser.IE ? function () {
+        renderHelperNode.remove();
         window.setTimeout(function () {
-            $('body').append(ie_spreadsheet_render_helper);
+            $('body').append(renderHelperNode);
         }, 20);
     } : _.noop;
 
@@ -82,7 +83,7 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
         // private methods ----------------------------------------------------
 
         //Debounced version of the method renderCellSelection().
-        var renderCellSelectionDebounced = this.createDebouncedMethod($.noop, renderCellSelection, { delay: 100 });
+        var renderCellSelectionDebounced = this.createDebouncedMethod($.noop, renderCellSelection, { delay: 100, infoString: 'SelectionRenderer: renderCellCollection', app: docView.getApp() });
 
         /**
          * Updates the position of the auto-fill handle and the resize handles
@@ -316,12 +317,11 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
             // update the visibility/position of additional DOM elements
             updateResizeHandlePositions();
 
+            // bug 41205: IE/Edge: navigating via tab key in last row results in rendering errors
+            setIERenderHelperNode();
+
             // notify listeners for additional rendering depending on the selection
             self.trigger('render:cellselection');
-
-            setIERenderHelper();
-
-            renderRemoteSelections();
         }
 
         /**
@@ -347,7 +347,7 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
             selectedDrawings.forEach(function (drawingPos) {
                 var drawingFrame = gridPane.getDrawingFrame(drawingPos);
                 drawingFrame.removeClass('remoteselection badge-inside');
-                drawingFrame.attr('data-username', null);
+                drawingFrame.removeAttr('data-username');
             });
             selectedDrawings = [];
 
@@ -386,7 +386,7 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
 
                             drawingFrame.addClass('remoteselection badge-inside');
 
-                            drawingFrame.attr('data-username', userName);
+                            drawingFrame.attr('data-username', _.noI18n(client.userName));
                             drawingFrame.attr('data-style', client.colorIndex);
                             selectedDrawings.push(drawingPos);
                         }
@@ -410,10 +410,10 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
                     }, { alignToGrid: true });
                 }
             });
-            if (remoteLayerNode[0].innerHTML !== markup) {
-                // insert entire HTML mark-up into the container node
-                remoteLayerNode[0].innerHTML = markup;
-            }
+
+            // insert entire HTML mark-up into the container node
+            remoteLayerNode[0].innerHTML = markup;
+
         } : $.noop;
 
         /**
@@ -479,7 +479,7 @@ define('io.ox/office/spreadsheet/view/render/selectionrenderer', [
         gridPane.listenToWhenVisible(this, docView, 'insert:merged delete:merged', renderCellSelectionDebounced);
 
         // update layers according to changed view attributes (only, if this grid pane is visible)
-        gridPane.listenToWhenVisible(this, docModel, 'change:viewattributes', changeViewAttributesHandler);
+        gridPane.listenToWhenVisible(this, docView, 'change:viewattributes', changeViewAttributesHandler);
         gridPane.listenToWhenVisible(this, docView, 'change:sheet:viewattributes', changeSheetViewAttributesHandler);
 
         // post-processing after scrolling, or after selection has been rendered
