@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -53,9 +54,7 @@ define('io.ox/office/spreadsheet/view/statuspane', [
             moreMenuGroup = null,
 
             // label control for the formula in the active cell
-            formulaLabel = null,
-            // old visible boolean for hiding this bar when soft keyboard is open on Android devices
-            visibleOverwrite = null;
+            formulaLabel = null;
 
         // base constructor ---------------------------------------------------
 
@@ -164,7 +163,7 @@ define('io.ox/office/spreadsheet/view/statuspane', [
         this.addViewComponent(new ToolBar(docView, { autoHideGroups: true })
             .addGroup('view/status', new Controls.DynamicLabel())
             .addGroup('view/subtotals/type', new Controls.SubtotalList(docView))
-            .addGroup('view/formula', formulaLabel = new Controls.DynamicLabel({ classes: 'formula-text', setToolTip: true })),
+            .addGroup('view/formula', formulaLabel = new Controls.FormulaLabel()),
         { targetArea: 'trailing' });
 
         // refresh sheet tool bar after sheet tabs have been inserted, deleted, or changed
@@ -179,19 +178,24 @@ define('io.ox/office/spreadsheet/view/statuspane', [
             //when the soft keyboard on Android devices pops up, the status bar stays over the keyboard
             //this makes no sense and looks ugly, so we detect the open keyboard and hide the status pane
             app.registerWindowResizeHandler(function () {
-                var softKeyboard = Utils.isSoftKeyboardOpen();
-                if (softKeyboard) {
-                    if (visibleOverwrite === null && self.isVisible()) {
-                        visibleOverwrite = true;
-                        self.hide();
+                // old visible boolean for hiding this bar when soft keyboard is open on Android devices
+                var visibleOverwrite = null;
+
+                return function () {
+                    var softKeyboard = Utils.isSoftKeyboardOpen();
+                    if (softKeyboard) {
+                        if (visibleOverwrite === null && self.isVisible()) {
+                            visibleOverwrite = true;
+                            self.hide();
+                        }
+                    } else {
+                        if (visibleOverwrite !== null) {
+                            self.toggle(visibleOverwrite);
+                        }
+                        visibleOverwrite = null;
                     }
-                } else {
-                    if (visibleOverwrite !== null) {
-                        self.toggle(visibleOverwrite);
-                    }
-                    visibleOverwrite = null;
-                }
-            });
+                };
+            }());
         }
 
         if (_.browser.iOS) {
