@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  * @author Malte Timmermann <malte.timmermann@open-xchange.com>
@@ -24,7 +25,6 @@ define('io.ox/office/text/app/application', [
     'io.ox/office/baseframework/utils/errorcode',
     'io.ox/office/baseframework/utils/errorcontext',
     'io.ox/office/baseframework/utils/errormessages',
-    'io.ox/office/baseframework/view/baselabels',
 
     'io.ox/office/editframework/app/editapplication',
     'io.ox/office/editframework/utils/attributeutils',
@@ -36,10 +36,11 @@ define('io.ox/office/text/app/application', [
     'io.ox/office/text/model/model',
     'io.ox/office/text/view/view',
     'io.ox/office/text/app/controller',
+    'io.ox/office/tk/utils/deferredutils',
 
     'gettext!io.ox/office/text/main'
 
-], function (ConverterUtils, Inline, Utils, DriveUtils, ErrorCode, ErrorContext, ErrorMessages, BaseLabels, EditApplication, AttributeUtils, DOM, Export, TextConfig, TextModel, TextView, TextController, gt) {
+], function (ConverterUtils, Inline, Utils, DriveUtils, ErrorCode, ErrorContext, ErrorMessages, EditApplication, AttributeUtils, DOM, Export, TextConfig, TextModel, TextView, TextController, DeferredUtils, gt) {
 
     'use strict';
 
@@ -171,6 +172,7 @@ define('io.ox/office/text/app/application', [
             operationFilter: operationFilter,
             importFailedHandler: importFailedHandler,
             prepareFlushHandler: prepareFlushDocument,
+            newDocumentInitHandler: newDocumentInitHandler,
             sendActionsDelay: 1000,
             isMultiSelectionApp: false,
             localStorageApp: true,
@@ -349,7 +351,7 @@ define('io.ox/office/text/app/application', [
                             img.src = InlineApi.getInsertedImageUrl(response);
                         });
                     }
-                });
+                }, { infoString: 'Application: sanitizeBase64ImageUrlsDeferred', app: self });
 
             return promise.then(function () {
 
@@ -365,12 +367,9 @@ define('io.ox/office/text/app/application', [
          *
          */
         function createPdfMailAttachment() {
-            var
-              //fileName = self.getFullFileName() + '.pdf',
-                fileName = self.getFullFileName(),
-
-                len     = fileName.length,
-                idx     = fileName.lastIndexOf('.');
+            var fileName = self.getFullFileName();
+            var len      = fileName.length;
+            var idx      = fileName.lastIndexOf('.');
 
             fileName = fileName.substring(0, ((idx >= 0) ? idx : len)) + '.pdf';
 
@@ -390,7 +389,7 @@ define('io.ox/office/text/app/application', [
 
             deferred.then(function (data) {
                 var
-                    interceptor = $.Deferred();
+                    interceptor = DeferredUtils.createDeferred(self, 'Applictation: createPdfMailAttachment');
 
                 if ('cause' in data) {
 
@@ -461,6 +460,13 @@ define('io.ox/office/text/app/application', [
             });
         }
 
+        /**
+         * Handler which called if a new document is initialized.
+         */
+        function newDocumentInitHandler() {
+            self.getModel().setDefaultPaperFormat();
+        }
+
         // public methods -----------------------------------------------------
 
         /**
@@ -501,9 +507,9 @@ define('io.ox/office/text/app/application', [
          *  an own model mixin ... maybe something like `sendAsMailMixin` that
          *  should reside in >> /ui/apps/io.ox/office/text/model/ << .
          */
-        // register the 'inline-html-document' converter.
-        this.registerConverter('pdf-mail-attachment', createPdfMailAttachment);
-        this.registerConverter('inline-html-document', createInlineHtmlDocument);
+        // register the 'inline-html' converter.
+        this.registerConverter('pdf-attachment', createPdfMailAttachment);
+        this.registerConverter('inline-html', createInlineHtmlDocument);
 
     } }); // class TextApplication
 
