@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -41,15 +42,23 @@ define('io.ox/office/text/app/controller', [
      */
     function TextController(app, docModel, docView) {
 
-        var // self reference
-            self = this;
+        // self reference
+        var self = this;
 
         // base constructor ---------------------------------------------------
 
-        EditController.call(this, app, docModel, docView, { updateDelay: 200 });
+        EditController.call(this, app, docModel, docView, searchHandler, { updateDelay: 200 });
 
         // private methods ----------------------------------------------------
 
+        /**
+         * Executes a search/replace operation, as requested by the base class
+         * EditController.
+         */
+        function searchHandler(command, settings) {
+            return docModel.getSearchHandler().executeCommand(command, settings);
+        }
+
         /**
          * Item getter function for a list style identifier. Will be called in
          * the context of a controller item instance.
@@ -137,11 +146,13 @@ define('io.ox/office/text/app/controller', [
         // initialization -----------------------------------------------------
 
         if (_.browser.Android) {
-            var originalUpdate = self.update;
+            var originalUpdate = _.wrap(self.update, function (update) {
+                return update.call(self);
+            });
 
             self.update = function () {
                 if (docModel.isAndroidTyping()) {
-                    self.executeDelayed(self.update, 1000, 'Text: android: update');
+                    self.executeDelayed(self.update, { delay: 1000, infoString: 'Text: android: update', app: app });
                 } else {
                     originalUpdate();
                 }
@@ -177,6 +188,11 @@ define('io.ox/office/text/app/controller', [
                 set: function (zoomType) { docView.setZoomType(zoomType); }
             },
 
+            'document/text': {
+                parent: 'app/valid',
+                enable: function () { return docModel.isTextSelected() || docModel.getSelection().isAnyTextFrameDrawingSelection(); }
+            },
+
             'document/editable/text': {
                 parent: 'document/editable',
                 enable: function () { return docModel.isTextSelected() || docModel.getSelection().isAnyTextFrameDrawingSelection(); }
@@ -363,7 +379,7 @@ define('io.ox/office/text/app/controller', [
                 parent: 'paragraph/attributes',
                 get: function (attributes) { return MixedBorder.getBorderMode(attributes, { paragraph: true }); },
                 set: function (borderMode) {
-                    var borderAttrs = MixedBorder.getBorderAttributes(borderMode, this.getParentValue(), ParagraphStyles.SINGLE_BORDER, { paragraph: true });
+                    var borderAttrs = MixedBorder.getBorderAttributes(borderMode, this.getParentValue(), ParagraphStyles.SINGLE_BORDER, { paragraph: true, clearBorderNoneFromAttributes: true });
                     docModel.setAttributes('paragraph', { paragraph: borderAttrs });
                 }
             },
@@ -424,6 +440,10 @@ define('io.ox/office/text/app/controller', [
                 parent: 'document/editable/text',
                 get: function () { return docModel.getAttributes('character', { maxIterations: 10 }) || {}; }
             },
+            'character/text/group': {
+                parent: 'document/text',
+                get: function () { return docModel.getAttributes('character', { maxIterations: 10 }) || {}; }
+            },
             'character/stylesheet': {
                 parent: 'character/group',
                 get: function (character) { return character.styleId; },
@@ -433,6 +453,10 @@ define('io.ox/office/text/app/controller', [
                 parent: 'character/group',
                 get: function (character) { return character.character || {}; }
             },
+            'character/text/attributes': {
+                parent: 'character/text/group',
+                get: function (character) { return character.character || {}; }
+            },
             'character/fontname': {
                 parent: 'character/attributes',
                 get: function (attributes) { return attributes.fontName; },
@@ -504,17 +528,17 @@ define('io.ox/office/text/app/controller', [
                 set: function () { return docModel.removeHyperlink(); }
             },
 
+            'character/hyperlink/valid': {
+                parent: 'character/text/attributes',
+                enable: function (attrs) { return attrs.url && HyperlinkUtils.hasSupportedProtocol(attrs.url) && HyperlinkUtils.isValidURL(attrs.url); }
+            },
+
             'character/reset': {
                 parent: 'document/editable/text',
                 set: function () { docModel.resetAttributes(); },
                 shortcut: { keyCode: 'SPACE', ctrl: true }
             },
 
-            'character/hyperlink/valid': {
-                parent: 'character/attributes',
-                enable: function (attrs) { return attrs.url && HyperlinkUtils.hasSupportedProtocol(attrs.url) && HyperlinkUtils.isValidURL(attrs.url); }
-            },
-
             'character/format': {
                 parent: 'app/valid'
             },
@@ -628,7 +652,9 @@ define('io.ox/office/text/app/controller', [
             },
             'table/cellattributes': {
                 parent: 'document/editable/table',
-                get: function () { return docModel.getAttributes('cell').cell || {}; }
+                get: function () {
+                    return docModel.getAttributes('cell').cell || {};
+                }
             },
             'table/cellborder': {
                 parent: 'table/attributes',
@@ -640,7 +666,9 @@ define('io.ox/office/text/app/controller', [
             },
             'table/borderwidth': {
                 parent: 'table/cellattributes',
-                get: function (attributes) { return TableStyles.getBorderStyleFromAttributes(attributes); },
+                get: function (attributes) {
+                    return TableStyles.getBorderStyleFromAttributes(attributes);
+                },
                 set: function (borderWidth) {
                     docModel.setAttributes('table', {
                         table: TableStyles.getAttributesFromBorderStyle(borderWidth, docModel.getAttributes('table').table)
@@ -963,9 +991,13 @@ define('io.ox/office/text/app/controller', [
                 parent: 'document/editable',
                 set: function () { docModel.getFieldManager().removeField(); }
             },
+            editField: {
+                parent: 'document/editable',
+                set: function () { docModel.getFieldManager().editFieldFromContextMenu(); }
+            },
 
             'document/insertfield': {
-                parent: 'document/editable/text',
+                parent: ['document/editable/text', 'insert/comment/odf/supported'],
                 set: function (value) { docModel.getFieldManager().dispatchInsertField(value, 'default'); }
             },
 
