@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -165,7 +166,7 @@ define('io.ox/office/text/components/drawing/drawingresize', [
                 shiftY = (event.pageY - event.startY + scrollY) / zoomFactor;
 
                 // only move the moveBox, if the mouse was really moved (Fix for 28633)
-                mouseMoved = ((shiftX !== 0) || (shiftY !== 0));
+                mouseMoved = (shiftX !== 0) || (shiftY !== 0);
 
                 if (mouseMoved) {
 
@@ -176,7 +177,7 @@ define('io.ox/office/text/components/drawing/drawingresize', [
                     if (event.pageY - topDrawingDistance < minTopPosition) { shiftY += (minTopPosition - event.PageY + topDrawingDistance) / zoomFactor; }
                     if (event.pageY - topDrawingDistance > maxBottomPosition) { shiftY += (maxBottomPosition - event.pageY + topDrawingDistance) / zoomFactor; }
 
-                    if (_.isNumber(shiftX) && _.isNumber(shiftY) && (shiftX !== 0) || (shiftY !== 0)) {
+                    if (_.isNumber(shiftX) && _.isNumber(shiftY) && ((shiftX !== 0) || (shiftY !== 0))) {
                         moveBox.css({ left: shiftX, top: shiftY, width: drawingWidth, height: drawingHeight });
                     }
                 }
@@ -746,7 +747,7 @@ define('io.ox/office/text/components/drawing/drawingresize', [
                         app.getModel().executeDelayed(function () {
                             DrawingFrame.clearSelection(drawingNode);
                             DrawingResize.drawDrawingSelection(app, drawingNode);
-                        });
+                        }, { infoString: 'DrawingResize: setTextSelectionAfterMove', app: app });
                     }
                 }
                 if (DOM.isMarginalNode(drawingNode)) {
