@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
@@ -25,6 +26,8 @@ define('io.ox/office/text/format/drawingstyles', [
 
     'use strict';
 
+    var parseInt = window.parseInt;
+
     var // definitions for text-specific drawing attributes
         DEFINITIONS = {
 
@@ -102,10 +105,25 @@ define('io.ox/office/text/format/drawingstyles', [
                 def: 0,
                 format: function (element, width) {
                     if (!DrawingFrame.isGroupedDrawingFrame(element)) {
-                        if (width === 0) {
-                            element.width('100%');
+
+                        // bugfix :: BUG#45141 :: https://bugs.open-xchange.com/show_bug.cgi?id=45141 :: Vertical drawing object is shown diagonally
+                        if (_.isString(width)) {
+                            var
+                                value = parseInt(width, 10),
+                                tuple = width.split(value),
+                                unit  = (tuple.length === 2) ? $.trim(tuple[1]) : '';
+
+                            if (unit === '%') {
+                                element.width([value, unit].join(''));
+                            }/* else if (unit !== '') {
+                                element.width(Utils.convertLength(value, unit, 'px', 1));
+                            }*/
                         } else {
-                            element.width(Utils.convertHmmToLength(width, 'px', 1));
+                            if (width === 0) {          // cause of BUG#45141 in presentation:
+                                element.width('100%');  // - needs to be removed after changig to shape geometry in OX Text.
+                            } else {                    // - see: >> office/presentation/format/drawingstyles.js <<
+                                element.width(Utils.convertHmmToLength(width, 'px', 1));
+                            }
                         }
                     }
                 }
@@ -195,7 +213,7 @@ define('io.ox/office/text/format/drawingstyles', [
         // base constructor ---------------------------------------------------
 
         DrawingStyleCollection.call(this, docModel, {
-            families: 'line fill image shape geometry changes',
+            families: 'line fill image shape geometry connector changes',
             formatHandler: updateDrawingFormatting
         });
 
@@ -889,8 +907,12 @@ define('io.ox/office/text/format/drawingstyles', [
          */
         function updateDrawingFormatting(drawing, mergedAttributes) {
 
+            if (docModel.getApp().isInQuit()) { return; }
+
             var // the drawing attributes of the passed attribute map
                 drawingAttributes = mergedAttributes.drawing,
+                // the current zoom factor
+                zoomFactor = docModel.getApp().getView().getZoomFactor() / 100,
                 // the paragraph element containing the drawing node
                 // -> this can also be a drawing group without paragraphs
                 paragraph = drawing.parent(),
@@ -912,13 +934,6 @@ define('io.ox/office/text/format/drawingstyles', [
                 // -> the canvas draws half of the border width outside and half of it inside the drawing.
                 drawingWidth = Utils.convertLengthToHmm(drawing.width(), 'px') + borderWidth;
 
-            if (docModel.getApp().isInQuit()) {
-                return;
-            }
-
-            // the current zoom factor in percent
-            var zoomFactor = docModel.getApp().getView().getZoomFactor() / 100;
-
             // Setting the height of the drawing
             setDrawingHeight(drawing, mergedAttributes);
 
@@ -1069,15 +1084,17 @@ define('io.ox/office/text/format/drawingstyles', [
 
         // inline flag overrules all other attributes, no need to return any other (unfortunately it is still necessary for undo reasons)
         if (position === 'inline') {
-            return { inline: true,
-                     anchorHorBase: null,
-                     anchorHorAlign: null,
-                     anchorHorOffset: null,
-                     anchorVertBase: null,
-                     anchorVertAlign: null,
-                     anchorVertOffset: null,
-                     textWrapMode: null,
-                     textWrapSide: null };
+            return {
+                inline: true,
+                anchorHorBase: null,
+                anchorHorAlign: null,
+                anchorHorOffset: null,
+                anchorVertBase: null,
+                anchorVertAlign: null,
+                anchorVertOffset: null,
+                textWrapMode: null,
+                textWrapSide: null
+            };
         }
 
         // check that passed position contains alignment and text wrapping mode
