@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Oliver Specht <oliver.specht@open-xchange.com>
  */
@@ -15,8 +16,11 @@ define('io.ox/office/text/format/listcollection', [
     'io.ox/office/baseframework/model/modelobject',
     'io.ox/office/textframework/utils/operations',
     'io.ox/office/textframework/utils/listutils',
+    'io.ox/office/textframework/utils/textutils',
+    'io.ox/office/textframework/utils/position',
+    'io.ox/office/textframework/utils/dom',
     'gettext!io.ox/office/text/main'
-], function (ModelObject, Operations, ListUtils, gt) {
+], function (ModelObject, Operations, ListUtils, TextUtils, Position, DOM, gt) {
 
     'use strict';
 
@@ -594,6 +598,33 @@ define('io.ox/office/text/format/listcollection', [
             });
         };
 
+        /**
+         * Returns the default list definition for bullet or numbering lists.
+         *
+         * @param {String} [type='numbering']
+         *  'bullet' or 'character' for bullet lists, 'numbering' for numbered lists.
+         *
+         * @returns {Object}
+         *  The default list definition.
+         */
+        this.getDefaultListDefinition = function (type) {
+            var listDefinition = null;
+
+            if (type === 'bullet' || type === 'character') {
+                listDefinition = _.copy(DEFAULT_BULLET_LIST_DEFINITION, true);
+                //replace ooxml special bullets
+                if (odfFormat) {
+                    listDefinition.listLevel0.levelText = '\u2022';
+                    listDefinition.listLevel3.levelText = '\u2022';
+                    listDefinition.listLevel6.levelText = '\u2022';
+                }
+            } else {
+                listDefinition = _.copy(DEFAULT_NUMBERING_LIST_DEFINITION, true);
+            }
+
+            return listDefinition;
+        };
+
         /**
          * @param {String} type
          *  either bullet or numbering
@@ -621,21 +652,15 @@ define('io.ox/office/text/format/listcollection', [
 
             if (target) { newOperation.target = target; } // 44393
 
-            if (type === 'bullet') {
-                newOperation.listDefinition = _.copy(DEFAULT_BULLET_LIST_DEFINITION, true);
-                if (odfFormat) { //replace ooxml special bullets
-                    newOperation.listDefinition.listLevel0.levelText = '\u2022';
-                    newOperation.listDefinition.listLevel3.levelText = '\u2022';
-                    newOperation.listDefinition.listLevel6.levelText = '\u2022';
-                }
+            newOperation.listDefinition = this.getDefaultListDefinition(type);
 
+            if (type === 'bullet') {
                 if (options && options.symbol && options.symbol !== '*') {
                     newOperation.listDefinition.listLevel0.levelText = options.symbol;
                 } else {
                     newOperation.listDefinition.defaultlist = type;
                 }
             } else {
-                newOperation.listDefinition = _.copy(DEFAULT_NUMBERING_LIST_DEFINITION, true);
                 var defaultlist = true;
                 if (options) {
                     if (options.listStartValue) {
@@ -852,23 +877,24 @@ define('io.ox/office/text/format/listcollection', [
          *  An optional target that is used for generating specific list IDs that are
          *  used in lists in ODT headers or footers (44393).
          *
-         * @returns {Object}
+         * @param {String} predefinedStyleId the styleId to get the predefined liststyle
+         *
+         * @returns {Object|Null}
          *  the operation that creates the requested list
          */
-        this.getSelectedListStyleOperation = function (listId, target) {
+        this.getSelectedListStyleOperation = function (listId, target, predefinedStyleId) {
 
             var fullListId = target ? (listId + '_' + target) : listId;
             var newOperation = { name: Operations.INSERT_LIST, listStyleId: fullListId };
 
             if (target && docModel.getApp().isODF() && docModel.isHeaderFooterEditState()) { newOperation.target = target; } // odt handling (44393)
 
-            if ((listId in PREDEFINED_LISTSTYLES) && !(fullListId in insertedListIds)) {
-                newOperation.listDefinition = _.copy(PREDEFINED_LISTSTYLES[listId].definition, true);
+            if ((predefinedStyleId in PREDEFINED_LISTSTYLES) && !(fullListId in insertedListIds)) {
+                newOperation.listDefinition = _.copy(PREDEFINED_LISTSTYLES[predefinedStyleId].definition, true);
                 insertedListIds[fullListId] = true;  // avoiding inserting list more than once
             } else {
                 newOperation = null;
             }
-
             return newOperation;
         };
 
@@ -1128,6 +1154,40 @@ define('io.ox/office/text/format/listcollection', [
             return PREDEFINED_LISTSTYLES;
         };
 
+        /**
+         * Get the listId for a liststyle. If the liststyle is used in the previous paragrap, return the previous
+         * listId, if the previous not empty paragraph has no liststyle or the given id is in use return null to create a new
+         * listId.
+         * @param {Object} listDefinition The default list definition.
+         * @param {String} id the liststyleId returned if the previous not empty paragraph has not liststyle and if this id is not in use
+         * @returns {String} the liststyleId to create a liststyle
+         */
+        this.getListId = function (listDefinition, id) {
+            var listId = this.hasListStyleId(id) ? null : id;
+            if (listDefinition) {
+                var pageNode = docModel.getNode();
+                var startPosition = docModel.getSelection().getStartPosition();
+                startPosition.pop();
+                var paragraph = Position.getParagraphElement(pageNode, startPosition);
+                var prevParagraph = TextUtils.findPreviousNode(pageNode, paragraph, DOM.PARAGRAPH_NODE_SELECTOR);
+                while (prevParagraph) {
+                    if (DOM.isEmptyParagraph(prevParagraph)) {
+                        prevParagraph = TextUtils.findPreviousNode(pageNode, prevParagraph, DOM.PARAGRAPH_NODE_SELECTOR);
+                    } else {
+                        var attrs = docModel.getParagraphStyles().getElementAttributes(prevParagraph);
+                        if (attrs.paragraph.listStyleId !== '' && isArrayDefinitionEqual(this.getList(attrs.paragraph.listStyleId), listDefinition)) {
+                            listId = attrs.paragraph.listStyleId;
+                        } else {
+                            listId = null;
+                        }
+                        prevParagraph = null;
+                    }
+                }
+            }
+
+            return listId;
+        };
+
         // initialization -----------------------------------------------------
 
         this.registerDestructor(function () {
