@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  */
@@ -115,31 +116,25 @@ define('io.ox/office/text/format/stylesheetmixin', [
         }
 
         function trim(string) {
-            return string.toLowerCase().replace(/\s/g, '');
+            return string.toLowerCase().replace(/\s+/g, '');
         }
 
         function getFuzzyStyleId() {
+
             var names = paraStyles.getStyleSheetNames();
             var normalIds = _.keys(names);
             var normalNames = _.values(names);
-            var trimedIds = [];
-            var trimedNames = [];
-
-            _.each(normalIds, function (normalId) {
-                trimedIds.push(trim(normalId));
-            });
-            _.each(normalNames, function (normalValue) {
-                trimedNames.push(trim(normalValue));
-            });
+            var trimmedIds = normalIds.map(trim);
+            var trimmedNames = normalNames.map(trim);
 
             for (var i = 0; i < arguments.length; i++) {
                 var arg = arguments[i];
                 var trimmedArg = trim(arg);
-                var index = trimedIds.indexOf(trimmedArg);
+                var index = trimmedIds.indexOf(trimmedArg);
                 if (index >= 0) {
                     return normalIds[index];
                 }
-                index = trimedNames.indexOf(trimmedArg);
+                index = trimmedNames.indexOf(trimmedArg);
                 if (index >= 0) {
                     return normalIds[index];
                 }
@@ -420,7 +415,7 @@ define('io.ox/office/text/format/stylesheetmixin', [
             }
         });
 
-        paraStyles.on('change:stylesheet', function (evt, styleId) {
+        this.listenTo(paraStyles, 'change:stylesheet', function (evt, styleId) {
             app.getView().enterBusy({
                 warningLabel: gt('Please wait while updating document.')
             });
@@ -436,7 +431,7 @@ define('io.ox/office/text/format/stylesheetmixin', [
                 if (paraStyles.isChildOfOther(paraStyleId, styleId)) {
                     paraStyles.updateElementFormatting(para);
                 }
-            }, { infoString: 'Text: Change:styleSheet' }).always(function () {
+            }, { infoString: 'Text: Change:styleSheet', app: app }).always(function () {
                 app.getView().leaveBusy();
                 self.insertPageBreaks();
             });
