@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -16,7 +17,7 @@ define('io.ox/office/text/format/tablecellstyles', [
     'io.ox/office/editframework/utils/color',
     'io.ox/office/editframework/utils/border',
     'io.ox/office/editframework/model/stylecollection',
-    'io.ox/office/text/dom'
+    'io.ox/office/textframework/utils/dom'
 ], function (Utils, Color, Border, StyleCollection, DOM) {
 
     'use strict';
