@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -74,9 +75,17 @@ define('io.ox/office/text/model/listhandlermixin', [
          *  The list type: 'numbering' or 'bullet'
          */
         this.createDefaultList = function (type) {
-
             var defListStyleId = self.getListCollection().getDefaultNumId(type);
 
+            if (defListStyleId) {
+                var listId = self.getListCollection().getListId(self.getListCollection().getDefaultListDefinition(type), defListStyleId);
+                if (listId) {
+                    defListStyleId = listId;
+                } else {
+                    defListStyleId = undefined;
+                }
+            }
+
             self.getUndoManager().enterUndoGroup(function () {
 
                 if (defListStyleId === undefined) {
@@ -162,15 +171,24 @@ define('io.ox/office/text/model/listhandlermixin', [
                     }
 
                 } else {
-
-                    if (self.getApp().isODF() && self.isHeaderFooterEditState()) { // odt handling (44393)
+                    var predefinedStyleId = listStyleId;
+                    if ((self.getApp().isODF() && self.isHeaderFooterEditState())) { // odt handling (44393)
                         target = self.getActiveTarget();
                         if (target) {
                             fullListStyleId = listStyleId + '_' + target;
                         }
+                    } else {
+                        var listId = self.getListCollection().getListId(self.getListCollection().getPredefinedListStyles()[listStyleId].definition, listStyleId);
+                        if (listId) {
+                            listStyleId = listId;
+                            fullListStyleId = listStyleId;
+                        } else {
+                            fullListStyleId = self.getListCollection().getFreeListId();
+                            listStyleId = fullListStyleId;
+                        }
                     }
 
-                    listOperation = self.getListCollection().getSelectedListStyleOperation(listStyleId, target);
+                    listOperation = self.getListCollection().getSelectedListStyleOperation(listStyleId, target, predefinedStyleId);
 
                     if (listOperation) {
                         this.applyOperations(listOperation);
