@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -77,10 +78,13 @@ define('io.ox/office/text/model/model', [
          * @param {HTMLElement|jQuery} drawing
          *  The drawing node.
          *
+         * @param {Object} [options]
+         *  Some additional options.
+         *
          * @returns {String|Null}
          *  The default text for a place holder drawing. Or null, if it cannot be determined.
          */
-        this.getDefaultTextForTextFrame = function (/*drawing*/) {
+        this.getDefaultTextForTextFrame = function (/*drawing, options*/) {
             return null;
         };
 
