@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -15,11 +16,11 @@ define('io.ox/office/text/model/modelattributesmixin', [
     'io.ox/office/textframework/format/characterstyles',
     'io.ox/office/text/format/paragraphstyles',
     'io.ox/office/text/format/drawingstyles',
+    'io.ox/office/text/format/tablecellstyles',
+    'io.ox/office/text/format/pagestyles',
     'io.ox/office/textframework/format/tablestyles',
-    'io.ox/office/textframework/format/tablerowstyles',
-    'io.ox/office/textframework/format/tablecellstyles',
-    'io.ox/office/text/format/pagestyles'
-], function (CharacterStyles, ParagraphStyles, DrawingStyles, TableStyles, TableRowStyles, TableCellStyles, PageStyles) {
+    'io.ox/office/textframework/format/tablerowstyles'
+], function (CharacterStyles, ParagraphStyles, DrawingStyles, TableCellStyles, PageStyles, TableStyles, TableRowStyles) {
 
     'use strict';
 
