@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -92,7 +93,7 @@ define('io.ox/office/text/model/pagehandlermixin', [
                 commentLayer = self.getCommentLayer();
 
             // fix for not clearing anoying selection range in Chrome on click
-            if (_.browser.Chrome && selection.hasRange() && !rightClick) {
+            if (_.browser.Chrome && selection.hasRange() && !rightClick && !event.shiftKey) {
                 window.getSelection().empty();
             }
 
