@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -15,8 +16,9 @@ define('io.ox/office/text/model/updatedocumentmixin', [
     'io.ox/office/drawinglayer/view/drawingframe',
     'io.ox/office/textframework/utils/config',
     'io.ox/office/textframework/utils/dom',
-    'io.ox/office/textframework/utils/textutils'
-], function (DrawingFrame, Config, DOM, Utils) {
+    'io.ox/office/textframework/utils/textutils',
+    'io.ox/office/tk/utils/deferredutils'
+], function (DrawingFrame, Config, DOM, Utils, DeferredUtils) {
 
     'use strict';
 
@@ -79,7 +81,7 @@ define('io.ox/office/text/model/updatedocumentmixin', [
                 pageLayout.headerFooterCollectionUpdate();
             }
 
-            pageLayout.callInitialPageBreaks(); // necessary always because of fields update. see #42606
+            pageLayout.callInitialPageBreaks({ triggerEvent: true }); // necessary always because of fields update. see #42606
 
             return $.when();
         };
@@ -95,7 +97,7 @@ define('io.ox/office/text/model/updatedocumentmixin', [
         this.updateDocumentFormatting = function () {
 
             var // the result deferred object
-                def = $.Deferred(),
+                def = DeferredUtils.createDeferred(app, 'UpdateDocumentMixin: updateDocumentFormatting'),
                 // the page node
                 editdiv = self.getNode(),
                 // the content node of the page
@@ -303,11 +305,11 @@ define('io.ox/office/text/model/updatedocumentmixin', [
             // abort first promise before calling function second time (avoid duplicate calls if first is not finished)
             if (initialPbPromise) { initialPbPromise.abort(); }
 
-            this.iterateArraySliced(formattingNodes, updateElementFormatting, { delay: 'immediate', infoString: 'Text: updateElementFormatting' })
+            this.iterateArraySliced(formattingNodes, updateElementFormatting, { delay: 'immediate', infoString: 'Text: updateElementFormatting', app: app })
                 // .then(updateDrawingGroups)
-                .then(function () { return app.getModel().startParagraphMarginColorFormating(); })
                 .then(updateListFormatting)
                 .then(function () { return pageLayout.callInitialPageBreaks({ triggerEvent: true }); })
+                .then(function () { return app.getModel().startParagraphMarginColorAndBorderFormating(); }) // must be after page-breaks
                 .done(function () { dumpProfilingInformation(); def.resolve(); })
                 .fail(function () { def.reject(); });
 
@@ -388,10 +390,38 @@ define('io.ox/office/text/model/updatedocumentmixin', [
 
             return self.applyActions(actions, { external: true, useStorageData: false }).done(function () {
                 self.firstPartOfDocumentFormatting();
-                self.getPageLayout().callInitialPageBreaks();
+                self.getPageLayout().callInitialPageBreaks({ triggerEvent: true });
             });
         };
 
+        /**
+         * Set the default paper format according to UI language if it is a new document
+         */
+        this.setDefaultPaperFormat = function () {
+            var attrs = self.getStyleCollection('page').getElementAttributes(self.getNode());
+
+            if (attrs.page) {
+                var page = _.copy(attrs.page, true),
+                    width = null,
+                    height = null;
+
+                var loaclePaperSize = Utils.getPaperSizeByLocale(Config.LOCALE);
+
+                if (page.width !== loaclePaperSize.width || page.height !== loaclePaperSize.Height) {
+                    width = loaclePaperSize.width;
+                    height = loaclePaperSize.height;
+                }
+
+                if (width !== null) {
+                    app.stopOperationDistribution(function () {
+                        self.setPaperFormat({ width: width, height: height, marginLeft: page.marginLeft, marginRight: page.marginRight }, page);
+                        self.getUndoManager().clearUndoActions();
+                    });
+                }
+            }
+
+        };
+
         // initialization -----------------------------------------------------
 
         // destroy all class members on destruction
