@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -37,7 +38,7 @@ define('io.ox/office/text/model/updatelistsmixin', [
             // collects information for debounced list update
             updateListsDebouncedOptions = {},
             // the debounced list handler function
-            updateListsDebounced = self.createDebouncedMethod(registerListUpdate, updateLists, { delay: 10, infoString: 'Text: updateLists' });
+            updateListsDebounced = self.createDebouncedMethod(registerListUpdate, updateLists, { delay: 10, infoString: 'Text: updateLists', app: app });
 
         // private methods ----------------------------------------------------
 
@@ -107,7 +108,10 @@ define('io.ox/office/text/model/updatelistsmixin', [
         function updateLists(options) {
 
             var listItemCounter = [],
+                // list item counter for deleted paragraphs (change-track)
+                deletedlistItemCounter = [],
                 listParagraphIndex = [], // paragraph index in a list
+                deletedlistParagraphIndex = [], // paragraph index in a list for deleted paragraphs (change-track)
                 // list of all paragraphs in the document
                 paragraphNodes = null,
                 // the deferred, whose promise will be returned
@@ -127,7 +131,9 @@ define('io.ox/office/text/model/updatelistsmixin', [
                 // whether the splitted paragraph in the numbered list was found
                 splittedNumberedListFound = false,
                 // whether DOM manipulations can be suppressed. This is the case for numbered
-                suppressDomManipulation = false;
+                suppressDomManipulation = false,
+                // whether to the the deleted paragraph list numbering (change-track)
+                showDeletedParagraphNumbering = false;
 
             function updateListInParagraph(para) {
 
@@ -145,8 +151,43 @@ define('io.ox/office/text/model/updatelistsmixin', [
                     // an array with all list style ids, that share the common base (and are counted together (40792))
                     listFamily = listStyleId !== '' ? listCollection.getAllListStylesWithSameBaseStyle(listStyleId) : null,
                     // using the first list id of a list family as counter (inside listItemCounter and listParagraphIndex)
-                    listCounterId = (listFamily && listFamily.length > 1) ? listFamily[0] : listStyleId;
+                    listCounterId = (listFamily && listFamily.length > 1) ? listFamily[0] : listStyleId,
+                    // whether the pararaph is deleted (change-track)
+                    deletedParagraph = DOM.isChangeTrackRemoveNode(para),
+                    // whether the list has no label
+                    noListLabel = paraAttributes.listLabelHidden === true;
 
+                function updateListItemCounter(itemCounter, paragraphIndex) {
+
+                    if (!itemCounter[listCounterId]) {
+                        itemCounter[listCounterId] = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0];
+                        paragraphIndex[listCounterId] = 0;
+                    }
+
+                    if (!noListLabel) {
+                        itemCounter[listCounterId][listLevel]++;
+                        paragraphIndex[listCounterId]++;
+                    }
+
+                    if (paraAttributes.listStartValue >= 0) {
+                        itemCounter[listCounterId][listLevel] = paraAttributes.listStartValue;
+                    }
+
+                    // TODO: reset sub-levels depending on their 'levelRestartValue' attribute
+                    var subLevelIdx = listLevel + 1;
+                    for (; subLevelIdx < 10; subLevelIdx++) {
+                        itemCounter[listCounterId][subLevelIdx] = 0;
+                    }
+
+                    // fix level counts of non-existing upper levels
+                    subLevelIdx = listLevel - 1;
+                    for (; subLevelIdx >= 0; subLevelIdx--) {
+                        if (itemCounter[listCounterId][subLevelIdx] === 0) {
+                            itemCounter[listCounterId][subLevelIdx] = 1;
+                        }
+                    }
+
+                }
                 // Updating paragraphs, that are no longer part of lists (for example after 'Backspace')
                 if ($(para).data('removeLabel')) {
                     removeLabel = true;
@@ -179,34 +220,19 @@ define('io.ox/office/text/model/updatelistsmixin', [
                 }
 
                 if (listStyleId !== '' || listLevel) {
-                    var noListLabel = paraAttributes.listLabelHidden === true;
+
                     if (listLevel < 0) {
                         // is a numbering level assigned to the current paragraph style?
                         listLevel = listCollection.findIlvl(listStyleId, elementAttributes.styleId);
                     }
                     if (listLevel !== -1 && listLevel < 10) {
-                        if (!listItemCounter[listCounterId]) {
-                            listItemCounter[listCounterId] = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0];
-                            listParagraphIndex[listCounterId] = 0;
+
+                        if (showDeletedParagraphNumbering) {
+                            updateListItemCounter(deletedlistItemCounter, deletedlistParagraphIndex);
                         }
-                        if (!noListLabel) {
-                            listItemCounter[listCounterId][listLevel]++;
-                            listParagraphIndex[listCounterId]++;
-                        }
-                        if (paraAttributes.listStartValue >= 0) {
-                            listItemCounter[listCounterId][listLevel] = paraAttributes.listStartValue;
-                        }
-                        // TODO: reset sub-levels depending on their 'levelRestartValue' attribute
-                        var subLevelIdx = listLevel + 1;
-                        for (; subLevelIdx < 10; subLevelIdx++) {
-                            listItemCounter[listCounterId][subLevelIdx] = 0;
-                        }
-                        // fix level counts of non-existing upper levels
-                        subLevelIdx = listLevel - 1;
-                        for (; subLevelIdx >= 0; subLevelIdx--) {
-                            if (listItemCounter[listCounterId][subLevelIdx] === 0) {
-                                listItemCounter[listCounterId][subLevelIdx] = 1;
-                            }
+
+                        if (!deletedParagraph) {
+                            updateListItemCounter(listItemCounter, listParagraphIndex);
                         }
 
                         // Performance III: After updating the listItemCounter and listParagraphIndex, the following
@@ -216,12 +242,13 @@ define('io.ox/office/text/model/updatelistsmixin', [
                         if (suppressDomManipulation) { return; }
 
                         updateParaTabstops = true;
-
-                        var listObject = listCollection.formatNumber(listCounterId, listLevel, listItemCounter[listCounterId], listParagraphIndex[listCounterId]),
+                        var listItemCounterItem = deletedParagraph ? deletedlistItemCounter[listCounterId] : listItemCounter[listCounterId];
+                        var listParagraphIndexItem = deletedParagraph ? deletedlistParagraphIndex[listCounterId] : listParagraphIndex[listCounterId];
+                        var listObject = listCollection.formatNumber(listCounterId, listLevel, listItemCounterItem, listParagraphIndexItem),
                             tab = !listObject.labelFollowedBy || listObject.labelFollowedBy === 'listtab';
 
                         if (!tab && (listObject.labelFollowedBy === 'space')) {
-                            listObject.text += String.fromCharCode(0x00a0);//add non breaking space
+                            listObject.text += '\xa0'; //add non breaking space
                         }
 
                         var numberingElement = DOM.createListLabelNode(noListLabel ? '' : listObject.text);
@@ -229,6 +256,15 @@ define('io.ox/office/text/model/updatelistsmixin', [
                         var span = DOM.findFirstPortionSpan(para);
                         var elementCharAttributes = self.getCharacterStyles().getElementAttributes(span).character;
                         var listSpans = numberingElement.children('span');
+
+                        if (deletedParagraph) {
+                            if (!showDeletedParagraphNumbering) {
+                                listSpans.text('\u2014');
+                            }
+                            listSpans.attr('data-change-track-removed', true);
+                            listSpans.attr('data-change-track-removed-author', $(para).attr('data-change-track-removed-author'));
+                        }
+
                         var paraCharStyles = null;
                         if (listObject.imgsrc && !noListLabel) {
                             var absUrl = app.getServerModuleUrl(IO.FILTER_MODULE_NAME, { action: 'getfile', get_filename: listObject.imgsrc }),
@@ -420,7 +456,7 @@ define('io.ox/office/text/model/updatelistsmixin', [
             if (doNothing) {
                 def = $.when();
             } else if (Utils.getBooleanOption(options, 'async', false)) {
-                def = self.iterateArraySliced(paragraphNodes, updateListInParagraph, { delay: 'immediate', infoString: 'Text: updateListInParagraph' });
+                def = self.iterateArraySliced(paragraphNodes, updateListInParagraph, { delay: 'immediate', infoString: 'Text: updateListInParagraph', app: app });
             } else {
                 paragraphNodes.each(function () { updateListInParagraph(this); });
                 def = $.when();
