@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Miroslav Dzunic <miroslav.dzunic@open-xchange.com>
  */
@@ -75,7 +76,7 @@ define('io.ox/office/textframework/components/field/basefield', [
         */
 
         this.isFileName = function (type) {
-            return (/FILE\-?NAME/i).test(type);
+            return (/FILE-?NAME/i).test(type);
         };
 
         this.isAuthor = function (type) {
