@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  * @author Miroslav Dzunic <miroslav.dzunic@open-xchange.com>
@@ -437,6 +438,34 @@ define('io.ox/office/textframework/components/field/complexfield', [
             $(specialField).data('length', 1).removeClass(DOM.SPECIAL_FIELD_NODE_CLASSNAME).after(content);
         }
 
+        /**
+         * Local helper used in case of undo of changetracked fields, where range start and range end are not changetracked.
+         * Method getComplexFieldIdFromStack needs to have insertRange, insertComplexField, insertRange order.
+         * Since ranges are not changetracked, on undo of changetrack operation, only insertComplexField operation comes,
+         * and id is not found. This method tries to get id from rangeStart node, that is already in dom.
+         *
+         * @param  {Array} start
+         *  Oxo position where field node should be inserted
+         * @param  {String} target
+         *  Target id of content node for position.
+         * @return {String|Null} Found id, or null.
+         */
+        function tryGetIDfromPrevRangeNode(start, target) {
+            var id = null;
+            var prevRangeMarkerPos = Position.decreaseLastIndex(start);
+            var startMarkerPoint = Position.getDOMPosition(model.getRootNode(target), prevRangeMarkerPos, true);
+            var startMarkerNode = startMarkerPoint && startMarkerPoint.node;
+
+            if (DOM.isRangeMarkerStartNode(startMarkerNode) && DOM.getRangeMarkerType(startMarkerNode) === 'field') {
+                id = DOM.getRangeMarkerId(startMarkerNode);
+                if (self.getComplexField(id)) { // if field with this id is already in a model, it is not correct id
+                    id = null;
+                }
+            }
+
+            return id;
+        }
+
         // methods ------------------------------------------------------------
 
         /**
@@ -561,11 +590,21 @@ define('io.ox/office/textframework/components/field/complexfield', [
                 // id of the field, to connect with range markers
                 id = model.getFieldManager().getComplexFieldIdFromStack(),
                 // the start marker node, that belongs to this complex field
-                startMarker = model.getRangeMarker().getStartMarker(id);
+                startMarker = null;
 
             if (!textSpan) { return false; }
 
-            if (!id) { Utils.error('insertComplexFieldHandler: no id!'); }
+            if (!id) {
+                // On undo change-tracked complex field,
+                // range start and range end are not handled, and it is possible not to fetch id from stack.
+                // Try to fetch range marker and id from previous dom node
+                id = tryGetIDfromPrevRangeNode(start, target);
+
+                if (!id) {
+                    Utils.error('insertComplexFieldHandler: no id!');
+                }
+            }
+            startMarker = model.getRangeMarker().getStartMarker(id);
 
             if (attrs && attrs.character &&  !_.isUndefined(attrs.character.autoDateField)) {
                 complexFieldNode.attr('data-auto-date', false);
