@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Miroslav Dzunic <miroslav.dzunic@open-xchange.com>
  */
@@ -382,9 +383,9 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
             var node,
                 domPos,
                 atEndOfSpan,
-                fieldValue = options && options.value || null,
-                fieldFormat = options && options.format || null,
-                standardizedDate = options && options.standard || null;
+                fieldValue = (options && options.value) || null,
+                fieldFormat = (options && options.format) || null,
+                standardizedDate = (options && options.standard) || null;
 
             if (!fieldValue) {
                 if (!fieldFormat) { return; } // no data to update, exit
@@ -462,7 +463,7 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
                     } else {
                         if (app.isODF()) {
                             type = 'date';
-                            attrs = { field: { fixed: JSON.stringify(!state), dateFormat: DOM.getFieldDateTimeFormat(node) } };
+                            attrs = { character: { field: { 'text:fixed': JSON.stringify(!state), dateFormat: DOM.getFieldDateTimeFormat(node) } } };
                         } else {
                             type = DOM.getFieldInstruction(node);
                             attrs = { character: { autoDateField: JSON.stringify(state) } };
@@ -764,7 +765,7 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
             if (highlightedFieldType && isSupportedFormat && isMouseTouchEvent && !isRightClick && isNotChangeTracked) {
                 fieldFormatPopupTimeout = self.executeDelayed(function () {
                     app.getView().showFieldFormatPopup(fieldinstruction, node, options);
-                }, 500, 'Text: FieldManager: fieldFormatPopupTimeout');
+                }, { delay: 500, infoString: 'Text: FieldManager: fieldFormatPopupTimeout', app: app });
             }
 
             // for debugging ->
@@ -893,7 +894,7 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
                 });
 
                 // iterate objects
-                generateDef = self.iterateObjectSliced(mergedFields, handleFieldUpdate, { delay: 'immediate', infoString: 'Text: handleFieldUpdate' })
+                generateDef = self.iterateObjectSliced(mergedFields, handleFieldUpdate, { delay: 'immediate', infoString: 'Text: handleFieldUpdate', app: app })
                 .always(function () {
                     // leave busy state
                     app.getView().leaveBusy().grabFocus();
@@ -1083,8 +1084,8 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
             // odf - field types needed to be updated in frontend
             if (type === 'page-number' || type === 'page-count') {
                 fieldNode.addClass('field-' + type);
-                if (attrs && attrs.field && attrs.field.pageNumFormat) {
-                    format = attrs.field.pageNumFormat;
+                if (attrs && attrs.character && attrs.character.field && attrs.character.field.pageNumFormat) {
+                    format = attrs.character.field.pageNumFormat;
                 }
                 if (type === 'page-count') {
                     model.getPageLayout().updatePageCountField(fieldNode, format);
@@ -1106,8 +1107,8 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
 
             // apply the passed field attributes
             if (_.isObject(attrs)) {
-                if (_.isObject(attrs.field)) {
-                    _.each(attrs.field, function (element, name) {
+                if (_.isObject(attrs.character) && attrs.character.field) {
+                    _.each(attrs.character.field, function (element, name) {
                         fieldNode.data(name, element);
                         if (name === 'name') {
                             fieldNode.addClass('user-field');
@@ -1474,6 +1475,16 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
             return node;
         };
 
+        /**
+         * Method to open field format popup from context menu.
+         *
+         */
+        this.editFieldFromContextMenu = function () {
+            var node = self.getSelectedFieldNode();
+
+            this.createEnterHighlight(node, { mouseTouchEvent: true, simpleField: !DOM.isComplexFieldNode(node) });
+        };
+
         /**
          * During delete of complex field, take care
          * that following span (or other) elements don't keep the coresponding class name.
@@ -1573,7 +1584,7 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
          * @returns {Boolean}
          */
         this.isSupportedFieldType = function () {
-            var supportedTypes = [/NUMPAGES/i, /PAGE/i, /^DATE/i, /^TIME/i, /FILE\-?NAME/i, /^AUTHOR$/i, /^author-name$/];
+            var supportedTypes = [/NUMPAGES/i, /PAGE/i, /^DATE/i, /^TIME/i, /FILE-?NAME/i, /^AUTHOR$/i, /^author-name$/, /^creator$/];
             var result = false;
 
             if (highlightedFieldType && !(/PAGEREF/i).test(highlightedFieldType)) {
@@ -1587,6 +1598,19 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
             return result;
         };
 
+        /**
+         * Check if currently highlighted field doesn't support format change.
+         * Usually ODF autor and document name fields don't support this feature.
+         * Info: when we extend list of supported fields, this regex needs to be expanded!
+         *
+         * @return {Boolean}
+         */
+        this.supportsFieldFormatting = function () {
+            var unsupportedRegex = /(^author-name$)|(^creator$)|(^file-name$)/;
+
+            return highlightedFieldType && !unsupportedRegex.test(highlightedFieldType);
+        };
+
         /**
          * Used to stack locally id for field during creation of complex field and preceding range start and following range end.
          *
@@ -1620,8 +1644,8 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
         // initialization -----------------------------------------------------
 
         app.onInit(function () {
-            var d1 = $.Deferred();
-            var d2 = $.Deferred();
+            var d1 = self.createDeferredObject({ infoString: 'FieldManager: app.onInit 1', app: app });
+            var d2 = self.createDeferredObject({ infoString: 'FieldManager: app.onInit 2', app: app });
 
             model = app.getModel();
             selection = model.getSelection();
@@ -1673,6 +1697,12 @@ define('io.ox/office/textframework/components/field/fieldmanager', [
 
             self.waitForImportFailure(function () {
                 // reject promise on import failed, so that update fields doesn't hang
+                d1.reject();
+                d2.reject();
+            });
+
+            self.listenTo(app, 'docs:beforequit', function () {
+                d1.reject();
                 d2.reject();
             });
 
