@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Miroslav Dzunic <miroslav.dzunic@open-xchange.com>
  */
@@ -79,11 +80,8 @@ define('io.ox/office/textframework/components/field/simplefield', [
                 attrsField = null;
 
             // when fastload, pageNum and dateFormat formats needs to be set to field data
-            if (fieldAttrs && fieldAttrs.field && fieldAttrs.field.pageNumFormat && !$fieldNode.data('pageNumFormat')) {
-                $fieldNode.data('pageNumFormat', fieldAttrs.field.pageNumFormat);
-            }
-            if (fieldAttrs && fieldAttrs.field) {
-                attrsField = fieldAttrs.field;
+            if (fieldAttrs && fieldAttrs.character && fieldAttrs.character.field) {
+                attrsField = fieldAttrs.character.field;
                 if (attrsField.pageNumFormat && !$fieldNode.data('pageNumFormat')) {
                     $fieldNode.data('pageNumFormat', attrsField.pageNumFormat);
                 }
@@ -191,7 +189,7 @@ define('io.ox/office/textframework/components/field/simplefield', [
                         operation = _.extend(operation, { attrs: operationAttrs });
                     }
                     if (dateFormat) {
-                        operation = _.extend(operation, { attrs: { field: { dateFormat: dateFormat } } });
+                        operation = _.extend(operation, { attrs: { character: { field: { dateFormat: dateFormat } } } });
                     }
 
                     model.applyOperations(operation);
@@ -717,7 +715,8 @@ define('io.ox/office/textframework/components/field/simplefield', [
                             representation = self.getDateTimeRepresentation(fieldFormat);
                             if (app.isODF()) {
                                 operation.attrs = operation.attrs || {};
-                                operation.attrs.field = { dateFormat: fieldFormat, fixed: JSON.stringify(isFixed) };
+                                operation.attrs.character = operation.attrs.character || {};
+                                operation.attrs.character.field = { dateFormat: fieldFormat, 'text:fixed': JSON.stringify(isFixed) };
                             } else {
                                 operation.type = fieldType + ' \\@ ' + fieldFormat;
                             }
@@ -744,7 +743,8 @@ define('io.ox/office/textframework/components/field/simplefield', [
                             representation = self.formatPageFieldInstruction(pageLayout.getNumberOfDocumentPages(), fieldFormat, true);
                             if (app.isODF()) {
                                 operation.attrs = operation.attrs || {};
-                                operation.attrs.field = { pageNumFormat: fieldFormat };
+                                operation.attrs.character = operation.attrs.character || {};
+                                operation.attrs.character.field = { pageNumFormat: fieldFormat };
                                 operation.type = 'page-count';
                             } else {
                                 operation.type = fieldType + ' \\* ' + fieldFormat;
@@ -753,7 +753,8 @@ define('io.ox/office/textframework/components/field/simplefield', [
                             representation = self.formatPageFieldInstruction(pageLayout.getPageNumber(), fieldFormat);
                             if (app.isODF()) {
                                 operation.attrs = operation.attrs || {};
-                                operation.attrs.field = { pageNumFormat: fieldFormat };
+                                operation.attrs.character = operation.attrs.character || {};
+                                operation.attrs.character.field = { pageNumFormat: fieldFormat };
                                 operation.type = 'page-number';
                             } else {
                                 operation.type = fieldType + ' \\* ' + fieldFormat;
@@ -818,7 +819,7 @@ define('io.ox/office/textframework/components/field/simplefield', [
                         operation = _.extend(operation, { attrs: operationAttrs });
                     }
                     if (dateFormat) {
-                        operation = _.extend(operation, { attrs: { field: { dateFormat: dateFormat, fixed: 'true', dateValue: standardizedDate } } });
+                        operation = _.extend(operation, { attrs: { character: { field: { dateFormat: dateFormat, 'text:fixed': 'true', dateValue: standardizedDate } } } });
                     }
 
                     model.applyOperations(operation);
@@ -871,13 +872,13 @@ define('io.ox/office/textframework/components/field/simplefield', [
                         }
                         undoManager.addUndo(undoOperation, redoOperation);
                     }
-                } else if (attrs.field && !_.isUndefined(attrs.field.fixed)) { // odf
-                    odfFixedField = attrs.field.fixed;
-                    $(fieldNode).data('fixed', odfFixedField);
-                    var tempAttrs = { field: { fixed: odfFixedField === 'true' ? 'false' : 'true' } };
-                    var redoTempAttrs = { field: { fixed: odfFixedField } };
-                    if (_.isObject($(fieldNode).data().attributes) && _.isObject($(fieldNode).data().attributes.field)) {
-                        $(fieldNode).data().attributes.field.fixed = odfFixedField;
+                } else if (attrs.character && attrs.character.field && !_.isUndefined(attrs.character.field['text:fixed'])) { // odf
+                    odfFixedField = attrs.character.field['text:fixed'];
+                    $(fieldNode).data('text:fixed', odfFixedField);
+                    var tempAttrs = { character: { field: { fixed: odfFixedField === 'true' ? 'false' : 'true' } } };
+                    var redoTempAttrs = { character: { field: { fixed: odfFixedField } } };
+                    if (_.isObject($(fieldNode).data().attributes) && _.isObject($(fieldNode).data().attributes.character) && _.isObject($(fieldNode).data().attributes.character.field)) {
+                        $(fieldNode).data().attributes.character.field['text:fixed'] = odfFixedField;
                     } else {
                         $(fieldNode).data('attributes', tempAttrs);
                     }
