@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -441,6 +442,11 @@ define('io.ox/office/textframework/components/rangemarker/rangemarker', [
                 id = model.getFieldManager().getComplexFieldIdFromStack(rangeStart, rangeEnd);
             }
 
+            // No inheritance of change track to following empty text span node (this would not be resolved during change track resolving)
+            if (DOM.isChangeTrackNode(textSpan) && textSpan.nextSibling && DOM.isEmptySpan(textSpan.nextSibling)) {
+                model.getCharacterStyles().setElementAttributes(textSpan.nextSibling, { changes: { inserted: null, removed: null, modified: null } });
+            }
+
             // saving also type and id at the range marker node
             rangeMarkerNode.attr('data-range-type', type);
             rangeMarkerNode.attr('data-range-id', id);
