@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  */
@@ -19,8 +20,10 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
     'io.ox/office/textframework/utils/position',
     'io.ox/office/textframework/view/labels',
     'io.ox/office/tk/object/triggerobject',
+    'io.ox/office/drawinglayer/view/drawingframe',
+    'io.ox/office/tk/utils/deferredutils',
     'gettext!io.ox/office/textframework/main'
-], function (AttributeUtils, Utils, Operations, DOM, Position, Labels, TriggerObject, gt) {
+], function (AttributeUtils, Utils, Operations, DOM, Position, Labels, TriggerObject, DrawingFrame, DeferredUtils, gt) {
 
     'use strict';
 
@@ -44,10 +47,12 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
             // the results of a quick search as oxoPositions
             searchResults = [],
             // the current index of the searchResults array
-            currentSearchResultId = 0,
+            currentSearchResultId = -1,
             // indicates if the applied operations is due to a search&replace
             // TODO: piggyback the information onto the operation directly
-            replaceOperation = false;
+            replaceOperation = false,
+            // the current query of the search result;
+            currentQuery = null;
 
         // base constructor ---------------------------------------------------
 
@@ -223,6 +228,12 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
                 if (result) {
                     currentSearchResultId = id;
 
+                    // Set the active slide if it is the presenter app
+                    if (model.useSlideMode()) {
+                        model.selectSlideView({ showMaster: result.isMaster });
+                        model.setActiveSlideId(result.slideID);
+                    }
+
                     if (model.getActiveTarget() && commentLayer.isCommentTarget(model.getActiveTarget())) {
                         commentLayer.deActivateCommentNode(model.getActiveTarget(), selection);
                     } else if (model.isHeaderFooterEditState()) {
@@ -248,7 +259,7 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
 
                     selection.setTextSelection(result.start, result.end);
                 }
-            }, undefined, 'Text: selectSearchResult');
+            }, { infoString: 'SearchHandler: selectSearchResult', app: app });
         }
 
         function handleNoResult() {
@@ -271,6 +282,31 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
             return attrs;
         }
 
+        /**
+         * returns if the drawing of this paragraph is a valid search and replace drawing.
+         * Placeholder with text on normal slides and shapes are valid. All other are not valid.
+         * @param {Node} paragraph node to test if drawing of the paragraph is valid
+         * @param {Boolen} isMasterOrLayout true if it is a master- or layoutslide
+         * @returns {Boolean} true if the drawing is valid, otherwise false.
+         */
+        function isValidDrawing(paragraph, isMasterOrLayout) {
+            return !$(paragraph).closest(DrawingFrame.CONTENT_NODE_SELECTOR).hasClass(DrawingFrame.EMPTYTEXTFRAME_CLASS) && (!isMasterOrLayout || !model.isPlaceHolderDrawing($(paragraph).closest('div.drawing')));
+        }
+
+        /**
+         * Start new quick search if the search result is empty or the current query is
+         * different to the given query.
+         * @param {String} query
+         * @returns {undefined}
+         */
+        function startNewQuickSearchIfNecessary(query) {
+            if ((_.isString(query) && query.length > 0) && (searchResults.length === 0 || query !== currentQuery)) {
+                self.quickSearch(query, 0);
+                return true;
+            }
+            return false;
+        }
+
         // methods ------------------------------------------------------------
 
         /**
@@ -288,7 +324,7 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
 
             // used for search and replace
             searchResults = [];
-            currentSearchResultId = 0;
+            currentSearchResultId = -1;
 
             // fade in entire document
             rootNode.removeClass('highlight');
@@ -317,7 +353,7 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
         this.selectNextSearchResult = function () {
 
             if (searchResults.length > 0) {
-                var id = (currentSearchResultId < searchResults.length - 1) ? currentSearchResultId + 1 : 0;
+                var id = currentSearchResultId < searchResults.length - 1 ? currentSearchResultId + 1 : 0;
                 selectSearchResult(id);
             } else {
                 handleNoResult();
@@ -400,6 +436,7 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
             }
 
             if (!currentResult) {
+                currentSearchResultId = 0;
                 return;
             }
 
@@ -414,6 +451,11 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
                 return;
             }
 
+            if (model.useSlideMode()) {
+                model.selectSlideView({ showMaster: currentResult.isMaster });
+                model.setActiveSlideId(currentResult.slideID);
+            }
+
             startPosition = _.clone(currentResult.start);
             endPosition = _.clone(currentResult.end);
             fullLength = _.last(endPosition) - _.last(startPosition);
@@ -525,7 +567,7 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
             }
 
             // create and return the debounced method Editor.debouncedQuickSearch()
-            return model.createDebouncedMethod(storeParameters, executeQuickSearch, { delay: 2000 });
+            return model.createDebouncedMethod(storeParameters, executeQuickSearch, { delay: 2000, infoString: 'SearchHandler debouncedQuickSearch()', app: app });
 
         }()); // Editor.debouncedQuickSearch()
 
@@ -555,7 +597,7 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
 
             // remove old highlighting and clear previous search results
             this.removeHighlighting();
-
+            currentQuery = query;
             // check input parameter
             if (!_.isString(query) || (query.length === 0)) {
                 return false;
@@ -564,6 +606,9 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
 
             regexp = generateRegExpForSearchString(query);
 
+            if (model.useSlideMode()) {
+                model.appendAllSlidesToDom();
+            }
             // search in all paragraph nodes (also embedded in tables etc.)
             Utils.iterateSelectedDescendantNodes(rootNode, DOM.PARAGRAPH_NODE_SELECTOR, function (paragraph) {
 
@@ -630,42 +675,65 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
                 // for case-insensitive matching
                 elementText = elementText.replace(/\s/g, ' ').toLowerCase();
 
-                while ((arrMatch = regexp.exec(elementText))) {
+                var matches = true;
+                var slideID = null;
+                var isMaster = false;
+                var nodeType = '';
+                if (DOM.isMarginalNode(paragraph)) {
+                    nodeType = 'marginal';
+
+                    targetNode = DOM.getMarginalTargetNode(rootNode, paragraph);
+                    target = DOM.getTargetContainerId(targetNode);
+
+                    if (!DOM.isFirstMarginalInDocument(rootNode, targetNode, target)) {
+                        matches = false;
+                    }
+                } else if (!model.getCommentLayer().isEmpty() && DOM.isNodeInsideComment(paragraph)) {
+                    nodeType = 'comment';
+
+                    targetNode = DOM.getSurroundingCommentNode(paragraph);
+                    target = DOM.getTargetContainerId(targetNode);
+                } else {
+                    if (model.useSlideMode()) {
+                        slideID = model.getSlideIdForNode(paragraph);
+                        isMaster = model.isLayoutOrMasterId(slideID);
+                        matches = isValidDrawing(paragraph, isMaster);
+                    }
+                }
+
+                while (matches && (arrMatch = regexp.exec(elementText))) {
 
                     start = arrMatch.index;
                     queryLength = arrMatch[0].length;
 
-                    matchingRanges.push({ start: start, end: start + queryLength });
+                    switch (nodeType) {
+                        case 'marginal':
+                            startPosition = Position.getOxoPosition(targetNode, paragraph, 0);
+                            startPosition.push(start);
+                            endPosition = Position.increaseLastIndex(startPosition, queryLength);
+                            targetSearchResults.push({ start: startPosition, end: endPosition, target: target, isReplaceable: isReplaceableRange(startPosition, endPosition, exceptionList) });
+                            break;
+                        case 'comment':
+                            startPosition = Position.getOxoPosition(targetNode, paragraph, 0);
+                            startPosition.push(start);
+                            endPosition = Position.increaseLastIndex(startPosition, queryLength);
+                            targetSearchResults.push({ start: startPosition, end: endPosition, target: target, isReplaceable: isReplaceableRange(startPosition, endPosition, exceptionList) });
+                            break;
+                        default:
+                            startPosition = Position.getOxoPosition(rootNode, paragraph, 0);
+                            startPosition.push(start);
+                            endPosition = Position.increaseLastIndex(startPosition, queryLength);
+                            var result = { start: startPosition, end: endPosition, isReplaceable: isReplaceableRange(startPosition, endPosition, exceptionList) };
+                            if (model.useSlideMode()) {
+                                result.slideID = slideID;
+                                result.isMaster = isMaster;
+                            }
 
-                    if (DOM.isMarginalNode(paragraph)) {
-
-                        targetNode = DOM.getMarginalTargetNode(rootNode, paragraph);
-                        target = DOM.getTargetContainerId(targetNode);
-
-                        if (!DOM.isFirstMarginalInDocument(rootNode, targetNode, target)) {
-                            return;
-                        }
-                        startPosition = Position.getOxoPosition(targetNode, paragraph, 0);
-                        startPosition.push(start);
-                        endPosition = Position.increaseLastIndex(startPosition, queryLength);
-                        targetSearchResults.push({ start: startPosition, end: endPosition, target: target, isReplaceable: isReplaceableRange(startPosition, endPosition, exceptionList) });
-
-                    } else if (!model.getCommentLayer().isEmpty() && DOM.isNodeInsideComment(paragraph)) {
-
-                        targetNode = DOM.getSurroundingCommentNode(paragraph);
-                        target = DOM.getTargetContainerId(targetNode);
-                        startPosition = Position.getOxoPosition(targetNode, paragraph, 0);
-                        startPosition.push(start);
-                        endPosition = Position.increaseLastIndex(startPosition, queryLength);
-                        targetSearchResults.push({ start: startPosition, end: endPosition, target: target, isReplaceable: isReplaceableRange(startPosition, endPosition, exceptionList) });
-
-                    } else {
-                        startPosition = Position.getOxoPosition(rootNode, paragraph, 0);
-                        startPosition.push(start);
-                        endPosition = Position.increaseLastIndex(startPosition, queryLength);
-                        searchResults.push({ start: startPosition, end: endPosition, isReplaceable: isReplaceableRange(startPosition, endPosition, exceptionList) });
+                            searchResults.push(result);
                     }
 
+                    matchingRanges.push({ start: start, end: start + queryLength });
+
                     // continue after the currently handled text
                     start += queryLength;
                 }
@@ -719,7 +787,11 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
             }, this);
 
             searchResults = _.union(searchResults, targetSearchResults);
-
+            if (searchResults.length > 0) {
+                currentSearchResultId = 0;
+            } else {
+                currentSearchResultId = -1;
+            }
             if (highlightedSpans.length > 0) {
                 // fade out entire document
                 rootNode.addClass('highlight');
@@ -779,6 +851,10 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
             // check input parameter
             if (!_.isString(query) || (query.length === 0)) { return; }
 
+            if (model.useSlideMode()) {
+                model.appendAllSlidesToDom();
+            }
+            replaceOperation = true;
             query = matchCase ? query : query.toLowerCase();
             queryLength = query.length;
             replacement = _.isString(replacement) ? replacement : '';
@@ -793,7 +869,7 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
             undoManager.enterUndoGroup(function () {
 
                 var // the deferred to keep the undo group open until it is resolved or rejected
-                    undoDef = $.Deferred(),
+                    undoDef = DeferredUtils.createDeferred(app, 'SearchHandler: searchAndReplaceAll'),
                     // the apply actions deferred
                     applyDef = null,
                     // the operations generator
@@ -884,8 +960,18 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
                         targetNode = DOM.getSurroundingCommentNode(paragraph);
                         target = DOM.getTargetContainerId(targetNode);
 
-                    }
+                    } else if (model.useSlideMode()) {
+                        var slideID = model.getSlideIdForNode(paragraph);
+                        var masteOrLayout = model.isLayoutOrMasterId(slideID);
 
+                        if (masteOrLayout) {
+                            target = slideID;
+                        }
+
+                        if (!isValidDrawing(paragraph, masteOrLayout)) {
+                            return;
+                        }
+                    }
                     while ((arrMatch = regexp.exec(elementText))) {
 
                         start = arrMatch.index;
@@ -942,11 +1028,14 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
 
                 }, this);
 
+                model.setGUITriggeredOperation(true);
                 // apply generated operations
                 applyDef = model.applyOperations(generator, { async: true })
                 // set cursor behind last replacement text
                 .done(function () {
                     selection.setTextSelection(initialStart);
+                    replaceOperation = false;
+                    model.setGUITriggeredOperation(false);
                 })
                 // leave busy state and close undo group
                 .always(function () {
@@ -981,11 +1070,40 @@ define('io.ox/office/textframework/components/searchhandler/searchhandler', [
                 // clear search results and trigger the debounced quick search
                 self.removeHighlighting();
                 if (app.getView().isSearchActive()) {
-                    self.debouncedQuickSearch(app.getView().getSearchSettings().query);
+                    self.debouncedQuickSearch(currentQuery);
                 }
             }
         };
 
+        /**
+         * Executes a search/replace operation, as requested by the base class
+         * EditView.
+         */
+        this.executeCommand = function (command, settings) {
+            switch (command) {
+                case 'search:start':
+                    return self.quickSearch(settings.query, 0);
+                case 'search:next':
+                    startNewQuickSearchIfNecessary(settings.query);
+                    return self.selectNextSearchResult();
+                case 'search:prev':
+                    startNewQuickSearchIfNecessary(settings.query);
+                    return self.selectPreviousSearchResult();
+                case 'search:end':
+                    return self.removeHighlighting();
+                case 'replace:next':
+                    if (startNewQuickSearchIfNecessary(settings.query)) {
+                        return self.selectNextSearchResult();
+                    }
+                    return self.replaceSelectedSearchResult(settings.replace);
+                case 'replace:all':
+                    return self.searchAndReplaceAll(settings.query, settings.replace);
+                default:
+                    Utils.error('TextView.searchHandler(): unsupported search command "' + command + '"');
+                    return 'internal';
+            }
+        };
+
         // initialization -----------------------------------------------------
 
         self.listenTo(model, 'operations:before', self.reset);
