@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
@@ -62,13 +63,13 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
             // list of unsupported languages with a notification
             unsupportedLanguages = [],
             // show the Notification if unsupported languages exist
-            showUnsupportedLanguageNotificationDebounced = model.createDebouncedMethod($.noop, showUnsupportedLanguageNotification, { delay: 1000, infoString: 'Text: spellchecker.showUnsupportedLanguageNotification' }),
+            showUnsupportedLanguageNotificationDebounced = model.createDebouncedMethod($.noop, showUnsupportedLanguageNotification, { delay: 1000, infoString: 'Text: spellchecker.showUnsupportedLanguageNotification', app: app }),
             // local list of misspelled words which are ignored by the user
             ignoredMisspelledWords = _.clone(UserDictionary.getDictionary()),
             // The undo manager
             undoManager = model.getUndoManager(),
             // A debounced function for starting adding or removing ignored words
-            implStartAddOrRemoveIgnoreWordsDebounced = model.createDebouncedMethod($.noop, implStartAddOrRemoveIgnoreWords, { delay: 500, infoString: 'Text: spellchecker.implStartOnlineSpelling' }),
+            implStartAddOrRemoveIgnoreWordsDebounced = model.createDebouncedMethod($.noop, implStartAddOrRemoveIgnoreWords, { delay: 500, infoString: 'Text: spellchecker.implStartOnlineSpelling', app: app }),
             // ignore actions for add or remove a ignore word, it will be used in the 'implStartAddOrRemoveIgnoreWords' function
             ignoreWordActions = [],
             // counter to set a unique request id
@@ -76,8 +77,15 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
             // Set to true if the User Dictionary is changed, but the app is not visible
             userDictionaryChanges = false,
             // If a word is misspelled select the whole word, on closing the contextmenu the selection must be restored
-            restoreStartPosition;
-
+            restoreStartPosition,
+            // handle if the app get visible
+            appVisibleHandler = function () {
+                // userDictionaryChanges is true if the user change the dictionary while the spellchecker document is not visible.
+                if (userDictionaryChanges) {
+                    userDictionaryChanges = false;
+                    implStartOnlineSpellingDebounced();
+                }
+            };
         // base constructor ---------------------------------------------------
 
         TriggerObject.call(this);
@@ -96,7 +104,9 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
          * Starting spell checking by calling the worker function 'implCheckSpelling'
          */
         function implStartOnlineSpelling() {
-            if (self.isImportFinished() && (onlineSpelling === true) && model.getEditMode()) {
+            // # 51390: Spellchecking can interrupt an active composition by manipulating
+            // DOM nodes. Make sure that this doesn't happen.
+            if (onlineSpelling && model.getEditMode() && (_.isFunction(model.isImeActive) && !model.isImeActive()) && self.isImportFinished()) {
                 implCheckSpelling();
             }
         }
@@ -104,7 +114,7 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
         /**
          * A debounced function for starting spell checking by calling 'implStartOnlineSpelling'
          */
-        var implStartOnlineSpellingDebounced = model.createDebouncedMethod($.noop, implStartOnlineSpelling, { delay: 1000, infoString: 'Text: spellchecker.implStartOnlineSpelling' });
+        var implStartOnlineSpellingDebounced = model.createDebouncedMethod($.noop, implStartOnlineSpelling, { delay: 1000, infoString: 'Text: spellchecker.implStartOnlineSpelling', app: app });
 
         /**
          * Receiving a list of replacement words for a specified word in a specified language from
@@ -466,8 +476,10 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
                 maxOffset = 1.5 * (scrollNode.height() + scrollNode.offset().top),
                 // the minimum offset for paragraphs that will be spell checked (a half screen upwards)
                 minOffset = -0.3 * maxOffset,
+                // container of the paragraph if presentation only the paragraphs of the active slide
+                paragraphContainer = model.useSlideMode() ? model.getSlideById(model.getActiveSlideId()) : model.getNode(),
                 // iterating over all paragraphs, that are not marked with class 'p_spelled'. If the paragraph cache was filled, use it
-                allParagraphs = paragraphCache.length > 0 ? paragraphCache : model.getNode().find(DOM.PARAGRAPH_NODE_SELECTOR).not('.p_spelled');
+                allParagraphs = paragraphContainer === null ? [] : paragraphCache.length > 0 ? paragraphCache : paragraphContainer.find(DOM.PARAGRAPH_NODE_SELECTOR).not('.p_spelled');
 
             // Slicing, so that there are not too many parallel server calls
             // -> it is useful to profile the sliced function using 'Utils.profileMethod' in following performance tests.
@@ -479,8 +491,9 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
                     paraSpans,
                     // requestID
                     requestID;
-
-                if (!$(paragraph).hasClass('p_spelled')) {
+                if ($(paragraph).hasClass(DOM.NO_SPELLCHECK_CLASSNAME) || $(paragraph).hasClass(DOM.PARAGRAPH_NODE_LIST_EMPTY_CLASS)) {
+                    removeAllSpellErrorsInParagraph(paragraph);
+                } else if (!$(paragraph).hasClass('p_spelled')) {
 
                     // calculating if this paragraph is in or near the visible region (for performance reasons)
                     topOffset = Utils.round($(paragraph).offset().top, 1);
@@ -535,7 +548,7 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
                         }
                     }
                 }
-            }, { delay: 'immediate', infoString: 'Spellchecker: implCheckSpelling' })
+            }, { delay: 'immediate', infoString: 'Spellchecker: implCheckSpelling', app: app })
                 .always(function () {
                     paragraphCache = $();
                 });
@@ -545,32 +558,12 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
          * Initialization of spell checker after document is loaded successfully.
          */
         function documentLoaded() {
+            // setting scroll node and register listener for 'scroll' events
+            scrollNode = app.getView().getContentRootNode();
 
             if (self.isOnlineSpelling()) {
                 self.setOnlineSpelling(true, true);
             }
-
-            // after receiving edit privileges it is necessary to check the document
-            self.listenTo(model, 'change:editmode operations:success', implStartOnlineSpellingDebounced);
-
-            // setting scroll node and register listener for 'scroll' events
-            scrollNode = app.getView().getContentRootNode();
-            self.listenTo(scrollNode, 'scroll', implStartOnlineSpellingDebounced);
-
-            // listen if the user update the user dictionary
-            self.listenTo(UserDictionary, 'save', onSaveUserDictionary);
-
-            // listen if the app will be visible. It's needed if e.g. the user change the dictionary in the settings and go back to the document,
-            // now the spellchecker must start to check the text with the updated dictionary.
-            self.listenTo(app.getWindow(), {
-                show: function () {
-                    // userDictionaryChanges is true if the user change the dictionary while the spellchecker document is not visible.
-                    if (userDictionaryChanges) {
-                        userDictionaryChanges = false;
-                        implStartOnlineSpellingDebounced();
-                    }
-                }
-            });
         }
 
         /**
@@ -603,7 +596,7 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
          * Start adding or removing ignored words.
          */
         function implStartAddOrRemoveIgnoreWords() {
-            if (self.isImportFinished() && (onlineSpelling === true) && model.getEditMode()) {
+            if (onlineSpelling && model.getEditMode() && self.isImportFinished()) {
                 while (ignoreWordActions.length > 0) {
                     implAddWordToIgnoreSpellcheck(ignoreWordActions.shift());
                 }
@@ -700,7 +693,7 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
                     self.resetDirectly(paragraph);
                     self.clearSpellResultCache(paragraph);
                 }
-            }, { delay: 'immediate', infoString: 'Spellchecker: implAddWordToIgnoreSpellcheck' })
+            }, { delay: 'immediate', infoString: 'Spellchecker: implAddWordToIgnoreSpellcheck', app: app })
                 .always(function () {
                     paragraphCache = $();
                     implStartOnlineSpellingDebounced();
@@ -749,7 +742,6 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
             if (!_.isEmpty(unsupportedLanguageWithoutNotification)) {
                 var msg = gt('This document contains text in languages which couldn\'t be proofed: ');
 
-                msg += '<b>';
                 _.each(unsupportedLanguageWithoutNotification, function (lang) {
 
                     langText = LocaleData.getLanguageName(lang.replace('-', '_'));
@@ -766,11 +758,9 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
                     unsupportedLanguages.push(lang);
 
                 });
-                msg += '</b>';
                 if (showDialog) {
                     app.getView().yell({
-                        message: msg,
-                        html: true
+                        message: msg
                     });
                 }
 
@@ -788,6 +778,30 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
             }
         }
 
+        /**
+         * Set or remove the event listeners
+         */
+        function setEventListeners() {
+            if (onlineSpelling) {
+                // after receiving edit privileges it is necessary to check the document
+                self.listenTo(model, 'change:editmode operations:success', implStartOnlineSpellingDebounced);
+
+                self.listenTo(scrollNode, 'scroll', implStartOnlineSpellingDebounced);
+
+                // listen if the user update the user dictionary
+                self.listenTo(UserDictionary, 'save', onSaveUserDictionary);
+
+                // listen if the app will be visible. It's needed if e.g. the user change the dictionary in the settings and go back to the document,
+                // now the spellchecker must start to check the text with the updated dictionary.
+                self.listenTo(app.getWindow(), 'show', appVisibleHandler);
+            } else {
+                self.stopListeningTo(model, 'change:editmode operations:success', implStartOnlineSpellingDebounced);
+                self.stopListeningTo(scrollNode, 'scroll', implStartOnlineSpellingDebounced);
+                self.stopListeningTo(UserDictionary, 'save', onSaveUserDictionary);
+                self.stopListeningTo(app.getWindow(), 'show', appVisibleHandler);
+            }
+        }
+
         // public methods -----------------------------------------------------
 
         this.getSpellErrorWord = function () {
@@ -914,7 +928,6 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
                 this.resetDirectly($(element).closest(DOM.PARAGRAPH_NODE_SELECTOR));
             }
         };
-
         /**
          * Removing the class marker for spell-checked paragraphs
          *
@@ -925,7 +938,9 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
             // reset to 'not spelled'
             $(paragraph).removeClass('p_spelled');
             // ... and caching paragraph for performance reasons
-            paragraphCache = paragraphCache.add(paragraph);
+            if (!model.useSlideMode()) {
+                paragraphCache = paragraphCache.add(paragraph);
+            }
             $(paragraph).removeData(SpellChecker.SPELL_REQUEST_ID);
         };
 
@@ -968,19 +983,30 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
          * Toggle automatic spell checking in the document.
          */
         this.setOnlineSpelling = function (state, noConfig) {
-            var rootNode = model.getNode();
-            if (state !== onlineSpelling || noConfig === true) {
+            var rootNode = model.getNode(),
+                stateChange = state !== onlineSpelling;
+            if (stateChange || noConfig === true) {
                 onlineSpelling = state;
                 if (noConfig !== true) {
                     app.setUserSettingsValue('onlineSpelling', onlineSpelling);
                 }
                 rootNode.toggleClass('spellerror-visible', onlineSpelling);
 
-                if (onlineSpelling === true) {
+                setEventListeners();
+
+                if (onlineSpelling) {
                     // deleting the paragraph cache, so that all paragraphs are checked
                     paragraphCache = $();
                     // start timeout handler
                     implStartOnlineSpellingDebounced();
+                } else {
+                    var allParagraphs = model.getNode().find(DOM.PARAGRAPH_NODE_SELECTOR + '.p_spelled');
+                    model.iterateArraySliced(allParagraphs, function (paragraph) {
+                        removeAllSpellErrorsInParagraph(paragraph);
+                        $(paragraph).removeClass('p_spelled');
+                        self.clearSpellResultCache(paragraph);
+                    }, { infoString: 'Spellchecker: setOnlineSpelling', app: app });
+                    paragraphCache = $();
                 }
             }
         };
