@@ -6,19 +6,22 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
 
 define('io.ox/office/textframework/components/table/table', [
     'io.ox/office/tk/utils',
+    'io.ox/office/drawinglayer/view/drawingframe',
     'io.ox/office/editframework/utils/attributeutils',
+    'io.ox/office/editframework/utils/border',
     'io.ox/office/textframework/utils/config',
     'io.ox/office/textframework/utils/operations',
     'io.ox/office/textframework/utils/dom',
     'io.ox/office/textframework/utils/position'
-], function (Utils, AttributeUtils, Config, Operations, DOM, Position) {
+], function (Utils, DrawingFrame, AttributeUtils, Border, Config, Operations, DOM, Position) {
 
     'use strict';
 
@@ -191,6 +194,15 @@ define('io.ox/office/textframework/components/table/table', [
         for (var i = 0; i < ranges.length; i++) {
             if ((ranges[i].start.node === node) && (ranges[i].end.node === node)) {
                 allOffsets.push([ranges[i].start.offset, ranges[i].end.offset]);
+            } else if (Utils.containsNode(node, ranges[i].start.node, { allowEqual: true }) && Utils.containsNode(node, ranges[i].end.node, { allowEqual: true })) {
+                // if the selection is not the td but inside a td
+                var nodeChildren = $(node).children();
+                var startNodeOffset = nodeChildren.index($(ranges[i].start.node).closest('td'));
+                var endNodeOffset = nodeChildren.index($(ranges[i].end.node).closest('td')) + 1;
+                if (endNodeOffset >= 0) {
+                    startNodeOffset = startNodeOffset >= 0 ? startNodeOffset : endNodeOffset > 0 ? endNodeOffset - 1 : 0;
+                    allOffsets.push([startNodeOffset, endNodeOffset]);
+                }
             }
         }
 
@@ -233,6 +245,10 @@ define('io.ox/office/textframework/components/table/table', [
         // checking offset
         allRangeOffsets = getAllRangeOffsets(ranges, anchorCellRange.start.node);
 
+        if (ranges.length === 0 || allRangeOffsets.length === 0) {
+            return null;
+        }
+
         if (anchorCellRange.start.offset === allRangeOffsets[0][0]) {
             startOffset = allRangeOffsets[allRangeOffsets.length - 1][0];
             endOffset = allRangeOffsets[allRangeOffsets.length - 1][1];
@@ -240,7 +256,6 @@ define('io.ox/office/textframework/components/table/table', [
             startOffset = allRangeOffsets[0][0];
             endOffset = allRangeOffsets[0][1];
         }
-
         // checking the node inside the range
         if (ranges[0].start.node === anchorCellRange.start.node) {
             activeCellNode = ranges[ranges.length - 1].end.node;
@@ -318,6 +333,10 @@ define('io.ox/office/textframework/components/table/table', [
         var tablePosition = Position.getDOMPosition(startnode, tablePos),
             tableGrid = null;
 
+        if (tablePosition && !$(tablePosition).is(DOM.TABLE_NODE_AND_DRAWING_SELECTOR)) {
+            tablePosition = Position.getDOMPosition(startnode, tablePos, true);
+        }
+
         if (tablePosition) {
             tableGrid = Table.getTableGridFromNode(tablePosition.node);
         }
@@ -340,6 +359,10 @@ define('io.ox/office/textframework/components/table/table', [
 
         var tableGrid = null;
 
+        if (DrawingFrame.isTableDrawingFrame(tableNode)) {
+            tableNode = $(tableNode).find('table');
+        }
+
         if (DOM.isTableNode(tableNode)) {
             tableGrid = AttributeUtils.getExplicitAttributes(tableNode, { family: 'table' }).tableGrid;
         }
@@ -569,7 +592,7 @@ define('io.ox/office/textframework/components/table/table', [
                 } else {
                     // the attributes are not set, the document is not loaded completely (44286)
                     explicitAttrs = AttributeUtils.getExplicitAttributes(this);
-                    colSpan = explicitAttrs && explicitAttrs.cell && explicitAttrs.cell.gridSpan || 1;
+                    colSpan = (explicitAttrs && explicitAttrs.cell && explicitAttrs.cell.gridSpan) || 1;
                 }
 
                 gridSum += colSpan;
@@ -791,8 +814,9 @@ define('io.ox/office/textframework/components/table/table', [
      */
     Table.getColumnCount = function (tableNode) {
         // do not use the number of <col> elements in <colgroup>, these elements
-        // are inserted/deleted deferred while formatting the table
-        var attributes = AttributeUtils.getExplicitAttributes(tableNode);
+        // are inserted/deleted deferred while formatting the table. Furthermore
+        // in FF there is an extra "col"-element, to prevent wrong border-display
+        var attributes = AttributeUtils.getExplicitAttributes(DrawingFrame.isTableDrawingFrame(tableNode) ? $(tableNode).find('table') : tableNode);
         if (_.isObject(attributes) && _.isObject(attributes.table) && _.isArray(attributes.table.tableGrid)) {
             return attributes.table.tableGrid.length;
         }
@@ -872,9 +896,6 @@ define('io.ox/office/textframework/components/table/table', [
             colgroup = $(table).children('colgroup');
 
         colgroup.append($('<col>').width('0%'));
-        colgroup.append($('<col>').width('0%'));
-        colgroup.children().last().remove();
-        colgroup.children().last().remove();
     };
 
     /**
@@ -887,21 +908,10 @@ define('io.ox/office/textframework/components/table/table', [
      *
      * @param {Array<Number>} tablegrid
      *  The grid array.
-     *
-     * @param {Object} [options]
-     *  Optional parameters:
-     *  @param {Boolean} [options.isGUIInsertOperation=false]
-     *      If set to true, this update was triggered by an insertColumn or
-     *      insertRow operation from the GUI.
-     *  @param {Boolean} [options.isGUIRemoveOperation=false]
-     *      If set to true, this update was triggered by an deleteColumn or
-     *      deleteRow operation from the GUI.
      */
-    Table.updateColGroup = function (table, tablegrid, options) {
+    Table.updateColGroup = function (table, tablegrid) {
 
         var colgroup = table.children('colgroup'),
-            isGUIInsertOperation = Utils.getBooleanOption(options, 'isGUIInsertOperation', false),
-            isGUIRemoveOperation = Utils.getBooleanOption(options, 'isGUIRemoveOperation', false),
             gridsum = 0,
             i = 0;
 
@@ -922,7 +932,7 @@ define('io.ox/office/textframework/components/table/table', [
             // Fix for 29401: This is also necessary during pasting internal clipboard with tables
             // Fix for 30477: This is also necessary in undo operations with tables
             // Firefox renders correctly after removing entry from colgroup.
-            if ((isGUIInsertOperation || isGUIRemoveOperation) && (i === (tablegrid.length - 1)) && ((_.browser.Firefox))) {
+            if (i === (tablegrid.length - 1) && _.browser.Firefox) {
                 // Forcing Firefox to render the table correctly
                 Table.forceTableRendering(table);
             }
@@ -1006,10 +1016,11 @@ define('io.ox/office/textframework/components/table/table', [
             i = 0;
 
         // scrolling to the active cell node, if it is not in the visible area
-        app.getView().scrollToChildNode(activeCellNode);
+        if (activeCellNode && activeCellNode.length > 0) {
+            app.getView().scrollToChildNode(activeCellNode);
+        }
 
         expandSelection = checkHorizontalExpand(selection, browserSelection, activeCellRange, backwards);
-
         if (backwards) {
 
             if (expandSelection) {
@@ -1080,13 +1091,24 @@ define('io.ox/office/textframework/components/table/table', [
                         }
                         allRangeOffsets = getAllRangeOffsets(ranges, ranges[last].end.node);
 
+                    } else {
+                        // get the tr for the last selection node
+                        siblingRow = $(ranges[last].end.node).closest('tr');
+                        if (siblingRow.length > 0) {
+                            while (siblingRow.hasClass('pb-row')) { //skip row containing page break
+                                siblingRow = siblingRow.next();
+                            }
+                            allRangeOffsets = getAllRangeOffsets(ranges, siblingRow.prev()[0]);
+                        }
+                    }
+
+                    if (siblingRow && allRangeOffsets.length > 0) {
                         for (i = 0; i < allRangeOffsets.length; i++) {
                             startPoint = new DOM.Point(siblingRow, allRangeOffsets[i][0]);
                             endPoint = new DOM.Point(siblingRow, allRangeOffsets[i][1]);
                             ranges.push(new DOM.Range(startPoint, endPoint));
                         }
                     }
-                    // else: Adding content behind the table
                 }
 
             } else {
@@ -1141,7 +1163,9 @@ define('io.ox/office/textframework/components/table/table', [
             i = 0;
 
         // scrolling to the active cell node, if it is not in the visible area
-        app.getView().scrollToChildNode(activeCellNode);
+        if (activeCellNode && activeCellNode.length > 0) {
+            app.getView().scrollToChildNode(activeCellNode);
+        }
 
         expandSelection = checkVerticalExpand(selection, browserSelection, activeCellRange, backwards);
 
@@ -1704,6 +1728,15 @@ define('io.ox/office/textframework/components/table/table', [
                 allCellOperationOptions.cell = cellOperationOptions;
                 operationOptions.attrs = allCellOperationOptions;
 
+                // INFO: In Presentation app it is possible, that 'borderInsideHor' and 'borderInsideVert' are set
+                //       to the 'cell' family in table styles. Therefore it can happen, that these properties are
+                //       set via the conditionalAttributes although this might not be wanted (48609). Then this
+                //       properties need to be overwritten with hard attributes in operations.
+                if (model.useSlideMode()) {
+                    operationOptions.attrs.cell.borderInsideHor = _.clone(Border.NONE);
+                    operationOptions.attrs.cell.borderInsideVert = _.clone(Border.NONE);
+                }
+
                 // Defining the oldAttrs, if change tracking is active
                 if (model.getChangeTrack().isActiveChangeTracking()) {
                     // Expanding operation for change tracking with old explicit attributes
@@ -1791,6 +1824,16 @@ define('io.ox/office/textframework/components/table/table', [
             });
 
             if (createOperation) {
+
+                // INFO: In Presentation app it is possible, that 'borderInsideHor' and 'borderInsideVert' are set
+                //       to the 'cell' family in table styles. Therefore it can happen, that these properties are
+                //       set via the conditionalAttributes although this might not be wanted (48609). Then this
+                //       properties need to be overwritten with hard attributes in operations.
+                if (model.useSlideMode()) {
+                    cellOperationOptions.borderInsideHor = _.clone(Border.NONE);
+                    cellOperationOptions.borderInsideVert = _.clone(Border.NONE);
+                }
+
                 allCellOperationOptions.cell = cellOperationOptions;
                 operationOptions.attrs = allCellOperationOptions;
 
@@ -1903,6 +1946,38 @@ define('io.ox/office/textframework/components/table/table', [
         return true;
     };
 
+    /**
+     * Helper function that checks, if a specified table cell is a horizontally merged cell.
+     *
+     * @param {Node|jQuery} node
+     *  The table cell node.
+     *
+     * @returns {Boolean}
+     *  Whether the specified cell node is horizontally merged.
+     */
+    Table.isHorizontallyMergedCell = function (cell) {
+        var expCellAttributes = AttributeUtils.getExplicitAttributes(cell, { family: 'cell' });
+        return !!(expCellAttributes && _.isNumber(expCellAttributes.gridSpan) && expCellAttributes.gridSpan > 1);
+    };
+
+    /**
+     * Getting the horizontal length of a table cell.
+     *
+     * @param {Node|jQuery} node
+     *  The table cell node.
+     *
+     * @returns {Number|Null}
+     *  The horizontal length of a table cell. Or null, if the specified node is no table cell.
+     */
+    Table.getHorizontalCellLength = function (cell) {
+
+        if (!DOM.isTableCellNode(cell)) { return null; }
+
+        var expCellAttributes = AttributeUtils.getExplicitAttributes(cell, { family: 'cell' });
+
+        return (expCellAttributes && _.isNumber(expCellAttributes.gridSpan)) ? expCellAttributes.gridSpan : 1;
+    };
+
     // exports ================================================================
 
     return Table;
