@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -14,11 +15,12 @@
 define('io.ox/office/textframework/components/table/tableresize', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/tracking',
+    'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/textframework/utils/operations',
     'io.ox/office/textframework/utils/dom',
     'io.ox/office/textframework/utils/position',
     'io.ox/office/textframework/components/table/table'
-], function (Utils, Tracking, Operations, DOM, Position, Table) {
+], function (Utils, Tracking, AttributeUtils, Operations, DOM, Position, Table) {
 
     'use strict';
 
@@ -67,6 +69,10 @@ define('io.ox/office/textframework/components/table/tableresize', [
                 verticalResize = false,
                 // horizontalResize is true, if the row height will be modified
                 horizontalResize = false,
+                // verticalResize is true, if the column width will be modified
+                isLeftResize = false,
+                // horizontalResize is true, if the row height will be modified
+                isTopResize = false,
                 // the container element used to visualize the resizing
                 resizeLine = $('<div>').addClass('resizeline'),
                 // the distance from body element to 'officemaindiv' in pixel
@@ -101,28 +107,34 @@ define('io.ox/office/textframework/components/table/tableresize', [
                 gridSum = 0,
                 // the number of the grid count, that will be modified
                 shiftedGrid = 0,
-                // maximum shift to the left
+                // maximum shift to the left (-1 means 'no limit')
                 maxLeftShift = 0,
-                // maximum shift to the right
+                // maximum shift to the right (-1 means 'no limit')
                 maxRightShift = 0,
-                // maximum shift to the top
+                // maximum shift to the top (-1 means 'no limit')
                 maxTopShift = 0,
-                // maximum shift to the bottom
+                // maximum shift to the bottom (-1 means 'no limit')
                 maxBottomShift = 0,
-                // maximum right value of shift position
+                // maximum right value of shift position (-1 means 'no limit')
                 maxRightValue = 0,
-                // minimum left value of shift position
+                // minimum left value of shift position (-1 means 'no limit')
                 minLeftValue = 0,
                 // minimum width of a column in px
                 // Fix for 29678, using min width like in Word
                 minColumnWidth = 16,
+                // minimum height of a row in px
+                minRowHeight = 5,
                 //zoom factor in floating point notation
                 zoomFactor = view.getZoomFactor() / 100,
                 // the current scroll position
                 scrollX = 0, scrollY = 0,
                 // the start scroll position
                 startScrollX = 0, startScrollY = 0,
-                //maximum height of page content in pixels (without margins)
+                // whether the most right cell can be expanded to the right
+                allowLastCellOverflow = false,
+                // whether the table is located inside a drawing node
+                isTableDrawing = false,
+               // maximum height of page content in pixels (without margins)
                 pageMaxHeight = editor.getPageLayout().getDefPageActiveHeight({ convertToPixel: true }) - 5; // -5 px because of difference in rounding and offsetHeight, position top in IE, FF
 
             /**
@@ -151,6 +163,12 @@ define('io.ox/office/textframework/components/table/tableresize', [
                     verticalResize = true;
                 } else if (resizeNode.is('div.resize.bottom')) {
                     horizontalResize = true;
+                } else if (resizeNode.is('div.resize.left')) {
+                    verticalResize = true;
+                    isLeftResize = true;
+                } else if (resizeNode.is('div.resize.top')) {
+                    horizontalResize = true;
+                    isTopResize = true;
                 }
 
                 // calculating maximum resize values
@@ -158,6 +176,10 @@ define('io.ox/office/textframework/components/table/tableresize', [
                 rowNode =  resizeNode.closest('tr');
                 tableNode = resizeNode.closest('table');
 
+                // in drawings of type 'table' the most right cells can be expanded to the right
+                isTableDrawing = DOM.isTableNodeInTableDrawing(tableNode);
+                allowLastCellOverflow = isTableDrawing;
+
                 if (verticalResize) {
                     $(resizeLine).css({ width: '1px', height: '100%', left: startX, top: '0px' });
                     officemaindiv.append(resizeLine);
@@ -187,20 +209,36 @@ define('io.ox/office/textframework/components/table/tableresize', [
                     // Fix for 30798, cells with lists need an increased minimum width
                     if (cellNode.find(DOM.LIST_LABEL_NODE_SELECTOR).length > 0) { minColumnWidth *= 4; }
 
-                    maxLeftShift = pixelGrid[shiftedGrid] * zoomFactor;
-                    if (!lastCell) {
-                        maxRightShift = pixelGrid[shiftedGrid + 1] * zoomFactor;
+                    if (isLeftResize) {
+                        maxLeftShift = -1; // no limit
+                        maxRightShift = pixelGrid[shiftedGrid] * zoomFactor - resizeNode.position().left; // taking into account, that the resizer is shifted to the right
+                        allowLastCellOverflow = false;
                     } else {
-                        maxRightShift = (maxTableWidth - oldTableWidth) * zoomFactor;
+                        maxLeftShift = pixelGrid[shiftedGrid] * zoomFactor;
+                        if (!lastCell) {
+                            maxRightShift = pixelGrid[shiftedGrid + 1] * zoomFactor;
+                            allowLastCellOverflow = false;
+                        } else {
+                            maxRightShift = (maxTableWidth - oldTableWidth) * zoomFactor;
+                        }
                     }
 
                 } else if (horizontalResize) {
                     $(resizeLine).css({ width: '100%', height: '1px', left: 0, top: startY });
                     officemaindiv.append(resizeLine);
-                    // calculating maxTopShift
-                    maxTopShift = cellNode.outerHeight() * zoomFactor;
-                    // calculating maxBottomShift - max height that single row can have
-                    maxBottomShift = (pageMaxHeight - cellNode.outerHeight()) * zoomFactor;
+
+                    if (isTopResize) {
+                        // calculating maxTopShift
+                        maxTopShift = -1; // no limit
+
+                        // calculating maxBottomShift - max height that single row can have
+                        maxBottomShift = cellNode.outerHeight() * zoomFactor - resizeNode.position().top - minRowHeight;
+                    } else {
+                        // calculating maxTopShift
+                        maxTopShift = cellNode.outerHeight() * zoomFactor;
+                        // calculating maxBottomShift - max height that single row can have
+                        maxBottomShift = (pageMaxHeight - cellNode.outerHeight()) * zoomFactor;
+                    }
                 }
 
                 editor.getCurrentRootNode().css('cursor', resizeNode.css('cursor'));  // setting cursor for increasing drawing
@@ -235,16 +273,17 @@ define('io.ox/office/textframework/components/table/tableresize', [
 
                 if (verticalResize) {
 
-                    maxRightValue = startX + maxRightShift;
-                    minLeftValue = startX - maxLeftShift + (minColumnWidth * zoomFactor);
-                    if (!lastCell) { maxRightValue -= (minColumnWidth * zoomFactor); }
+                    maxRightValue = (maxRightShift > -1) ? startX + maxRightShift : -1;
+                    minLeftValue = (maxLeftShift > -1) ? (startX - maxLeftShift + (minColumnWidth * zoomFactor)) : -1;
+
+                    if (maxRightValue > -1 && !lastCell) { maxRightValue -= (minColumnWidth * zoomFactor); }
 
                     shiftX = currentX;
                     shiftY = 0;
 
-                    if (shiftX >= maxRightValue) {
+                    if (maxRightValue > -1 && shiftX >= maxRightValue && !allowLastCellOverflow) {
                         shiftX = maxRightValue;
-                    } else if (shiftX <= minLeftValue) {
+                    } else if (minLeftValue > -1 && shiftX <= minLeftValue) {
                         shiftX = minLeftValue;
                     }
 
@@ -252,10 +291,10 @@ define('io.ox/office/textframework/components/table/tableresize', [
                     shiftX = 0;
                     shiftY = currentY;
 
-                    if ((shiftY - startY) <= -maxTopShift) {
+                    if (maxTopShift > -1 && (shiftY - startY) <= -maxTopShift) {
                         shiftY = startY - maxTopShift;
                     }
-                    if ((shiftY - startY) >= maxBottomShift) {
+                    if (maxBottomShift > -1 && (shiftY - startY) >= maxBottomShift) {
                         shiftY = startY + maxBottomShift;
                     }
                 }
@@ -298,13 +337,102 @@ define('io.ox/office/textframework/components/table/tableresize', [
                 var generator = editor.createOperationsGenerator(),
                     rowPosition = null,
                     rowHeight = 0,
-                    newRowHeight = 0,
+                    newRowHeight = 0, oldRowHeight = 0,
                     // the old attributes
                     oldAttrs = null,
-                    // the attributes for the setAttributes operation
-                    attrs = null,
+                    // the attributes for the setAttributes operation(s)
+                    attrs = null, drawingOperationProperties = null,
                     target = editor.getActiveTarget(),
-                    operationProperties = {};
+                    operationProperties = {},
+                    // the logical table position
+                    tablePos = null,
+                    // the shift of the table
+                    tableShift = null,
+                    // the drawing node of a table drawing
+                    drawingNode = null,
+                    // the attributes of a table drawing node and row
+                    drawingAttrs = null, rowAttrs = null,
+                    // a shift of the position of the table drawing node
+                    deltaTablePos = 0,
+                    // saving the old value for the top and left position in the drawing attributes
+                    oldDrawingAttrsTop = 0, oldDrawingAttrsLeft = 0,
+                    // the height of the table row in the DOM
+                    realRowNodeHeight = 0;
+
+                // helper function for the left resizer
+                function handleLeftResize() {
+
+                    // setting the table attributes
+                    drawingNode = tableNode.closest('div.drawing');
+                    // table drawings always have explicit 'drawing' attributes
+                    drawingAttrs = AttributeUtils.getExplicitAttributes(drawingNode, { family: 'drawing' });
+
+                    oldDrawingAttrsLeft = drawingAttrs.left;
+
+                    if (editor.useSlideMode()) {
+                        // setting the left value of the drawing by comparing the vertical line with the slide position
+                        drawingAttrs.left = Utils.convertLengthToHmm((resizeLine.offset().left - drawingNode.closest('div.slide').offset().left) / zoomFactor);
+
+                        // improving precision -> table width can only be modified like change of left drawing position
+
+                    } else {
+                        // TODO
+                        // drawingAttrs.left += Utils.convertLengthToHmm(shiftX, 'px'); // setting new left position of the table drawing (OX Text style)
+                    }
+
+                    attrs = attrs || {};
+                    attrs.drawing = drawingAttrs;
+                    attrs.drawing.width = newTableWidth; // modifying the table width
+
+                    // improving precision of shiftX by simply using the shift of the table in horizontal direction
+                    deltaTablePos = drawingAttrs.left - oldDrawingAttrsLeft;
+
+                    shiftX = Utils.convertHmmToLength(deltaTablePos, 'px', 1);
+                }
+
+                // helper function for the top resizer
+                function handleTopResize() {
+
+                    // the upper left position of the table (drawing) was changed
+                    tablePos = _.initial(rowPosition);
+                    tableShift = Utils.convertLengthToHmm(rowHeight - oldRowHeight, 'px');
+
+                    if (tableShift !== 0 && isTableDrawing) {
+
+                        drawingNode = tableNode.closest('div.drawing');
+                        // table drawings always have explicit 'drawing' attributes
+                        drawingAttrs = AttributeUtils.getExplicitAttributes(drawingNode, { family: 'drawing' });
+
+                        oldDrawingAttrsTop = drawingAttrs.top;
+
+                        if (editor.useSlideMode()) {
+                            // setting the top value of the drawing by comparing the horizontal line with the slide position
+                            drawingAttrs.top = Utils.convertLengthToHmm((resizeLine.offset().top - drawingNode.closest('div.slide').offset().top) / zoomFactor);
+                        } else {
+                            // TODO
+                            drawingAttrs.top -= tableShift;
+                        }
+
+                        drawingOperationProperties = {
+                            attrs: { drawing: drawingAttrs },
+                            start: tablePos
+                        };
+
+                        if (target) { drawingOperationProperties.target = target; }
+
+                        generator.generateOperation(Operations.SET_ATTRIBUTES, drawingOperationProperties);
+
+                        // shift of table in vertical direction
+                        deltaTablePos = oldDrawingAttrsTop - drawingAttrs.top;
+
+                        // the height of the first row can be calculated more precise by using the difference of top position of table
+                        rowAttrs = AttributeUtils.getExplicitAttributes(rowNode, { family: 'row' });
+                        if (rowAttrs && _.isNumber(rowAttrs.height)) {
+                            realRowNodeHeight = Utils.convertLengthToHmm(rowNode.outerHeight(true), 'px');
+                            newRowHeight = Math.max(realRowNodeHeight, rowAttrs.height) + deltaTablePos;
+                        }
+                    }
+                }
 
                 // taking care of scroll node
                 scrollX = scrollNode.scrollLeft() - startScrollX;
@@ -329,37 +457,50 @@ define('io.ox/office/textframework/components/table/tableresize', [
 
                     if ((_.isNumber(currentX)) && (currentX !== startX)) {
 
-                        maxRightValue = startX + maxRightShift;
-                        minLeftValue = startX - maxLeftShift + (minColumnWidth * zoomFactor);
-                        if (!lastCell) { maxRightValue -= (minColumnWidth * zoomFactor); }
+                        maxRightValue = (maxRightShift > -1) ? (startX + maxRightShift) : -1;
+                        minLeftValue = (maxLeftShift > -1) ? (startX - maxLeftShift + (minColumnWidth * zoomFactor)) : -1;
+                        if (!lastCell && maxRightValue > -1) { maxRightValue -= (minColumnWidth * zoomFactor); }
 
-                        if (currentX >= maxRightValue) {
+                        if (maxRightValue > -1 && currentX >= maxRightValue && !allowLastCellOverflow) {
                             currentX = maxRightValue;
-                        } else if (currentX <= minLeftValue) {
+                        } else if (minLeftValue > -1 && currentX <= minLeftValue) {
                             currentX = minLeftValue;
                         }
 
                         shiftX = (currentX - startX) / zoomFactor;
 
-                        newTableWidth = lastCell ? (oldTableWidth + shiftX) : oldTableWidth;
+                        // the table (drawing) needs to get a new upper left position
+                        if (isLeftResize && shiftX !== 0 && isTableDrawing) { handleLeftResize(); }
+
+                        newTableWidth = isLeftResize ? (oldTableWidth - shiftX) : (lastCell ? (oldTableWidth + shiftX) : oldTableWidth);
 
                         // -> shifting the border
-                        pixelGrid[shiftedGrid] += shiftX;
-                        if (!lastCell) { pixelGrid[shiftedGrid + 1] -= shiftX; }
+                        pixelGrid[shiftedGrid] = isLeftResize ? (pixelGrid[shiftedGrid] - shiftX) : (pixelGrid[shiftedGrid] + shiftX);
+
+                        if (!lastCell && !isLeftResize) { pixelGrid[shiftedGrid + 1] -= shiftX; }
 
                         // converting modified pixel grid to new relation table grid
                         for (var i = 0; i < pixelGrid.length; i++) {
                             tableGrid.push(Math.round(gridSum * pixelGrid[i] / newTableWidth));  // only ints
                         }
 
-                        if (!lastCell && (editor.getStyleCollection('table').getElementAttributes(tableNode).table.width === 'auto')) {
+                        if (!lastCell && !isLeftResize && (editor.getStyleCollection('table').getElementAttributes(tableNode).table.width === 'auto')) {
                             newTableWidth = 'auto';
                         } else {
                             newTableWidth = Utils.convertLengthToHmm(newTableWidth, 'px');
                         }
 
                         // the table attributes for the setAttributes operation
-                        attrs = { table: { tableGrid: tableGrid, width: newTableWidth } };
+                        attrs = attrs || {};
+                        if (isTableDrawing) {
+                            attrs.table = { tableGrid: tableGrid };
+                            if (newTableWidth !== 'auto') {
+                                attrs.drawing = attrs.drawing || {};
+                                attrs.drawing.width = newTableWidth;
+                            } // width must be assigned to table drawing
+                        } else {
+                            attrs.table = { tableGrid: tableGrid, width: newTableWidth };
+                        }
 
                         if (editor.getChangeTrack().isActiveChangeTracking()) {
                             // Expanding operation for change tracking with old explicit attributes
@@ -393,14 +534,16 @@ define('io.ox/office/textframework/components/table/tableresize', [
 
                     if ((_.isNumber(currentY)) && (currentY !== startY)) {
 
-                        rowHeight = rowNode.outerHeight() + ((currentY - startY) / zoomFactor);
+                        oldRowHeight = rowNode.outerHeight();
 
+                        rowHeight = isTopResize ? (oldRowHeight - ((currentY - startY) / zoomFactor)) : (oldRowHeight + ((currentY - startY) / zoomFactor));
                         if (rowHeight < 0) { rowHeight = 0; }
                         if (rowHeight > pageMaxHeight) { rowHeight = pageMaxHeight; }
-
                         newRowHeight = Utils.convertLengthToHmm(rowHeight, 'px');
                         rowPosition = Position.getOxoPosition(editor.getCurrentRootNode(), rowNode.get(0), 0);
 
+                        if (isTopResize && isTableDrawing) { handleTopResize(); }  // handling a top resize of the table
+
                         // the row attributes for the setAttributes operation
                         attrs = { row: { height: newRowHeight } };
 
