@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -16,8 +17,9 @@ define('io.ox/office/textframework/format/characterstyles', [
     'io.ox/office/editframework/utils/color',
     'io.ox/office/editframework/utils/lineheight',
     'io.ox/office/editframework/model/stylecollection',
+    'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/textframework/utils/dom'
-], function (Utils, Color, LineHeight, StyleCollection, DOM) {
+], function (Utils, Color, LineHeight, StyleCollection, AttributeUtils, DOM) {
 
     'use strict';
 
@@ -26,10 +28,24 @@ define('io.ox/office/textframework/format/characterstyles', [
 
             fontName: {
                 def: 'Arial',
-                format: function (element, fontName) {
+                preview: function (element, fontName) {
                     element.css('font-family', this.getCssFontFamily(fontName));
-                },
-                preview: true // 'true' calls the own 'format' method
+                }
+            },
+
+            fontNameSymbol: {
+                def: '',
+                preview: function (element, fontName) {
+                    element.css('font-family', this.getCssFontFamily(fontName));
+                }
+            },
+
+            fontNameComplex: {
+                def: ''
+            },
+
+            fontNameEastAsia: {
+                def: ''
             },
 
             fontSize: {
@@ -65,8 +81,12 @@ define('io.ox/office/textframework/format/characterstyles', [
                 def: 'none'
             },
 
+            // baseline for Text
             vertAlign: { def: 'baseline' },
 
+            // baseline for Presentation
+            baseline: { def: 0 },
+
             color: {
                 def: Color.AUTO,
                 // format: color will be set in format handler, depending on fill colors
@@ -118,6 +138,10 @@ define('io.ox/office/textframework/format/characterstyles', [
                 }
             },
 
+            field: {
+                def: '' // #45332, new odf filter sends field properties as character attribute
+            },
+
             // special attributes
 
             spellerror: {
@@ -136,6 +160,14 @@ define('io.ox/office/textframework/format/characterstyles', [
                     element.toggleClass('highlight', state);
                 },
                 special: true
+            },
+
+            caps: {
+                def: 'none',
+                format: function (element, state) {
+                    element.toggleClass('uppercase', state === 'all');
+                    element.toggleClass('lowercase', state === 'small');
+                }
             }
 
         },
@@ -213,7 +245,9 @@ define('io.ox/office/textframework/format/characterstyles', [
                 // the effective line height, that might be reduced inside comment
                 effectiveLineHeight = paragraphAttributes.lineHeight,
                 // the maximum font size inside a comment
-                commentMaxFontSize = 10;
+                commentMaxFontSize = 10,
+                // the target chain, that is required to resolve the correct theme
+                target = null;
 
             // restriction of max font size for small devices
             if (Utils.SMALL_DEVICE && fontSize > 16) {
@@ -239,26 +273,24 @@ define('io.ox/office/textframework/format/characterstyles', [
             allFillColors.push(characterAttributes.fillColor);
 
             // calculate effective text color, according to fill colors
-            // or theme if it's hyperlink, #46253
+            // or theme if it's hyperlink, #45263
             if (DOM.isHyperlinkNode(textSpan) && docModel.useSlideMode()) {
-                textColor = '#' + docModel.getTheme().getSchemeColor('hyperlink', '00f');
+                textColor = '#' + docModel.getTheme(docModel.getTargetChainForNode(textSpan)).getSchemeColor('hyperlink', '00f');
                 textDecoration = 'underline';
             } else {
-                textColor = self.getCssTextColor(textColor, allFillColors);
+                if (docModel.useSlideMode() && AttributeUtils.isColorThemed(textColor)) { target = docModel.getTargetChainForNode(paragraph); }
+                textColor = self.getCssTextColor(textColor, allFillColors, target);
             }
 
             // calculate font height and vertical alignment (according to escapement)
-            switch (characterAttributes.vertAlign) {
-                case 'sub':
-                    position = 'relative';
-                    bottom = 0;
-                    fontSize = Utils.round(fontSize * 0.66, 0.1);
-                    break;
-                case 'super':
-                    position = 'relative';
-                    bottom = Utils.convertToEM(fontSize * 0.5, 'pt');
-                    fontSize = Utils.round(fontSize * 0.66, 0.1);
-                    break;
+            if (characterAttributes.vertAlign === 'sub' || characterAttributes.baseline < 0) {
+                position = 'relative';
+                bottom = 0;
+                fontSize = Utils.round(fontSize * 0.66, 0.1);
+            } else if (characterAttributes.vertAlign === 'super' || characterAttributes.baseline > 0) {
+                position = 'relative';
+                bottom = '0.5EM';
+                fontSize = Utils.round(fontSize * 0.66, 0.1);
             }
 
             // inside comments the paragraph bottom margin must be 0 (even if this was not applied via operation),
@@ -271,17 +303,27 @@ define('io.ox/office/textframework/format/characterstyles', [
                 effectiveLineHeight = LineHeight.SINGLE;
             }
 
+            if (!target && docModel.useSlideMode() && AttributeUtils.isCharacterFontThemed(characterAttributes)) {
+                target = docModel.getTargetChainForNode(paragraph);
+            }
+
+            var fontFamily = self.getCssFontFamily(characterAttributes.fontName, target);
+            if (characterAttributes.fontNameSymbol !== '') {
+                fontFamily += fontFamily === '' ? '' : ', ';
+                fontFamily += self.getCssFontFamily(characterAttributes.fontNameSymbol);
+            }
             // update CSS of the text span
             textSpan.css({
                 color: textColor,
                 fontSize: Utils.convertToEM(fontSize, 'pt'),
                 textDecoration: textDecoration,
                 position: position,
-                bottom: bottom
+                bottom: bottom,
+                fontFamily: fontFamily
             });
 
             // update line height due to changed font settings
-            self.updateElementLineHeight(textSpan, effectiveLineHeight, characterAttributes);
+            self.updateElementLineHeight(textSpan, effectiveLineHeight, characterAttributes, target);
 
             // change track attribute handling
             docModel.getChangeTrack().updateChangeTrackAttributes(textSpan, mergedAttributes);
@@ -317,36 +359,13 @@ define('io.ox/office/textframework/format/characterstyles', [
          *      Whether the text will be rendered in bold characters.
          *  @param {Boolean} [attributes.italic=false]
          *      Whether the text will be rendered in italic characters.
+         *
+         * @param {String|Array<String>} [target]
+         *  An optional target string or an ordered collection of target strings
+         *  to specify the theme's target.
+         *
          */
-        this.updateElementLineHeight = function (element, lineHeight, charAttributes) {
-
-            var calced = this.calculateLineHeight(lineHeight, charAttributes);
-            $(element).first().css('line-height', calced.val + calced.type);
-        };
-
-        /**
-         * calculate text line height for assigned lineHeight options.
-         *
-         * @param {Object} lineHeight
-         *  The new line height value. Must contain the properties 'type' and
-         *  'value'.
-         *
-         * @param {Object} attributes
-         *  Character formatting attributes influencing the normal line height.
-         *  @param {String} attributes.fontName
-         *      The name of the original font family (case-insensitive).
-         *  @param {Number} attributes.fontSize
-         *      The font size, in points.
-         *  @param {Boolean} [attributes.bold=false]
-         *      Whether the text will be rendered in bold characters.
-         *  @param {Boolean} [attributes.italic=false]
-         *      Whether the text will be rendered in italic characters.
-         *
-         *  @return {Object}
-         *      object with type & value
-         *      { val: 5, type: 'px'} or { val: 35.1, type: '%'}
-         */
-        this.calculateLineHeight = function (lineHeight, charAttributes) {
+        this.updateElementLineHeight = function (element, lineHeight, charAttributes, target) {
 
             var // the font collection
                 fontCollection = docModel.getFontCollection(),
@@ -355,12 +374,29 @@ define('io.ox/office/textframework/format/characterstyles', [
                 // type could be 'px' or '%
                 type = 'px',
                 //
-                normalLineHeight = 0;
+                normalLineHeight = 0,
+                //
+                fontHeight = 0,
+                //
+                theme = null,
+                //
+                vertAlign = null;
 
             if (lineHeight.type === 'fixed') {
                 //line height as passed
             } else {
-                normalLineHeight = fontCollection.getNormalLineHeight(charAttributes);
+                if (target) {
+                    theme = docModel.getThemeCollection().getTheme('', target);
+                }
+                // workaround for bug 47960
+                normalLineHeight = fontCollection.getNormalLineHeight(charAttributes, { theme: theme, zoom: 10 }) / 10;
+
+                // workaround for Bug 47960 & Bug 45951
+                if (docModel.useSlideMode()) {
+                    fontHeight = normalLineHeight;
+                } else {
+                    fontHeight = Utils.convertLength(charAttributes.fontSize, 'pt', 'px');
+                }
 
                 // calculate effective line height
                 switch (lineHeight.type) {
@@ -380,12 +416,22 @@ define('io.ox/office/textframework/format/characterstyles', [
                         Utils.error('CharacterStyles.updateElementLineHeight(): invalid line height type');
                 }
 
-                //transform to relative size, (lineHeight / fontSize)
-                height = (height / normalLineHeight) * 100;
-                type = '%';
-            }
+                // offset to pretend rounding error fix for Bug 47960
+                height =  Math.ceil(height) + 0.5;
 
-            return { val: height, type: type };
+                //transform to relative size, (lineHeight / fontSize)
+                height = Utils.round((height / fontHeight) * 100, 0.01);
+                type = '%';
+
+                if (height < 100) {
+                    //workaround for Bug 48695
+                    vertAlign = '0.5em';
+                }
+            }
+            $(element).first().css({
+                lineHeight: height + type,
+                verticalAlign: vertAlign
+            });
         };
 
         // initialization -----------------------------------------------------
