@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -19,8 +20,10 @@ define('io.ox/office/textframework/format/tablestyles', [
     'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/editframework/model/stylecollection',
     'io.ox/office/textframework/utils/dom',
-    'io.ox/office/textframework/components/table/table'
-], function (Utils, Color, Border, LineHeight, AttributeUtils, StyleCollection, DOM, Table) {
+    'io.ox/office/textframework/components/table/table',
+    'io.ox/office/editframework/utils/gradient'
+
+], function (Utils, Color, Border, LineHeight, AttributeUtils, StyleCollection, DOM, Table, Gradient) {
 
     'use strict';
 
@@ -136,7 +139,10 @@ define('io.ox/office/textframework/format/tablestyles', [
         },
 
         // the conditional table attributes (only 'wholeTable' has no geometric dependencies)
-        GEOMETRIC_TABLE_ATTRIBUTES = ['firstRow', 'lastRow', 'firstCol', 'lastCol', 'band1Vert', 'band2Vert', 'band1Hor', 'band2Hor', 'northEastCell', 'northWestCell', 'southEastCell', 'southWestCell'];
+        GEOMETRIC_TABLE_ATTRIBUTES = ['firstRow', 'lastRow', 'firstCol', 'lastCol', 'band1Vert', 'band2Vert', 'band1Hor', 'band2Hor', 'northEastCell', 'northWestCell', 'southEastCell', 'southWestCell'],
+
+        // the border properties
+        BORDER_PROPS = ['borderTop', 'borderBottom', 'borderLeft', 'borderRight', 'borderInsideHor', 'borderInsideVert'];
 
     // class TableStyles ======================================================
 
@@ -154,7 +160,8 @@ define('io.ox/office/textframework/format/tablestyles', [
     function TableStyles(docModel) {
 
         var // self reference
-            self = this;
+            self = this,
+            app = docModel.getApp();
 
         // base constructor ---------------------------------------------------
 
@@ -272,6 +279,11 @@ define('io.ox/office/textframework/format/tablestyles', [
                     // copy all attributes from the style sheet to the result object
                     docModel.extendAttributes(attributes, conditionalAttributes);
 
+                    // INFO: In Presentation app it is possible, that 'borderInsideHor' and 'borderInsideVert' are set
+                    //       to the 'cell' family in table styles. Therefore it can happen, that these properties are
+                    //       set via the conditionalAttributes although this might not be wanted (48609). Then this
+                    //       properties need to be overwritten with hard attributes in operations.
+
                     // copy inner borders to outer cell borders, if cell is located inside the current table area
                     updateOuterCellBorder(conditionalAttributes, 'borderTop', 'borderInsideHor', !isVerticalBand || isFirstRow);
                     updateOuterCellBorder(conditionalAttributes, 'borderBottom', 'borderInsideHor', !isVerticalBand || isLastRow);
@@ -285,6 +297,22 @@ define('io.ox/office/textframework/format/tablestyles', [
                 }
             }
 
+            // in presentation app the border attributes are assigned to 'cell' family, not 'table' family. But for correct
+            // resolving of table border properties it is necessary, that they are assigned to the 'table' family, too (48647).
+            function transferWholeTableBordersToTable() {
+                if (styleAttributes.wholeTable.cell) {
+                    _.each(BORDER_PROPS, function (prop) {
+                        if (styleAttributes.wholeTable.cell[prop] && (!styleAttributes.wholeTable.table || !styleAttributes.wholeTable.table[prop])) {
+                            if (!attributes.table) { attributes.table = {}; }
+                            attributes.table[prop] = _.copy(styleAttributes.wholeTable.cell[prop], true);
+                        }
+                    });
+                }
+            }
+
+            // in presentation app the border attributes are set at the 'cell' family
+            if (docModel.useSlideMode() && styleAttributes.wholeTable) { transferWholeTableBordersToTable(); }
+
             // wholeTable: always
             mergeConditionalAttributes('wholeTable', true, true);
 
@@ -365,6 +393,60 @@ define('io.ox/office/textframework/format/tablestyles', [
             return resolveTableStyleAttributes({ wholeTable: elementAttributes }, tableNode, cellNode);
         }
 
+        /**
+         * Setting the table background. This can currently only be done using a style.
+         * Only supported in presentation app.
+         *
+         * @param {jQuery} tableNode
+         *  The DOM table node, as jQuery object.
+         *
+         * @param {Object} styleSheetAttributeMap
+         *  The style sheet attributes of the table
+         */
+        function handleTableBackground(table, styleSheetAttributeMap) {
+
+            if (styleSheetAttributeMap && styleSheetAttributeMap.backgroundStyle && styleSheetAttributeMap.backgroundStyle.fill) {
+
+                var // the fill attributes of the slide
+                    fillAttrs = styleSheetAttributeMap.backgroundStyle.fill,
+                    // the CSS properties for the slide
+                    cssProps = {};
+
+                // calculate the CSS fill attributes
+                switch (fillAttrs.type) {
+                    case 'none':
+                        // clear everything: color and bitmaps
+                        cssProps.background = '';
+                        break;
+
+                    case 'solid':
+                        cssProps.background = docModel.getCssColor(fillAttrs.color, 'fill', docModel.getTargetChain(docModel.getSlideIdForNode(table)));
+                        break;
+
+                    case 'gradient':
+                        var
+                            elmSlide  = table[0],
+                            target    = docModel.getTargetChain(docModel.getSlideIdForNode(table)),
+                            gradient  = Gradient.create(Gradient.getDescriptorFromAttributes(fillAttrs)),
+                            dataUrl   = Gradient.parseImageDataUrl(gradient, docModel, { width: elmSlide.offsetWidth, height: elmSlide.offsetHeight }, target);
+
+                        cssProps.background = ['url("', dataUrl, '")'].join('');
+                        cssProps.backgroundSize = '100%'; // #49272
+                        break;
+
+                    default:
+                        Utils.warn('TableStyles.handleTableBackground(): unknown fill type "' + fillAttrs.type + '"');
+                }
+
+                // apply the fill attributes
+                table.css(cssProps);
+
+            } else {
+                table.css({ background: '' }); // removing background
+            }
+
+        }
+
         /**
          * Will be called for every table element whose attributes have been
          * changed. Repositions and reformats the table according to the passed
@@ -403,16 +485,22 @@ define('io.ox/office/textframework/format/tablestyles', [
                 tableAttributes = AttributeUtils.getExplicitAttributes(table, { family: 'table' }),
                 // all row nodes in the table
                 rowNodes = DOM.getTableRows(table),
+                // a collector for all cells in the first row
+                allCellsInFirstRow = rowNodes.first().children('td').children('div.cell'),
+                // the upper left cell of the table (the div.cell element)
+                firstCell = allCellsInFirstRow.first(),
+                // a counter for the cells (performance)
+                cellCounter = allCellsInFirstRow.length * rowNodes.length,
                 // whether this update was triggered by a resize of table (column width)
                 isTableResize = false,
                 // whether the table has a 'simple' style
                 isSimpleTableStyle = false,
-                // whether cells were added to the table
-                isGUIInsertOperation = false,
                 // whether cells were removed from the table
                 isGUIRemoveOperation = false,
                 // the number of the first row, that requires a formatting update
                 minUpdateRow = null,
+                // the style sheet attributes for the table
+                styleSheetAttributeMap = null,
                 // the result Deferred object
                 def = null;
 
@@ -421,8 +509,9 @@ define('io.ox/office/textframework/format/tablestyles', [
             // Otherwise only the new cells (insert operations) or no cells
             // (delete operations) need to be formatted.
             function checkSimpleTableStyle() {
-                var isSimple = true,
-                    styleSheetAttributeMap = tableStyles.getStyleSheetAttributeMap(mergedAttributes.styleId);
+
+                var isSimple = true;
+
                 _.each(GEOMETRIC_TABLE_ATTRIBUTES, function (attribute) {
                     if ((attribute in styleSheetAttributeMap) && !_.contains(tableAttributes.exclude, attribute)) {
                         isSimple = false;
@@ -431,6 +520,24 @@ define('io.ox/office/textframework/format/tablestyles', [
                 return isSimple;
             }
 
+            // helper function to update the top and the left resizers in the table cell
+            function updateTopLeftResizers() {
+
+                // the old upper left cell is no longer the current upper left cell
+                table.find('.upperLeftCell').removeClass('upperLeftCell').removeData('cellcount');
+
+                // removing old top and left resizer nodes
+                table.find('.resize.top, .resize.left').remove();
+
+                // adding new top and left resizers to first row and first column
+                allCellsInFirstRow.prepend($('<div>').addClass('resize top'));
+
+                rowNodes.children('td:first-child').children('div.cell').prepend($('<div>').addClass('resize left'));
+
+                // marking the new upper left cell (saving cell count for performance reasons)
+                firstCell.addClass('upperLeftCell').data('cellcount', cellCounter);
+            }
+
             // updates the formatting of the passed table row
             function updateRowFormatting(rowNode) {
 
@@ -477,15 +584,17 @@ define('io.ox/office/textframework/format/tablestyles', [
                 });
             }
 
-            // checking if the attributes have table geometric dependencies
+            // checking if the attributes have table geometric dependencies or table background
             if (mergedAttributes.styleId) {
+                styleSheetAttributeMap = tableStyles.getStyleSheetAttributeMap(mergedAttributes.styleId);
                 isSimpleTableStyle = checkSimpleTableStyle();
             }
 
+            // handling of table background
+            // if (docModel.useSlideMode()) { handleTableBackground(table, styleSheetAttributeMap); }
+
             if (table.data('gui')) {
-                if (table.data('gui') === 'insert') {
-                    isGUIInsertOperation = true;
-                } else if (table.data('gui') === 'remove') {
+                if (table.data('gui') === 'remove') {
                     isGUIRemoveOperation = true;
                 }
                 table.removeData('gui');
@@ -500,11 +609,10 @@ define('io.ox/office/textframework/format/tablestyles', [
             if ((table.data('internalClipboard') || table.data('undoRedoRunning')) && _.browser.Firefox) {
                 table.removeData('internalClipboard');
                 table.removeData('undoRedoRunning');
-                isGUIInsertOperation = true;
             }
 
             // update column widths (also required for bug fixes 29212 and 29675)
-            Table.updateColGroup(table, tableGrid, { isGUIInsertOperation: isGUIInsertOperation, isGUIRemoveOperation: isGUIRemoveOperation });
+            Table.updateColGroup(table, tableGrid);
 
             // Fix for 30821 (on webkit browsers), max-width of 100% is ignored, if width is defined
             if ((_.browser.WebKit) && (table.closest('div.cellcontent').length > 0) && (table.css('max-width') === '100%') && (table.width() > table.closest('div.cellcontent').width())) {
@@ -526,6 +634,11 @@ define('io.ox/office/textframework/format/tablestyles', [
             // required, so that the user gets faster feed back
             async = async || (Utils.IOS && Utils.SLOW_DEVICE);
 
+            // updating the top and left resize markers in the table. This is necessary, if the
+            // upper left cell is no longer the upper left cell of the table or if the number of
+            // cells in the table has changed (insertRow, ...)
+            if (docModel.useSlideMode() && firstCell.length > 0 && (!firstCell.hasClass('upperLeftCell') || firstCell.data('cellcount') !== cellCounter)) { updateTopLeftResizers(); }
+
             // Performance: Reducing the number of rows, because upper rows require no update
             if (_.isNumber(minUpdateRow)) {
                 rowNodes = rowNodes.slice(minUpdateRow);
@@ -537,14 +650,24 @@ define('io.ox/office/textframework/format/tablestyles', [
             // update rows, cells, ... , but only if required
             if (async) {
                 // process the table asynchronously
-                def = self.iterateArraySliced(rowNodes, updateRowFormatting, { infoString: 'Text: Table: updateRowFormatting' });
+                def = self.iterateArraySliced(rowNodes, updateRowFormatting, { infoString: 'Text: Table: updateRowFormatting', app: app });
+                def.always(function () {
+                    if (docModel.useSlideMode()) { handleTableBackground(table, styleSheetAttributeMap); } // (48370)
+                    docModel.trigger('table:formatting:done');
+                });
+
             } else {
                 // update all rows at once (but asynchronous, so that for example a new column is visible immediately)
                 def = self.executeDelayed(function () {
                     rowNodes.each(function () { updateRowFormatting(this); });
-                }, undefined, 'Text: updateTableFormatting');
+                    if (docModel.useSlideMode()) { handleTableBackground(table, styleSheetAttributeMap); } // (48370)
+                    docModel.trigger('table:formatting:done');
+                }, { infoString: 'TableStyles: updateTableFormatting', app: app });
             }
 
+            // handling table background (48370)
+            // def.done(function () { if (docModel.useSlideMode()) { handleTableBackground(table, styleSheetAttributeMap); } });
+
             return def.promise();
         }
 
@@ -559,10 +682,20 @@ define('io.ox/office/textframework/format/tablestyles', [
          *  family, containing the effective attribute values merged from style
          *  sheets and explicit attributes.
          */
-        function updateTablePreviewFormatting(table/*, mergedAttributes*/) {
+        function updateTablePreviewFormatting(table, mergedAttributes) {
 
             var // the table cell styles/formatter
-                tableCellStyles = docModel.getStyleCollection('cell');
+                tableCellStyles = docModel.getStyleCollection('cell'),
+                // the table styles/formatter
+                tableStyles = docModel.getStyleCollection('table'),
+                // the the style sheet attributes for the table
+                styleSheetAttributeMap = null;
+
+            // setting table backgrounds (48370)
+            if (docModel.useSlideMode() && mergedAttributes.styleId) {
+                styleSheetAttributeMap = tableStyles.getStyleSheetAttributeMap(mergedAttributes.styleId);
+                handleTableBackground(table, styleSheetAttributeMap);
+            }
 
             // iterate over all cells in the table to set the cell attributes
             DOM.getTableCells(table).each(function () {
@@ -572,6 +705,28 @@ define('io.ox/office/textframework/format/tablestyles', [
             });
         }
 
+        // public methods -----------------------------------------------------
+
+        /**
+         * Performance: Helper function to update an optional table background.
+         * This is only supported in the presentation app.
+         *
+         * @param {Node|jQuery} drawing
+         *  The table drawing node.
+         */
+        this.updateTableDrawingBackground = function (drawing) {
+
+            // the explicit drawing attributes
+            var expAttrs = AttributeUtils.getExplicitAttributes(drawing);
+            // the table node inside the drawing
+            var tableNode = $(drawing).find(DOM.TABLE_NODE_SELECTOR);
+
+            if (tableNode.length > 0 && expAttrs && expAttrs.styleId) {
+                var styleSheetAttributeMap = self.getStyleSheetAttributeMap(expAttrs.styleId);
+                handleTableBackground(tableNode, styleSheetAttributeMap);
+            }
+        };
+
         // initialization -----------------------------------------------------
 
         // register the attribute definitions for the style family
@@ -758,6 +913,179 @@ define('io.ox/office/textframework/format/tablestyles', [
         };
     };
 
+    // Light Style 3 table style attributes (Presentation)
+    TableStyles.getLightStyle3TableStyleAttributesPresentation = function (colorValue1, colorValue2) {
+        return {
+            wholeTable: {
+                cell: {
+                    borderLeft: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } },
+                    borderRight: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } },
+                    borderBottom: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } },
+                    borderTop: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } },
+                    borderInsideHor: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } },
+                    borderInsideVert: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } }
+                },
+                character: { color: { type: 'scheme', value: colorValue2 } }
+            },
+            band1Hor: { cell: { fillColor: { type: 'scheme', value: colorValue1, transformations: [{ type: 'alpha', value: 20000 }] } } },
+            band1Vert: { cell: { fillColor: { type: 'scheme', value: colorValue1, transformations: [{ type: 'alpha', value: 20000 }] } } },
+            firstRow: {
+                cell: { borderBottom: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } } },
+                character: { bold: true }
+            },
+            lastRow: {
+                cell: { borderTop: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } } },
+                character: { bold: true }
+            }
+        };
+    };
+
+    // Medium Style 2 table style attributes (Presentation)
+    TableStyles.getMediumStyle2TableStyleAttributesPresentation = function (colorValue1, colorValue2, colorValue3) { // 'accent1', 'light1', 'dark1'
+        return {
+            wholeTable: {
+                cell: {
+                    fillColor: { type: 'scheme', value: colorValue1, transformations: [{ type: 'tint', value: 20000 }] },
+                    borderLeft: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue2 } },
+                    borderRight: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue2 } },
+                    borderBottom: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue2 } },
+                    borderTop: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue2 } },
+                    borderInsideHor: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue2 } },
+                    borderInsideVert: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue2 } }
+                },
+                character: { color: { type: 'scheme', value: colorValue3 } }
+            },
+            band1Hor: { cell: { fillColor: { type: 'scheme', value: colorValue1, transformations: [{ type: 'tint', value: 40000 }] } } },
+            band1Vert: { cell: { fillColor: { type: 'scheme', value: colorValue1, transformations: [{ type: 'tint', value: 40000 }] } } },
+            firstCol: {
+                cell: { fillColor: { type: 'scheme', value: colorValue1 } },
+                character: { color: { type: 'scheme', value: colorValue2 }, bold: true }
+            },
+            firstRow: {
+                cell: {
+                    fillColor: { type: 'scheme', value: colorValue1 },
+                    borderBottom: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue2 } }
+                },
+                character: {
+                    color: { type: 'scheme', value: colorValue2 },
+                    bold: true
+                }
+            },
+            lastCol: {
+                cell: { fillColor: { type: 'scheme', value: colorValue1 } },
+                character: { color: { type: 'scheme', value: colorValue2 }, bold: true }
+            },
+            lastRow: {
+                cell: {
+                    fillColor: { type: 'scheme', value: colorValue1 },
+                    borderTop: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue2 } }
+                },
+                character: {
+                    color: { type: 'scheme', value: colorValue2 },
+                    bold: true
+                }
+            }
+        };
+    };
+
+    // Medium Style 3 table style attributes (Presentation)
+    TableStyles.getMediumStyle3TableStyleAttributesPresentation = function (colorValue1, colorValue2, colorValue3) { // 'accent1', 'light1', 'dark1'
+        return {
+            wholeTable: {
+                cell: {
+                    fillColor: { type: 'scheme', value: colorValue2 },
+                    borderBottom: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue3 } },
+                    borderTop: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue3 } }
+                },
+                character: { color: { type: 'scheme', value: colorValue3 } }
+            },
+            band1Hor: { cell: { fillColor: { type: 'scheme', value: colorValue3, transformations: [{ type: 'tint', value: 20000 }] } } },
+            band1Vert: { cell: { fillColor: { type: 'scheme', value: colorValue3, transformations: [{ type: 'tint', value: 20000 }] } } },
+            firstCol: {
+                cell: { fillColor: { type: 'scheme', value: colorValue1 } },
+                character: { color: { type: 'scheme', value: colorValue2 }, bold: true }
+            },
+            firstRow: {
+                cell: { fillColor: { type: 'scheme', value: colorValue1 }, borderBottom: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue3 } } },
+                character: { color: { type: 'scheme', value: colorValue2 }, bold: true }
+            },
+            lastCol: {
+                cell: { fillColor: { type: 'scheme', value: colorValue1 } },
+                character: { color: { type: 'scheme', value: colorValue2 }, bold: true }
+            },
+            lastRow: {
+                cell: { fillColor: { type: 'scheme', value: colorValue2 }, borderTop: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue3 } } }
+            }
+            // southEastCell:{
+            //     character: { color: { type: 'scheme', value: colorValue3 } }
+            // },
+            // southWestCell:{
+            //     character: { color: { type: 'scheme', value: colorValue3 } }
+            // }
+        };
+    };
+
+    // Medium Style 4 table style attributes (Presentation)
+    TableStyles.getMediumStyle4TableStyleAttributesPresentation = function (colorValue1, colorValue2) {
+        return {
+            wholeTable: {
+                cell: {
+                    fillColor: { type: 'scheme', value: colorValue1, transformations: [{ type: 'tint', value: 20000 }] },
+                    borderLeft: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } },
+                    borderRight: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } },
+                    borderBottom: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } },
+                    borderTop: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } },
+                    borderInsideHor: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } },
+                    borderInsideVert: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } }
+                },
+                character: { color: { type: 'scheme', value: colorValue2 } }
+            },
+            band1Hor: { cell: { fillColor: { type: 'scheme', value: colorValue1, transformations: [{ type: 'tint', value: 40000 }] } } },
+            band1Vert: { cell: { fillColor: { type: 'scheme', value: colorValue1, transformations: [{ type: 'tint', value: 40000 }] } } },
+            firstRow: {
+                cell: { fillColor: { type: 'scheme', value: colorValue1, transformations: [{ type: 'tint', value: 20000 }] } },
+                character: { bold: true }
+            },
+            lastRow: {
+                cell: { fillColor: { type: 'scheme', value: colorValue1, transformations: [{ type: 'tint', value: 20000 }] }, borderTop: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue1 } } },
+                character: { bold: true }
+            }
+        };
+    };
+
+    // Table grid, no style
+    TableStyles.getTableGridPresentation = function (colorValue) {
+        return {
+            wholeTable: {
+                cell: {
+                    borderLeft: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue } },
+                    borderRight: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue } },
+                    borderBottom: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue } },
+                    borderTop: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue } },
+                    borderInsideHor: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue } },
+                    borderInsideVert: { style: 'single', width: 35, color: { type: 'scheme', value: colorValue } }
+                }
+            }
+        };
+    };
+
+    // No grid, no style
+    TableStyles.getTableNoGridNoStylePresentation = function (colorValue) {
+        return {
+            wholeTable: {
+                cell: {
+                    borderLeft: { style: 'none' },
+                    borderRight: { style: 'none' },
+                    borderBottom: { style: 'none' },
+                    borderTop: { style: 'none' },
+                    borderInsideHor: { style: 'none' },
+                    borderInsideVert: { style: 'none' }
+                },
+                character: { fontName: 'Calibri Light', color: { type: 'scheme', value: colorValue }, bold: false }
+            }
+        };
+    };
+
     // exports ================================================================
 
     // derive this class from class StyleCollection
