@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -126,8 +127,8 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
         }
 
         /**
-         * Updating the neighbor paragraphs, if the list level of the specified paragraph
-         * was modified and the paragraph has a visible top or bottom border (43897).
+         * Updating the neighbor paragraphs, if the list level, border, color or margin of the specified paragraph
+         * was modified.
          *
          * @param {Node|jQuery} paragraph
          *  The paragraph node that gets new attributes assigned.
@@ -135,27 +136,49 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
          * @param {Object} attributes
          *  The container with the modified attributes of the paragraph.
          */
-        function handleNeighborBorderUpdate(paragraph, attributes) {
+        function handleNeighborUpdate(paragraph, attributes) {
 
             var // the previous and the next paragraph nodes
-                prevParagraph = null, nextParagraph = null,
-                // the full set of element attributes
-                allAttrs = null;
+                prevParagraph = null, nextParagraph = null;
 
-            if (attributes && attributes.paragraph && _.isNumber(attributes.paragraph.listLevel)) {
+            // update neighbors when listLevel, a border, the margin or the fillColor is changed (note: null must also be checked, there are some cases where the attribute has changed and the value is null)
+            if (attributes && attributes.paragraph && (_.isNumber(attributes.paragraph.listLevel) || attributes.paragraph.borderLeft || attributes.paragraph.borderRight || attributes.paragraph.borderTop || attributes.paragraph.borderBottom || attributes.paragraph.borderInside || _.isNumber(attributes.paragraph.marginTop) || _.isNumber(attributes.paragraph.marginBottom) || attributes.paragraph.fillColor || attributes.paragraph.fillColor === null || attributes.paragraph.borderLeft === null || attributes.paragraph.borderRight === null || attributes.paragraph.borderTop === null || attributes.paragraph.borderBottom === null || attributes.paragraph.borderInside === null)) {
 
-                allAttrs = self.getParagraphStyles().getElementAttributes(paragraph);
-
-                if (Border.isVisibleBorder(allAttrs.paragraph.borderTop)) { prevParagraph = $(paragraph).prev(); }
-                if (Border.isVisibleBorder(allAttrs.paragraph.borderBottom)) { nextParagraph = $(paragraph).next(); }
+                // get the neighbors
+                prevParagraph = $(paragraph).prev();
+                nextParagraph = $(paragraph).next();
 
                 // also updating the neighboring paragraphs
-                if (prevParagraph && prevParagraph.length > 0 && DOM.isParagraphNode(prevParagraph)) { self.getParagraphStyles().updateElementFormatting(prevParagraph); }
-                if (nextParagraph && nextParagraph.length > 0 && DOM.isParagraphNode(nextParagraph)) { self.getParagraphStyles().updateElementFormatting(nextParagraph); }
+                if (prevParagraph && prevParagraph.length > 0 && DOM.isParagraphNode(prevParagraph)) { self.implParagraphChanged(prevParagraph); }
+                if (nextParagraph && nextParagraph.length > 0 && DOM.isParagraphNode(nextParagraph)) { self.implParagraphChanged(nextParagraph); }
             }
 
         }
 
+        /**
+         * Updating the table node inside a specified table drawing node.
+         *
+         * @param {Node|jQuery} drawing
+         *  The drawing node whose table node gets new attributes assigned.
+         *
+         * @param {Object} attributes
+         *  The container with the modified attributes of the table drawing node.
+         */
+        function setTableAttributesInTableDrawing(drawing, attributes) {
+
+            var tableNode = $(drawing).find('table'),
+                tableAttrs = null;
+
+            if (attributes.table) { tableAttrs = { table:  attributes.table }; }
+
+            if (attributes.styleId) {
+                tableAttrs = tableAttrs || {};
+                tableAttrs.styleId = attributes.styleId;
+            }
+
+            if (tableAttrs) { self.getTableStyles().setElementAttributes(tableNode, tableAttrs); }
+        }
+
         /**
          * Changes a specific formatting attribute of the specified element or
          * text range. The type of the attributes will be determined from the
@@ -222,6 +245,7 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
                     isAttributesInParagraph,
                     isPageBreakBeforeAttributeInParagraph,
                     isParSpacing,
+                    isBorderTopBot,
                     // if target is present, root node is header or footer, otherwise editdiv
                     rootNode = self.getRootNode(target),
                     // the parent node
@@ -253,7 +277,9 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
                         // the operation used to undo the attribute changes
                         undoOperation = { name: Operations.SET_ATTRIBUTES, start: range.start, end: range.end, attrs: undoAttributes },
                         // last undo operation (used to merge character attributes of sibling text spans)
-                        lastUndoOperation = ((undoOperations.length > 0) && (styleFamily === 'character')) ? _.last(undoOperations) : null;
+                        lastUndoOperation = ((undoOperations.length > 0) && (styleFamily === 'character')) ? _.last(undoOperations) : null,
+                        // autoResizeHeight property for old and new attributes
+                        oldAttrsAutoHeight, newAttrsAutoHeight;
 
                     function insertUndoAttribute(family, name, value) {
                         undoAttributes[family] = undoAttributes[family] || {};
@@ -281,23 +307,13 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
                         }
                     }
 
-                    // exceptional case for setting fill type to 'none', to save the old color
-                    if (_.has(attributes, 'fill') && _.has(attributes.fill, 'type')) {
-
-                        // swtiching from type 'solid' to 'none' or 'bitmap'
-                        if (attributes.fill.type === 'none' || attributes.fill.type === 'bitmap') {
-
-                            if (_.has(oldAttributes, 'fill') && _.has(oldAttributes.fill, 'color') && !_.isUndefined(oldAttributes.fill.color)) {
-                                undoAttributes.fill = {};
-                                undoAttributes.fill.color = oldAttributes.fill.color;
-                            }
-
-                        } else if (attributes.fill.type === 'none' || attributes.fill.type === 'solid') {
-
-                            if (_.has(oldAttributes, 'fill') && _.has(oldAttributes.fill, 'imageUrl') && !_.isUndefined(oldAttributes.fill.imageUrl)) {
-                                undoAttributes.fill = {};
-                                undoAttributes.fill.imageUrl = oldAttributes.fill.imageUrl;
-                            }
+                    // exceptional case for setting auto-fit property in presentation, to preserve drawing height in undo, #46349
+                    if (self.useSlideMode()) {
+                        newAttrsAutoHeight = newAttributes && DrawingFrame.isAutoResizeHeightAttributes(newAttributes.shape);
+                        oldAttrsAutoHeight = oldAttributes && DrawingFrame.isAutoResizeHeightAttributes(oldAttributes.shape);
+                        if (newAttrsAutoHeight && !oldAttrsAutoHeight && oldAttributes && oldAttributes.drawing) {
+                            undoAttributes.drawing = undoAttributes.drawing || {};
+                            undoAttributes.drawing = _.extend(undoAttributes.drawing, oldAttributes.drawing);
                         }
                     }
 
@@ -418,11 +434,15 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
                 // updating the slide model (the attributes are not only saved in the 'data' object, but also in the model itself)
                 if (self.useSlideMode()) {
                     // updating the attributes of family 'slide'
-                    if (startInfo.family === 'slide') { self.updateSlideFamilyModel(start, attributes, target); }
-                    // updating the list style attributes at drawing nodes
-                    if (startInfo.family === 'drawing') { self.getDrawingStyles().setDrawingListStyleAttributes(startInfo.node, attributes); }
-                    // Special handling for presentation in master/layout slides -> updating styles (before calling setElementAttributes)
-                    if (target && _.isFunction(self.isLayoutOrMasterId) && self.isLayoutOrMasterId(target)) { forceLayoutFormattingData = self.updateMasterLayoutStyles(styleFamily === 'character' ? startInfo.node.parentNode : startInfo.node, target, startInfo.family, attributes, { immediateUpdate: false, saveOldAttrs: true }); }
+                    if (startInfo.family === 'slide') {
+                        self.updateSlideFamilyModel(start, attributes, target);
+                        if (target && _.isFunction(self.isLayoutOrMasterId) && self.isLayoutOrMasterId(target) && attributes && attributes.fill) {  forceLayoutFormattingData = { slideBackgroundUpdate: true, target: target, attrs: _.copy(attributes, true) }; } // only required for 48471
+                    } else {
+                        // updating the list style attributes at drawing nodes
+                        if (startInfo.family === 'drawing') { self.getDrawingStyles().setDrawingListStyleAttributes(startInfo.node, attributes); }
+                        // Special handling for presentation in master/layout slides -> updating styles (before calling setElementAttributes)
+                        if (target && _.isFunction(self.isLayoutOrMasterId) && self.isLayoutOrMasterId(target)) { forceLayoutFormattingData = self.updateMasterLayoutStyles(styleFamily === 'character' ? startInfo.node.parentNode : startInfo.node, target, startInfo.family, attributes, { immediateUpdate: false, saveOldAttrs: true }); }
+                    }
                 }
 
                 // characters (start or end may point to a drawing node, ignore that but format as
@@ -455,9 +475,15 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
                         if (DOM.isHardBreakNode(node)) {
                             setElementAttributes(node.firstChild);
                         }
-                        // if element is field, set fixed attribute (for automatic updating)
+                        // if element is field, set fixed attribute (for automatic updating), also bug #43655
                         if (DOM.isComplexFieldNode(node) || DOM.isFieldNode(node) || DOM.isRangeMarkerNode(node)) {
                             setElementAttributes(node);
+                            if (DOM.isFieldNode(node)) {
+                                if (!self.useSlideMode()) {
+                                    self.getFieldManager().addSimpleFieldToCollection(node, target);
+                                }
+                                $(node).css('font-size', ''); // see bug #47515
+                            }
                         }
 
                         // DOM.iterateTextSpans() visits the node itself if it is a
@@ -491,6 +517,18 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
                         Utils.mergeSiblingTextSpans(lastTextSpan, true);
                     }
 
+                    // BUG #48392 - Part 1
+                    // check, whether we have to update the styles of the first (empty) span, or not
+                    if ($(startInfo.node).prev().is('.drawing')) {
+                        var firstSpan = $(startInfo.node).prevAll('span').first();
+                        if (DOM.isEmptySpan(firstSpan) && DOM.isFirstTextSpanInParagraph(firstSpan)) {
+                            if (attributes && attributes.character) {
+                                // set new character-attrs to the leading empty span
+                                self.getCharacterStyles().setElementAttributes(firstSpan, { character: attributes.character });
+                            }
+                        }
+                    }
+
                 // otherwise: only single components allowed at this time
                 } else {
 
@@ -529,11 +567,47 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
 
                         setElementAttributes(startInfo.node);
 
-                        // update also the neighbors, if the list level was modified (43897)
-                        handleNeighborBorderUpdate(startInfo.node, attributes);
+                        // update also the neighbors, if the list level, border, color or margin was modified
+                        handleNeighborUpdate(startInfo.node, attributes);
+
+                        // handling table attributes for drawing tables (in presentation app)
+                        if (self.useSlideMode() && styleFamily === 'drawing' && DrawingFrame.isTableDrawingFrame(startInfo.node)) {
+                            // TODO: Avoid duplicate table attributation (setElementAttributes for the drawing already formatted the table)
+                            // -> in the following function the attributes shall only be set at the drawing node
+                            setTableAttributesInTableDrawing(startInfo.node, attributes);
+                        }
+
+                        // updating the selection of a selected drawing node (and drawing table node)
+                        if (self.useSlideMode()) {
+                            if (styleFamily === 'drawing') {
+                                DrawingFrame.updateSelectionDrawingSize(startInfo.node);
+                            } else if (styleFamily === 'row') {
+                                DrawingFrame.updateSelectionDrawingSize($(startInfo.node).closest(DrawingFrame.NODE_SELECTOR));
+                            }
+                        }
 
                         if (styleFamily === 'drawing') {
+
                             self.trigger('change:drawing');
+
+                            // BUG #48392 - Part 2
+                            // wait for "importSuccess" to be able to reach the sibbling-elements
+                            self.waitForImportSuccess(function () {
+                                var prevElement = $(startInfo.node).prev();
+                                // If the previous element is a empty span (to be able to set the cursor before the drawing)
+                                if (DOM.isEmptySpan(prevElement) && DOM.isFirstTextSpanInParagraph(prevElement)) {
+                                    var nextElement = $(startInfo.node).nextAll('span').first();
+                                    // and the next span-element ...
+                                    if (nextElement) {
+                                        var nextAttrs = AttributeUtils.getExplicitAttributes(nextElement);
+                                        // ... has some explicit attributes
+                                        if (nextAttrs && nextAttrs.character) {
+                                            // set character-attrs from the following span to the leading empty span
+                                            self.getCharacterStyles().setElementAttributes(prevElement, { character: nextAttrs.character });
+                                        }
+                                    }
+                                }
+                            });
                         }
                     }
 
@@ -549,7 +623,12 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
 
                 // update numberings and bullets (but updateListsDebounced can only be called after successful document import)
                 if (self.isImportFinished() && (styleFamily === 'paragraph')) {
-                    if ((('styleId' in attributes) || _.isObject(attributes.paragraph) && (('listLevel' in attributes.paragraph) || ('listStyleId' in attributes.paragraph)))) {
+                    if (('styleId' in attributes) ||
+                        (
+                            _.isObject(attributes.paragraph) &&
+                            (('listLevel' in attributes.paragraph) || ('listStyleId' in attributes.paragraph))
+                        )
+                    ) {
 
                         // determining listStyleId und listLevel
                         if ((_.isObject(attributes.paragraph)) && ('listStyleId' in attributes.paragraph) && (attributes.paragraph.listStyleId !== null)) {
@@ -589,7 +668,7 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
                             }
 
                             // not registering listStyle for updating, if this is a bullet list -> updating only specific paragraphs
-                            if (self.getListCollection().isAllLevelsBulletsList(listStyleId)) { listStyleId = null; }
+                            if (self.getListCollection() && self.getListCollection().isAllLevelsBulletsList(listStyleId)) { listStyleId = null; }
 
                             self.updateListsDebounced({ useSelectedListStyleIDs: true, paraInsert: true, listStyleId: listStyleId, listLevel: listLevel });
                         }
@@ -655,30 +734,36 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
                     // after document is loaded, trigger pagebreaks reposition on certain events like font size change, height of drawing or row changed
                     isCharOrDrawingOrRow = 'character' in attributes || 'drawing' in attributes || 'row' in attributes || ('line' in attributes && 'width' in attributes.line);
                     isClearFormatting = 'styleId' in attributes && attributes.styleId === null;
-                    if (_.isObject(attributes.paragraph)) {
 
-                        // check level in Presentation & listLevel in Text
-                        isAttributesInParagraph = ('lineHeight' in attributes.paragraph) || ('listLevel' in attributes.paragraph) || ('level' in attributes.paragraph) || ('listStyleId' in attributes.paragraph);
-                        isPageBreakBeforeAttributeInParagraph = ('pageBreakBefore' in attributes.paragraph);
-                        isParSpacing = 'marginBottom' in attributes.paragraph;
-                    }
-                    if ((isCharOrDrawingOrRow || isClearFormatting || isAttributesInParagraph || isPageBreakBeforeAttributeInParagraph || isParSpacing)) {
-                        if (start.length > 1) {
-                            // if its paragraph creation inside of table
-                            currentElement = Position.getContentNodeElement(rootNode, start.slice(0, 1));
-                        } else {
-                            currentElement = Position.getContentNodeElement(rootNode, start);
+                    if (!self.useSlideMode()) { // handling of page breaks, not required in presentation app
+
+                        if (_.isObject(attributes.paragraph)) {
+
+                            // check level in Presentation & listLevel in Text
+                            isAttributesInParagraph = ('lineHeight' in attributes.paragraph) || ('listLevel' in attributes.paragraph) || ('level' in attributes.paragraph) || ('listStyleId' in attributes.paragraph);
+                            isPageBreakBeforeAttributeInParagraph = ('pageBreakBefore' in attributes.paragraph);
+                            isParSpacing = 'marginBottom' in attributes.paragraph;
+                            isBorderTopBot = 'borderTop' in attributes.paragraph || 'borderBottom' in attributes.paragraph;
                         }
-                        if ($(currentElement).data('lineBreaksData')) {
-                            $(currentElement).removeData('lineBreaksData'); //we changed paragraph layout, cached line breaks data needs to be invalidated
+
+                        if (isCharOrDrawingOrRow || isClearFormatting || isAttributesInParagraph || isPageBreakBeforeAttributeInParagraph || isParSpacing || isBorderTopBot) {
+                            if (start.length > 1) {
+                                // if its paragraph creation inside of table
+                                currentElement = Position.getContentNodeElement(rootNode, start.slice(0, 1));
+                            } else {
+                                currentElement = Position.getContentNodeElement(rootNode, start);
+                            }
+                            if ($(currentElement).data('lineBreaksData')) {
+                                $(currentElement).removeData('lineBreaksData'); //we changed paragraph layout, cached line breaks data needs to be invalidated
+                            }
+                            // attribute removed by user, needs to refresh page layout
+                            if (isPageBreakBeforeAttributeInParagraph && !attributes.paragraph.pageBreakBefore) {
+                                $(startInfo.node).removeClass('manual-page-break'); // remove class from div.p element
+                                $(currentElement).removeClass('manual-page-break'); // remove class from parent table element also
+                            }
+                            self.insertPageBreaks(currentElement, DrawingFrame.getClosestTextFrameDrawingNode(startInfo.node));
+                            if (!self.isPageBreakMode()) { app.getView().recalculateDocumentMargin(); }
                         }
-                        // attribute removed by user, needs to refresh page layout
-                        if (isPageBreakBeforeAttributeInParagraph && !attributes.paragraph.pageBreakBefore) {
-                            $(startInfo.node).removeClass('manual-page-break'); // remove class from div.p element
-                            $(currentElement).removeClass('manual-page-break'); // remove class from parent table element also
-                        }
-                        self.insertPageBreaks(currentElement, DrawingFrame.getClosestTextFrameDrawingNode(startInfo.node));
-                        if (!self.isPageBreakMode()) { app.getView().recalculateDocumentMargin(); }
                     }
                 }
 
@@ -774,7 +859,17 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
                         // the logical end position, if specified
                         localEndPos = (selectionRange && selectionRange[1]) || null,
                         // the change track object
-                        changeTrack = self.getChangeTrack();
+                        changeTrack = self.getChangeTrack(),
+                        // array containing start end end position of word in which cursor is placed
+                        wordBoundaryPos = null,
+                        // start postion of wrapped word
+                        wordBoundaryStart = null,
+                        // end position of wrapped word
+                        wordBoundaryEnd = null,
+                        // start position of changetracked span
+                        changeTrackStartPos = null,
+                        // end position of changetracked span
+                        changeTrackEndPos = null;
 
                     // generates a 'setAttributes' operation with the correct attributes
                     function generateSetAttributeOperation(startPosition, endPosition, oldAttrs) {
@@ -836,7 +931,20 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
                                             // evaluate only text spans that are partly or completely covered by selection
                                             if (DOM.isTextSpan(node)) {
                                                 // one operation for each span
-                                                generateSetAttributeOperation(position.concat([nodestart + offsetstart]), position.concat([nodestart + offsetstart + offsetlength - 1]), changeTrack.getOldNodeAttributes(node));
+                                                changeTrackStartPos = nodestart + offsetstart;
+                                                changeTrackEndPos = nodestart + offsetstart + offsetlength - 1;
+                                                // decrease end position as long as it is whitespace character at that position
+                                                // but only if it is last span in paragraph
+                                                if (endOffset === changeTrackEndPos) {
+                                                    if (!Position.isWhitespaceCharInPosition(activeRootNode, position.concat([changeTrackEndPos + 1]))) {
+                                                        while (changeTrackEndPos >= changeTrackStartPos && Position.isWhitespaceCharInPosition(activeRootNode, position.concat([changeTrackEndPos]))) {
+                                                            changeTrackEndPos -= 1;
+                                                        }
+                                                    }
+                                                }
+                                                if (changeTrackEndPos >= changeTrackStartPos) {
+                                                    generateSetAttributeOperation(position.concat([changeTrackStartPos]), position.concat([changeTrackEndPos]), changeTrack.getOldNodeAttributes(node));
+                                                }
                                             }
 
                                         }, undefined, { start: startOffset, end: endOffset });
@@ -850,6 +958,14 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
                                         } else if (startOffset === 0 && endOffset <= 0 && Position.getParagraphNodeLength(paragraph) === 0) {
                                             generateSetAttributeOperation(position);  // assigning attribute to existing empty paragraph
                                         } else if (startOffset <= endOffset) {
+                                            // decrease end position as long as it is whitespace character at that position
+                                            // we dont want ending whitespace to be attributed (underlined for example).
+                                            // Exception is when end selection range is at the end of the paragraph (see #48059)
+                                            if (!Position.isWhitespaceCharInPosition(activeRootNode, position.concat([endOffset + 1])) && (endOffset !== Position.getParagraphNodeLength(paragraph) - 1)) {
+                                                while (endOffset > startOffset && Position.isWhitespaceCharInPosition(activeRootNode, position.concat([endOffset]))) {
+                                                    endOffset -= 1;
+                                                }
+                                            }
                                             generateSetAttributeOperation(position.concat([startOffset]), position.concat([endOffset]));
                                         }
 
@@ -857,7 +973,28 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
                                     self.getSpellChecker().reset(attributes, paragraph);
                                 }, null, { startPos: localStartPos, endPos: localEndPos });
                             } else {  // selection has no range
-                                if (Position.getParagraphLength(activeRootNode, _.clone(selection.getStartPosition())) === 0) {
+                                // expand set attributes operation to whole word if cursor is inside word
+                                if (Position.shouldSetAttsExtendToWord(activeRootNode, selection.getStartPosition())) {
+                                    wordBoundaryPos = Position.getWordBoundaries(activeRootNode, selection.getStartPosition());
+                                    paraPos = _.clone(selection.getStartPosition());
+                                    paraPos.pop();
+                                    paraNode = Position.getParagraphElement(activeRootNode, paraPos);
+
+                                    if (changeTrack.isActiveChangeTracking()) {
+                                        // Creating one setAttribute operation for each span inside the paragraph, because of old attributes!
+                                        oldAttrs = {};
+                                        if (DOM.isParagraphNode(paraNode)) { oldAttrs = changeTrack.getOldNodeAttributes(paraNode); }
+                                    }
+                                    // set the attributes at the extended text range
+                                    if (_.isArray(wordBoundaryPos) && wordBoundaryPos.length === 2) {
+                                        wordBoundaryStart = _.isArray(wordBoundaryPos[0]) ? wordBoundaryPos[0] : null;
+                                        wordBoundaryEnd = _.isArray(wordBoundaryPos[1]) ? Position.decreaseLastIndex(wordBoundaryPos[1]) : null;
+                                        if (wordBoundaryStart && wordBoundaryEnd) {
+                                            generateSetAttributeOperation(wordBoundaryStart, wordBoundaryEnd, oldAttrs);
+                                            self.getSpellChecker().reset(attributes, paraNode);
+                                        }
+                                    }
+                                } else if (Position.getParagraphLength(activeRootNode, _.clone(selection.getStartPosition())) === 0) {
                                     // Task 28187: Setting character attributes at empty paragraphs
                                     // In implSetAttributes it is additionally necessary to remove the character attributes
                                     // from text span so that character styles at paragraph become visible
@@ -925,7 +1062,14 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
                             break;
 
                         case 'table':
-                            if ((element = selection.getEnclosingTable())) {
+
+                            element = selection.getEnclosingTable();
+
+                            if (!element && self.useSlideMode() && selection.isDrawingSelection() && DrawingFrame.isTableDrawingFrame(selection.getSelectedDrawing())) {
+                                element = selection.getSelectedDrawing();
+                            }
+
+                            if (element) {
 
                                 localPosition = Position.getOxoPosition(activeRootNode, element, 0);  // the logical position of the table
 
@@ -1126,7 +1270,7 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
                     operationGeneratorPromise = self.iterateArraySliced(splittedSelectionRange, function (oneRange) {
                         // calling function to generate operations synchronously with reduced selection range
                         generateAllSetAttributeOperations(oneRange);
-                    }, { delay: 'immediate', infoString: 'Text: generateAllSetAttributeOperations' })
+                    }, { delay: 'immediate', infoString: 'Text: generateAllSetAttributeOperations', app: app })
                         // add progress handling
                         .progress(function (progress) {
                             // update the progress bar according to progress of the operations promise
@@ -1395,7 +1539,13 @@ define('io.ox/office/textframework/model/attributeoperationmixin', [
                     break;
 
                 case 'table':
-                    if ((element = selection.getEnclosingTable())) {
+                    element = selection.getEnclosingTable();
+
+                    if (!element && self.useSlideMode() && selection.isDrawingSelection() && DrawingFrame.isTableDrawingFrame(selection.getSelectedDrawing())) {
+                        element = selection.getSelectedDrawing();
+                    }
+
+                    if (element) {
                         mergeElementAttributes(self.getTableStyles().getElementAttributes(element));
                     }
                     break;
