@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Mario Schroeder <mario.schroeder@open-xchange.com>
  */
@@ -37,13 +38,13 @@ define('io.ox/office/textframework/model/clipboardmixin', [
         var // self reference (the spreadsheet view)
             self = this,
             // regExp to parse list label text for decimal numbering
-            decimalRegEx = new RegExp(/^\d+[\.\)]/),
+            decimalRegEx = new RegExp(/^\d+[.)]/),
             // regExp to parse list label text for roman numbering
-            upperRomanRegEx = new RegExp(/^M{0,4}(CM|CD|D?C{0,3})(XC|XL|L?X{0,3})(IX|IV|V?I{0,3})[\.\)]/),
-            lowerRomanRegEx = new RegExp(/^m{0,4}(cm|cd|d?C{0,3})(xc|xl|l?x{0,3})(ix|iv|v?i{0,3})[\.\)]/),
+            upperRomanRegEx = new RegExp(/^M{0,4}(CM|CD|D?C{0,3})(XC|XL|L?X{0,3})(IX|IV|V?I{0,3})[.)]/),
+            lowerRomanRegEx = new RegExp(/^m{0,4}(cm|cd|d?C{0,3})(xc|xl|l?x{0,3})(ix|iv|v?i{0,3})[.)]/),
             // regExp to parse list label text for alpha numbering
-            upperLetterRegEx = new RegExp(/^[A-Z]+[\.\)]/),
-            lowerLetterRegEx = new RegExp(/^[a-z]+[\.\)]/);
+            upperLetterRegEx = new RegExp(/^[A-Z]+[.)]/),
+            lowerLetterRegEx = new RegExp(/^[a-z]+[.)]/);
 
         // private methods ----------------------------------------------------
 
@@ -78,6 +79,28 @@ define('io.ox/office/textframework/model/clipboardmixin', [
             return text.replace(/["\\]/g, '');
         }
 
+        function calcTableSize(child) {
+            var rows        = $(child).find('tr'),
+                rowCount    = rows.length,
+                whileCount  = (rowCount > 50) ? 50 : rowCount,
+                size        = 0,
+                i           = 0;
+
+            while (i < whileCount) {
+                var row     = $(rows[i]),
+                    cols    = row.find('>td,>th').length,
+                    colSpan = $(row).attr('colspan') - 1;
+
+                if (colSpan >= 1) { cols += colSpan; }
+
+                if (cols > size) { size = cols; }
+
+                i++;
+            }
+
+            return size;
+        }
+
         // methods ------------------------------------------------------------
 
         // Text parser --------------------------------------------------------
@@ -100,8 +123,17 @@ define('io.ox/office/textframework/model/clipboardmixin', [
 
                 paragraphs = text.split(/\r\n?|\n/);
                 _.each(paragraphs, function (para) {
-                    ops.push({ operation: Operations.PARA_INSERT });
-                    ops.push({ operation: Operations.TEXT_INSERT, data: para });
+                    var splitted = para.match(/[^\t]+|\t/g);
+                    // insert paragraph
+                    ops.push({ operation: Operations.PARA_INSERT, listLevel: -1 });
+                    // insert tab or text
+                    _.each(splitted, function (part) {
+                        if (part === '\t') {
+                            ops.push({ operation: Operations.TAB_INSERT });
+                        } else {
+                            ops.push({ operation: Operations.TEXT_INSERT, data: part });
+                        }
+                    });
                 });
             }
 
@@ -128,7 +160,7 @@ define('io.ox/office/textframework/model/clipboardmixin', [
                 // the definition off all MS list styles
                 msListDefinitions = null;
 
-            (function findTextNodes(current, depth, listLevel, type) {
+            (function findTextNodes(current, depth, listLevel, tableLevel, type) {
 
                 var // the length (of chars, tabs, drawings...) to be added to the oxo position
                     insertLength = 0,
@@ -145,11 +177,14 @@ define('io.ox/office/textframework/model/clipboardmixin', [
                     // a single MS list style deinition
                     msListStyle,
                     // determins if the node gets parsed recursively or is skipped
-                    nextLevel;
+                    nextLevel,
+                    // contains the last operation
+                    lastOp;
 
                 for (var i = 0; i < current.childNodes.length; i++) {
-                    child = current.childNodes[i];
-                    nextLevel = true;
+                    child       = current.childNodes[i];
+                    nextLevel   = true;
+                    lastOp      = _.last(result);
 
                     if (child.nodeType === 3 && acceptTextNodes && !skipTextNodes) {
                         // handle non-whitespace characters and non-breaking spaces only
@@ -169,7 +204,11 @@ define('io.ox/office/textframework/model/clipboardmixin', [
                                     // replace invisible control characters and reduce space sequences to a single spaces
                                     text = text.replace(/[\r\n]/g, ' ').replace(/[\x00-\x1f]/g, '').replace(/ +/g, ' ');
                                     insertLength += text.length;
-                                    result.push({ operation: Operations.TEXT_INSERT, data: text, depth: depth });
+                                    if (tableLevel >= 0) {
+                                        result.push({ operation: 'insertCellData', data: text });
+                                    } else {
+                                        result.push({ operation: Operations.TEXT_INSERT, data: text, depth: depth });
+                                    }
                                 }
                             }
                         }
@@ -194,13 +233,17 @@ define('io.ox/office/textframework/model/clipboardmixin', [
                         //      <br> tags not nested inside a <div>, <p> or <li>
                         //      <p> tags not nested inside a <li>
 
-                        if (($(child).is('div') || $(child).is('span') || $(child).is('br')) && $(child.parentNode).is('a')) {
+                        if ($(child.parentNode).is('a') && ($(child).is('div') || $(child).is('span') || $(child).is('br'))) {
+                            insertLength += findTextNodes(child, depth + 1, listLevel, tableLevel, type);
                             // these children in links lead to empty following paragraphs, that receive setAttributes operations
                             nextLevel = false;
 
-                        } else if ($(child).is('div, h1, h2, h3, h4, h5, h6') ||
-                            ($(child).is('br') && (!$(child.parentNode).is('p, div, li')) ||
-                            ($(child.parentNode).hasClass('clipboard') && !$(child).is('style, pre'))) ||
+                        } else if (
+                            $(child).is('div, h1, h2, h3, h4, h5, h6') ||
+                            (
+                                ($(child).is('br') && !$(child.parentNode).is('p, div, li')) ||
+                                ($(child.parentNode).hasClass('clipboard') && !$(child).is('style, pre, ol, ul, table') && $(child.parentNode).children(':first').is(child))
+                            ) ||
                             ($(child).is('p') && !$(child.parentNode).is('li'))
                         ) {
                             if (self.isMSListParagraph(child)) {
@@ -221,14 +264,14 @@ define('io.ox/office/textframework/model/clipboardmixin', [
 
                                     // insert paragraph and list element for current list level
                                     result.push({ operation: Operations.PARA_INSERT, depth: depth, listLevel: msParagraphLevelInfo.level });
-                                    result.push({ operation: 'insertListElement', depth: depth, listLevel: msParagraphLevelInfo.level });
+                                    result.push({ operation: 'insertListElement', depth: depth, listLevel: msParagraphLevelInfo.level, type: msListStyle });
 
                                 } else {
                                     // special handling for pasting list paragraphs without bullet or numbering
                                     result.push({ operation: 'insertListParagraph', depth: depth, listLevel: 0 });
                                 }
 
-                            } else {
+                            } else if (tableLevel === -1 && (!lastOp || (lastOp && lastOp.operation !== Operations.PARA_INSERT && lastOp.type !== 'leaveTable'))) {
                                 result.push({ operation: Operations.PARA_INSERT, depth: depth, listLevel: listLevel });
                             }
 
@@ -250,43 +293,57 @@ define('io.ox/office/textframework/model/clipboardmixin', [
 
                         } else if ($(child).is('img')) {
 
-                            // the img alt tag optionally stores the document media URL, the session id and the file id
-                            try {
-                                childData = JSON.parse($(child).attr('alt'));
-                            } catch (e) {
-                                childData = {};
-                            }
-                            if (ox.session === childData.sessionId && fileId === childData.fileId && childData.altsrc) {
-                                // The image URL points to a document and the copy&paste action
-                                // takes place inside the same editor instance, so we use relative document media URL.
-                                result.push({ operation: Operations.DRAWING_INSERT, data: childData.altsrc, depth: depth });
+                            // we don't support images within tables
+                            if (tableLevel === -1) {
 
-                            } else if (DOM.isDocumentImageNode(child)) {
-                                // The image URL points to a document, but copy&paste is done from one editor instance to another
-                                // and the image src has not been replaced with a base64 data URL (e.g. IE 9 does not support this).
-                                // So the base64 data URL can be generated from the image node as long as the session is valid.
-                                result.push({
-                                    operation: Operations.DRAWING_INSERT,
-                                    data: DOM.getBase64FromImageNode(child, ImageUtil.getMimeTypeFromImageUri(DOM.getUrlParamFromImageNode(child, 'get_filename'))),
-                                    depth: depth
-                                });
+                                // the img alt tag optionally stores the document media URL, the session id and the file id
+                                try {
+                                    childData = JSON.parse($(child).attr('alt'));
+                                } catch (e) {
+                                    childData = {};
+                                }
+                                if (ox.session === childData.sessionId && fileId === childData.fileId && childData.altsrc) {
+                                    // The image URL points to a document and the copy&paste action
+                                    // takes place inside the same editor instance, so we use relative document media URL.
+                                    result.push({ operation: Operations.DRAWING_INSERT, type: 'image', data: childData.altsrc, depth: depth });
 
+                                } else if (DOM.isDocumentImageNode(child)) {
+                                    // The image URL points to a document, but copy&paste is done from one editor instance to another
+                                    // and the image src has not been replaced with a base64 data URL (e.g. IE 9 does not support this).
+                                    // So the base64 data URL can be generated from the image node as long as the session is valid.
+                                    result.push({
+                                        operation: Operations.DRAWING_INSERT,
+                                        type: 'image',
+                                        data: DOM.getBase64FromImageNode(child, ImageUtil.getMimeTypeFromImageUri(DOM.getUrlParamFromImageNode(child, 'get_filename'))),
+                                        depth: depth
+                                    });
+
+                                } else {
+                                    // The image src is an external web URL or already a base64 data URL
+                                    result.push({ operation: Operations.DRAWING_INSERT, type: 'image', data: child.src, depth: depth });
+
+                                }
+                                insertLength += 1;
                             } else {
-                                // The image src is an external web URL or already a base64 data URL
-                                result.push({ operation: Operations.DRAWING_INSERT, data: child.src, depth: depth });
-
+                                // placeholder for removed table
+                                result.push({ operation: 'insertCellData', data: ' ' });
                             }
-                            insertLength += 1;
+
                         } else if ($(child).is('style, title')) {
                             // don't parse <style> and <title> elements
                             nextLevel = false;
 
                         }  else if ($(child).is('a')) {
-                            // before we can add the operation for inserting the hyperlink we need to add the insertText operation
-                            // so we first parse the next recursion level
-                            var len = findTextNodes(child, depth + 1, listLevel, type);
-                            // and then add the hyperlink
-                            result.push({ operation: 'insertHyperlink', data: child.href, length: len, depth: depth });
+                            if ($(child).children('img').length === 0) {
+                                // before we can add the operation for inserting the hyperlink we need to add the insertText operation
+                                // so we first parse the next recursion level
+                                var len = findTextNodes(child, depth + 1, listLevel, tableLevel, type);
+                                // and then add the hyperlink
+                                result.push({ operation: 'insertHyperlink', data: child.href, length: len, depth: depth });
+                            } else {
+                                insertLength += findTextNodes(child, depth + 1, listLevel, tableLevel, type);
+                            }
+
                             // we already traversed the tree, so don't do it again
                             nextLevel = false;
 
@@ -298,7 +355,7 @@ define('io.ox/office/textframework/model/clipboardmixin', [
                             // insert list entry for current list level
                             result.push({ operation: 'insertList', depth: depth, listLevel: listLevel, type: type });
                             // look for deeper list levels
-                            insertLength += findTextNodes(child, depth + 1, listLevel + 1, type);
+                            insertLength += findTextNodes(child, depth + 1, listLevel + 1, tableLevel, type);
                             // we already traversed the tree, so don't do it again
                             nextLevel = false;
 
@@ -306,36 +363,46 @@ define('io.ox/office/textframework/model/clipboardmixin', [
                             // insert paragraph and list element for current list level
                             result.push({ operation: Operations.PARA_INSERT, depth: depth, listLevel: listLevel });
                             result.push({ operation: 'insertListElement', depth: depth, listLevel: listLevel, type: type });
-                        /*
+
                         } else if ($(child).is('table')) {
-                            // insertTable  {start:[1],attrs:{table:{tableGrid:[1000,1000,1000],width:"auto",exclude:["lastRow","lastCol","bandsVert"]},styleId:"TableGrid"}}
+                            if (tableLevel === -1) {
+                                if ($(child).find('td').length > 1) {
+                                    var size = calcTableSize(child);
+                                    result.push({ operation: 'insertTable', size: size });
+                                    insertLength += findTextNodes(child, depth + 1, listLevel, tableLevel + 1, type);
+                                    nextLevel = false;
+                                    result.push({ operation: Operations.PARA_INSERT, type: 'leaveTable' });
+                                }
+                            } else {
+                                // placeholder for removed table
+                                result.push({ operation: 'insertCellData', data: ' ' });
+                                // stop traversing nested tables!
+                                nextLevel = false;
+                            }
 
-                            var tds = $(child).find('tr:first td');
-                            var colCount = 0;
-                            tds.each(function() {
-                                colCount += parseInt($(this).attr('colspan') || '1', 10);
-                            });
-                            result.push({ operation: Operations.TABLE_INSERT, depth: depth, colCount: colCount });
                         } else if ($(child).is('tr')) {
-                            // insertRows   {start:[1,0],count:2,insertDefaultCells:true}
-
-                        }
-                        */
-                        } else if ($(child).is('tr')) {
-                            //split para
-                            result.push({ operation: Operations.PARA_INSERT, depth: depth });
-                            if ($(child).is('tr:first-of-type')) {
-                                //workaround for cleanup code in editor.js createOperationsFromExternalClipboard()
+                            if (tableLevel !== -1) {
+                                result.push({ operation: 'insertRow' });
+                            } else {
+                                //split para
                                 result.push({ operation: Operations.PARA_INSERT, depth: depth });
                             }
-                        } else if ($(child).is('td')) {
-                            //insert tab
-                            if ($(child).is('td:not(:first-of-type)')) {
-                                var lastOp = _.last(result);
-                                if (lastOp && lastOp.operation === Operations.TEXT_INSERT) {
-                                    lastOp.data = lastOp.data.replace(/^\s*/, '');
+
+                        } else if ($(child).is('td') || $(child).is('th')) {
+                            if (tableLevel !== -1) {
+                                result.push({ operation: 'prepareCell', depth: depth });
+                                insertLength += findTextNodes(child, depth + 1, listLevel, tableLevel, type);
+                                result.push({ operation: 'finalizeCell', depth: depth });
+                                nextLevel = false;
+
+                            } else {
+                                //insert tab
+                                if ($(child).is('td:not(:first-of-type)')) {
+                                    if (lastOp && lastOp.operation === Operations.TEXT_INSERT) {
+                                        lastOp.data = lastOp.data.replace(/^\s*/, '');
+                                    }
+                                    result.push({ operation: Operations.TAB_INSERT, depth: depth });
                                 }
-                                result.push({ operation: Operations.TAB_INSERT, depth: depth });
                             }
 
                         } else if ($(child).is('pre')) {
@@ -347,16 +414,16 @@ define('io.ox/office/textframework/model/clipboardmixin', [
                         }
 
                         if (nextLevel) {
-                            insertLength += findTextNodes(child, depth + 1, listLevel, type);
+                            insertLength += findTextNodes(child, depth + 1, listLevel, tableLevel, type);
                         }
                     }
                 }
 
                 return insertLength;
 
-            }(/*node*/ clipboard.get(0), /*depth*/ 0, /*listLevel*/ -1, /*type*/ undefined));
+            }(/*node*/ clipboard.get(0), /*depth*/ 0, /*listLevel*/ -1, /*tableLevel*/ -1, /*type*/ undefined));
 
-            //console.warn('paste result', result);
+            // console.warn('paste result', result);
             return result;
         };
 
@@ -471,7 +538,7 @@ define('io.ox/office/textframework/model/clipboardmixin', [
                 result = {};
 
             // parse list styles out of all styles
-            listStyles = stylesText.match(/@list\s+l\d+:level\d+\s*\{[^\}]*\}/ig);
+            listStyles = stylesText.match(/@list\s+l\d+:level\d+\s*\{[^}]*\}/ig);
             if (!_.isArray(listStyles)) { return null; }
 
             _.each(listStyles, function (item) {
@@ -820,23 +887,22 @@ define('io.ox/office/textframework/model/clipboardmixin', [
          *                  The font family of the char.
          */
         this.getUnicodeReplacementForChar = function (char, fontFamily) {
-
-            if (_.isString(fontFamily) && fontFamily.indexOf('ingdings') > 0) {
-                return this.getUnicodeForWingdingsChar(char);
-
-            } else if (_.isString(fontFamily) && fontFamily.indexOf('ymbol') > 0) {
-                return this.getUnicodeForSymbolChar(char);
-
-            } else {
-                return char;
+            if (_.isString(fontFamily) && !_.isEmpty(fontFamily)) {
+                if (fontFamily.indexOf('ingdings') > 0) {
+                    return (fontFamily.indexOf('2') > 0) ? this.getUnicodeForWingdings2Char(char) : this.getUnicodeForWingdings1Char(char);
+                } else if (fontFamily.indexOf('ymbol') > 0) {
+                    return this.getUnicodeForSymbolChar(char);
+                }
             }
+
+            return char;
         };
 
         /**
-         * Returns a Unicode replacement for a Wingdings encoded char that can be displayed in common browser fonts.
+         * Returns a Unicode replacement for a Wingdings 1 encoded char that can be displayed in common browser fonts.
          *
          * @param {String} char
-         *  The Wingdings char.
+         *  The Wingdings 1 char.
          *
          * @returns {Object}
          *              {String} levelText
@@ -844,7 +910,7 @@ define('io.ox/office/textframework/model/clipboardmixin', [
          *              {String} fontFamily
          *                  The font family of the char.
          */
-        this.getUnicodeForWingdingsChar = function (char) {
+        this.getUnicodeForWingdings1Char = function (char) {
 
             if (!_.isString(char) || (char.length !== 1)) {
                 return { levelText: '\u2022', fontFamily: 'Times New Roman' };
@@ -1352,6 +1418,38 @@ define('io.ox/office/textframework/model/clipboardmixin', [
             }
         };
 
+        /**
+         * Returns a Unicode replacement for a Wingdings 2 encoded char that can be displayed in common browser fonts.
+         *
+         * @param {String} char
+         *  The Wingdings 2 char.
+         *
+         * @returns {Object}
+         *              {String} levelText
+         *                  The Unicode char.
+         *              {String} fontFamily
+         *                  The font family of the char.
+         */
+        this.getUnicodeForWingdings2Char = function (char) {
+
+            if (!_.isString(char) || (char.length !== 1)) {
+                return { levelText: '\u2022', fontFamily: 'Times New Roman' };
+            }
+
+            switch (char.charCodeAt(0)) {
+                case 61591:
+                case 151:
+                    return { levelText: '\u25cf', fontFamily: 'Times New Roman' };
+
+                case 61598:
+                case 158:
+                    return { levelText: '\u29bf', fontFamily: 'Times New Roman' };
+
+                default:
+                    return { levelText: '\u2022', fontFamily: 'Times New Roman' };
+            }
+        };
+
         /**
          * Returns a Unicode replacement for a Symbol encoded char that can be displayed in common browser fonts.
          *
