@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -147,6 +148,9 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
                     _.each(allChildDrawings, function (drawing, counter) {
                         self.getDrawingStyles().setElementAttributes(drawing, childAttrs[counter]);
                     });
+
+                    // updating the new group once more (45853)
+                    self.getDrawingStyles().updateElementFormatting(drawingNode);
                 }
             }
 
@@ -250,7 +254,8 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
                 }
             });
 
-            // finally the (empty) drawing group node can be removed
+            // finally the (empty) drawing group node (and its selection) can be removed
+            if (drawingGroupNode.data('selection')) { DrawingFrame.removeDrawingSelection(drawingGroupNode); }
             drawingGroupNode.remove();
 
             return true;
@@ -280,6 +285,9 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
 
                     explicitAttrs = explicitAttrs.drawing;
 
+                    if (!_.isNumber(explicitAttrs.left)) { explicitAttrs.left = 0; } // setting the default value (47463)
+                    if (!_.isNumber(explicitAttrs.top)) { explicitAttrs.top = 0; } // setting the default value
+
                     if ((_.isNumber(explicitAttrs.left)) && ((attrs.left === -1) || (explicitAttrs.left < attrs.left))) { attrs.left = explicitAttrs.left; }
                     if ((_.isNumber(explicitAttrs.top)) && ((attrs.top === -1) || (explicitAttrs.top < attrs.top))) { attrs.top = explicitAttrs.top; }
 
