@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -190,7 +191,8 @@ define('io.ox/office/textframework/model/hardbreakmixin', [
             var // the undo manager object
                 undoManager = self.getUndoManager();
 
-            if (self.isHeaderFooterEditState()) { return; }
+            // no page break in header/footer or comments or text frames
+            if (self.getSelection().isAdditionalTextframeSelection() || self.isTargetFunctionality()) { return; }
 
             // the undo manager returns the return value of the callback function
             return undoManager.enterUndoGroup(function () {
