@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -237,6 +238,15 @@ define('io.ox/office/textframework/model/hyperlinkmixin', [
 
                 self.getUndoManager().enterUndoGroup(function () {
 
+                    // the start position of a selected range
+                    var rangeStart = null;
+                    // the end position of a selected range
+                    var rangeEnd = null;
+                    // whether a selected range can be deleted after inserted a modified text
+                    var deleteRangeAfterInsert = false;
+                    // the operation attributes object
+                    var operationProperties = null;
+
                     if (data.url === null && data.text === null) {
                         // remove hyper link
                         // setAttribute uses a closed range therefore -1
@@ -254,6 +264,12 @@ define('io.ox/office/textframework/model/hyperlinkmixin', [
                             }
                         }
                     } else {
+                        // insert new text frame in Presentation if selection is not set in any existing, see #47413
+                        if (self.useSlideMode() && !selection.isAdditionalTextframeSelection()) {
+                            if (selection.isMultiSelection()) { selection.clearMultiSelection(); }
+                            self.insertTextFrame();
+                            start = selection.getStartPosition();
+                        }
 
                         // if the data.text is a emtpy string, a default value is set (fix for Bug 40313)
                         if (data.text === '') {
@@ -265,8 +281,15 @@ define('io.ox/office/textframework/model/hyperlinkmixin', [
 
                             // text has been changed
                             if (selection.hasRange()) {
-                                self.deleteSelected();
                                 start = selection.getStartPosition();
+                                rangeStart = _.clone(start);
+                                rangeEnd = selection.getEndPosition();
+
+                                if (_.isEqual(_.initial(rangeStart), _.initial(rangeEnd))) {  // single paragraph selection
+                                    deleteRangeAfterInsert = true;  // deleting later to keep attributes (48157)
+                                } else {
+                                    self.deleteSelected();
+                                }
                             }
 
                             if (changeTrack.isActiveChangeTracking()) {
@@ -281,6 +304,15 @@ define('io.ox/office/textframework/model/hyperlinkmixin', [
                             self.extendPropertiesWithTarget(newOperation, target);
                             generator.generateOperation(Operations.TEXT_INSERT, newOperation);
 
+                            // -> deleting a range -> this must happen after inserting, because otherwise the attributes can be lost (48157)
+                            if (deleteRangeAfterInsert) {
+                                rangeStart = Position.increaseLastIndex(rangeStart, data.text.length); // adapting the start position of the removed the range
+                                rangeEnd = Position.increaseLastIndex(rangeEnd, data.text.length - 1);  // adapting also the end position
+                                operationProperties = { start: rangeStart, end: rangeEnd };
+                                self.extendPropertiesWithTarget(operationProperties, target);
+                                generator.generateOperation(Operations.DELETE, operationProperties); // generating a single delete operation
+                            }
+
                             // Calculate end position of new text, will be used for setAttributes operation
                             end = Position.increaseLastIndex(start, data.text.length);
                         }
@@ -352,6 +384,14 @@ define('io.ox/office/textframework/model/hyperlinkmixin', [
                 // the change track object
                 changeTrack = self.getChangeTrack();
 
+            // Bug 47546: The context menu with options for removing and editing hyperlinks is only opened
+            // when there is no range selected. In some situations in OSX a text range selection is applied to a
+            // hyperlink while this context menu opens. This selection contains in most cases and depending on
+            // the browser only a part from the hyperlink and therefore only a part of the hyperlink  would  be
+            // removed. To be sure that the whole hyperlink is removed, clear the textSelection, so that
+            // the text selection for the hyperlink is determined again with the following 'Hyperlink.findSelectionRange()'.
+            if (_.browser.MacOS && (_.browser.Chrome || _.browser.Safari)) { selection.setTextSelection(start, start); }
+
             if (!selection.hasRange()) {
                 newSelection = Hyperlink.findSelectionRange(this, selection);
                 if (newSelection.start !== null && newSelection.end !== null) {
@@ -398,7 +438,7 @@ define('io.ox/office/textframework/model/hyperlinkmixin', [
                     if (startPos) {
                         selection.setTextSelection(startPos);
                     }
-                }, undefined, 'Text: removeHyperLink');
+                }, { infoString: 'HyperlinkMixin: removeHyperLink', app: app });
             }
         };
 
