@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -116,6 +117,9 @@ define('io.ox/office/textframework/model/paragraphmixin', [
             // return with error, if paragraph could not be found or offset is bigger than the length of the paragraph
             if (!paragraph || offset > paraLength) { return false; }
 
+            // also not allowing splitting of slides in presentation app
+            if (paragraph && self.useSlideMode() && DOM.isSlideNode(paragraph)) { return false; }
+
             // checking if a selected drawing is affected by this split
             if (readOnly && selection.getSelectionType() === 'drawing') {
                 // is the drawing inside the splitted paragraph and is the drawing behind the split?
@@ -180,6 +184,12 @@ define('io.ox/office/textframework/model/paragraphmixin', [
             self.implParagraphChanged(paragraph);
             self.implParagraphChanged(newParagraph);
 
+            // only for text, there are no paragraph borders and color in presentation
+            if (!self.useSlideMode()) {
+                // only needed for updating paragraphs that have a color or a border
+                self.getParagraphStyles().updateParagraphBorderAndColorNodes($(newParagraph).next());
+            }
+
             // invalidating an optional cache with spell results synchronously
             if (spellChecker.hasSpellResultCache(paragraph)) {
                 spellChecker.clearSpellResultCache(paragraph);
@@ -219,6 +229,9 @@ define('io.ox/office/textframework/model/paragraphmixin', [
                 newParagraph.removeData('lineBreaksData'); // for the cloned paragraph also
             }
 
+            // removing selected classes from the new paragraph (48180)
+            newParagraph.removeClass(DOM.PARAGRAPH_NODE_LIST_EMPTY_CLASS + ' ' + DOM.PARAGRAPH_NODE_LIST_EMPTY_SELECTED_CLASS);
+
             //quitFromPageBreak = true; // quit from any currently running pagebreak calculus - performance optimization
             self.insertPageBreaks(currentElement, DrawingFrame.getClosestTextFrameDrawingNode(paragraph));
             if (!self.isPageBreakMode()) { app.getView().recalculateDocumentMargin(); }
@@ -402,6 +415,7 @@ define('io.ox/office/textframework/model/paragraphmixin', [
 
             // get next paragraph
             nextParagraph = thisParagraph.next();
+
             // but make sure next paragraph is only valid node, and not pagebreak for example
             while (nextParagraph.length > 0 && !nextParagraph.is(DOM.CONTENT_NODE_SELECTOR)) {
                 nextParagraph = nextParagraph.next();
@@ -481,6 +495,12 @@ define('io.ox/office/textframework/model/paragraphmixin', [
             self.insertPageBreaks(currentElement, DrawingFrame.getClosestTextFrameDrawingNode(thisParagraph));
             if (!self.isPageBreakMode()) { app.getView().recalculateDocumentMargin(); }
 
+            // only for text, there are no paragraph borders and color in presentation
+            if (!self.useSlideMode()) {
+                // only needed for updating paragraphs that have a color or a border
+                self.getParagraphStyles().updateParagraphBorderAndColorNodes(thisParagraph.next());
+            }
+
             return true;
         };
 
@@ -511,6 +531,9 @@ define('io.ox/office/textframework/model/paragraphmixin', [
                 // the undo manager object
                 undoManager = self.getUndoManager();
 
+            // checking valid paragraph operation for presentation app (48608)
+            if (self.useSlideMode() && operation.start.length < 3) { return false; }
+
             if (parents.length > 0) {
                 currentElement = parents.last();
             }
@@ -581,6 +604,13 @@ define('io.ox/office/textframework/model/paragraphmixin', [
             // or update them immediately after the document import has finished (Task 28370)
             if (self.isImportFinished()) {
                 self.implParagraphChangedSync($(paragraph));
+
+                // only for text, there are no paragraph borders and color in presentation
+                if (!self.useSlideMode()) {
+                    // only needed for updating paragraphs that have a color or a border
+                    self.getParagraphStyles().updateParagraphBorderAndColorNodes($(paragraph).next());
+                }
+
             } else {
                 self.implParagraphChanged(paragraph);
             }
