@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -14,8 +15,9 @@
 define('io.ox/office/textframework/model/stringconvertermixin', [
     'io.ox/office/drawinglayer/view/drawingframe',
     'io.ox/office/textframework/utils/dom',
-    'io.ox/office/textframework/utils/textutils'
-], function (DrawingFrame, DOM, Utils) {
+    'io.ox/office/textframework/utils/textutils',
+    'io.ox/office/tk/utils/deferredutils'
+], function (DrawingFrame, DOM, Utils, DeferredUtils) {
 
     'use strict';
 
@@ -149,7 +151,7 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
                 var // the jQuery data object of the node
                     dataObject = null,
                     // the return promise
-                    def = $.Deferred();
+                    def = DeferredUtils.createDeferred(app, 'StringConverterMixin: prepareNodeForStorage');
 
                 // updating progress bar
                 if (maindef) {
@@ -274,12 +276,12 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
             // iterating over all nodes (first page content, then drawing layer, ...)
             return self.iterateArraySliced(allNodesCollector, function (oneLayer) {
 
-                return self.iterateArraySliced(oneLayer.allNodes, prepareNodeForStorage, { delay: 'immediate', infoString: 'Text: getFullModelDescription: inner' })
+                return self.iterateArraySliced(oneLayer.allNodes, prepareNodeForStorage, { delay: 'immediate', infoString: 'Text: getFullModelDescription: inner', app: app })
                 .done(function () {
                     // collecting the html strings for each layer
                     allHtmlStrings.push({ extension: oneLayer.extension, htmlString: self.getNode().children(oneLayer.selector).html() });
                 });
-            }, { infoString: 'Text: getFullModelDescription: outer' })
+            }, { infoString: 'Text: getFullModelDescription: outer', app: app })
             .then(function () {
                 return allHtmlStrings;
             });
@@ -391,7 +393,7 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
                         }
 
                         if (node.attr('jquerydata')) {
-                            // Utils.log('Restoring style at: ' + this.nodeName + ' ' + this.className + ' : ' + $(this).attr('jquerydata'));
+
                             try {
                                 dataObject = JSON.parse(node.attr('jquerydata'));
 
@@ -461,6 +463,12 @@ define('io.ox/office/textframework/model/stringconvertermixin', [
                     contentNode.children(':first').removeAttr('pagecontentattr');
                 }
 
+                if (app.isODF()) { // in odt it is possible to have empty fields, text node needs to be ensured, #49844
+                    _.each(contentNode.find('.empty-field'), function (fieldNode) {
+                        DOM.ensureExistingTextNodeInField(fieldNode.firstChild);
+                    });
+                }
+
                 if (!_.isEmpty(dataKeys)) { Utils.info('Setting data keys: ' + getSortedArrayString(dataKeys)); }
             }
         };
