@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -55,7 +56,7 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                 // the last paragraph in the cell
                 paragraph = null;
 
-            paragraph = DOM.createImplicitParagraphNode();
+            paragraph = DOM.createParagraphNode();
             container.empty().append(paragraph);
             // in Internet Explorer it is necessary to add new empty text nodes in paragraph again
             // newly, also in other browsers (new jQuery version?)
@@ -223,7 +224,8 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                 useReferenceRow = _.isNumber(referenceRow),
                 newRow = null,
                 currentElement,
-                rootNode = self.getRootNode(target);
+                rootNode = self.getRootNode(target),
+                table = null; // the table node
 
             currentElement = Position.getContentNodeElement(self.getNode(), start.slice(0, 1));
 
@@ -238,8 +240,16 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
             var tablePos = _.copy(localPosition, true);
             tablePos.pop();
 
-            var table = Position.getDOMPosition(rootNode, tablePos).node,
-                tableRowDomPos = Position.getDOMPosition(rootNode, localPosition),
+            if (self.useSlideMode()) {
+                table = Position.getDOMPosition(rootNode, tablePos, true).node; // returns the drawing that contains the table node
+                if (DrawingFrame.isTableDrawingFrame(table)) {
+                    table = $(table).find('table'); // getting the table node inside the table drawing
+                }
+            } else {
+                table = Position.getDOMPosition(rootNode, tablePos).node;
+            }
+
+            var tableRowDomPos = Position.getDOMPosition(rootNode, localPosition),
                 tableRowNode = null,
                 row = null,
                 cellsInserted = false;
@@ -283,7 +293,7 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
 
                 var columnCount = Table.getColumnCount(table),
                     // prototype elements for row, cell, and paragraph
-                    paragraph = DOM.createImplicitParagraphNode(),
+                    paragraph = DOM.createParagraphNode(), // no implicit paragraph
                     cell = DOM.createTableCellNode(paragraph);
 
                 // insert empty text node into the paragraph
@@ -367,37 +377,95 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
         function implInsertColumn(start, gridPosition, insertMode, target) {
 
             var localPosition = _.copy(start, true),
-                rootNode = self.getRootNode(target);
+                rootNode = self.getRootNode(target),
+                table = null,
+                allRows = null,
+                // whether the presentation model needs to be used
+                isSlideMode = self.useSlideMode();
 
             if (!Position.isPositionInTable(rootNode, localPosition)) {
                 return false;
             }
 
-            var table = Position.getDOMPosition(rootNode, localPosition).node,
-                allRows = DOM.getTableRows(table);
+            table = isSlideMode ? Position.getDOMPosition(rootNode, localPosition, true).node : Position.getDOMPosition(rootNode, localPosition).node;
+            allRows = DOM.getTableRows(table);
+
+            if (isSlideMode && DrawingFrame.isTableDrawingFrame(table)) { table = $(table).find('table'); }
 
             if (self.isGUITriggeredOperation()) {  // called from 'insertColumn' -> temporary branding for table
                 $(table).data('gui', 'insert');
             }
 
-            allRows.each(
-                function (i, row) {
-                    var cellPosition = Table.getCellPositionFromGridPosition(row, gridPosition),
-                        cellClone = $(row).children(DOM.TABLE_CELLNODE_SELECTOR).slice(cellPosition, cellPosition + 1).clone(true);
+            _.each(allRows, function (row) {
 
-                    implClearCell(cellClone);
+                var cellPosition = Table.getCellPositionFromGridPosition(row, gridPosition),
+                    cellNode = $(row).children(DOM.TABLE_CELLNODE_SELECTOR).eq(cellPosition),
+                    expCellAttributes = AttributeUtils.getExplicitAttributes(cellNode, { family: 'cell' }),
+                    isMergedCell = expCellAttributes && _.isNumber(expCellAttributes.gridSpan) && expCellAttributes.gridSpan > 1,
+                    // gridPos = null,
+                    cellClone = null;
+                    // increaseCellLength = false;
 
-                    if (insertMode === 'behind') {
-                        cellClone.insertAfter($(row).children().get(cellPosition));
-                    } else {
-                        cellClone.insertBefore($(row).children().get(cellPosition));
-                    }
+                  // -> this process simulates the PowerPoint behavior.
+                  // -> merged table cells are increased in length, no new table cell is inserted
+//                if (isSlideMode) {
+//
+//                    if (isMergedCell) {
+//
+//                        gridPos = Table.getGridPositionFromCellPosition(row, cellPosition);
+//
+//                        if ((insertMode === 'behind' && gridPos.end > gridPosition) || (insertMode !== 'behind' && gridPos.start < gridPosition)) {
+//                            increaseCellLength = true;
+//                        }
+//                    }
+//
+//                    if (increaseCellLength) {
+//                        // apply the passed table cell attributes
+//                        self.getTableCellStyles().setElementAttributes(cellNode, { cell: { gridSpan: (expCellAttributes.gridSpan + 1) } });
+//
+//                    } else {
+//                        // inserting a new cell
+//                        cellClone = cellNode.clone(true);
+//                        implClearCell(cellClone);
+//
+//                        if (insertMode === 'behind') {
+//                            cellClone.insertAfter($(row).children().get(cellPosition));
+//                        } else {
+//                            cellClone.insertBefore($(row).children().get(cellPosition));
+//                        }
+//
+//                        if (isMergedCell) {
+//                            self.getTableCellStyles().setElementAttributes(cellClone, { cell: { gridSpan: 1 } });
+//                        }
+//                    }
+//
+//                } else {
 
+                // this behavior is the OX Text behavior, that client and filter also support in OX Presentation
+
+                cellClone = cellNode.clone(true);
+
+                implClearCell(cellClone);
+
+                if (insertMode === 'behind') {
+                    cellClone.insertAfter($(row).children().get(cellPosition));
+                } else {
+                    cellClone.insertBefore($(row).children().get(cellPosition));
+                }
+
+                if (isMergedCell) {
+                    self.getTableCellStyles().setElementAttributes(cellClone, { cell: { gridSpan: 1 } });
+                }
+
+//                }
+
+                if (cellClone) {
                     // in Internet Explorer it is necessary to add new empty text nodes in columns again
                     // newly, also in other browsers (new jQuery version?)
                     self.repairEmptyTextNodes(cellClone);
                 }
-            );
+
+            });
 
             // recalculating the attributes of the table cells
             if (self.requiresElementFormattingUpdate()) {
@@ -633,14 +701,20 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                 paragraph = null,
                 cell = null,
                 row = null,
-                rootNode = self.getRootNode(target);
+                rootNode = self.getRootNode(target),
+                selector = self.useSlideMode() ? DOM.TABLE_NODE_AND_DRAWING_SELECTOR : DOM.TABLE_NODE_SELECTOR;
 
-            tableNode = Position.getLastNodeFromPositionByNodeName(rootNode, start, DOM.TABLE_NODE_SELECTOR);
+            tableNode = Position.getLastNodeFromPositionByNodeName(rootNode, start, selector);
 
             if (!tableNode) {
                 return;
             }
 
+            if (DrawingFrame.isTableDrawingFrame(tableNode)) {
+                // the table is a drawing, but the table node is required
+                tableNode = $(tableNode).find('table');
+            }
+
             if (!_.isNumber(count)) {
                 count = 1; // setting default for number of rows
             }
@@ -652,7 +726,7 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
             }
 
             // prototype elements for row, cell, and paragraph
-            paragraph = DOM.createImplicitParagraphNode();
+            paragraph = DOM.createImplicitParagraphNode();  // must be implicit because of undo-operation
 
             // insert empty text node into the paragraph
             self.validateParagraphNode(paragraph);
@@ -743,6 +817,12 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                     // the selection object
                     selection = self.getSelection();
 
+                // #49674 - odf's default table style has no borders, so we overwrite it with 'TableGridOx'
+                //  'TableGrid' can be already sent with document, and it also has no border data
+                if (app.isODF() && tableStyleId === '_default') {
+                    tableStyleId = self.getDefaultLateralTableODFDefinition().styleId;
+                }
+
                 function doInsertTable() {
 
                     startPosition = selection.getStartPosition();
@@ -758,15 +838,22 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                         endOffset = Position.getLastTextNodePositionInParagraph(paragraph);
 
                         if ((!paragraph.nextSibling) && (offset === endOffset)) {
-                            // create a new empty implicit paragraph behind the table
-                            newParagraph = DOM.createImplicitParagraphNode();
-                            self.validateParagraphNode(newParagraph);
-                            $(paragraph).after(newParagraph);
-                            self.implParagraphChanged(newParagraph);
-                            position = Position.increaseLastIndex(position);
-                            // in Internet Explorer it is necessary to add new empty text nodes in paragraph again
-                            // newly, also in other browsers (new jQuery version?)
-                            self.repairEmptyTextNodes(newParagraph);
+                            if (DOM.isCellContentNode(paragraph.parentNode)) {
+                                insertAdditionalParagraph = true; // inserting a valid paragraph behind the table in a table cell
+                                position = Position.increaseLastIndex(position);
+                                paraPosition = _.clone(position);
+                                paraPosition = Position.increaseLastIndex(paraPosition);
+                            } else {
+                                // create a new empty implicit paragraph behind the table (if not inside another table)
+                                newParagraph = DOM.createImplicitParagraphNode();
+                                self.validateParagraphNode(newParagraph);
+                                $(paragraph).after(newParagraph);
+                                self.implParagraphChanged(newParagraph);
+                                position = Position.increaseLastIndex(position);
+                                // in Internet Explorer it is necessary to add new empty text nodes in paragraph again
+                                // newly, also in other browsers (new jQuery version?)
+                                self.repairEmptyTextNodes(newParagraph);
+                            }
                         } else if ((startOffset < offset) && (offset < endOffset)) {
                             self.splitParagraph(startPosition);
                             position = Position.increaseLastIndex(position);
@@ -834,7 +921,7 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                         if (self.getChangeTrack().isActiveChangeTracking()) {
                             paraOperationAttrs.changes = { inserted: self.getChangeTrack().getChangeTrackInfo() };
                         }
-                        generatorProperties = { start: paraPosition, attrs: paraOperationAttrs };
+                        generatorProperties =  _.isEmpty(paraOperationAttrs) ? { start: paraPosition } : { start: paraPosition, attrs: paraOperationAttrs };
                         self.extendPropertiesWithTarget(generatorProperties, target);
                         generator.generateOperation(Operations.PARA_INSERT, generatorProperties);
                     }
@@ -934,12 +1021,10 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                                 if (!_.isEmpty(paraAttributes)) {
                                     paraPos.push($(this).prevAll().length);
                                     paraPos.push(0);
-                                    // generating an operation for setting paragraph attributes in the new row
-                                    // -> no implicit paragraph in these cells
-
+                                    // generating an operation for setting paragraph attributes at the paragraphs in the new row
                                     newOperation = { start: paraPos, attrs: paraAttributes };
                                     self.extendPropertiesWithTarget(newOperation, target);
-                                    generator.generateOperation(Operations.PARA_INSERT, newOperation);
+                                    generator.generateOperation(Operations.SET_ATTRIBUTES, newOperation);
                                 }
                             }
                         });
@@ -971,21 +1056,23 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
 
                 var // the selection object
                     selection = self.getSelection(),
+                    // the selector for searching the table position
+                    selector = self.useSlideMode ? DOM.TABLE_NODE_AND_DRAWING_SELECTOR : DOM.TABLE_NODE_SELECTOR,
                     // the logical end position of the selection
                     position = selection.getEndPosition(),
                     // target for operation - if exists, it's for ex. header or footer
                     target = self.getActiveTarget(),
                     rootNode = self.getCurrentRootNode(target),
                     cellPosition = Position.getColumnIndexInRow(rootNode, position),
-                    tablePos = Position.getLastPositionFromPositionByNodeName(rootNode, position, DOM.TABLE_NODE_SELECTOR),
+                    tablePos = Position.getLastPositionFromPositionByNodeName(rootNode, position, selector),
                     rowNode = Position.getLastNodeFromPositionByNodeName(rootNode, position, 'tr'),
                     insertMode = 'behind',
-                    gridPosition = Table.getGridPositionFromCellPosition(rowNode, cellPosition).start,
+                    gridPosition = Table.getGridPositionFromCellPosition(rowNode, cellPosition).end, // inserting behind the end of the grid
                     tableGrid = Table.getTableGridWithNewColumn(rootNode, tablePos, gridPosition, insertMode),
                     // table node element
-                    table = Position.getTableElement(rootNode, tablePos),
+                    tablePoint = Position.getDOMPosition(rootNode, tablePos, true),
                     // all rows in the table
-                    allRows = DOM.getTableRows(table),
+                    allRows = DOM.getTableRows(tablePoint.node),
                     // operations generator
                     generator = this.createOperationsGenerator(),
                     // the attributes assigned to the cell(s)
@@ -1454,7 +1541,7 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                     // at very different grid positions. It is only possible to remove the new cells with deleteCells operation.
                     var localPos = _.clone(operation.start),
                         rootNode = self.getRootNode(operation.target),
-                        table = Position.getDOMPosition(rootNode, localPos).node,  // -> this is already the new grid with the new column!
+                        table = self.useSlideMode() ? Position.getDOMPosition(rootNode, localPos, true).node : Position.getDOMPosition(rootNode, localPos).node,  // -> this is already the new grid with the new column!
                         allRows = DOM.getTableRows(table),
                         allCellInsertPositions = Table.getAllInsertPositions(allRows, operation.gridPosition, operation.insertMode),
                         cellPosition = null,
