@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  */
@@ -541,7 +542,7 @@ define('io.ox/office/textframework/selection/androidselection', [
         textarea = $('<textarea>');
 
         function selectTextArea() {
-            textarea.focus();
+            Utils.setFocus(textarea);
             textarea.val(INITTEXT + word);
             Forms.setInputSelection(textarea, DUMMYLEN + (_.last(oldStart) - _.last(wordFrom)));
         }
@@ -571,7 +572,7 @@ define('io.ox/office/textframework/selection/androidselection', [
         var processSelectUpdate = (function () {
             var always = function () {
                 var selecttype = window.getSelection().type;
-                if (Utils.getActiveElement() === rootNode[0]) {
+                if (Utils.getActiveElement() === rootNode[0] || (app.getModel().useSlideMode() && $(Utils.getActiveElement()).is('.drawing'))) {
                     //listener hangs directly on document, but we only want the events of editdiv
                     if (selecttype !== 'None') {
                         self.updateSelectionAfterBrowserSelection({ preserveFocus: false, forceTrigger: false });
@@ -639,7 +640,7 @@ define('io.ox/office/textframework/selection/androidselection', [
                     oldPara.toggleClass(BLINK);
                 }
             }
-        }, { delay: 500 }, 'Text: Selection: blinkDeferred');
+        }, { delay: 500, infoString: 'Text: Selection: blinkDeferred', app: app });
 
         this.waitForImportSuccess(function () {
             var docView = app.getView();
