@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH.
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -20,8 +21,6 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
 
     'use strict';
 
-    // private static functions ===============================================
-
     // class MultiSelectionMixin ==============================================
 
     /**
@@ -127,6 +126,18 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
             return multipleSelections.length > 0;
         };
 
+        /**
+         * Returns whether several drawings are selected and none of these
+         * drawings is of type 'table'.
+         *
+         * @returns {Boolean}
+         *  Whether several drawings are selected and none of these drawings
+         *  is of type 'table'.
+         */
+        this.isMultiSelectionWithoutTable = function () {
+            return self.isMultiSelection() && !self.isAtLeastOneTableInMultiSelection();
+        };
+
         /**
          * Returns the container of selections. This container stores objects
          * containing the properties 'startPosition' and 'endPosition'. The values
@@ -174,6 +185,19 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
             }));
         };
 
+        /**
+         * Returns, whether in a multi drawing selection at least one table drawing
+         * is seleted.
+         *
+         * @returns {Boolean}
+         *  Whether in a multi drawing selection at least one table drawing is seleted.
+         */
+        this.isAtLeastOneTableInMultiSelection = function () {
+            return self.isMultiSelectionSupported() && self.isMultiSelection() && _.isObject(_.find(multipleSelections, function (selection) {
+                return DrawingFrame.isTableDrawingFrame(self.getDrawingNodeFromMultiSelection(selection));
+            }));
+        };
+
         /**
          * Returns, whether in a multi drawing selection at least one drawing of type 'group' is selected.
          *
@@ -704,6 +728,9 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
                     doTrigger = true;
                 }
 
+            } else {
+                doTrigger = false;
+                focusClipboard = false;
             }
 
             // bring clipboard node in sync with the currently selected drawings
@@ -817,8 +844,7 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
 
             if (!app.getModel().useSlideMode()) { return true; }
 
-            // in PowerPoint it is necessary, that no place holder drawing is selected
-            return !app.getModel().isAtLeastOnePlaceholderInMultiSelection();
+            return !app.getModel().isAtLeastOneNotGroupableDrawingInSelection();
         };
 
         /**
