@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Edy Haryono <edy.haryono@open-xchange.com>
  */
@@ -143,7 +144,7 @@ define('io.ox/office/textframework/selection/remoteselection', [
                 // render all remote selections
                 _.each(app.getActiveClients(), renderSelection);
             }
-        }, { delay: 100 });
+        }, { delay: 100, infoString: 'RemoteSelection renderCollaborativeSelectionDebounced()', app: app });
 
         /**
          * Create a Overlay with the username to show the remote username for a selection.
@@ -182,6 +183,19 @@ define('io.ox/office/textframework/selection/remoteselection', [
                 userTargetSelection = client.userData.target,
                 userTargetIndex = client.userData.targetIndex;
 
+            // helper function to determine if selection is on active slide
+            function isSelectionOnActiveSlide(userSelection) {
+                var state = false;
+                var activeSlideId = docModel.getActiveSlideId();
+
+                if (docModel.isLayoutOrMasterId(activeSlideId)) {
+                    state = activeSlideId === client.userData.target;
+                } else {
+                    state = docModel.getActiveSlideIndex() === _.first(userSelection.start);
+                }
+                return state;
+            }
+
             // draw nothing and quit if:
             // - user is the current user himself
             // - no user data/selection is available.
@@ -210,6 +224,9 @@ define('io.ox/office/textframework/selection/remoteselection', [
                     return;
                 }
 
+                // Don't draw selection if is on inactive slide, #46237
+                if (useSlideMode && !isSelectionOnActiveSlide(userSelection)) { return; }
+
                 var activeRootNode = docModel.getRootNode(userTargetSelection, userTargetIndex),
                     selectionAnchorPoint = Position.getDOMPosition(activeRootNode, userSelection.start),
                     selectionFocusPoint = Position.getDOMPosition(activeRootNode, userSelection.end);
@@ -438,7 +455,7 @@ define('io.ox/office/textframework/selection/remoteselection', [
 
             overlayTimer = self.executeDelayed(function () {
                 overlay.find('.collaborative-username').fadeOut('fast');
-            }, 3000);
+            }, { delay: 3000, infoString: 'RemoteSelection: overlayTimer', app: app });
         }
 
         /**
