@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Carsten Driesner <carsten.driesner@open-xchange.com>
  */
@@ -17,18 +18,22 @@ define('io.ox/office/textframework/utils/export', [
 
     'io.ox/office/textframework/utils/dom',
     'io.ox/office/editframework/utils/hyperlinkutils',
+    'io.ox/office/editframework/utils/color',
 
+    'io.ox/office/drawinglayer/view/drawingframe',
     'io.ox/office/drawinglayer/view/imageutil'
 
-], function (Utils, DOM, HyperlinkUtils, Image) {
+], function (Utils, DOM, HyperlinkUtils, Color, DrawingFrame, Image) {
 
     'use strict';
 
     var COPY_STYLES = {
         paragraph: ['text-align', 'background-color', 'padding', 'margin', 'text-indent', 'margin', 'border-color', 'border-style', 'border-width'],
-        span: ['font-family', 'font-weight', 'text-decoration', 'background-color', 'color', 'font-size', 'vertical-align', 'line-height', 'lang'],
+        span: ['font-family', 'font-weight', 'text-decoration', 'color', 'font-size', 'vertical-align', 'line-height', 'lang'],
+        textframe_p: ['margin', 'padding'],
         table: ['width', 'background-color'],
-        td: ['height', 'background-color', 'border-top-style', 'border-right-style', 'border-bottom-style', 'border-left-style', 'border-top-width', 'border-right-width', 'border-bottom-width', 'border-left-width', 'border-color', 'padding'],
+        tr: ['background-color'],
+        td: ['height', 'background-color', 'border-top', 'border-right', 'border-bottom', 'border-left', 'padding'],
         img: ['width', 'height', 'border', 'margin', 'title']
     };
 
@@ -57,19 +62,44 @@ define('io.ox/office/textframework/utils/export', [
      *  The normalized HTML mark-up for export.
      */
     Export.getHTMLFromSelection = function (editor, options) {
-        var resultDiv = $('<div>'),
-            selection = editor.getSelection(),
-            paragraphStyles = editor.getStyleCollection('paragraph'),
-            listStyles = editor.getListCollection(),
-            paraStylesIds = createParagraphStyleIds(selection, paragraphStyles),
-            html = $('<span>').html(selection.getHtmlFromBrowserSelection()),
-            clipboardId = Utils.getStringOption(options, 'clipboardId', ''),
+        /**
+         * Returns the currently selected contents as HTML mark-up.
+         *
+         * @returns {String}
+         *  The selected content, as HTML mark-up string.
+         */
+        function getHtmlFromBrowserSelection() {
+            var returnValue = $('<div>');
+            var allDrawingsInSelection = selection.getAllDrawingsInSelection();
+
+            if (allDrawingsInSelection.length > 0) {
+                _.each(allDrawingsInSelection, function (drawing) {
+                    returnValue.append(parseSelection(editor, selection, drawing, { type: 'html' }), '<span>&#8203;</span>');
+                });
+            } else {
+                returnValue.append('<div>');
+            }
+
+            return returnValue;
+        }
+
+        var resultDiv           = $('<div>'),
+            selection           = editor.getSelection(),
+            paragraphStyles     = editor.getStyleCollection('paragraph'),
+            listStyles          = editor.getListCollection(),
+            paraStylesIds       = createParagraphStyleIds(selection, paragraphStyles),
+            clipboardId         = Utils.getStringOption(options, 'clipboardId', ''),
             clipboardOperations = Utils.getArrayOption(options, 'clipboardOperations', []),
-            clipboardOrigin = Utils.getStringOption(options, 'clipboardOrigin', ''),
-            isEncodeBase64 = Utils.getBooleanOption(options, 'isEncodeBase64', true),
+            clipboardOrigin     = Utils.getStringOption(options, 'clipboardOrigin', ''),
+            isEncodeBase64      = Utils.getBooleanOption(options, 'isEncodeBase64', true),
+            html                = (editor.useSlideMode()) ? getHtmlFromBrowserSelection() : $('<span>').html(selection.getHtmlFromBrowserSelection()),
             metaElement;
 
-        createOptimizedStructure(html, resultDiv, paraStylesIds, listStyles, isEncodeBase64);
+        if (!editor.useSlideMode()) {
+            createOptimizedStructure(html, resultDiv, paraStylesIds, listStyles, isEncodeBase64);
+        } else {
+            resultDiv = html;
+        }
         clearParagraphStyleIds(selection);
 
         // use the first child to store meta information on
@@ -92,6 +122,230 @@ define('io.ox/office/textframework/utils/export', [
         return resultDiv.html();
     };
 
+    Export.getPlainTextFromSelection = function (editor) {
+        var selection       = editor.getSelection(),
+            text            = '';
+
+        function getTextFromDrawingSelection() {
+            var returnValue = '';
+
+            _.each(selection.getAllDrawingsInSelection(), function (drawing, i) {
+                if (i > 0) { returnValue += '\r\n\r\n'; }
+                returnValue += parseSelection(editor, selection, drawing, { type: 'text' });
+            });
+            return returnValue;
+        }
+
+        // iterate through all drawings and get their texts
+        text += getTextFromDrawingSelection();
+
+        return text;
+    };
+
+    function getPreparedText(arrElements, options) {
+        var type = Utils.getStringOption(options, 'type', 'html'),
+            text = '',
+            i = 0;
+
+        function addText(element) {
+            if (!_.isEmpty(element.textContent)) {
+                if (i > 0 && type === 'text') { text += '\r\n'; }
+                // #55651 - escape HTML to avoid XSS
+                text += Utils.escapeHTML(element.textContent);
+                i++;
+            }
+        }
+
+        function iterateChildren(arrElements) {
+            _.each(arrElements, function (element) {
+                var tmp_i = i;
+                if ($(element).hasClass('selection') || (type === 'html' && $(element).is('table'))) { return; }
+
+                // open the paragraph-element
+                if (type === 'html' && $(element).hasClass('p')) { text += '<p style="margin: 0px; padding: 0px;">'; }
+
+                if (element.children && element.children.length > 0) {
+                    iterateChildren(element.children);
+                } else {
+                    addText(element);
+                }
+
+                if (type === 'html' && $(element).hasClass('p')) {
+                    // if there were no text added, add a "placeholder" to create valid html
+                    if (tmp_i === i) { text += '&#8203;'; }
+                    // close the paragraph-element
+                    text += '</p>';
+                }
+            });
+        }
+
+        iterateChildren(arrElements);
+
+        return text;
+    }
+
+    function parseSelection(editor, selection, drawing, options) {
+        var type             = Utils.getStringOption(options, 'type', 'html'),
+            browserSelection = window.getSelection(),
+            result           = null;
+
+        // drawing selected OR no text is selected
+        if (selection.getSelectionType() === 'drawing' || selection.isTextCursor()) {
+            switch (DrawingFrame.getDrawingType(drawing)) {
+                case 'shape':
+                    result = extractShape(editor, drawing, { type: type });
+                    break;
+                case 'table':
+                    result = extractTable(drawing, { type: type });
+                    break;
+                case 'image':
+                    result = extractImage(editor, drawing, { type: type });
+                    break;
+            }
+            return (type === 'html') ? result : result;
+
+        } else {
+            result = $('<div>');
+            // read all selection ranges
+            for (var index = 0; index < browserSelection.rangeCount; index += 1) {
+                var content = browserSelection.getRangeAt(index).cloneContents(),
+                    text = '';
+                if (content.children && content.children.length > 0) {
+                    text += getPreparedText(content.children, { type: type });
+                } else {
+                    text += $(content).text();
+                }
+                result = result.append(Utils.escapeHTML(text)); // 56580
+            }
+            return (type === 'html') ? $('<span>').append(result.html()) : result.text();
+        }
+    }
+
+    function extractImage(editor, drawing, options) {
+        var attributes  = drawing.first().data('attributes');
+
+        if (Utils.getStringOption(options, 'type', 'html') === 'html') {
+            var width        = Utils.convertHmmToLength(attributes.drawing.width, 'px', 1),
+                height       = Utils.convertHmmToLength(attributes.drawing.height, 'px', 1),
+                imageNode    = $(drawing).find('img'),
+                imageUrl     = attributes.image.imageUrl,
+                base64String = attributes.image.imageData;
+
+            if (!base64String) {
+                base64String = DOM.getBase64FromImageNode(imageNode, Image.getMimeTypeFromImageUri(imageUrl));
+            }
+
+            return applyFillAndLineStyles($('<img src="' + base64String + '" width="' + width + 'px" height="' + height + 'px">'), editor, drawing)[0];
+
+        } else {
+            return attributes.drawing.name;
+        }
+    }
+
+    function extractTable(drawing, options) {
+        var sourceTable = ($(drawing).is('table')) ? $(drawing) : $(drawing).find('table'),
+            rows        = sourceTable.find('th,tr'),
+            table       = $('<table style="border-collapse: collapse;">'),
+            text        = '';
+
+        // apply table-styles
+        copyStyles(sourceTable, table, 'table');
+
+        rows.each(function (i, row) {
+            var rowNode = $('<' + row.nodeName + '>'),
+                cells   = $(row).find('td');
+
+            // apply row-styles
+            copyStyles(row, rowNode, 'tr');
+
+            var cell_i = 0;
+            cells.each(function (j, cell) {
+                var cellText    = $(cell).text(),
+                    cellContent = $('<div class="cellcontent">').text(cellText),
+                    cellNode    = $('<td>').html(cellContent);
+
+                // apply cell-styles
+                copyStyles(cell, cellNode, 'td');
+                // apply font-styles
+                copyStyles($(cell).find('.p>span'), cellContent, 'span');
+
+                // add td to tr
+                rowNode.append(cellNode);
+
+                // add celltext to "plain-text"-content
+                text += cellText;
+                if (cell_i < (cells.length - 1)) { text += '\t'; }
+                cell_i++;
+            });
+
+            // add tr to table
+            table.append(rowNode);
+
+            // add 'newline' to "plain-text"
+            text += '\n';
+        });
+
+        return (Utils.getStringOption(options, 'type', 'html') === 'html') ? $('<div>').append(table) : text;
+    }
+
+    function extractShape(editor, drawing, options) {
+        var type        = Utils.getStringOption(options, 'type', 'html'),
+            attributes  = drawing.first().data('attributes'),
+            canvas      = drawing.find('canvas'),
+            textframe   = drawing.find('.textframe'),
+            paragraph   = $(textframe).find('>.p'),
+            span        = $(paragraph).find('>span'),
+            text        = getPreparedText(drawing[0].children, { type: type }),
+            content     = $('<div class="content">').append(text),
+            shape       = $('<div class="shape" style="display: block; width: ' + canvas.width() + 'px; height: ' + canvas.height() + 'px;">');
+
+        copyStyles(paragraph, shape, 'textframe_p');
+        copyStyles(span, content, 'span');
+
+        // if we have a preset-shape
+        if (!(attributes.geometry && attributes.geometry.presetShape && attributes.geometry.presetShape === 'rect')) {
+            shape.attr('style', shape.attr('style') + ' background-image: url(\'' + canvas[0].toDataURL() + '\'); background-repeat: no-repeat; background-position: top left;');
+
+        // if we have a "normal" shape (rectangle)
+        } else {
+            shape = applyFillAndLineStyles(shape, editor, drawing);
+        }
+
+        return (type === 'html') ? shape.append(content) : text;
+    }
+
+    function applyFillAndLineStyles(shape, editor, drawing) {
+        var attributes      = drawing.first().data('attributes'),
+
+            fillC           = (attributes.fill) ? attributes.fill.color : null,
+            fillColor       = (fillC) ? new Color(fillC.type, fillC.value, fillC.transformations, fillC.fallbackValue) : null,
+            fillColorDesc   = (fillC) ? fillColor.resolve('fill', editor.getDocModel().getTheme()) : null,
+
+            lineC           = (attributes.line) ? attributes.line.color : null,
+            lineColor       = (lineC) ? new Color(lineC.type, lineC.value, lineC.transformations, lineC.fallbackValue) : null,
+            lineColorDesc   = (lineC) ? lineColor.resolve('line', editor.getDocModel().getTheme()) : null,
+            lineWidth       = (lineC) ? Math.max(1, Utils.convertHmmToLength(attributes.line.width, 'px', 1)) : null,
+            lineType        = 'solid';
+
+        // if the shape has a background
+        if (fillColorDesc) {
+            shape.attr('style', ((shape.attr('style')) ? shape.attr('style') : '') + ' background: ' + fillColorDesc.css + ';');
+        }
+
+        // if the shape has a border
+        if (lineWidth && lineColorDesc) {
+            if (attributes.line.style === 'dotted') {
+                lineType        = 'dotted';
+            } else if (attributes.line.style === 'dashed') {
+                lineType        = 'dashed';
+            }
+
+            shape.attr('style', ((shape.attr('style')) ? shape.attr('style') : '') + ' border: ' + lineWidth + 'px ' + lineType + ' ' + lineColorDesc.css + ';');
+        }
+
+        return shape;
+    }
+
     function restoreHyperlinks($node) {
         var
             isValidURL  = HyperlinkUtils.isValidURL,
