@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
@@ -91,8 +92,8 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
          * @param {Object} [options]
          *  Optional parameters:
          *  @param {String} [options.ignoreFamily]
-         *      If specified, this property will be ignored in the generated
-         *      operation.
+         *      If specified, this families will be ignored in the generated
+         *      operation. More than one family can be specified space separated.
          *  @param {String} [options.target]
          *      If specified, this property will be send as target with operation.
          *  @param {Object} [options.drawingListStyles]
@@ -117,8 +118,12 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
             // receiving additional attributes from empty paragraph
             if (characterAttributes) { attributes.character = characterAttributes; }
 
-            // deleting the specified property from the attributes
-            if (attributes && ignoreFamily.length > 0 && attributes[ignoreFamily]) { delete attributes[ignoreFamily]; }
+            // deleting the specified families from the attributes
+            if (attributes && ignoreFamily.length > 0) {
+                _.each(ignoreFamily.split(' '), function (oneFamily) {
+                    if (attributes[oneFamily]) { delete attributes[oneFamily]; }
+                });
+            }
 
             // add the 'attrs' entry if there are attributes
             if (!_.isEmpty(attributes)) {
@@ -126,7 +131,7 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
             }
             if (!_.isEmpty(drawingListStyles)) {
                 operationOptions.attrs = operationOptions.attrs || {};
-                operationOptions.attrs = _.extend(drawingListStyles, operationOptions.attrs);
+                operationOptions.attrs = _.extend(_.copy(drawingListStyles, true), operationOptions.attrs); // always create a clone for drawing list styles
             }
 
             // push the operation
@@ -156,18 +161,20 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
          *      attributes with null values will be inserted into the
          *      'setAttributes' operation.
          *  @param {String} [options.ignoreFamily]
-         *      If specified, this property will be ignored in the generated
-         *      'setAttributes' operation.
+         *      If specified, this families will be ignored in the generated
+         *      'setAttributes' operation. More than one family can be specified space separated.
          *  @param {String} [options.target]
          *      If specified, this property will be send as target with operation.
+         *  @param {Boolean} [options.allAttributes]
+         *      If true, merged attributes will be used instead of explicit attributes.
          *
          * @returns {OperationsGenerator}
          *  A reference to this instance.
          */
         this.generateSetAttributesOperation = function (element, position, options) {
 
-            var // explicit attributes of the passed node
-                elementAttributes = AttributeUtils.getExplicitAttributes(element),
+            var // explicit or merged attributes of the passed node
+                elementAttributes = null,
                 // the operation options
                 operationOptions = _.clone(position),
                 // the style families for generated null attributes
@@ -175,10 +182,33 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
                 // a specified property, that shall be ignored in the setAttributes operation
                 ignoreFamily = Utils.getStringOption(options, 'ignoreFamily', ''),
                 // a specified property, that shall send target string with operation
-                target = Utils.getStringOption(options, 'target', '');
+                target = Utils.getStringOption(options, 'target', ''),
+                // a specified property, that determines whether to use merged attributes instead of explicit attributes
+                allAttributes = Utils.getBooleanOption(options, 'allAttributes', false);
 
-            // deleting the specified property from the attributes
-            if (elementAttributes && ignoreFamily.length > 0 && elementAttributes[ignoreFamily]) { delete elementAttributes[ignoreFamily]; }
+            if (allAttributes && docModel.useSlideMode() && docModel.isPlaceHolderDrawing(element)) {
+                // merged attributes of the passed node
+                elementAttributes = docModel.getDrawingStyles().getElementAttributes(element);
+
+            } else if (allAttributes && docModel.useSlideMode() && docModel.isPlaceHolderDrawing($(element).parents(DrawingFrame.NODE_SELECTOR))) {
+                // merged attributes of the passed node
+                if (DOM.isParagraphNode(element)) {
+                    elementAttributes = docModel.getParagraphStyles().getElementAttributes(element);
+                } else if (DOM.isTextSpan(element)) {
+                    elementAttributes = docModel.getCharacterStyles().getElementAttributes(element);
+                }
+
+            } else {
+                // explicit attributes of the passed node
+                elementAttributes = AttributeUtils.getExplicitAttributes(element);
+            }
+
+            // deleting the specified families from the attributes
+            if (elementAttributes && ignoreFamily.length > 0) {
+                _.each(ignoreFamily.split(' '), function (oneFamily) {
+                    if (elementAttributes[oneFamily]) { delete elementAttributes[oneFamily]; }
+                });
+            }
 
             // insert null values for all attributes registered for the specified style family
             if (clearFamily.length > 0) {
@@ -228,7 +258,8 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
          *      the operations at another place in the document clones the
          *      character formatting of the target position.
          *  @param {String} [options.ignoreFamily]
-         *      If specified, this property will be ignored.
+         *      If specified, this families will be ignored in the generated
+         *      operation. More than one family can be specified space separated.
          *  @param {Number} [options.targetOffset]
          *      If set to a number, the logical positions in the operations
          *      generated for the child nodes will start at this offset. If
@@ -238,6 +269,8 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
          *      If specified, this property will be send as target with operation.
          *  @param {String} [options.getDrawingListStyles]
          *      If specified, for drawings inside paragraph list styles will be fetched.
+         *  @param {Boolean} [options.allAttributes]
+         *      If true, merged attributes will be used instead of explicit attributes.
          *
          * @returns {TextOperationsGenerator}
          *  A reference to this instance.
@@ -258,6 +291,8 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
                 target = Utils.getStringOption(options, 'target', ''),
                 // fetch list style properties for drawings
                 getDrawingListStyles = Utils.getBooleanOption(options, 'getDrawingListStyles', false),
+                // a specified property, that determines whether to use merged attributes instead of explicit attributes
+                allAttributes = Utils.getBooleanOption(options, 'allAttributes', false),
                 // formatting ranges for text portions, must be applied after the contents
                 attributeRanges = [],
                 // attributes passed to the first insert operation to clear all formatting
@@ -327,11 +362,12 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
                     if (DOM.isFieldNode(node)) {
                         // extract text of all embedded spans representing the field
                         text = $(node).text();
-                        attrs.field = {};
+                        attrs.character = {};
+                        attrs.character.field = {};
                         $.each($(node).data(), function (name, value) {
                             if (name !== 'type') {
                                 if (name !== 'sFieldId' && name !== 'attributes') { // #45332 - dont send unnecessary and invalid properties
-                                    attrs.field[name] = value;
+                                    attrs.character.field[name] = value;
                                 }
                             } else {
                                 type = value;
@@ -343,7 +379,7 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
 
                     // operation to create a tabulator
                     } else if (DOM.isTabNode(node)) {
-                        generateOperationWithClearAttributes(Operations.TAB_INSERT, extendPropertiesWithTarget({ start: startPosition }, options.target));
+                        generateOperationWithClearAttributes(Operations.TAB_INSERT, extendPropertiesWithTarget({ start: startPosition }, target));
                         // attributes are contained in the embedded span elements
                         attributeRanges.push({ node: node.firstChild, position: { start: startPosition } });
 
@@ -366,25 +402,25 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
                             return;
                         }
                         // generate operations for the drawing
-                        this.generateDrawingOperations(node, startPosition, { ignoreFamily: ignoreFamily, target: options.target, getDrawingListStyles: getDrawingListStyles });
+                        this.generateDrawingOperations(node, startPosition, extendPropertiesWithTarget({ ignoreFamily: ignoreFamily, getDrawingListStyles: getDrawingListStyles }, target));
 
                     } else if (DOM.isCommentPlaceHolderNode(node)) {
                         // switching to node in comment layer
                         node = DOM.getCommentPlaceHolderNode(node);
 
                         // generate operations for the drawing
-                        this.generateCommentOperations(node, startPosition, { ignoreFamily: ignoreFamily, target: options.target });
+                        this.generateCommentOperations(node, startPosition, { ignoreFamily: ignoreFamily, target: target });
 
                     } else if (DOM.isRangeMarkerNode(node)) {
 
                         rangeId = DOM.getRangeMarkerId(node);
                         rangePos = DOM.isRangeMarkerStartNode(node) ? 'start' : (DOM.isRangeMarkerEndNode(node) ? 'end' : undefined);
                         type = DOM.getRangeMarkerType(node);
-                        self.generateOperation(Operations.RANGE_INSERT, extendPropertiesWithTarget({ start: startPosition, id: rangeId, type: type, position: rangePos }, options.target));
+                        self.generateOperation(Operations.RANGE_INSERT, extendPropertiesWithTarget({ start: startPosition, id: rangeId, type: type, position: rangePos }, target));
 
                     } else if (DOM.isComplexFieldNode(node)) {
 
-                        self.generateOperation(Operations.COMPLEXFIELD_INSERT, extendPropertiesWithTarget({ start: startPosition, instruction: DOM.getComplexFieldInstruction(node) }, options.target));
+                        self.generateOperation(Operations.COMPLEXFIELD_INSERT, extendPropertiesWithTarget({ start: startPosition, instruction: DOM.getComplexFieldInstruction(node) }, target));
 
                     } else {
                         Utils.error('TextOperationsGenerator.generateParagraphChildOperations(): unknown content node');
@@ -399,12 +435,20 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
 
             }, this, { start: rangeStart, end: rangeEnd });
 
+            // if it's presentation paragraph inside placeholder drawing and it has only template text, generate possible character attrs
+            if (docModel.useSlideMode() && !DOM.isSlideNode(paragraph) && docModel.isPlaceHolderDrawing($(paragraph).parents(DrawingFrame.NODE_SELECTOR))) {
+                var $templateTextSpan = $(paragraph).find(DOM.TEMPLATE_TEXT_SELECTOR);
+                if ($templateTextSpan.length) {
+                    attributeRanges.push({ node: $templateTextSpan, position: { start: position } });
+                }
+            }
+
             // Generate 'setAttribute' operations after all contents have been
             // created via 'insertText', 'insertField', etc. Otherwise, these
             // operations would clone the attributes of the last text portion
             // instead of creating a clean text node as expected in this case.
             _(attributeRanges).each(function (range) {
-                this.generateSetAttributesOperation(range.node, range.position, { ignoreFamily: ignoreFamily, target: target });
+                this.generateSetAttributesOperation(range.node, range.position, extendPropertiesWithTarget({ ignoreFamily: ignoreFamily, allAttributes: allAttributes }, target));
             }, this);
 
             return this;
@@ -425,9 +469,12 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
          * @param {Object} [options]
          *  Optional parameters:
          *  @param {String} [options.ignoreFamily]
-         *      If specified, this property will be ignored.
+         *      If specified, this families will be ignored in the generated
+         *      operation. More than one family can be specified space separated.
          *  @param {String} [options.target]
          *      If specified, this property will be send as target with operation.
+         *  @param {Boolean} [options.allAttributes]
+         *      If true, merged attributes will be used instead of explicit attributes.
          *
          * @returns {TextOperationsGenerator}
          *  A reference to this instance.
@@ -446,7 +493,7 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
                 elementAttrs = null,
                 // a specified property, that shall be ignored in the setAttributes operation
                 ignoreFamily = Utils.getStringOption(options, 'ignoreFamily', ''),
-                // a specified property, that determines whether to use merged attributes instead explicit attributes
+                // a specified property, that determines whether to use merged attributes instead of explicit attributes
                 allAttributes = Utils.getBooleanOption(options, 'allAttributes', false);
 
             if (!options) { options = {}; }
@@ -474,10 +521,13 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
                 if (allAttributes && docModel.useSlideMode() && docModel.isPlaceHolderDrawing($(paragraph).parents(DrawingFrame.NODE_SELECTOR))) {
                     elementAttrs = docModel.getParagraphStyles().getElementAttributes(paragraph);
                     if (elementAttrs) {
-                        // deleting the specified property from the attributes
-                        if (ignoreFamily.length > 0 && elementAttrs[ignoreFamily]) { delete elementAttrs[ignoreFamily]; }
-                        // delete empty URL attribute to avoid generation of a hyper link
-                        //if (elementAttrs && elementAttrs.character && _.isEmpty(elementAttrs.character.url)) { delete elementAttrs.character.url; }
+                        // deleting the specified families from the attributes
+                        if (ignoreFamily.length > 0) {
+                            _.each(ignoreFamily.split(' '), function (oneFamily) {
+                                if (elementAttrs[oneFamily]) { delete elementAttrs[oneFamily]; }
+                            });
+                        }
+
                         operationOptions = _.extend({ attrs: elementAttrs }, operationOptions);
                     }
                 }
@@ -504,7 +554,8 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
          * @param {Object} [options]
          *  Optional parameters:
          *  @param {String} [options.ignoreFamily]
-         *      If specified, this property will be ignored.
+         *      If specified, this families will be ignored in the generated
+         *      operation. More than one family can be specified space separated.
          *  @param {String} [options.target]
          *      If specified, this property will be send as target with operation.
          *
@@ -534,7 +585,8 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
          * @param {Object} [options]
          *  Optional parameters:
          *  @param {String} [options.ignoreFamily]
-         *      If specified, this property will be ignored.
+         *      If specified, this families will be ignored in the generated
+         *      operation. More than one family can be specified space separated.
          *  @param {String} [options.target]
          *      If specified, this property will be send as target with operation.
          *
@@ -570,7 +622,8 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
          * @param {Object} [options]
          *  Optional parameters:
          *  @param {String} [options.ignoreFamily]
-         *      If specified, this property will be ignored.
+         *      If specified, this families will be ignored in the generated
+         *      operation. More than one family can be specified space separated.
          *  @param {String} [options.target]
          *      If specified, this property will be send as target with operation.
          *
@@ -579,11 +632,16 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
          */
         this.generateTableOperations = function (tableNode, position, options) {
 
-            // operation to create the table element
-            this.generateOperationWithAttributes(tableNode, Operations.TABLE_INSERT, { start: position }, options);
+            var // whether the table node is a table node inside a drawing of type 'table'
+                isTableDrawing = DOM.isTableNodeInTableDrawing(tableNode);
+
+            // operation to create the table element (not necessary for drawings of type 'table')
+            if (!isTableDrawing) {
+                this.generateOperationWithAttributes(tableNode, Operations.TABLE_INSERT, { start: position }, options);
+                position = Position.appendNewIndex(position);
+            }
 
             // generate operations for all rows
-            position = Position.appendNewIndex(position);
             DOM.getTableRows(tableNode).each(function () {
                 self.generateTableRowOperations(this, position, options);
                 position = Position.increaseLastIndex(position);
@@ -606,9 +664,12 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
          * @param {Object} [options]
          *  Optional parameters:
          *  @param {String} [options.ignoreFamily]
-         *      If specified, this property will be ignored.
+         *      If specified, this families will be ignored in the generated
+         *      operation. More than one family can be specified space separated.
          *  @param {String} [options.target]
          *      If specified, this property will be send as target with operation.
+         *  @param {Boolean} [options.allAttributes]
+         *      If true, merged attributes will be used instead of explicit attributes.
          *  @param {String} [options.getDrawingListStyles]
          *      If specified, for drawings inside paragraph list styles will be fetched.
          *
@@ -625,7 +686,7 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
                 elementAttrs = null,
                 // a specified property, that shall be ignored in the setAttributes operation
                 ignoreFamily = Utils.getStringOption(options, 'ignoreFamily', ''),
-                // a specified property, that determines whether to use merged attributes instead explicit attributes
+                // a specified property, that determines whether to use merged attributes instead of explicit attributes
                 allAttributes = Utils.getBooleanOption(options, 'allAttributes', false),
                 // fetch list style properties for drawings
                 getDrawingListStyles = Utils.getBooleanOption(options, 'getDrawingListStyles', false);
@@ -638,9 +699,12 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
                 if (allAttributes && (type === 'shape') && docModel.useSlideMode() && docModel.isPlaceHolderDrawing(drawingNode)) {
                     elementAttrs = docModel.getDrawingStyles().getElementAttributes(drawingNode);
                     if (elementAttrs) {
-                        // deleting the specified property from the attributes
-                        if (ignoreFamily.length > 0 && elementAttrs[ignoreFamily]) { delete elementAttrs[ignoreFamily]; }
-                        //delete elementAttrs.presentation;
+                        // deleting the specified families from the attributes
+                        if (ignoreFamily.length > 0) {
+                            _.each(ignoreFamily.split(' '), function (oneFamily) {
+                                if (elementAttrs[oneFamily]) { delete elementAttrs[oneFamily]; }
+                            });
+                        }
                         operationOptions = _.extend({ attrs: elementAttrs }, operationOptions);
                     }
                 }
@@ -651,10 +715,13 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
 
                 this.generateOperationWithAttributes(drawingNode, Operations.DRAWING_INSERT, operationOptions, options);
 
+                // the drawing list styles shall not be used for generating the content of the drawing (for example for paragraphs)
+                if (options.drawingListStyles) { delete options.drawingListStyles; }
+
                 if (type === 'group') {
                     // generate operations for the contents of the text frame
                     this.generateDrawingGroupChildOperations(drawingNode, position, options);
-                } else if (type === 'shape' && DrawingFrame.isTextFrameShapeDrawingFrame(drawingNode)) {
+                } else if ((type === 'shape' && DrawingFrame.isTextFrameShapeDrawingFrame(drawingNode)) || type === 'table') {
                     // generate operations for the contents of the text frame
                     this.generateContentOperations(drawingNode, position, options);
                 }
@@ -677,7 +744,8 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
          * @param {Object} [options]
          *  Optional parameters:
          *  @param {String} [options.ignoreFamily]
-         *      If specified, this property will be ignored.
+         *      If specified, this families will be ignored in the generated
+         *      operation. More than one family can be specified space separated.
          *  @param {String} [options.target]
          *      If specified, this property will be send as target with operation.
          *
@@ -717,7 +785,8 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
          * @param {Object} [options]
          *  Optional parameters:
          *  @param {String} [options.ignoreFamily]
-         *      If specified, this property will be ignored in the generated
+         *      If specified, this families will be ignored in the generated
+         *      operation. More than one family can be specified space separated.
          *      operation.
          *  @param {String} [options.target]
          *      If specified, this property will be send as target with operation.
@@ -760,7 +829,8 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
          * @param {Object} [options]
          *  Optional parameters:
          *  @param {String} [options.ignoreFamily]
-         *      If specified, this property will be ignored.
+         *      If specified, this families will be ignored in the generated
+         *      operation. More than one family can be specified space separated.
          *  @param {String} [options.target]
          *      If specified, this property will be send as target with operation.
          *
@@ -800,7 +870,8 @@ define('io.ox/office/textframework/utils/operationsgenerator', [
          * @param {Object} [options]
          *  Optional parameters:
          *  @param {String} [options.ignoreFamily]
-         *      If specified, this property will be ignored.
+         *      If specified, this families will be ignored in the generated
+         *      operation. More than one family can be specified space separated.
          *  @param {String} [options.target]
          *      If specified, this property will be send as target with operation.
          *
