@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -52,6 +53,8 @@ define('io.ox/office/textframework/utils/snapshot', [
             headerWrapper = null, footerWrapper = null,
             // the nodes for master slide layer and layout slide layer
             masterSlideLayer = null, layoutSlideLayer = null,
+            // active slide id
+            activeSlideId = null,
             // the margin at the page, that is used for centering the page including comment layer
             commentMargin = null,
             // the current root node (in which content is deleted, inserted, or gets new attributes)
@@ -107,10 +110,14 @@ define('io.ox/office/textframework/utils/snapshot', [
             // saving the operation state number
             osn = model.getOperationStateNumber();
 
+            // adding all slides into the page, before creating snapshot
+            if (model.useSlideMode()) { model.appendAllSlidesToDom(); }
+
             // saving the current content node
             contentNode = DOM.getPageContentNode(pageNode).clone(true, true);
 
             if (model.useSlideMode()) { // OX Presentation specific nodes
+                activeSlideId = model.getActiveSlideId();
 
                 // getting the layer nodes for master and layout slides
                 masterSlideLayerNode = model.getMasterSlideLayerNode();
@@ -193,7 +200,7 @@ define('io.ox/office/textframework/utils/snapshot', [
             // updating cached page content node in page layout object (updating all cached content nodes)
             model.getPageLayout().refreshPageContentNode();
 
-            // triggering that all models are completely recreated -> the models need to be rebuilt from scratch
+            // triggering that the model will  be recreated -> the models need to be rebuilt from scratch
             model.trigger('document:reloaded', self);
 
             // setting the OSN
@@ -208,9 +215,14 @@ define('io.ox/office/textframework/utils/snapshot', [
             // setting application specific data into the model
             if (modelData) { model.setModelDataObject(modelData); }
 
+            // if active slide id is stored, set it again
+            if (activeSlideId) { model.setActiveSlideId(activeSlideId, { forceUpdate: true }); }
+
+            // triggering to listeners that all models are completely recreated
+            model.trigger('document:reloaded:after', self);
+
             // all canvas elements need to be repainted
             redrawAllCanvasDrawings();
-
         });
 
         /**
