@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Edy Haryono <edy.haryono@open-xchange.com>
  */
@@ -30,6 +31,53 @@ define('io.ox/office/textframework/utils/textutils', [
     // a logger bound to a specific URL option
     var logger = new Logger({ prefix: 'TEXT', enable: 'office:log-textutils' });
 
+    // supported locales with the default format
+    TextUtils.DEFAULT_PAPER_FORMAT = {
+        en_US: 'Letter',
+        en_GB: 'A4',
+        de_DE: 'A4',
+        fr_FR: 'A4',
+        fr_CA: 'Letter',
+        es_ES: 'A4',
+        es_MX: 'Letter',
+        nl_NL: 'A4',
+        pl_PL: 'A4',
+        ja_JP: 'A4',
+        it_IT: 'A4',
+        zh_CN: 'A4',
+        zh_TW: 'A4',
+        hu_HU: 'A4',
+        sk_SK: 'A4',
+        cs_CZ: 'A4',
+        lv_LV: 'A4',
+        ro_RO: 'A4',
+        pt_BR: 'Letter',
+        sv_SE: 'A4',
+        da_DK: 'A4',
+        ru_RU: 'A4'
+    };
+
+    /**
+     * Characters which starts a composition on the Mac as they can be used to create composed characters
+     */
+    TextUtils.MAC_COMPOSE_CHARS = ['^', '~', '\xb4', '`'];
+
+    /**
+     * Default background attributes for drawing.
+     */
+    TextUtils.NO_DRAWING_BACKGROUND = { fill: { type: 'none', color: null, backgroundColor: null, transparency: null, gradient: null, bitmap: null, pattern: null } };
+
+    /**
+     * Default background attributes for slide.
+     */
+    TextUtils.NO_SLIDE_BACKGROUND = { fill: { type: null, color: null, backgroundColor: null, transparency: null, gradient: null, bitmap: null, pattern: null } };
+
+    // default paperformats of the supported locales
+    var PAPERSIZE_BY_FORMAT = {
+        Letter: { width: 21590, height: 27940 },
+        A4: { width: 21000, height: 29700 }
+    };
+
     // private methods ----------------------------------------------------------------
 
     /**
@@ -397,7 +445,7 @@ define('io.ox/office/textframework/utils/textutils', [
      *  returns a sorted Array all absolute drawings in textdrawinglayer and textcontent,
      */
     TextUtils.getAllAbsoluteDrawingsOnPage = logger.profileMethod('TextUtils.getAllAbsoluteDrawingsOnNode()', function (targetRootNode, pageNumber) {
-        var subSelector = '.drawing.absolute';
+        var subSelector = '.drawing.absolute:not(.grouped)';
         var selector = '>.textdrawinglayer >' + subSelector + '[page-number="' + pageNumber + '"]';
 
         var allPageDrawings = targetRootNode.find(selector);
@@ -557,6 +605,40 @@ define('io.ox/office/textframework/utils/textutils', [
         return HANGUL.test(text);
     };
 
+    /**
+     * Get the default paper size by the given locale.
+     * @param {String} locale the locale to get the default page size
+     * @returns {Object}
+     *  {Number} width of the page
+     *  {Number} height of the page
+     *  If the locale is not supported return the page size of DIN A4
+     */
+    TextUtils.getPaperSizeByLocale = function (locale) {
+        var paperFormat = TextUtils.DEFAULT_PAPER_FORMAT[locale];
+        var size = paperFormat ? PAPERSIZE_BY_FORMAT[paperFormat] : null;
+        return size || PAPERSIZE_BY_FORMAT.A4;
+    };
+
+    /**
+     * Receiving the attributes that are necessary to remove a drawing background.
+     *
+     * @returns {Object}
+     *  The attributes required to remove the drawing background.
+     */
+    TextUtils.getEmptyDrawingBackgroundAttributes = function () {
+        return TextUtils.NO_DRAWING_BACKGROUND;
+    };
+
+    /**
+     * Receiving the attributes that are necessary to remove a slide background.
+     *
+     * @returns {Object}
+     *  The attributes required to remove the slide background.
+     */
+    TextUtils.getEmptySlideBackgroundAttributes = function () {
+        return TextUtils.NO_SLIDE_BACKGROUND;
+    };
+
     // exports ================================================================
 
     return TextUtils;
