@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -14,9 +15,10 @@
 define('io.ox/office/textframework/view/control/changetrackbadge', [
     'io.ox/office/tk/utils',
     'io.ox/office/baseframework/view/control/userpicture',
+    'io.ox/office/editframework/utils/editconfig',
     'io.ox/office/tk/utils/driveutils',
     'gettext!io.ox/office/textframework/main'
-], function (Utils, UserPicture, DriveUtils, gt) {
+], function (Utils, UserPicture, Config, DriveUtils, gt) {
 
     'use strict';
 
@@ -35,7 +37,7 @@ define('io.ox/office/textframework/view/control/changetrackbadge', [
         var // self reference
             self = this,
 
-            authorLinkNode = (DriveUtils.isContactsEnabled() ? $('<a>') : $('<div>').css('cursor', 'default')).addClass('change-track-author').text(gt('Unknown')),
+            authorLinkNode = $(Config.CONTACTS_AVAILABLE ? '<a>' : '<div>').css('cursor', 'default').addClass('change-track-author').text(gt('Unknown')),
             dateNode = $('<div>').addClass('change-track-date').text(gt('Unknown')),
             actionNode = $('<div>').addClass('change-track-action').text(gt('Unknown')),
             descriptionNode = $('<div>').addClass('change-track-description');
@@ -62,7 +64,7 @@ define('io.ox/office/textframework/view/control/changetrackbadge', [
                     self.setValue({ userId: data.authorUserId, userName: displayName });
                     authorLinkNode.text(displayName);
 
-                    if (!info.guest && !DriveUtils.isGuest() && DriveUtils.isContactsEnabled()) {
+                    if (!info.guest && !DriveUtils.isGuest() && Config.CONTACTS_AVAILABLE) {
                         authorLinkNode.addClass('halo-link').data('internal_userid', data.authorUserId);
                     }
                 });
