@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -94,6 +95,59 @@ define('io.ox/office/textframework/view/controls', [
 
     } }); // class ParagraphAlignmentPicker
 
+    // class ParagraphAlignmentPicker =========================================
+
+    /**
+     * A picker control for horizontal text alignment & vertical paragraph alignment.
+     *
+     * @constructor
+     *
+     * @extends RadioGroup
+     */
+    TextControls.GeneralAlignmentPicker = EditControls.CompoundButton.extend({ constructor: function (docView, initOptions) {
+
+        EditControls.CompoundButton.call(this, docView, Utils.extendOptions({
+            icon: 'docs-para-align-left',
+            tooltip: gt('Paragraph alignment'),
+            updateCaptionMode: 'none'
+        }, initOptions));
+
+        var horizontal = new EditControls.RadioGroup();
+        _.each(Labels.PARA_ALIGNMENT_STYLES, function (style) {
+            horizontal.createOptionButton(style.value, { icon: style.icon, label: style.label });
+        });
+        this.addSectionLabel(gt('Horizontal alignment'));
+        this.addGroup('paragraph/alignment', horizontal);
+
+        var vertical = new EditControls.RadioGroup();
+        _.each(Labels.PARA_VERT_ALIGNMENT_STYLES, function (style) {
+            vertical.createOptionButton(style.value, { icon: style.icon, label: style.label });
+        });
+        this.addSectionLabel(gt('Vertical alignment'));
+        this.addGroup('drawing/verticalalignment', vertical);
+
+    } }); // class GeneralAlignmentPicker
+
+    // class SpacingGroup ================================================
+
+    TextControls.SpacingGroup = EditControls.CompoundButton.extend({ constructor: function (docView) {
+        EditControls.CompoundButton.call(this, docView, {
+            icon: 'docs-para-line-spacing-100',
+            tooltip: Labels.PARAGRAPH_AND_LINE_SPACING_LABEL,
+            dropDownVersion: { label: Labels.PARAGRAPH_AND_LINE_SPACING_LABEL }
+        });
+
+        var pickLineHeight       = new TextControls.LineHeightPicker();
+        var pickParagraphSpacing = new TextControls.ParagraphSpacingPicker();
+
+        this.addSectionLabel(Labels.LINE_SPACING_LABEL);
+        this.addGroup('paragraph/lineheight', pickLineHeight);
+
+        this.addSectionLabel(Labels.PARAGRAPH_SPACING_LABEL);
+        this.addGroup('paragraph/spacing', pickParagraphSpacing);
+
+    } }); // class SpacingGroup
+
     // class TextPositionGroup ================================================
 
     /**
@@ -345,31 +399,6 @@ define('io.ox/office/textframework/view/controls', [
             .createOptionButton('page',       { icon: 'docs-position-on-page',         label: /*#. drawing object position in paragraph */ gt.pgettext('drawing-pos', 'Move with page') });
     } }); // class AnchoragePicker
 
-    // class DrawingOrder ============================================
-
-    /**
-     *
-     * Drop-down menu control for z-order of drawing
-     * objects in text documents.
-     *
-     * @constructor
-     *
-     * @extends RadioList
-     */
-    TextControls.DrawingOrder = EditControls.CompoundButton.extend({ constructor: function (docView, options) {
-
-        // base constructor ---------------------------------------------------
-
-        EditControls.CompoundButton.call(this, docView, Utils.extendOptions(options, { label: /*#. button for drawing objects z-index (depth), is used for overlapping objects to change their order */ gt.pgettext('drawing-pos', 'Reorder'), smallerVersion: { hideLabel: true } }));
-
-        // initialization -----------------------------------------------------
-
-        this.addGroup('drawing/order', new TextControls.Button({ value: 'front',       tooltip: /*#. button for drawing objects z-index (depth)*/ gt.pgettext('drawing-pos', 'Bring object to the front'),                  /*#. button for drawing objects z-index (depth)*/ label: gt.pgettext('drawing-pos', 'Bring to front') }))
-            .addGroup('drawing/order', new TextControls.Button({ value: 'forward',     tooltip: /*#. button for drawing objects z-index (depth)*/ gt.pgettext('drawing-pos', 'Move object up one placement to the front'),  /*#. button for drawing objects z-index (depth)*/ label: gt.pgettext('drawing-pos', 'Bring forward') }))
-            .addGroup('drawing/order', new TextControls.Button({ value: 'backward',    tooltip: /*#. button for drawing objects z-index (depth)*/ gt.pgettext('drawing-pos', 'Send object one placement to the back'),      /*#. button for drawing objects z-index (depth)*/ label: gt.pgettext('drawing-pos', 'Send backward') }))
-            .addGroup('drawing/order', new TextControls.Button({ value: 'back',        tooltip: /*#. button for drawing objects z-index (depth)*/ gt.pgettext('drawing-pos', 'Send object to the back'),                    /*#. button for drawing objects z-index (depth)*/ label: gt.pgettext('drawing-pos', 'Send to back') }));
-    } });
-
     // class DrawingPositionPicker ============================================
 
     /**
@@ -465,53 +494,49 @@ define('io.ox/office/textframework/view/controls', [
      *
      * @constructor
      *
-     * @extends RadioList
+     * @extends CompoundButton
      */
-    TextControls.InsertFieldPicker = EditControls.RadioList.extend({ constructor: function () {
+    TextControls.InsertFieldPicker = EditControls.CompoundButton.extend({ constructor: function (docView, options) {
 
-        EditControls.RadioList.call(this, {
-            icon: 'docs-field',
-            label: gt('Field'),
+        EditControls.CompoundButton.call(this, docView, Utils.extendOptions(options, {
+            label: /*#. button to insert field in document */ gt('Field'),
             tooltip: gt('Insert field'),
-            smallerVersion: {
-                hideLabel: true
-            }
-        });
+            icon: 'docs-field',
+            smallerVersion: { hideLabel: true }
+        }));
 
-        this.createOptionButton('pagenumber',   { label: /*#. insert page number */ gt('Page number') })
-            .createOptionButton('numpages',     { label: /*#. insert number of pages in document */ gt('Page count') })
-            .createOptionButton('date',         { label: /*#. insert current date and time */ gt('Date & time') })
-            .createOptionButton('filename',     { label: /*#. insert document name */ gt('Document name') })
-            .createOptionButton('author',       { label: /*#. insert author's name */ gt('Author name') });
+        this.addGroup('document/insertfield', new TextControls.Button({ value: 'pagenumber',    label: /*#. insert page number */ gt('Page number') }))
+            .addGroup('document/insertfield', new TextControls.Button({ value: 'numpages',      label: /*#. insert number of pages in document */ gt('Page count') }))
+            .addGroup('document/insertfield', new TextControls.Button({ value: 'date',          label: /*#. insert current date and time */ gt('Date & time') }))
+            .addGroup('document/insertfield', new TextControls.Button({ value: 'filename',      label: /*#. insert document name */ gt('Document name') }))
+            .addGroup('document/insertfield', new TextControls.Button({ value: 'author',        label: /*#. insert author's name */ gt('Author name') }));
 
     } }); // class InsertFieldPicker
 
-    // class PresentationDateNumberPicker =================================================
+    // class PresentationDateNumberPicker =====================================
 
     /**
      * Control to pick field from dropdown
      *
      * @constructor
      *
-     * @extends RadioList
+     * @extends CompoundButton
      */
-    TextControls.PresentationDateNumberPicker = EditControls.RadioList.extend({ constructor: function () {
+    TextControls.PresentationDateNumberPicker = EditControls.CompoundButton.extend({ constructor: function (docView, options) {
 
-        EditControls.RadioList.call(this, {
-            icon: 'docs-field',
-            label: gt('Field'),
+        EditControls.CompoundButton.call(this, docView, Utils.extendOptions(options, {
+            label: /*#. button to insert slide number or date */ gt('Field'),
             tooltip: gt('Insert field'),
-            smallerVersion: {
-                hideLabel: true
-            }
-        });
+            icon: 'docs-field',
+            smallerVersion: { hideLabel: true }
+        }));
 
-        this.createOptionButton('slidenum', { label: /*#. insert slide number */ gt('Slide number') })
-            .createOptionButton('datetime', { label: /*#. insert current date and time */ gt('Date & time') });
+        this.addGroup('document/insertfield', new TextControls.Button({ value: 'slidenum', label: /*#. insert slide number */ gt('Slide number') }))
+            .addGroup('document/insertfield', new TextControls.Button({ value: 'datetime', label: /*#. insert current date and time */ gt('Date & time') }));
 
-    } }); // end of class PresentationDateNumberPicker
+    } }); // class PresentationDateNumberPicker
 
-    // class VerticalAlignmentPicker ============================================
+    // class VerticalAlignmentPicker ==========================================
 
     /**
      * Drop-down menu control for modifying the view of the comments layer. This is
@@ -530,45 +555,17 @@ define('io.ox/office/textframework/view/controls', [
             label: gt('Vertical alignment'),
             tooltip: gt('Set the vertical text alignment'),
             updateCaptionMode: 'icon',
-            smallerVersion: {
-                hideLabel: true
-            }
+            smallerVersion: { hideLabel: true }
         });
 
         // initialization -----------------------------------------------------
 
-        this.createOptionButton('top',      { icon: 'fa-indent',   label: gt('Top') })
-            .createOptionButton('centered', { icon: 'fa-outdent',  label: gt('Centered') })
-            .createOptionButton('bottom',   { icon: 'fa-list-alt', label: gt('Bottom') });
+        _.each(Labels.PARA_VERT_ALIGNMENT_STYLES, function (style) {
+            this.createOptionButton(style.value, { icon: style.icon, label: style.label });
+        }, this);
 
     } }); // class VerticalAlignmentPicker
 
-    // class DrawingAlignment ============================================
-
-    /**
-     *
-     * Drop-down menu control for the alignment of selected drawings in text/presentation documents.
-     *
-     * @constructor
-     *
-     * @extends RadioList
-     */
-    TextControls.DrawingAlignment = EditControls.CompoundButton.extend({ constructor: function (docView, options) {
-
-        // base constructor ---------------------------------------------------
-
-        EditControls.CompoundButton.call(this, docView, Utils.extendOptions(options, { label: /*#. button to change the alignment of the selected drawing/s */ gt.pgettext('drawing-pos', 'Align'), smallerVersion: { hideLabel: true } }));
-
-        // initialization -----------------------------------------------------
-
-        this.addGroup('drawing/align', new TextControls.Button({ value: 'left',     /*#. button to change the drawing/s to left alignment*/ label: gt.pgettext('drawing-pos', 'Align left') }))
-            .addGroup('drawing/align', new TextControls.Button({ value: 'center',   /*#. button to change the drawing/s to center alignment*/ label: gt.pgettext('drawing-pos', 'Align center') }))
-            .addGroup('drawing/align', new TextControls.Button({ value: 'right',    /*#. button to change the drawing/s to right alignment*/ label: gt.pgettext('drawing-pos', 'Align right') }))
-            .addGroup('drawing/align', new TextControls.Button({ value: 'top',      /*#. button to change the drawing/s to top alignment*/ label: gt.pgettext('drawing-pos', 'Align top') }))
-            .addGroup('drawing/align', new TextControls.Button({ value: 'middle',   /*#. button to change the drawing/s to middle alignment*/ label: gt.pgettext('drawing-pos', 'Align middle') }))
-            .addGroup('drawing/align', new TextControls.Button({ value: 'bottom',   /*#. button to change the drawing/s to bottom alignment*/ label: gt.pgettext('drawing-pos', 'Align bottom') }));
-    } }); // class DrawingAlignment
-
     // exports ================================================================
 
     return TextControls;
