@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Kai Ahrens <kai.ahrens@open-xchange.com>
  */
@@ -15,11 +16,10 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/forms',
     'io.ox/office/tk/dialogs',
-    'io.ox/office/textframework/utils/operations',
-    'io.ox/office/settings/units',
+    'io.ox/office/editframework/view/editcontrols',
     'gettext!io.ox/office/textframework/main',
     'less!io.ox/office/textframework/view/dialog/pagesettingsdialog'
-], function (Utils, Forms, Dialogs, Operations, Units, gt) {
+], function (Utils, Forms, Dialogs, EditControls, gt) {
 
     'use strict';
 
@@ -75,10 +75,11 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
              *  slide-specific:
              *  - width/height values need to be set paper format alike in order to handle orientation calculation properly for both use cases screen and paper.
              */
-            screen_4_by_3:    { value: 'screen_4_by_3', name: /*#. Predefined 'Standard (4:3)' slide format for presentations */ gt('Standard (4:3)'), width: 19050, height: 25400 },
-            screen_16_by_9:   { value: 'screen_16_by_9', name: /*#. Predefined 'Widescreen (16:9)' slide format for presentations */ gt('Widescreen (16:9)'), width: 14290, height: 25400 },
-            screen_16_by_10:  { value: 'screen_16_by_10', name: /*#. Predefined 'Widescreen (16:10)' slide format for presentations */ gt('Widescreen (16:10)'), width: 15880, height: 25400 },
-            screen_ultrawide: { value: 'screen_ultrawide', name: /*#. Predefined 'Ultra Widescreen' slide format for presentations */ gt('Ultra Widescreen'), width: 19050, height: 33870 }
+            screen_4_by_3:      { value: 'screen_4_by_3', name: /*#. Predefined 'Standard (4:3)' slide format for presentations */ gt('Standard (4:3)'), width: 19050, height: 25400 },
+            screen_16_by_9:     { value: 'screen_16_by_9', name: /*#. Predefined 'Widescreen (16:9)' slide format for presentations */ gt('Widescreen (16:9)'), width: 14290, height: 25400 },
+            screen_16_by_10:    { value: 'screen_16_by_10', name: /*#. Predefined 'Widescreen (16:10)' slide format for presentations */ gt('Widescreen (16:10)'), width: 15880, height: 25400 },
+          //screen_ultrawide:   { value: 'screen_ultrawide', name: /*#. Predefined 'Ultra Widescreen' slide format for presentations */ gt('Ultra Widescreen'),          width: 19050, height: 33870 },
+            screen_16_by_9_hd:  { value: 'screen_16_by_9_hd', name: /*#. Predefined 'Widescreen HD (16:9)' slide format for presentations */ gt('Widescreen HD (16:9)'), width: 19050, height: 33870 }
         },
 
         PAGE_FORMAT_SETTING_KEY_LIST = [
@@ -98,12 +99,12 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
             'screen_4_by_3',
             'screen_16_by_9',
             'screen_16_by_10',
-            'screen_ultrawide',
-            'letter',
-            'a3',
-            'a4',
-            'b4',
-            'b5'
+            'screen_16_by_9_hd'
+          //'letter',           // not provided, but could be.
+          //'a3',               //
+          //'a4',               //
+          //'b4',               //
+          //'b5'                //
         ],
 
         ORIENTATION_SETTING_LIST = [
@@ -115,7 +116,10 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
            { value: 'narrow', name: marginNarrowStr, left: 1270, top: 1270, right: 1270, bottom: 1270 },
            { value: 'normal', name: marginNormalStr, left: 2540, top: 2540, right: 2540, bottom: 2540 },
            { value: 'wide', name: marginWideStr, left: 5080, top: 5080, right: 5080, bottom: 5080 }
-        ];
+        ],
+
+        MARGIN_MIN = 0,
+        MARGIN_MAX = 5000;
 
     function collectFormatSettings(collector, formatKey/*, idx, list*/) {
         if (formatKey in FORMAT_SETTING_MAP) {
@@ -152,23 +156,23 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
         var self = this,
             // Misc
             docModel = docView.getDocModel(),
-            unit = Units.getStandardUnit(),
-            step = Units.getStandardUnitStep(),
             // jQuery DOM objects
             jqFormat = null,
             jqOrientation = null,
             jqMargins = null,
-            jqWidth = null,
-            jqHeight = null,
-            jqMarginTop = null,
-            jqMarginBottom = null,
-            jqMarginLeft = null,
-            jqMarginRight = null,
             jqSizeTitle = null,
             jqMarginTitle = null,
             jqTable = null,
             jqTableVertMargins = null,
             jqTableHorzMargins = null,
+            // spinner
+            widthSpinner = null,
+            heightSpinner = null,
+            marginTopSpinner = null,
+            maringBottomSpinner = null,
+            marginLeftSpinner = null,
+            marginRightSpinner = null,
+
             // Page data
             formatSettingList = null,
             isPresentationApp = docModel.useSlideMode(),
@@ -190,10 +194,74 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
             // text-app specific format-settings
             formatSettingList = PAGE_FORMAT_SETTING_KEY_LIST.reduce(collectFormatSettings, []);
         }
-        Dialogs.ModalDialog.call(this, { title: pageSettingsStr, width: (ox.mobile || isPresentationApp) ? 320 : 530 });
+
+        Dialogs.ModalDialog.call(this, { title: pageSettingsStr, width: (Utils.SMALL_DEVICE || isPresentationApp) ? 320 : 530, container: docView.getApp().getWindowNode() });
 
         // private methods ----------------------------------------------------
 
+        /**
+         * Spinner wrapper.
+         * @param {Number} min Value
+         * @param {Number} max Value
+         * @param {String} pageDataKey
+         *  The property name of the current pageData object, whose value
+         *  should be set accordingly.
+         * @param {String} label String for the label
+         */
+        function Spinner(min, max, pageDataKey, label) {
+            var spinnerValue,
+                spinnerNode,
+                cleanLabel  = label ? Utils.trimAndCleanString(label.toLowerCase().replace(' ', '')) : false,
+                labelNode = Forms.createElementMarkup('label', { attributes: { class: 'spin-field-label', for: cleanLabel }, content: label });
+
+            EditControls.UnitField.call(this, {
+                width: 70,
+                tooltip: label,
+                min: min,
+                max: max,
+                smallerVersion: { hide: true }
+            });
+
+            this.setValue = function (value) {
+                spinnerValue = value;
+                this.setFieldValue(spinnerValue);
+                setPageValue(null, pageDataKey, spinnerValue);
+
+                this.getInputNode().trigger('input');
+            };
+
+            this.triggerChange = function (value, options) {
+
+                if (!_.isNull(value)) {
+                    this.setValue(value);
+                    if (options.sourceEvent.keyCode === 13) {
+                        self.invoke('ok');
+                    }
+                } else {
+                    this.setValue(spinnerValue);
+                }
+            };
+
+            /**
+             * Returns the node of the spinner
+             * @returns {jQuery} the spinner node.
+             */
+            this.node = function () {
+                if (!spinnerNode) {
+                    spinnerNode = $(this.getNode());
+                }
+                return spinnerNode;
+            };
+
+            /**
+             * Returns the label for the spinner.
+             * @returns {String} markup of the label.
+             */
+            this.label = function () {
+                return labelNode;
+            };
+        }
+
         /**
          * Creates and layouts all dialog controls, contained within the body of the
          * dialog.
@@ -239,19 +307,16 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
                 dropDownContainer.append(jqMargins);
             }
 
+            var minWidthHeight = isPresentationApp ? 2540 : 10000,
+                maxWidthHeight = isPresentationApp ? 142240 : 55000;
+
             // create controls
 
             // Width spinfield
-            jqWidth = $(Forms.createSpinFieldMarkup({ label: pageWidthStr, tail: unit, min: cmToUnit(10), max: cmToUnit(55), step: step }));
-            jqWidth.children('input').attr('tabindex', 10).on('change', function () {
-                setPageValue(jqWidth, 'width', getPageValue($(this).val()));
-            });
+            widthSpinner = new Spinner(minWidthHeight, maxWidthHeight, 'width', pageWidthStr);
 
             // Height spinfield
-            jqHeight = $(Forms.createSpinFieldMarkup({ label: pageHeightStr, tail: unit, min: cmToUnit(10), max: cmToUnit(55), step: step }));
-            jqHeight.children('input').attr('tabindex', 11).on('change', function () {
-                setPageValue(jqHeight, 'height', getPageValue($(this).val()));
-            });
+            heightSpinner = new Spinner(minWidthHeight, maxWidthHeight, 'height', pageHeightStr);
 
             // create title row with title element
             jqSizeTitle =  $('<h4>').text(pageSizeStr);
@@ -264,41 +329,30 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
                 jqMarginTitle = $('<h4 class="column60">').text(pageMarginsStr);
 
                 // MarginTop spinfield
-                jqMarginTop = $(Forms.createSpinFieldMarkup({ label: marginTopStr, tail: unit, min: cmToUnit(0), max: cmToUnit(5), step: step }));
-                jqMarginTop.children('input').attr('tabindex', 20).on('change', function () {
-                    setPageValue(jqMarginTop, 'marginTop', getPageValue($(this).val()));
-                });
+                marginTopSpinner = new Spinner(MARGIN_MIN, MARGIN_MAX, 'marginTop', marginTopStr);
 
                 // MarginBottom spinfield
-                jqMarginBottom = $(Forms.createSpinFieldMarkup({ label: marginBottomStr, tail: unit, min: cmToUnit(0), max: cmToUnit(5), step: step }));
-                jqMarginBottom.children('input').attr('tabindex', 21).on('change', function () {
-                    setPageValue(jqMarginBottom, 'marginBottom', getPageValue($(this).val()));
-                });
+                maringBottomSpinner = new Spinner(MARGIN_MIN, MARGIN_MAX, 'marginBottom', marginBottomStr);
+
                 // MarginLeft spinfield
-                jqMarginLeft = $(Forms.createSpinFieldMarkup({ label: marginLeftStr, tail: unit, min: cmToUnit(0), max: cmToUnit(5), step: step }));
-                jqMarginLeft.children('input').attr('tabindex', 30).on('change', function () {
-                    setPageValue(jqMarginLeft, 'marginLeft', getPageValue($(this).val()));
-                });
+                marginLeftSpinner = new Spinner(MARGIN_MIN, MARGIN_MAX, 'marginLeft', marginLeftStr);
 
                 // MarginRight spinfield
-                jqMarginRight = $(Forms.createSpinFieldMarkup({ label: marginRightStr, tail: unit, min: cmToUnit(0), max: cmToUnit(5), step: step }));
-                jqMarginRight.children('input').attr('tabindex', 31).on('change', function () {
-                    setPageValue(jqMarginRight, 'marginRight', getPageValue($(this).val()));
-                });
+                marginRightSpinner = new Spinner(MARGIN_MIN, MARGIN_MAX, 'marginRight', marginRightStr);
 
                 jqTable = $('<table class="extents">').append(
-                    $('<tr>').append($('<td>').append(jqWidth)),
-                    $('<tr>').append($('<td>').append(jqHeight))
+                    $('<tr>').append($('<td>').append(widthSpinner.label(), widthSpinner.node())),
+                    $('<tr>').append($('<td>').append(heightSpinner.label(), heightSpinner.node()))
                 );
 
                 jqTableVertMargins = $('<table class="margins">').append(
-                    $('<tr>').append($('<td>').append(jqMarginTop)),
-                    $('<tr>').append($('<td>').append(jqMarginBottom))
+                    $('<tr>').append($('<td>').append(marginTopSpinner.label(), marginTopSpinner.node())),
+                    $('<tr>').append($('<td>').append(maringBottomSpinner.label(), maringBottomSpinner.node()))
                 );
 
                 jqTableHorzMargins = $('<table class="margins">').append(
-                    $('<tr>').append($('<td>').append(jqMarginLeft)),
-                    $('<tr>').append($('<td>').append(jqMarginRight))
+                    $('<tr>').append($('<td>').append(marginLeftSpinner.label(), marginLeftSpinner.node())),
+                    $('<tr>').append($('<td>').append(marginRightSpinner.label(), marginRightSpinner.node()))
                 );
 
                 // append control divs to body
@@ -318,8 +372,8 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
             } else {
 
                 var $tr = $('<tr>');
-                $tr.append($('<td>').append(jqWidth));
-                $tr.append($('<td>').append(jqHeight));
+                $tr.append($('<td style="width: 55%;">').append(widthSpinner.label(), widthSpinner.node()));
+                $tr.append($('<td>').append(heightSpinner.label(), heightSpinner.node()));
 
                 jqTable = $('<table>').append($tr);
 
@@ -359,7 +413,7 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
                 // create menu anchor
                 menu = $('<span class="dropdown">').
                     append($('<a href="#">').
-                        attr({ tabindex: 1, 'data-type': firstValue.value, 'aria-haspopup': true, 'data-toggle': 'dropdown' }).
+                        attr({ tabindex: 0, 'data-type': firstValue.value, 'aria-haspopup': true, 'data-toggle': 'dropdown' }).
                         addClass('text').
                         text(firstValue.name)).
                     append(jqList);
@@ -383,7 +437,6 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
                         }));
                 });
             }
-
             return menu;
         }
 
@@ -409,8 +462,8 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
                 }
                 var isPortrait = (pageAttrs.orientation === 'portrait');
 
-                setPageValue(jqWidth, 'width', isPortrait ? pageFormat.width :  pageFormat.height);
-                setPageValue(jqHeight, 'height', isPortrait ? pageFormat.height : pageFormat.width);
+                setPageValue(widthSpinner, 'width', isPortrait ? pageFormat.width :  pageFormat.height);
+                setPageValue(heightSpinner, 'height', isPortrait ? pageFormat.height : pageFormat.width);
             }
         }
 
@@ -441,8 +494,8 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
 
                     pageAttrs.orientation = orientation;
 
-                    setPageValue(jqWidth, 'width', oldHeight);
-                    setPageValue(jqHeight, 'height', oldWidth);
+                    setPageValue(widthSpinner, 'width', oldHeight);
+                    setPageValue(heightSpinner, 'height', oldWidth);
                 }
             }
         }
@@ -466,22 +519,22 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
          */
         function setPageMargins(pageMargins) {
             if (_.isObject(pageMargins)) {
-                setPageValue(jqMarginLeft, 'marginLeft', pageMargins.left);
-                setPageValue(jqMarginTop, 'marginTop', pageMargins.top);
-                setPageValue(jqMarginRight, 'marginRight', pageMargins.right);
-                setPageValue(jqMarginBottom, 'marginBottom', pageMargins.bottom);
+                setPageValue(marginLeftSpinner, 'marginLeft', pageMargins.left);
+                setPageValue(marginTopSpinner, 'marginTop', pageMargins.top);
+                setPageValue(marginRightSpinner, 'marginRight', pageMargins.right);
+                setPageValue(maringBottomSpinner, 'marginBottom', pageMargins.bottom);
             }
         }
 
         /**
          * Sets the current value and updates the corresponding page control,
-         * depending on the given jQuery Node and the property key of the
+         * depending on the given Spinner and the property key of the
          * current pageData Object.
          * All three parameters need to be given, if an update
          * is to be performed.
          *
-         * @param {jQuery} jqNode
-         *  The jQuery node that needs to be updated.
+         * @param {Spinner} spinner
+         *  The Spinner that needs to be updated.
          *
          * @param {String} pageDataKey
          *  The property name of the current pageData object, whose value
@@ -490,11 +543,14 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
          * @param {Number} pageValue
          *   The page value to be set in 100th millimeters
          */
-        function setPageValue(jqNode, pageDataKey, pageValue) {
+        function setPageValue(spinner, pageDataKey, pageValue) {
 
             // set current page value and update corresponding control
             pageAttrs[pageDataKey] = pageValue;
-            jqNode.children('input').val(getUIValue(pageValue));
+
+            if (spinner) {
+                spinner.setValue(pageValue);
+            }
 
             // update selection and text of dropdown menus
             var isPortrait = pageAttrs.orientation === 'portrait',
@@ -508,6 +564,14 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
                 })
             );
 
+            if (isPresentationApp) {
+                if (pageAttrs.width >= pageAttrs.height) {
+                    pageAttrs.orientation = 'landscape';
+                } else {
+                    pageAttrs.orientation = 'portrait';
+                }
+            }
+
             selectDropdownEntry(jqOrientation,
                 _.findWhere(ORIENTATION_SETTING_LIST, {
                     value: pageAttrs.orientation
@@ -541,59 +605,18 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
          *      to be selected.
          */
         function selectDropdownEntry(jqNode, dataObject) {
+            if (jqNode) {
+                jqNode.find('.selected').removeClass('selected');
 
-            jqNode.find('.selected').removeClass('selected');
-
-            if (dataObject && dataObject.value) {
-                jqNode.find('a[data-toggle="dropdown"]').text(dataObject.name);
-                jqNode.find('a[data-value="' + dataObject.value + '"]').addClass('selected');
-            } else {
-                jqNode.find('a[data-toggle="dropdown"]').text(customStr);
+                if (dataObject && dataObject.value) {
+                    jqNode.find('a[data-toggle="dropdown"]').text(dataObject.name);
+                    jqNode.find('a[data-value="' + dataObject.value + '"]').addClass('selected');
+                } else {
+                    jqNode.find('a[data-toggle="dropdown"]').text(customStr);
+                }
             }
         }
 
-        /**
-         * converts assigned centimeter to the general unit
-         *
-         * @param {Number} cm in centimeter
-         *
-         * @returns {Number}
-         *  in general unit
-         */
-        function cmToUnit(cm) {
-            return Utils.convertLength(cm, 'cm', unit, 0.01);
-        }
-
-        /**
-         * Returns the UI value in mm, cm or inch for the given
-         * page value in 100th millimeters.
-         *
-         * @param {Number} pageValue
-         *  The page value to be converted in 100th millimeters.
-         *
-         * @returns {Number}
-         *  The UI value in mm, cm or inch, depending on the used metric
-         *  system, rounded to 2 decimal places
-         */
-        function getUIValue(pageValue) {
-            return Utils.convertHmmToLength(pageValue, unit, 0.01);
-
-        }
-
-        /**
-         * Returns the page value in 100th millimeters for the given
-         * ui value in mm, cm or inch.
-         *
-         * @param {Number} uiValue
-         *  The UI value in mm, cm or inch, depending on the used metric system,
-         *
-         * @returns {Number}
-         *  The page value in 100th millimeters
-         */
-        function getPageValue(uiValue) {
-            return Utils.convertLengthToHmm(uiValue, unit);
-        }
-
         // public methods -----------------------------------------------------
 
         /**
@@ -606,64 +629,18 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
         this.show = _.wrap(this.show, function (show) {
             return show.call(this).done(function () {
 
-                var newPageAttrs = {};
-                _.each(pageAttrs, function (value, key) {
-                    if (value !== initialPageAttrs[key]) {
-                        newPageAttrs[key] = _.isNumber(value) ? Utils.round(value, 10) : value;
-                    }
-                });
+                docModel.setPaperFormat(pageAttrs, initialPageAttrs);
 
-                if (!_.isEmpty(newPageAttrs)) {
-                    if (isPresentationApp) {
-
-                      //docModel.createAndApplyOperations($.noop);
-                      //docModel.reformatDocument(newPageAttrs); // process will use its own operations generator.
-
-                        docModel.executeDelayed(function () {
-                            this.reformatDocument(newPageAttrs);
-                        });
-
-                    } else {
-                        docModel.createAndApplyOperations(function (generator) {
-
-                            generator.generateOperation(Operations.SET_DOCUMENT_ATTRIBUTES, { attrs: { page: newPageAttrs } });
-
-                            var paraStyles = docModel.getStyleCollection('paragraph');
-
-                            function createTabStopOp(styleId) {
-
-                                if (paraStyles.isDirty(styleId)) { return; }
-
-                                var styleAttrs = paraStyles.getStyleSheetAttributeMap(styleId);
-                                if (styleAttrs.paragraph && styleAttrs.paragraph.tabStops) {
-
-                                    var oldWidth = initialPageAttrs.width - initialPageAttrs.marginLeft - initialPageAttrs.marginRight;
-                                    var newWidth = pageAttrs.width - pageAttrs.marginLeft - pageAttrs.marginRight;
-
-                                    _.each(styleAttrs.paragraph.tabStops, function (tabStop) {
-                                        var relPos = tabStop.pos / oldWidth;
-                                        tabStop.pos = Math.round(relPos * newWidth);
-                                    });
-
-                                    generator.generateOperation(Operations.CHANGE_STYLESHEET, { styleId: styleId, attrs: styleAttrs, type: 'paragraph' });
-                                }
-                            }
-                            createTabStopOp(docModel.getDefaultHeaderTextDefinition().styleId);
-                            createTabStopOp(docModel.getDefaultFooterTextDefinition().styleId);
-                        });
-                    }
-
-                }
             }).always(function () {
                 jqFormat = null;
                 jqOrientation = null;
                 jqMargins = null;
-                jqWidth = null;
-                jqHeight = null;
-                jqMarginTop = null;
-                jqMarginBottom = null;
-                jqMarginLeft = null;
-                jqMarginRight = null;
+                widthSpinner = null;
+                heightSpinner = null;
+                marginTopSpinner = null;
+                maringBottomSpinner = null;
+                marginLeftSpinner = null;
+                marginRightSpinner = null;
                 jqSizeTitle = null;
                 jqMarginTitle = null;
                 jqTable = null;
@@ -694,7 +671,7 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
         }
         this.getBody()
             .addClass(dialogCssCLassName)
-            .toggleClass('mobile', !!ox.mobile);
+            .toggleClass('mobile', Utils.SMALL_DEVICE);
 
         // create the layout of the dialog
         initControls();
@@ -704,22 +681,22 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
             // blocking keyboard input during applying of operations
             docModel.setBlockKeyboardEvent(true);
 
-            setPageValue(jqWidth, 'width', pageAttrs.width);
-            setPageValue(jqHeight, 'height', pageAttrs.height);
+            setPageValue(widthSpinner, 'width', pageAttrs.width);
+            setPageValue(heightSpinner, 'height', pageAttrs.height);
 
             if (!isPresentationApp) {
 
-                setPageValue(jqMarginLeft, 'marginLeft', pageAttrs.marginLeft);
-                setPageValue(jqMarginTop, 'marginTop', pageAttrs.marginTop);
-                setPageValue(jqMarginRight, 'marginRight', pageAttrs.marginRight);
-                setPageValue(jqMarginBottom, 'marginBottom', pageAttrs.marginBottom);
+                setPageValue(marginLeftSpinner, 'marginLeft', pageAttrs.marginLeft);
+                setPageValue(marginTopSpinner, 'marginTop', pageAttrs.marginTop);
+                setPageValue(marginRightSpinner, 'marginRight', pageAttrs.marginRight);
+                setPageValue(maringBottomSpinner, 'marginBottom', pageAttrs.marginBottom);
             }
             // us 102078426: dialogs on small devices should come up w/o keyboard,
-            // so the focus shoud not be in an input element
+            // so the focus should not be in an input element
             if (Utils.SMALL_DEVICE) {
-                self.getOkButton().focus();
+                Utils.setFocus(self.getOkButton());
             } else {
-                jqWidth.find('input').focus();
+                Utils.setFocus(widthSpinner.getInputNode());
             }
         });
 
