@@ -6,14 +6,16 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/textframework/view/labels', [
     'io.ox/office/editframework/view/editlabels',
-    'gettext!io.ox/office/textframework/main'
+    'gettext!io.ox/office/textframework/main',
+    'less!io.ox/office/textframework/view/style'
 ], function (EditLabels, gt) {
 
     'use strict';
@@ -49,7 +51,7 @@ define('io.ox/office/textframework/view/labels', [
     TextLabels.PARAGRAPH_AND_LINE_SPACING_LABEL = /*#. combined label text of both label texts from above  */ gt('Paragraph & Line spacing');
 
     /**
-     * An array with style options for all supported paragraph alignments.
+     * An array with style options for all supported horizontal paragraph alignments.
      *
      * @constant
      */
@@ -60,6 +62,17 @@ define('io.ox/office/textframework/view/labels', [
         { value: 'justify', icon: 'docs-para-align-justify', label: EditLabels.HOR_ALIGNMENT_LABELS.justify }
     ];
 
+    /**
+     * An array with style options for all supported vertical paragraph alignments.
+     *
+     * @constant
+     */
+    TextLabels.PARA_VERT_ALIGNMENT_STYLES = [
+        { value: 'top',      icon: 'docs-cell-v-align-top',   label: gt('Top') },
+        { value: 'centered', icon: 'docs-cell-v-align-middle',  label: gt('Middle') },
+        { value: 'bottom',   icon: 'docs-cell-v-align-bottom', label: gt('Bottom') }
+    ];
+
     /**
      * A map with labels for different change tracking actions.
      *
@@ -173,6 +186,14 @@ define('io.ox/office/textframework/view/labels', [
 
     // fields options --------------------------------------------------------
 
+    /**
+     * @constant
+     */
+    TextLabels.EDIT_FIELD_OPTIONS = {
+        label: /*#. fields: edit format of selected field */gt('Edit field format'),
+        tooltip: gt('Edit format of selected field')
+    };
+
     /**
      * @constant
      */
