@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Michael Nimz <michael.nimz@open-xchange.com>
  */
@@ -26,6 +27,10 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
 
     'use strict';
 
+    // convenience shortcuts
+    var Button = Controls.Button;
+    var CompoundButton = Controls.CompoundButton;
+
     // class UniversalContextMenu ================================================
 
     /**
@@ -64,16 +69,14 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
             // xox position of the cursor
             resetSelectionTo = null,
 
-            // attributes of the current text selection (to detect hyperlinks aso.)
-            characterAttrs = null,
-
             // needs to use special behavior for osx chrome
-            chromeOnOSX = (_.browser.MacOS && _.browser.Chrome);
+            chromeOnOSX = (_.browser.MacOS && _.browser.Chrome),
+
+            enableKeys = ['document/editable'];
 
         // base constructor ---------------------------------------------------
 
         ContextMenu.call(this, docView, editDiv, Utils.extendOptions({
-            enableKey: Utils.getArrayOption(initOptions, 'enableKey', ['document/editable']),
             delay: Utils.getNumberOption(initOptions, 'delay', 0)
         }, initOptions));
 
@@ -147,55 +150,77 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
         }
 
         function initMenu() {
+            var controller = docView.getApp().getController();
+
             // remove all existing controls from context menu
             self.destroyAllGroups();
 
-            // Is Drawing
-            if (Dom.isDrawingFrame(eleType)) {
-                if (!Dom.isInCommentNode(node)) {
-                    prepareDrawingMenu();
-                    return;
-                }
+            if (enableKeys.every(controller.isItemEnabled, controller)) {
 
-                // Is Table
-            } else if (Dom.isTableNode(eleType) || Dom.isCellNode(eleType)) {
-                if (Dom.isCellNode(eleType)) {
-                    if (Dom.isSpan(node) && !Dom.isEmptyCell(Dom.getCellContentNode($(node).parent()))) {
-                        prepareTextMenu();
+                // Is Drawing
+                if (Dom.isDrawingFrame(eleType)) {
+                    if (!Dom.isInCommentNode(node)) {
+                        prepareDrawingMenu();
+                        self.updateAllGroups(); //Bug 47352
                         return;
                     }
-                }
-                prepareTableMenu();
-                return;
 
-                // Is Text
-            } else {
-                // Is TextFrame
-                if (selection.isAdditionalTextframeSelection() && !Dom.isTextSpan(node)) {
-                    prepareDrawingMenu();
+                    // Is Table
+                } else if (Dom.isTableNode(eleType) || Dom.isCellNode(eleType)) {
+                    if (Dom.isCellNode(eleType)) {
+                        if (Dom.isSpan(node) && !Dom.isEmptyCell(Dom.getCellContentNode($(node).parent()))) {
+                            prepareTextMenu();
+                            self.updateAllGroups(); //Bug 47352
+                            return;
+                        }
+                    }
+                    prepareTableMenu();
+                    self.updateAllGroups(); //Bug 47352
+                    return;
+
+                    // Is Text
+                } else {
+                    // Is TextFrame
+                    if (selection.isAdditionalTextframeSelection() && !Dom.isTextSpan(node)) {
+                        prepareDrawingMenu();
+                        self.updateAllGroups(); //Bug 47352
+                        return;
+                    } else if (selection.isSlideSelection()) {
+                        self.prepareSlideMenu();
+                        self.updateAllGroups(); //Bug 47352
+                        return;
+                    }
+                    prepareTextMenu();
+                    self.updateAllGroups(); //Bug 47352
                     return;
                 }
-                prepareTextMenu();
-                return;
+            } else {
+                prepareHyperlinkMenu();
+                self.updateAllGroups(); //Bug 47352
             }
         }
-
         // preparation of context menus ---------------------------------------
         /**
          * Prepares the context menu for text
          */
         function prepareTextMenu() {
+            var characterAttrs = null;
+
             if (Dom.isChangeTrackNode(node) && !isRangeSelected) {
-                self.addGroup('acceptSelectedChangeTracking', new Controls.Button(Labels.ACCEPT_CURRENT_OPTIONS))
-                    .addGroup('rejectSelectedChangeTracking', new Controls.Button(Labels.REJECT_CURRENT_OPTIONS))
-                    .addGroup('acceptChangeTracking', new Controls.Button(Labels.ACCEPT_ALL_OPTIONS))
-                    .addGroup('rejectChangeTracking', new Controls.Button(Labels.REJECT_ALL_OPTIONS));
+                self.addGroup('acceptSelectedChangeTracking', new Button(Labels.ACCEPT_CURRENT_OPTIONS))
+                    .addGroup('rejectSelectedChangeTracking', new Button(Labels.REJECT_CURRENT_OPTIONS))
+                    .addGroup('acceptChangeTracking', new Button(Labels.ACCEPT_ALL_OPTIONS))
+                    .addGroup('rejectChangeTracking', new Button(Labels.REJECT_ALL_OPTIONS));
 
             } else if (fieldManager.isHighlightState() && !docModel.useSlideMode()) {
                 if (fieldManager.isSupportedFieldType()) {
-                    self.addGroup('updateField', new Controls.Button(Labels.UPDATE_FIELD_OPTIONS));
+                    if (fieldManager.supportsFieldFormatting()) {
+                        self.addGroup('editField', new Button(Labels.EDIT_FIELD_OPTIONS));
+                    }
+                    self.addGroup('updateField', new Button(Labels.UPDATE_FIELD_OPTIONS))
+                    .addSeparator();
+                    self.addGroup('updateAllFields', new Button(Labels.UPDATE_ALL_FIELDS_OPTIONS));
                 }
-                self.addGroup('updateAllFields', new Controls.Button(Labels.UPDATE_ALL_FIELDS_OPTIONS));
             } else {
                 characterAttrs = AttributeUtils.getExplicitAttributes(node, { family: 'character', direct: true });
 
@@ -208,23 +233,23 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
 
                     if (spellResult.replacements && spellResult.replacements.length > 0) {
                         _.each(spellResult.replacements, function (replace) {
-                            self.addGroup('document/spelling/replace', new Controls.Button({ label: replace, value: replace }));
+                            self.addGroup('document/spelling/replace', new Button({ label: replace, value: replace }));
                         });
                     }
 
                     if (spellResult.word && spellChecker.hasSpellerrorClass(spellResult.node)) {
                         self.addSeparator()
-                            .addGroup('document/spelling/ignoreword', new Controls.Button({ label: /*#. Context menu entry to ignore a word from spellchecking. */ gt('Ignore all'), value: { word: spellResult.word, start: spellResult.start, end: spellResult.end, nodes: spellResult.nodes, target: docModel.getActiveTarget() } }))
-                            .addGroup('document/spelling/userdictionary', new Controls.Button({ label: /*#. Context menu entry to add a word into the user dictionary. */ gt('Add to dictionary'), value: { word: spellResult.word, start: spellResult.start, end: spellResult.end, nodes: spellResult.nodes, target: docModel.getActiveTarget(), userDictionary: true } }));
+                            .addGroup('document/spelling/ignoreword', new Button({ label: /*#. Context menu entry to ignore a word from spellchecking. */ gt('Ignore all'), value: { word: spellResult.word, start: spellResult.start, end: spellResult.end, nodes: spellResult.nodes, target: docModel.getActiveTarget() } }))
+                            .addGroup('document/spelling/userdictionary', new Button({ label: /*#. Context menu entry to add a word into the user dictionary. */ gt('Add to dictionary'), value: { word: spellResult.word, start: spellResult.start, end: spellResult.end, nodes: spellResult.nodes, target: docModel.getActiveTarget(), userDictionary: true } }));
                     }
 
                     addLanguageGroupToMenu();
 
                     // Hyperlink
                 } else if (characterAttrs.url && !isRangeSelected) {
-                    self.addGroup('character/hyperlink/dialog', new Controls.Button({ label: Labels.EDIT_HYPERLINK_LABEL }))
-                        .addGroup('character/hyperlink/remove', new Controls.Button({ label: Labels.REMOVE_HYPERLINK_LABEL }))
-                        .addGroup('character/hyperlink/valid', new Controls.Button({ label: Labels.OPEN_HYPERLINK_LABEL, href: characterAttrs.url }));
+                    self.addGroup('character/hyperlink/dialog', new Button({ label: Labels.EDIT_HYPERLINK_LABEL }))
+                        .addGroup('character/hyperlink/remove', new Button({ label: Labels.REMOVE_HYPERLINK_LABEL }))
+                        .addGroup('character/hyperlink/valid', new Button({ label: Labels.OPEN_HYPERLINK_LABEL, href: characterAttrs.url }));
 
                     //AppTooltipMixin
                     docView.getApp().enableTooltipOnShow(self, characterAttrs.url);
@@ -242,18 +267,30 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
             self.refreshImmediately();
         }
 
+        function prepareHyperlinkMenu() {
+            var characterAttrs = AttributeUtils.getExplicitAttributes(node, { family: 'character', direct: true });
+
+            if (characterAttrs.url && !isRangeSelected) {
+                self.addGroup('character/hyperlink/valid', new Button({ label: Labels.OPEN_HYPERLINK_LABEL, href: characterAttrs.url }));
+
+                docView.getApp().enableTooltipOnShow(self, characterAttrs.url);
+            }
+
+            self.refreshImmediately();
+        }
+
         /**
          * Build compound control group and fill it with groups for normal text.
          */
         function buildNormalTextMenu() {
-            var compoundNormalTextBtn = new Controls.CompoundButton(docView, { autoCloseParent: false, autoHideGroups: true, label: Labels.INSERT_HEADER_LABEL, anchorBorder: 'right left', icon: 'fa-chevron-right', iconPos: 'trailing', caret: false });
-            compoundNormalTextBtn.addGroup('image/insert/dialog', new Controls.Button(Labels.INSERT_IMAGE_OPTIONS))
-                                .addGroup('textframe/insert', new Controls.Button(Labels.INSERT_TEXTFRAME_OPTIONS))
-                                .addGroup('comment/insert', new Controls.Button(Labels.INSERT_COMMENT_OPTIONS))
-                                .addGroup('character/hyperlink/dialog', new Controls.Button(Labels.INSERT_HYPERLINK_OPTIONS));
+            var compoundNormalTextBtn = new CompoundButton(docView, { autoCloseParent: false, autoHideGroups: true, label: Labels.INSERT_HEADER_LABEL, anchorBorder: 'right left', icon: 'fa-chevron-right', iconPos: 'trailing', caret: false });
+            compoundNormalTextBtn.addGroup('image/insert/dialog', new Button(Labels.INSERT_IMAGE_OPTIONS))
+                                .addGroup('textframe/insert', new Button(Labels.INSERT_TEXTFRAME_OPTIONS))
+                                .addGroup('comment/insert', new Button(Labels.INSERT_COMMENT_OPTIONS))
+                                .addGroup('character/hyperlink/dialog', new Button(Labels.INSERT_HYPERLINK_OPTIONS));
             if (docModel.useSlideMode()) {
-                compoundNormalTextBtn.addGroup('insertSlideNumber', new Controls.Button(Labels.INSERT_SLIDE_NUMBER_OPTIONS))
-                                    .addGroup('insertDateTime', new Controls.Button(Labels.INSERT_DATE_TIME_OPTIONS));
+                compoundNormalTextBtn.addGroup('insertSlideNumber', new Button(Labels.INSERT_SLIDE_NUMBER_OPTIONS))
+                                    .addGroup('insertDateTime', new Button(Labels.INSERT_DATE_TIME_OPTIONS));
             }
             self.addGroup(null, compoundNormalTextBtn);
         }
@@ -270,30 +307,30 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
          * Prepares the context menu for drawings
          */
         function prepareDrawingMenu() {
-            self.addGroup('drawing/delete', new Controls.Button({ label: Labels.DELETE_DRAWING_LABEL, tooltip: Labels.DELETE_DRAWING_TOOLTIP }))
+            self.addGroup('drawing/delete', new Button({ label: Labels.DELETE_DRAWING_LABEL, tooltip: Labels.DELETE_DRAWING_TOOLTIP }))
                 .addSeparator()
-                .addGroup('drawing/group', new Controls.Button({ label: Labels.GROUP_DRAWING_LABEL, tooltip: Labels.GROUP_DRAWING_TOOLTIP }))
-                .addGroup('drawing/ungroup', new Controls.Button({ label: Labels.UNGROUP_DRAWING_LABEL, tooltip: Labels.UNGROUP_DRAWING_TOOLTIP }))
+                .addGroup('drawing/group', new Button({ label: Labels.GROUP_DRAWING_LABEL, tooltip: Labels.GROUP_DRAWING_TOOLTIP }))
+                .addGroup('drawing/ungroup', new Button({ label: Labels.UNGROUP_DRAWING_LABEL, tooltip: Labels.UNGROUP_DRAWING_TOOLTIP }))
                 .addSeparator()
-                .addGroup('drawing/order', new Controls.DrawingOrder(docView, { caret: false, icon: 'fa-chevron-right', iconPos: 'trailing', anchorBorder: 'right left' }));
+                .addGroup('drawing/order', new Controls.DrawingOrderPicker(docView, { caret: false, icon: 'fa-chevron-right', iconPos: 'trailing', anchorBorder: 'right left' }));
         }
 
         /**
          * Prepares the context menu for tables
          */
         function prepareTableMenu() {
-            self.addGroup('table/insert/row', new Controls.Button({ label: gt('Insert row') }))
-                .addGroup('table/delete/row', new Controls.Button({ label: gt('Delete row') }))
-                .addGroup('table/insert/column', new Controls.Button({ label: gt('Insert column') }))
-                .addGroup('table/delete/column', new Controls.Button({ label: gt('Delete column') }))
-                .addGroup('table/delete', new Controls.Button({ label: gt('Delete table') }))
+            self.addGroup('table/insert/row', new Button({ label: gt('Insert row') }))
+                .addGroup('table/delete/row', new Button({ label: gt('Delete row') }))
+                .addGroup('table/insert/column', new Button({ label: gt('Insert column') }))
+                .addGroup('table/delete/column', new Button({ label: gt('Delete column') }))
+                .addGroup('table/delete', new Button({ label: gt('Delete table') }))
                 .addSeparator()
-                .addGroup(null, new Controls.CompoundButton(docView, { autoCloseParent: false, autoHideGroups: true, label: Labels.INSERT_HEADER_LABEL, anchorBorder: 'right left', icon: 'fa-chevron-right', iconPos: 'trailing', caret: false })
-                    .addGroup('image/insert/dialog', new Controls.Button(Labels.INSERT_IMAGE_OPTIONS))
-                    .addGroup('textframe/insert', new Controls.Button(Labels.INSERT_TEXTFRAME_OPTIONS))
-                    .addGroup('comment/insert', new Controls.Button(Labels.INSERT_COMMENT_OPTIONS))
-                    .addGroup('character/hyperlink/dialog', new Controls.Button(Labels.INSERT_HYPERLINK_OPTIONS))
-                    );
+                .addGroup(null, new CompoundButton(docView, { autoCloseParent: false, autoHideGroups: true, label: Labels.INSERT_HEADER_LABEL, anchorBorder: 'right left', icon: 'fa-chevron-right', iconPos: 'trailing', caret: false })
+                    .addGroup('image/insert/dialog', new Button(Labels.INSERT_IMAGE_OPTIONS))
+                    .addGroup('textframe/insert', new Button(Labels.INSERT_TEXTFRAME_OPTIONS))
+                    .addGroup('comment/insert', new Button(Labels.INSERT_COMMENT_OPTIONS))
+                    .addGroup('character/hyperlink/dialog', new Button(Labels.INSERT_HYPERLINK_OPTIONS))
+                );
         }
 
         /**
@@ -302,8 +339,9 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
          * and initialize the correct menu
          */
         function contextMenuPrepareHandler(event) {
-            var sourceEvent     = event.sourceEvent,
-                sourceTarget    = (sourceEvent) ? sourceEvent.target : null;
+            var sourceEvent     = event.sourceEvent;
+            var sourceTarget    = (sourceEvent) ? sourceEvent.target : null;
+            var controller      = docView.getApp().getController();
 
             selection           = docModel.getSelection();
             isDrawingSelected   = docModel.isDrawingSelected();
@@ -327,8 +365,22 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
             });
 
             eleType = _.last(arrDomTree);
+
+            if (!enableKeys.every(controller.isItemEnabled, controller)) {
+                if (isRangeSelected) {
+                    event.preventDefault();
+                    return;
+                }
+                var characterAttrs = AttributeUtils.getExplicitAttributes(node, { family: 'character', direct: true });
+                if (!characterAttrs.url) {
+                    event.preventDefault();
+                    return;
+                }
+            }
         }
 
+        function selfHide() { self.hide(); }
+
         // public methods ----------------------------------------------------
         /**
          * Returns whether a range is selected or not
@@ -380,7 +432,8 @@ define('io.ox/office/textframework/view/popup/universalcontextmenu', [
 
         this.on('popup:beforeshow', initMenu);
 
-        this.listenTo(docView.getContentRootNode(), 'scroll', function () { self.hide(); });
+        this.listenTo(docView.getContentRootNode(), 'scroll', selfHide);
+        this.listenTo(docView.getContentRootNode(), 'activedragging', selfHide);
 
         // destroy all class members
         this.registerDestructor(function () {
