@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH.
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -46,6 +47,8 @@ define('io.ox/office/textframework/view/selectionbox', [
             selectionBoxActive = false,
             // whether the selection box is visible
             selectionBoxAppended = false,
+            // whether the click happened on the vertical scrollbar
+            isScrollBarEvent = false,
             // the selection box element
             selectionBoxNode = $('<div>').addClass('selectionbox'),
             // the container for all registered modes
@@ -99,6 +102,19 @@ define('io.ox/office/textframework/view/selectionbox', [
 
                 if (!selectionFilter || $(event.target).is(selectionFilter)) {
 
+                    // check, if this is an event on the vertical or horizontal scroll bar
+                    isScrollBarEvent = false; // reset
+                    if (Utils.hasVerticalScrollBar(scrollNode)) {
+                        isScrollBarEvent = event.clientX > (scrollNode.offset().left + Utils.getDomNode(scrollNode).clientWidth);
+                        if (isScrollBarEvent) { return; }
+                    }
+
+                    if (Utils.hasHorizontalScrollBar(scrollNode)) {
+                        isScrollBarEvent = event.clientY > (scrollNode.offset().top + Utils.getDomNode(scrollNode).clientHeight);
+                        if (isScrollBarEvent) { return; }
+                    }
+
+                    // -> selection box can be activated
                     selectionBoxActive = true;
 
                     if (previousMode) { selectionBoxNode.removeClass(previousMode); }
@@ -119,7 +135,12 @@ define('io.ox/office/textframework/view/selectionbox', [
                         self.cancelSelectionBox();
                         return;
                     }
+
+                    addCaptureEventListeners();
                 }
+
+                // fix for Bug 48616
+                Utils.clearBrowserSelection();
             }
 
             // updating the selection box according to the passed event
@@ -136,7 +157,13 @@ define('io.ox/office/textframework/view/selectionbox', [
                     // the context of the callback functions
                     context = Utils.getOption(modeOptions, 'context'),
                     // the horizontal and vertical event positions
-                    eventPosition = isTouch ? getTouchEventPosition(event) : { x: event.pageX, y: event.pageY };
+                    eventPosition = isTouch ? getTouchEventPosition(event) : { x: event.pageX, y: event.pageY },
+                    // temporary width and height variables
+                    tempWidth, tempHeight,
+                    // temporary left and top position variables
+                    tempLeft, tempTop,
+                    // keyboard key used for placing shape center in start position
+                    eventKeyForCenterPos = _.browser.MacOS ? event.altKey : event.ctrlKey;
 
                 if (!selectionBoxActive) { return; }
 
@@ -145,6 +172,7 @@ define('io.ox/office/textframework/view/selectionbox', [
                     return;
                 }
 
+                // appending the selection box to the scroll node
                 if (!selectionBoxAppended) {
                     scrollNode.append(selectionBoxNode);
                     selectionBoxAppended = true;
@@ -171,9 +199,25 @@ define('io.ox/office/textframework/view/selectionbox', [
                     shiftY = -shiftY;
                 }
 
-                selectionBoxNode.css({ left: left, top: top, width: shiftX, height: shiftY });
+                tempWidth = shiftX;
+                tempHeight = shiftY;
+                if (activeMode === 'shape' && event.shiftKey) {
+                    if (tempWidth > tempHeight) {
+                        tempHeight = tempWidth;
+                    } else {
+                        tempWidth = tempHeight;
+                    }
+                }
+                tempLeft = left;
+                tempTop = top;
+                if (activeMode === 'shape' && eventKeyForCenterPos) {
+                    tempLeft = startX - tempWidth / 2;
+                    tempTop = startY - tempHeight / 2;
+                }
 
-                if (moveHandler) { moveHandler.call(context, { left: left, top: top, width: shiftX, height: shiftY }); }
+                selectionBoxNode.css({ left: tempLeft, top: tempTop, width: tempWidth, height: tempHeight });
+
+                if (moveHandler) { moveHandler.call(context, { left: tempLeft, top: tempTop, width: tempWidth, height: tempHeight }); }
             }
 
             // handling the selection box size, when moving is stopped according to the passed event
@@ -190,10 +234,18 @@ define('io.ox/office/textframework/view/selectionbox', [
                     // the context of the callback functions
                     context = Utils.getOption(modeOptions, 'context'),
                     // the horizontal and vertical event positions
-                    eventPosition = isTouch ? getTouchEventPosition(event) : { x: event.pageX, y: event.pageY };
+                    eventPosition = isTouch ? getTouchEventPosition(event) : { x: event.pageX, y: event.pageY },
+                    // temporary width and height variables
+                    tempWidth, tempHeight,
+                    // temporary left and top position variables
+                    tempLeft, tempTop,
+                    // keyboard key used for placing shape center in start position
+                    eventKeyForCenterPos = _.browser.MacOS ? event.altKey : event.ctrlKey;
 
                 if (!selectionBoxActive) { return; }
 
+                if (isScrollBarEvent) { return; } // this happens after a click on the vertical or horizontal scroll bar
+
                 if (!eventPosition && isTouch) {
                     self.cancelSelectionBox();
                     return;
@@ -215,9 +267,25 @@ define('io.ox/office/textframework/view/selectionbox', [
                     shiftY = -shiftY;
                 }
 
-                selectionBoxNode.css({ left: left, top: top, width: shiftX, height: shiftY });
+                tempWidth = shiftX;
+                tempHeight = shiftY;
+                if (activeMode === 'shape' && event.shiftKey) {
+                    if (tempWidth > tempHeight) {
+                        tempHeight = tempWidth;
+                    } else {
+                        tempWidth = tempHeight;
+                    }
+                }
+                tempLeft = left;
+                tempTop = top;
+                if (activeMode === 'shape' && eventKeyForCenterPos) {
+                    tempLeft = startX - tempWidth / 2;
+                    tempTop = startY - tempHeight / 2;
+                }
 
-                if (stopHandler) { stopHandler.call(context, { left: left, top: top, width: shiftX, height: shiftY }); }
+                selectionBoxNode.css({ left: tempLeft, top: tempTop, width: tempWidth, height: tempHeight });
+
+                if (stopHandler) { stopHandler.call(context, { left: tempLeft, top: tempTop, width: tempWidth, height: tempHeight }); }
             }
 
             // return the actual selection box handler function
@@ -226,7 +294,11 @@ define('io.ox/office/textframework/view/selectionbox', [
                 switch (event.type) {
                     case 'mousedown':
                     case 'touchstart':
-                        startSelectionBox(event, (event.type === 'touchstart'));
+                        if (event.button !== 2) { // no selection box on right click
+                            startSelectionBox(event, (event.type === 'touchstart'));
+                        } else if ($(event.target).is(app.getModel().getMultiSelectionBoxFilterSelector())) { // setting slide selection on right click when target is outside of slide
+                            app.getModel().getSelection().setSlideSelection();
+                        }
                         break;
                     case 'mousemove':
                     case 'touchmove':
@@ -259,6 +331,8 @@ define('io.ox/office/textframework/view/selectionbox', [
                 // the context of the callback functions
                 context = Utils.getOption(modeOptions, 'context');
 
+            removeCaptureEventListeners();
+
             selectionBoxNode.css({ left: '', top: '', width: '', height: '' });
             selectionBoxNode.detach();
 
@@ -270,6 +344,7 @@ define('io.ox/office/textframework/view/selectionbox', [
 
             selectionBoxActive = false;
             selectionBoxAppended = false;
+            isScrollBarEvent = false;
         }
 
         /**
@@ -316,6 +391,24 @@ define('io.ox/office/textframework/view/selectionbox', [
             return ((touches.length === ((event.type === 'touchend') ? 0 : 1)) && (changed.length === 1)) ? { x: changed[0].pageX, y: changed[0].pageY } : null;
         }
 
+        /**
+         * Add eventListener to window, to capture the events (mousemove, mouseup,...) which are outside of the slide or browser
+         */
+        function addCaptureEventListeners() {
+            SelectionBox.CAPTURE_EVENTS.forEach(function (event) {
+                window.addEventListener(event, selectionBoxHandler, true);
+            });
+        }
+
+        /**
+         * Remove the capture events.
+         */
+        function removeCaptureEventListeners() {
+            SelectionBox.CAPTURE_EVENTS.forEach(function (event) {
+                window.removeEventListener(event, selectionBoxHandler, true);
+            });
+        }
+
         // public methods -----------------------------------------------------
 
         /**
@@ -468,6 +561,28 @@ define('io.ox/office/textframework/view/selectionbox', [
             return selectionBoxActive;
         };
 
+        /**
+         * Whether the selection box is currently appended to the application content
+         * root node.
+         *
+         * @returns {Boolean}
+         *  Whether the selection box is currently appended to the application content
+         *  root node.
+         */
+        this.isSelectionBoxAppended = function () {
+            return selectionBoxAppended;
+        };
+
+        /**
+         * Whether the vertical scroll bar is moved. In this case no seletion box is shown.
+         *
+         * @returns {Boolean}
+         *  Whether the vertical scroll bar is currently moved.
+         */
+        this.isVerticalScrollBarActive = function () {
+            return isScrollBarEvent;
+        };
+
         /**
          * Whether the currently active mode shall be stopped when the
          * user cancels it.
@@ -511,7 +626,10 @@ define('io.ox/office/textframework/view/selectionbox', [
     // constants --------------------------------------------------------------
 
     // the events for the selection box
-    SelectionBox.SELECTION_BOX_EVENTS = 'mousedown touchstart mouseup touchend mousemove touchmove touchcancel';
+    SelectionBox.SELECTION_BOX_EVENTS = 'mousedown touchstart'; //'mousedown touchstart mouseup touchend mousemove touchmove touchcancel';
+
+    // events to capture if the selection box is active, it's need to catch the events wich are outside of the slide or browser
+    SelectionBox.CAPTURE_EVENTS = ['mouseup', 'touchend', 'mousemove', 'touchmove', 'touchcancel'];
 
     // exports ================================================================
 
