@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -119,7 +120,7 @@ define('io.ox/office/tk/control/buttongroup', [
             }
 
             self.getNode().append($(optionButtons));
-        });
+        }, { infoString: 'ButtonGroup sortOptionButtons()' });
 
         /**
          * Modifies the button group for the drop-down view.
