@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -72,8 +73,8 @@ define('io.ox/office/tk/control/combofield', [
             if (!Utils.TOUCHDEVICE) {
                 // deferred to not confuse focus listeners due to mixed focus events triggered from mouse click and focus() call
                 self.executeDelayed(function () {
-                    self.getInputNode().focus();
-                }, undefined, 'TK: ComboField');
+                    Utils.setFocus(self.getInputNode());
+                }, { infoString: 'TK: ComboField: returnFocusToTextField' });
             }
         }
 
