@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -528,7 +529,7 @@ define('io.ox/office/tk/control/group', [
          */
         this.refresh = this.createDebouncedMethod(Utils.NOOP, function () {
             updateValue(groupValue);
-        });
+        }, { infoString: 'Group refresh()' });
 
         /**
          * Triggers a 'group:change' event at this control group instance, and
