@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -114,11 +115,13 @@ define('io.ox/office/tk/control/menumixin', [
         /**
          * Deinitializes the drop-down menu before it will be hidden.
          */
-        function popupBeforeHideHandler() {
-
-            // move focus to drop-down button, if drop-down menu is focused
-            if (menu.hasFocus()) {
-                menuButton.focus();
+        function popupBeforeHideHandler(event, browserEvent, node) {
+            // move focus to drop-down button, if drop-down menu is focused and the user press ESC or F6
+            if (menu.hasFocus() && browserEvent && (browserEvent.keyCode === KeyCodes.ESCAPE || browserEvent.keyCode === KeyCodes.F6)) {
+                Utils.setFocus(menuButton);
+            } else {
+                Utils.setFocus(node);
+                Utils.trigger('change:focus', node, node, null);
             }
 
             // remove CSS marker class from the group
@@ -196,7 +199,7 @@ define('io.ox/office/tk/control/menumixin', [
          */
         function menuButtonKeyDownHandler(event) {
             if ((event.keyCode === KeyCodes.ESCAPE) && menu.isVisible()) {
-                menu.hide();
+                menu.hide(event);
                 return false;
             }
         }
@@ -218,14 +221,14 @@ define('io.ox/office/tk/control/menumixin', [
                         // from the menu *button*), stop propagation of the original
                         // event, and focus the next control manually.
                         var nextFocusNode = Utils[event.shiftKey ? 'findPreviousNode' : 'findNextNode'](document, menuButton, Forms.FOCUSABLE_SELECTOR);
-                        $(nextFocusNode).focus();
+                        Utils.setFocus($(nextFocusNode));
                         menu.hide();
                         return false;
                     }
                     break;
                 case KeyCodes.ESCAPE:
                     if (keydown) {
-                        menu.hide();
+                        menu.hide(event);
                     }
                     return false;
                 case KeyCodes.F6:
@@ -237,7 +240,7 @@ define('io.ox/office/tk/control/menumixin', [
                     // non-MacOS systems where F6 traveling is triggered by Ctrl+F6
                     // (browsers will move the focus away anyway).
                     if (keydown) {
-                        menu.hide();
+                        menu.hide(event);
                     }
                     break;
             }
