@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -58,6 +59,8 @@ define('io.ox/office/tk/control/textfield', [
      *  @param {Object} [initOptions.smallerVersion]
      *      If specified, the Textfield will known, how it should act, if there
      *      will be not enough free place to show normal view
+     *  @param {Boolean} [initOptions.showClearButton=false]
+     *      If set to true, a clear button is visible to clear the text in the
      */
     function TextField(initOptions) {
 
@@ -89,7 +92,26 @@ define('io.ox/office/tk/control/textfield', [
             savedStyles = {},
 
             // smaller version of group (to fit in smaller resolutions)
-            smallerVersion = Utils.getOption(initOptions, 'smallerVersion', false);
+            smallerVersion = Utils.getOption(initOptions, 'smallerVersion', false),
+
+            // wheter the clear button is visible in the text box
+            showClearButton = Utils.getBooleanOption(initOptions, 'showClearButton', false),
+
+            // the clear button to clear the textbox
+            clearButton;
+
+        if (showClearButton) {
+            clearButton = $('<i>').addClass('fa fa-times-circle clear-button');
+            inputNode.css('padding-right', '12px');
+            clearButton.hide();
+            wrapperNode.append(clearButton);
+
+            clearButton.on('click', function (event) {
+                clearButton.hide();
+                inputNode.val(initialText);
+                self.triggerChange('', { sourceEvent: event });
+            });
+        }
 
         // base constructor ---------------------------------------------------
 
@@ -208,9 +230,9 @@ define('io.ox/office/tk/control/textfield', [
                     // It's an iOS problem.
                     if (Utils.IOS) {
                         // see http://stackoverflow.com/questions/3272089/programmatically-selecting-text-in-an-input-field-on-ios-devices-mobile-safari
-                        window.setTimeout(function () {
+                        self.executeDelayed(function () {
                             inputNode[0].setSelectionRange(0, 9999);
-                        }, 1);
+                        }, { delay: 1, infoString: 'TextField: globalFocusHandler' });
 
                     // this is how selecting the whole text is supposed to work
                     } else {
@@ -293,6 +315,14 @@ define('io.ox/office/tk/control/textfield', [
                 // result of the text field validation
                 result = null;
 
+            if (showClearButton) {
+                if (currText.length > 0) {
+                    clearButton.show();
+                } else {
+                    clearButton.hide();
+                }
+            }
+
             // do not perform validation if nothing has changed
             if (currText === prevText) { return; }
 
@@ -415,7 +445,7 @@ define('io.ox/office/tk/control/textfield', [
          *  A reference to this instance.
          */
         this.grabFocus = function () {
-            inputNode.focus();
+            Utils.setFocus(inputNode);
             return this;
         };
 
@@ -466,7 +496,7 @@ define('io.ox/office/tk/control/textfield', [
         // forward clicks on the wrapper node (left/right padding beside the input field)
         wrapperNode.on('click', function (event) {
             if (self.isEnabled() && wrapperNode.is(event.target)) {
-                inputNode.focus();
+                Utils.setFocus(inputNode);
             }
         });
 
