@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -72,8 +73,7 @@ define('io.ox/office/tk/control/unitfield', [
          * Converts the passed display string of a length with measurement unit
          * to a number. Supported unit strings are 'px', 'pc', 'pt', 'in', 'cm'
          * and 'mm'. If this unit string is not defined or cannot be resolved
-         * to one of the listed units, 'mm' is used as default, to calculate
-         * the length in 1/100 mm.
+         * to one of the listed units.
          *
          * @param {String} text
          *  The display string of a length with measurement unit.
@@ -89,7 +89,7 @@ define('io.ox/office/tk/control/unitfield', [
 
             value = Parser.stringToNumber(value);
             if (_.isNumber(value) && _.isFinite(value)) {
-                unit = /^(px|pc|pt|in|cm|mm)$/.test(unit) ? unit : 'mm';
+                unit = /^(px|pc|pt|in|cm|mm)$/.test(unit) ? unit : Units.getStandardUnit(); //getStandardUnit is fix for Bug 48909
                 return this.restrictValue(Utils.convertLengthToHmm(value, unit));
             }
 
