@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -17,8 +18,9 @@ define('io.ox/office/tk/dialogs', [
     'io.ox/office/tk/forms',
     'io.ox/office/tk/keycodes',
     'io.ox/office/tk/utils/driveutils',
+    'io.ox/office/tk/utils/deferredutils',
     'gettext!io.ox/office/tk/main'
-], function (CoreDialogs, Utils, Forms, KeyCodes, DriveUtils, gt) {
+], function (CoreDialogs, Utils, Forms, KeyCodes, DriveUtils, DeferredUtils, gt) {
 
     'use strict';
 
@@ -118,6 +120,8 @@ define('io.ox/office/tk/dialogs', [
      *      promise will be rejected immediately with the value 'cancel'.
      *  @param {Boolean} [initOptions.async=false]
      *      Whether the dialog will be opened in asynchronous mode.
+     *  @param {JQuery} [initOptions.container]
+     *      The container node for the modal dialog, otherwise the container is $('#io-ox-core')
      */
     Dialogs.ModalDialog = _.makeExtendable(CoreDialogs.ModalDialog).extend({ constructor: function (initOptions) {
 
@@ -138,12 +142,17 @@ define('io.ox/office/tk/dialogs', [
 
         // base constructor ---------------------------------------------------
 
-        CoreDialogs.ModalDialog.call(this, {
+        var dialogOptions = {
             width: Dialogs.getBestDialogWidth(Utils.getIntegerOption(initOptions, 'width', 500)),
             async: Utils.getBooleanOption(initOptions, 'async', false),
             enter: inputEnterHandler,
             focus: false
-        });
+        };
+        var container = Utils.getObjectOption(initOptions, 'container', null);
+        if (container) {
+            dialogOptions.container = container;
+        }
+        CoreDialogs.ModalDialog.call(this, dialogOptions);
 
         // private methods ----------------------------------------------------
 
@@ -276,7 +285,7 @@ define('io.ox/office/tk/dialogs', [
             // - the promise returned by show() will not resolve/reject when triggering an action
             // - the generic 'action' event does not send the action identifier
             // solution is to process all dialog events and look for an action button to resolve/reject the own promise
-            var def = $.Deferred();
+            var def = DeferredUtils.createDeferred(null, 'Dialogs: show');
 
             // event handler for all events triggered by this dialog, resolves/rejects
             // the own deferred object after activating an action button
@@ -364,7 +373,7 @@ define('io.ox/office/tk/dialogs', [
         // override all 'addSomeButton()' methods: set 'dataaction' parameter to 'action', add tabIndex option
         ['addButton', 'addDangerButton', 'addSuccessButton', 'addWarningButton', 'addPrimaryButton', 'addAlternativeButton'].forEach(function (methodName) {
             this[methodName] = _.wrap(this[methodName], function (baseMethod, action, label, options) {
-                return baseMethod.call(this, action, label, action, _.extend({ tabIndex: 1 }, options));
+                return baseMethod.call(this, action, label, action, _.extend({ tabIndex: 0 }, options));
             });
         }, this);
 
@@ -449,7 +458,7 @@ define('io.ox/office/tk/dialogs', [
          * panel.
          */
         function focusActiveTabButton() {
-            tabBarNode.find('li.active a').first().focus();
+            Utils.setFocus(tabBarNode.find('li.active a').first());
         }
 
         /**
@@ -519,7 +528,7 @@ define('io.ox/office/tk/dialogs', [
             var panelId = _.uniqueId('panel');
 
             // the button element in the tab bar
-            var tabButton = $('<a href="#' + panelId + '" id="' + buttonId + '" tabindex="1" role="tab" data-toggle="tab" data-user-id="' + tabId + '" aria-selected="false" aria-controls="' + panelId + '">');
+            var tabButton = $('<a href="#' + panelId + '" id="' + buttonId + '" tabindex="0" role="tab" data-toggle="tab" data-user-id="' + tabId + '" aria-selected="false" aria-controls="' + panelId + '">');
             // the container element for the tab panel
             var tabPanel = $('<div class="tab-pane row-fluid" id="' + panelId + '" role="tabpanel" data-user-id="' + tabId + '" aria-labelledby="' + buttonId + '">');
 
@@ -648,7 +657,7 @@ define('io.ox/office/tk/dialogs', [
         this.getCancelButton().hide();
 
         // focus the OK button when showing the dialog
-        this.on('show', function () { this.getOkButton().focus(); });
+        this.on('show', function () { Utils.setFocus(this.getOkButton()); });
 
     } }); // class ModalMessageDialog
 
@@ -736,7 +745,7 @@ define('io.ox/office/tk/dialogs', [
         }
 
         // focus the OK button when showing the dialog
-        this.on('show', function () { this.getOkButton().focus(); });
+        this.on('show', function () { Utils.setFocus(this.getOkButton()); });
 
     } }); // class ModalQueryDialog
 
@@ -784,7 +793,7 @@ define('io.ox/office/tk/dialogs', [
         var labelNode = inputLabel ? $('<label>').text(inputLabel) : $();
 
         // the text field control
-        var inputNode = $('<input type="text" class="form-control" tabindex="1">').attr({
+        var inputNode = $('<input type="text" class="form-control" tabindex="0">').attr({
             placeholder: Utils.getStringOption(initOptions, 'placeholder', ''),
             value: Utils.getStringOption(initOptions, 'value', '')
         });
@@ -860,11 +869,14 @@ define('io.ox/office/tk/dialogs', [
         // focus and select the text in the input field
         this.on('show', function () {
             // us 102078426: dialogs on small devices should come up w/o keyboard,
-            // so the focus shoud not be in an input element
-            if (Utils.SMALL_DEVICE) {
-                self.getOkButton().focus();
+            // so the focus should not be in an input element
+
+            // Bug 46886
+            // Also for IPad because since IOS 9, body is not scrolled when code triggers focus on input element
+            if (Utils.SMALL_DEVICE || Utils.IOS) {
+                Utils.setFocus(self.getOkButton());
             } else {
-                inputNode.focus().select();
+                Utils.setFocus(inputNode).select();
             }
         });
 
