@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -703,7 +704,7 @@ define('io.ox/office/tk/forms', [
      *  searches all nodes it contains for a focusable form control.
      */
     Forms.grabFocus = function (nodes) {
-        Forms.findFocusableNodes(nodes).first().focus();
+        Utils.setFocus(Forms.findFocusableNodes(nodes).first());
     };
 
     /**
@@ -729,7 +730,7 @@ define('io.ox/office/tk/forms', [
             anchorHorNode = null;
 
         function setFocus(focusNode, resetAnchor) {
-            focusNode.focus();
+            Utils.setFocus(focusNode);
             if (resetAnchor || !anchorVertNode) { anchorVertNode = focusNode; }
             if (resetAnchor || !anchorHorNode) { anchorHorNode = focusNode; }
         }
@@ -1342,7 +1343,7 @@ define('io.ox/office/tk/forms', [
             ariaOwns = Utils.getStringOption(options, 'aria-owns');
 
         // add more element attributes, return the mark-up
-        attributes = _.extend({ tabindex: focusable ? 1 : -1, role: 'button' }, attributes);
+        attributes = _.extend({ tabindex: focusable ? 0 : -1, role: 'button' }, attributes);
         if (!focusable) { attributes = _.extend({ 'aria-hidden': true }, attributes); }
         attributes.class = Forms.BUTTON_CLASS;
         if (classes.length > 0) { attributes.class += ' ' + classes; }
@@ -1721,7 +1722,7 @@ define('io.ox/office/tk/forms', [
 
         var type = Utils.TOUCHDEVICE ? Utils.getStringOption(options, 'keyboard', 'text') : 'text',
             attributes = Utils.getObjectOption(options, 'attributes', {}),
-            tabIndex = Utils.getIntegerOption(options, 'tabindex', 1),
+            tabIndex = Utils.getIntegerOption(options, 'tabindex', 0),
             placeHolder = Utils.getStringOption(options, 'placeholder'),
             maxLength = Utils.getIntegerOption(options, 'maxLength'),
             autoCorrection = Utils.getBooleanOption(options, 'autoCorrection', false);
@@ -1758,7 +1759,7 @@ define('io.ox/office/tk/forms', [
     Forms.createTextAreaMarkup = function (options) {
 
         var attributes = Utils.getObjectOption(options, 'attributes', {}),
-            tabIndex = Utils.getIntegerOption(options, 'tabindex', 1),
+            tabIndex = Utils.getIntegerOption(options, 'tabindex', 0),
             placeHolder = Utils.getStringOption(options, 'placeholder'),
             maxLength = Utils.getIntegerOption(options, 'maxLength'),
             autoCorrection = Utils.getBooleanOption(options, 'autoCorrection', false);
@@ -1945,7 +1946,7 @@ define('io.ox/office/tk/forms', [
             // object which contains all selectBox attributes
             selectAttributes = {
                 size: Utils.getNumberOption(options, 'size', 0),
-                tabindex: Utils.getIntegerOption(options, 'tabindex', 1)
+                tabindex: Utils.getIntegerOption(options, 'tabindex', 0)
             };
 
         // collect list-elements
@@ -2024,8 +2025,8 @@ define('io.ox/office/tk/forms', [
             spinFieldAttributes = {
                 min: Utils.getNumberOption(options, 'min', 0.0),
                 max: Utils.getNumberOption(options, 'max', 10.0),
-                step: Utils.getNumberOption(options, 'step', 0.1),
-                tabindex: Utils.getIntegerOption(options, 'tabindex', 1),
+                step: Utils.getNumberOption(options, 'step', 0.1).toFixed(1),
+                tabindex: Utils.getIntegerOption(options, 'tabindex', 0),
                 type: Utils.getStringOption(options, 'type', 'number'),
                 value: Utils.getNumberOption(options, 'value')
             };
