@@ -6,16 +6,17 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/tk/io', [
     'io.ox/core/http',
-    'io.ox/office/tk/config',
-    'io.ox/office/tk/utils'
-], function (CoreHTTP, Config, Utils) {
+    'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/deferredutils'
+], function (CoreHTTP, Utils, DeferredUtils) {
 
     'use strict';
 
@@ -27,7 +28,7 @@ define('io.ox/office/tk/io', [
      */
     var IO = {};
 
-    // constants --------------------------------------------------------------
+// constants --------------------------------------------------------------
 
     /**
      * The name of the document filter server module.
@@ -66,7 +67,7 @@ define('io.ox/office/tk/io', [
         return function (response) {
 
             var // the resulting deferred object
-                def = $.Deferred(),
+                def = DeferredUtils.createDeferred(IO, 'IO: createDeferredFilter'),
                 // call passed filter callback
                 value = _.isObject(response) ? filter.call(context, response) : undefined;
 
@@ -158,7 +159,7 @@ define('io.ox/office/tk/io', [
     IO.readClientFileAsDataUrl = function (fileDesc) {
 
         var // resulting deferred object
-            def = $.Deferred(),
+            def = DeferredUtils.createDeferred(IO, 'IO: readClientFileAsDataURL'),
             // create a browser file reader instance
             reader = window.FileReader ? new window.FileReader() : null;
 
