@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -275,6 +276,20 @@ define('io.ox/office/tk/keycodes', function () {
         return (event.keyCode === (_.isString(keyCode) ? KeyCodes[keyCode] : keyCode)) && KeyCodes.matchModifierKeys(event, options);
     };
 
+    /**
+     * Returns whether any function key is pressed in the passed event object.
+     * (F1 till F12)
+     *
+     * @param {Event|jQuery.Event} event
+     *  An event object containing a keyCode to compare
+     *
+     * @returns {Boolean}
+     *  Whether any function key is pressed in the passed event object.
+     */
+    KeyCodes.hasFunctionKeys = function (event) {
+        return event.keyCode >= 112 && event.keyCode <= 123;
+    };
+
     // exports ================================================================
 
     return KeyCodes;
