@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -101,13 +102,13 @@ define('io.ox/office/tk/locale/formatter', [
             case 1:
                 return String(month + 1);
             case 3:
-                return DateUtils.getLocaleMonthShort(month);
+                return LocaleData.SHORT_MONTHS[month];
             case 4:
-                return DateUtils.getLocaleMonth(month);
+                return LocaleData.LONG_MONTHS[month];
             case 5:
-                return DateUtils.getLocaleMonthShort(month)[0];
+                return LocaleData.LONG_MONTHS[month][0];
             default:
-                return formatInteger(month + 1, length);
+                return formatInteger(month + 1, 2);
         }
     }
 
@@ -130,11 +131,11 @@ define('io.ox/office/tk/locale/formatter', [
             case 1:
                 return String(date.getUTCDate());
             case 3:
-                return DateUtils.getLocaleDayShort(date.getUTCDay());
+                return LocaleData.SHORT_WEEKDAYS[date.getUTCDay()];
             case 4:
-                return DateUtils.getLocaleDay(date.getUTCDay());
+                return LocaleData.LONG_WEEKDAYS[date.getUTCDay()];
             default:
-                return formatInteger(date.getUTCDate(), length);
+                return formatInteger(date.getUTCDate(), 2);
         }
     }
 
@@ -153,7 +154,7 @@ define('io.ox/office/tk/locale/formatter', [
      */
     function formatQuarter(date, length) {
         var quarter = Math.floor(date.getUTCMonth() / 3);
-        var quarters = (length === 1) ? LocaleData.QUARTERABBR : LocaleData.QUARTER;
+        var quarters = (length === 1) ? LocaleData.SHORT_QUARTERS : LocaleData.LONG_QUARTERS;
         return quarters[quarter];
     }
 
@@ -176,10 +177,15 @@ define('io.ox/office/tk/locale/formatter', [
      *      The group separator (a.k.a. thousands separator) character. If
      *      omitted, the group separator of the current UI language will be
      *      used.
-     *  @param {Date} [initOptions.nullDate]
-     *      The null date used by this formatter (the number 0 formatted as
-     *      date/time will result in this date). By default, the date
+     *  @param {Date|Number} [initOptions.nullDate]
+     *      The null date used by this formatter (i.e. the date that will be
+     *      formatted for the serial number 0), as UTC date object or as number
+     *      of milliseconds as returned by Date.UTC(). By default, the date
      *      1899-11-30 will be used as null date.
+     *  @param {Boolean} [initOptions.leapYearBug=false]
+     *      Whether to implement the faulty behavior that 1900 was a yeap year
+     *      for compatibility with other spreadsheet applications, i.e. whether
+     *      to treat 1900-02-29 as a valid date.
      *  @param {Number} [initOptions.centuryThreshold=30]
      *      An integer in the range 0 to 100 that specifies how to convert a
      *      number below 100 to a 4-digit year. See DateUtils.expandYear() for
@@ -209,6 +215,9 @@ define('io.ox/office/tk/locale/formatter', [
         // null date (corresponding to number zero)
         var nullDate = Date.UTC(1899, 11, 30);
 
+        // whether to treat 1900-02-29 as a valid date
+        var leapYearBug = false;
+
         // threshold for full-year conversion
         var centuryThreshold = 30;
 
@@ -218,6 +227,12 @@ define('io.ox/office/tk/locale/formatter', [
         // number of characters for a 'General' format token
         var generalLength = 11;
 
+        // parsed format code for long system date (used for LCID 0xF800)
+        var sysDateFormat = Parser.parseFormatCode('ooxml', 'op', LocaleData.LONG_DATE);
+
+        // parsed format code for long system date (used for LCID 0xF400)
+        var sysTimeFormat = Parser.parseFormatCode('ooxml', 'op', LocaleData.LONG_TIME);
+
         // base constructor ---------------------------------------------------
 
         BaseObject.call(this);
@@ -378,7 +393,7 @@ define('io.ox/office/tk/locale/formatter', [
          *
          * @param {Object} info
          *  The info structure for a floating-point number, as returned by the
-         *  method getNumberInfo().
+         *  private method Formatter.getNumberInfo().
          *
          * @param {String} mant
          *  The resulting formatted absolute mantissa for scientific notation,
@@ -432,13 +447,13 @@ define('io.ox/office/tk/locale/formatter', [
          *
          * @param {Object} info
          *  The info structure for a floating-point number, as returned by the
-         *  method getNumberInfo().
+         *  private method Formatter.getNumberInfo().
          *
-         * @param {Function} [finalizer]
+         * @param {Function} finalizer
          *  A callback function used to convert the formatted absolute value of
          *  the number to the result object that will be returned by this
-         *  method. If not specified, the method finalizeStandard() will be
-         *  used instead.
+         *  method. Must support the function signature of the private method
+         *  Formatter.finalizeStandard().
          *
          * @returns {Object|Null}
          *  A result object with the finalized formatted number; or null, if
@@ -447,9 +462,6 @@ define('io.ox/office/tk/locale/formatter', [
          */
         function formatStandard(info, finalizer) {
 
-            // Fall-back to the standard finalizer.
-            if (!_.isFunction(finalizer)) { finalizer = finalizeStandard; }
-
             // Create local copies of the properties for temporary modifications below.
             var mant = info.mant;
             var exp = info.exp;
@@ -590,8 +602,8 @@ define('io.ox/office/tk/locale/formatter', [
          *
          * @param {Object} info
          *  The info structure for a floating-point number, as returned by the
-         *  method getNumberInfo(), with the additional properties 'font' and
-         *  'maxWidth'.
+         *  private method Formatter.getNumberInfo(), with the additional
+         *  properties 'font' and 'maxWidth'.
          *
          * @param {String} mant
          *  The resulting formatted absolute mantissa for scientific notation,
@@ -626,31 +638,20 @@ define('io.ox/office/tk/locale/formatter', [
          *
          * @param {Object} info
          *  The info structure for a floating-point number, as returned by the
-         *  method getNumberInfo(), with the additional properties 'font' and
-         *  'maxWidth'.
-         *
-         * @param {Function} [finalizer]
-         *  A callback function used to convert the formatted absolute value of
-         *  the number to the result object that will be returned by this
-         *  method. If not specified, the method finalizeStandardToWidth() will
-         *  be used instead.
+         *  private method Formatter.getNumberInfo(), with the additional
+         *  properties 'font' and 'maxWidth'.
          *
          * @returns {Object|Null}
          *  A result object with the finalized formatted number; or null, if
          *  the number could not be formatted successfully. See method
          *  Formatter.formatStandardNumberToWidth() for details.
          */
-        function formatStandardToWidth(info, finalizer) {
-
-            // Fall-back to the pixel-exact finalizer.
-            if (!_.isFunction(finalizer)) { finalizer = finalizeStandardToWidth; }
+        function formatStandardToWidth(info) {
 
             // Fast exit, if the number is exactly or very close to zero (do not try to format denormalized numbers).
-            //
-            if (info.mant === 0) { return finalizer(info, '0'); }
+            if (info.mant === 0) { return finalizeStandardToWidth(info, '0'); }
 
             // Get font measures for digits and other characters.
-            //
             var digitWidths = info.font.getDigitWidths();
             var minDigitWidth = Math.max(1, digitWidths.minWidth);
             var maxDigitWidth = Math.max(1, digitWidths.maxWidth);
@@ -701,7 +702,7 @@ define('io.ox/office/tk/locale/formatter', [
             // If the number cannot be formatted into the available width (using the maximum digit width), or if the
             // widths of all digits of the used font are equal (as is the case for most fonts), do not try further.
             //
-            var result = formatStandard(info, finalizer);
+            var result = formatStandard(info, finalizeStandardToWidth);
             if (!result || (minDigitWidth === maxDigitWidth)) { return result; }
 
             // If the number has been formatted successfully, and there is still enough room for another digit, and
@@ -728,7 +729,7 @@ define('io.ox/office/tk/locale/formatter', [
                 // of the number. If the new number still fits into the width, store the new better result, and
                 // continue searching for a better version.
                 //
-                var newResult = formatStandard(info, finalizer);
+                var newResult = formatStandard(info, finalizeStandardToWidth);
                 if (!newResult || (newResult.width > info.maxWidth)) { break; }
                 result = newResult;
             }
@@ -755,16 +756,23 @@ define('io.ox/office/tk/locale/formatter', [
             GROUP = Utils.getStringOption(options, 'group', GROUP);
 
             // change the null date
-            if (_.isObject(options) && (options.nullDate instanceof Date)) {
-                nullDate = options.nullDate;
+            if (options && ('nullDate' in options)) {
+                if (typeof options.nullDate === 'number') {
+                    nullDate = options.nullDate;
+                } else if (options.nullDate instanceof Date) {
+                    nullDate = options.nullDate.getTime();
+                }
             }
 
+            // change the 1900-leap-year-bug flag
+            leapYearBug = Utils.getBooleanOption(options, 'leapYearBug', leapYearBug);
+
             // change the century threshold
-            if (_.isObject(options) && _.isNumber(options.centuryThreshold)) {
+            if (options && _.isNumber(options.centuryThreshold)) {
                 centuryThreshold = Utils.minMax(options.centuryThreshold, 0, 100);
             }
 
-            // change the negative date mode
+            // change the flag whether to support negative dates
             negativeDates = Utils.getBooleanOption(options, 'negativeDates', negativeDates);
 
             // number of characters for a 'General' format token
@@ -790,10 +798,10 @@ define('io.ox/office/tk/locale/formatter', [
 
             // milliseconds from native null date (1970-01-01)
             var time = date.getTime();
-            // the year
+            // the full (4-digit) year
             var year = date.getUTCFullYear();
 
-            // check the year, check for 'negative' dates
+            // check the year, check for negative dates
             return isFinite(time) && (negativeDates || (nullDate <= time)) && (year >= 0) && (year <= 9999);
         };
 
@@ -1048,7 +1056,7 @@ define('io.ox/office/tk/locale/formatter', [
             if (!numberInfo) { return null; }
 
             // format the number according to the settings passed to this method
-            var result = formatStandard(numberInfo);
+            var result = formatStandard(numberInfo, finalizeStandard);
             return result ? result.text : null;
         };
 
@@ -1073,14 +1081,14 @@ define('io.ox/office/tk/locale/formatter', [
          *  The maximum width of the formatted number, in pixels.
          *
          * @param {Object} [options]
-         *  Optional parameters. See method Formatter.formatStandardNumber()
-         *  for details.
+         *  Optional parameters. Supports all options that are also supported
+         *  by the method Formatter.formatStandardNumber().
          *
          * @returns {Object|Null}
          *  A result object with the finalized formatted number with correct
-         *  sign and maximum pixel width,if it has been formatted successfully;
-         *  otherwise null. The result object will contain the following
-         *  properties:
+         *  sign and maximum pixel width, if it has been formatted successfully
+         *  to the specified pixel width; otherwise null. The result object
+         *  will contain the following properties:
          *  - {String} text
          *      The finalized formatted number with correct sign.
          *  - {String} mant
@@ -1098,9 +1106,9 @@ define('io.ox/office/tk/locale/formatter', [
          *      The width of the formatted number with sign, in pixels.
          *  - {Array<Object>|Null} portions
          *      If the formatted number cannot be displayed as plain text, an
-         *      array of descriptors that describe the single text portions of
-         *      the formatted number in detail. Each descriptor contains the
-         *      following properties:
+         *      array of descriptor objects for the single text portions of the
+         *      formatted number. Each descriptor contains the following
+         *      properties:
          *      - {String} portion.text
          *          The text contents of the text portion.
          *      - {Font} portion.font
@@ -1222,7 +1230,7 @@ define('io.ox/office/tk/locale/formatter', [
             }
 
             // format of the integer part of the number
-            function formatNumber(token, tokenIndex) {
+            function formatNumber() {
                 var text = null;
                 if (section.flags.float && section.flags.floatCode) {
                     var prepared = prepareSign(section.flags.floatCode);
@@ -1232,9 +1240,9 @@ define('io.ox/office/tk/locale/formatter', [
                         text = String(Math.floor(number));
                     }
                 } else if (section.flags.fraction && section.flags.fractionCode) {
-                    var closest = prepareFraction(section.flags.fractionCode, tokenIndex);
-                    if (closest.num === closest.deno) {
-                        text = String(Math.ceil(number));
+                    var closest = prepareFraction(section.flags.fractionCode);
+                    if (!closest.num || !closest.fraction) {
+                        return String(Math.round(number));
                     } else {
                         text = String(Math.floor(number));
                     }
@@ -1251,13 +1259,12 @@ define('io.ox/office/tk/locale/formatter', [
                 }
 
                 text = setPlaceHolders(text, section.flags.ungroupText);
-
                 return text;
             }
 
             //prepares the format of the fraction part numerator & denominator
             //at the moment we only support until 3 signs for the denominator
-            function prepareFraction(code, tokenIndex) {
+            function prepareFraction(code) {
                 var parts = code.split('/');
 
                 var denomLen = parts[1].length;
@@ -1271,7 +1278,7 @@ define('io.ox/office/tk/locale/formatter', [
                 var fractStart = Math.pow(10, denomLen - 1);
                 var fractEnd = fractStart * 10 - 1;
 
-                var frac = section.tokens[tokenIndex].isProperFraction ? number - Math.floor(number) : number;
+                var frac = section.isProperFraction ? number - Math.floor(number) : number;
 
                 var closest = null;
                 var near = Number.POSITIVE_INFINITY;
@@ -1291,6 +1298,9 @@ define('io.ox/office/tk/locale/formatter', [
                         preciseNum = frac * i;
                         // if preciseNum is smaller than "1" fraction gets ignored like "0"
                         num = preciseNum < 1 ? 0 : Math.round(preciseNum);
+                        if (num > i) {
+                            break;
+                        }
                         var compare = num / i;
                         var dif = Math.abs(frac - compare);
                         if (dif < near) {
@@ -1312,33 +1322,41 @@ define('io.ox/office/tk/locale/formatter', [
 
                     // preciseNum was not that preciseNum anymore after cancelFract(),
                     // so it is better to use a precision-rounded version of that
-                    if (closest.deno > 1 && Math.ceil(Utils.round(closest.preciseNum, 0.00001)) === closest.deno) {
+                    // fix for Bug 41434
+                    if (closest.deno > 1 && Utils.round(closest.preciseNum, 0.00001) === closest.deno) {
                         closest.num = closest.deno;
                     }
                     closest.fraction = true;
                     closest.parts = parts;
-                    return closest;
+
+                    if (closest.num === 0 || closest.num === closest.deno) {
+                        closest.num = 0;
+                        closest.deno = 0;
+                    }
+                } else {
+                    closest = { fraction: false, num: frac };
                 }
-                return { fraction: false, num: frac };
+                return closest;
             }
 
             //formats of the fraction part numerator & denominator
             //at the moment we only support until 3 signs for the denominator
-            function formatFraction(token, properFraction) {
-                var closest = prepareFraction(token.text, properFraction);
+            function formatFraction(token) {
+                var closest = prepareFraction(token.text);
 
                 if (closest.fraction) {
                     var parts = closest.parts;
-                    if (closest.num === 0) {
-                        //only placeholders
-                        return Utils.repeatString(' ', parts[0].length + parts[1].length);
-                    }
-                    if (closest.num === closest.deno) {
-                        //only placeholders
-                        return Utils.repeatString(' ', parts[0].length + parts[1].length);
+                    if (!closest.num) {
+                        //zero & placeholders
+                        return Utils.repeatString(' ', parts[0].length + parts[1].length + 1);
                     }
                     closest.num = setPlaceHolders(closest.num, parts[0]);
-                    closest.deno = setPlaceHolders(closest.deno, parts[1]);
+                    var deno = setPlaceHolders(closest.deno, parts[1]);
+
+                    var denoWhiteSpace = deno.match(/^(\s*)(.*)/);
+                    deno = denoWhiteSpace[2] + denoWhiteSpace[1];
+
+                    closest.deno = deno;
                     return closest.num + '/' + closest.deno;
                 }
                 return DEC + closest.num;
@@ -1389,6 +1407,12 @@ define('io.ox/office/tk/locale/formatter', [
             // format the value, or if the passed number is not finite
             if (!section || !isFinite(number)) { return null; }
 
+            // special behaviour for a few section LCIDs
+            switch (section.lcid) {
+                case 0xf400: section = sysTimeFormat.numberSections[0]; break;
+                case 0xf800: section = sysDateFormat.numberSections[0]; break;
+            }
+
             // bail out if the passed format code contains date/time tokens,
             // but no valid date is available
             if ((section.flags.date || section.flags.time) && !date) { return null; }
