@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -15,7 +16,7 @@ define.async('io.ox/office/tk/locale/localedata', [
     'io.ox/office/tk/config',
     'io.ox/office/tk/utils',
     'io.ox/office/tk/io',
-    'io.ox/office/tk/utils/simplemap',
+    'io.ox/office/tk/container/simplemap',
     'gettext!io.ox/office/tk/main'
 ], function (Config, Utils, IO, SimpleMap, gt) {
 
@@ -157,7 +158,10 @@ define.async('io.ox/office/tk/locale/localedata', [
      *  Whether the 24-hours time format is preferred over the 12-hours AM/PM
      *  time format.
      *
-     * @property {Object} tokens
+     * @property {String} stdToken
+     *  The translated number format token for the 'General' format code.
+     *
+     * @property {Object<String,String>} dateTokens
      *  The translated number format tokens for date/time format codes. Each
      *  property value of this map is a single character. The map contains the
      *  following properties:
@@ -179,6 +183,24 @@ define.async('io.ox/office/tk/locale/localedata', [
      *      The translated format token for era names.
      *  - {String} e
      *      The translated format token for era years.
+     *
+     * @property {Array<String>} shortWeekdays
+     *  The translated short names of all days in a week, starting with Sunday.
+     *
+     * @property {Array<String>} longWeekdays
+     *  The translated full names of all days in a week, starting with Sunday.
+     *
+     * @property {Array<String>} shortMonths
+     *  The translated short names of all months in a year.
+     *
+     * @property {Array<String>} longMonths
+     *  The translated full names of all months in a year.
+     *
+     * @property {Array<String>} shortQuarters
+     *  The translated short names of the four quarters of the year.
+     *
+     * @property {Array<String>} longQuarters
+     *  The translated full names of the four quarters of the year.
      */
     function LocaleDataEntry(lc, jsonData) {
 
@@ -195,9 +217,10 @@ define.async('io.ox/office/tk/locale/localedata', [
         this.country = parts[1];
         this.name = LANGUAGE_NAMES[lc] || null;
 
-        // convert format code tokens from string to map
-        var t = this.tokens;
-        this.tokens = { D: t[0], M: t[1], Y: t[2], h: t[3], m: t[4], s: t[5], b: t[6], g: t[7], e: t[8] };
+        // convert date/time format code tokens from string to map
+        this.dateTokens = (function (t) {
+            return { Y: t[0], M: t[1], D: t[2], h: t[3], m: t[4], s: t[5], b: t[6], g: t[7], e: t[8] };
+        }(this.dateTokens));
 
         // add other properties
         this.leadingMonth = /M.*D/.test(this.shortDate);
@@ -300,11 +323,39 @@ define.async('io.ox/office/tk/locale/localedata', [
      *  time format in the current UI locale. Provided as a convenience
      *  shortcut for 'LocaleData.get().hours24'.
      *
-     * @property {Object} TOKENS
+     * @property {String} STD_TOKEN
+     *  The translated number format token for the 'General' format code.
+     *  Provided as a convenience shortcut for 'LocaleData.get().stdToken'.
+     *
+     * @property {Object<String,String>} DATE_TOKENS
      *  The translated number format tokens for date/time format codes. Each
-     *  property value of this map is a single character. See descriptopn of
-     *  the property LocaleDataEntry.tokens for detail. Provided as a
-     *  convenience shortcut for 'LocaleData.get().tokens'.
+     *  property value of this map is a single character. See description of
+     *  the property LocaleDataEntry.dateTokens for detail. Provided as a
+     *  convenience shortcut for 'LocaleData.get().dateTokens'.
+     *
+     * @property {Array<String>} SHORT_WEEKDAYS
+     *  The translated short names of all days in a week, starting with Sunday.
+     *  Provided as a convenience shortcut for 'LocaleData.get().shortWeekdays'.
+     *
+     * @property {Array<String>} LONG_WEEKDAYS
+     *  The translated full names of all days in a week, starting with Sunday.
+     *  Provided as a convenience shortcut for 'LocaleData.get().longWeekdays'.
+     *
+     * @property {Array<String>} SHORT_MONTHS
+     *  The translated short names of all months in a year. Provided as a
+     *  convenience shortcut for 'LocaleData.get().shortMonths'.
+     *
+     * @property {Array<String>} LONG_MONTHS
+     *  The translated full names of all months in a year. Provided as a
+     *  convenience shortcut for 'LocaleData.get().longMonths'.
+     *
+     * @property {Array<String>} SHORT_QUARTERS
+     *  The translated short names of the four quarters of the year. Provided
+     *  as a convenience shortcut for 'LocaleData.get().shortQuarters'.
+     *
+     * @property {Array<String>} LONG_QUARTERS
+     *  The translated full names of the four quarters of the year. Provided as
+     *  a convenience shortcut for 'LocaleData.get().longQuarters'.
      */
     var LocaleData = {};
 
@@ -498,9 +549,14 @@ define.async('io.ox/office/tk/locale/localedata', [
         LocaleData.LEADING_MONTH = localeData.leadingMonth;
         LocaleData.LEADING_YEAR = localeData.leadingYear;
         LocaleData.HOURS24 = localeData.hours24;
-        LocaleData.TOKENS = localeData.tokens;
-        LocaleData.QUARTER = localeData.quarter;
-        LocaleData.QUARTERABBR = localeData.quarterAbbr;
+        LocaleData.STD_TOKEN = localeData.stdToken;
+        LocaleData.DATE_TOKENS = localeData.dateTokens;
+        LocaleData.SHORT_WEEKDAYS = localeData.shortWeekdays;
+        LocaleData.LONG_WEEKDAYS = localeData.longWeekdays;
+        LocaleData.SHORT_MONTHS = localeData.shortMonths;
+        LocaleData.LONG_MONTHS = localeData.longMonths;
+        LocaleData.SHORT_QUARTERS = localeData.shortQuarters;
+        LocaleData.LONG_QUARTERS = localeData.longQuarters;
         return LocaleData;
     });
 
