@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -14,9 +15,9 @@
 define('io.ox/office/tk/locale/parser', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/dateutils',
-    'io.ox/office/tk/utils/arraytemplate',
+    'io.ox/office/tk/container/typedarray',
     'io.ox/office/tk/locale/localedata'
-], function (Utils, DateUtils, ArrayTemplate, LocaleData) {
+], function (Utils, DateUtils, TypedArray, LocaleData) {
 
     'use strict';
 
@@ -44,10 +45,10 @@ define('io.ox/office/tk/locale/parser', [
     // - Group 1: The matched currency symbol.
     var LITERAL_CURRENCY_RE = new RegExp('^(' + LITERAL_CURRENCY_SYMBOLS.map(_.escapeRegExp).join('|') + ')');
 
-    // A map for all locale correct month-names. Stores pieces of month-names also (like "Janua", or "Dezemb")
+    // A map for all translated month names. Stores pieces of month names also (like "Janua", or "Dezemb")
     var MONTH_MAP = (function () {
         var returnVal = {};
-        _.each(DateUtils.getLocaleMonths(), function (monthString, monthIndex) {
+        LocaleData.LONG_MONTHS.forEach(function (monthString, monthIndex) {
             var // monthName in lower case
                 monthName = monthString.toLowerCase(),
                 // first three letters (they must match)
@@ -61,7 +62,7 @@ define('io.ox/office/tk/locale/parser', [
             // run through all remeining letters of the month
             _.each(remainingLetters, function (letter, index) {
                 var indexString = firstLetters + remainingLetters.substr(0, (index + 1));
-                // add string with growing month-name
+                // add string with growing month name
                 // ("january" = 'jan' + ('u', 'ua', 'uar', 'uary'))
                 returnVal[indexString] = monthIndex;
             });
@@ -69,17 +70,17 @@ define('io.ox/office/tk/locale/parser', [
         return returnVal;
     }());
 
-    // creates and caches the regular expressions to detect currency-formats
+    // creates and caches the regular expressions to detect currency formats
     var getCurrencyMatchingRegExp = _.memoize(function (options) {
         var sign = _.escapeRegExp(LocaleData.CURRENCY),
             code = _.escapeRegExp(LocaleData.ISO_CURRENCY);
 
         if (Utils.getBooleanOption(options, 'leading', true)) {
-            // checks a complete string and searches a leading currency-symbol e.g. "€ 213" or "€ string"
+            // checks a complete string and searches a leading currency symbol e.g. "$ 213" or "$ string"
             // (means: "[currency][string]")
             return new RegExp('^(' + sign + '|' + code + '])\\s*(.*)$');
         } else {
-            // checks only remaining strings like " €" from "12 €"
+            // checks only remaining strings like " $" from "12 $"
             // (means: "[space][currency]"")
             return new RegExp('^\\s*(' + sign + '|' + code + ')$');
         }
@@ -88,15 +89,15 @@ define('io.ox/office/tk/locale/parser', [
         return Utils.getBooleanOption(options, 'leading', true);
     });
 
-    // creates and caches the regular expressions to detect date-formats
+    // creates and caches the regular expressions to detect date formats
     var getMonthRegExp = _.memoize(function (monthName, options) {
 
         function generator(monthName, options) {
             // monthName in lower case
             monthName = monthName.toLowerCase();
 
-            var end             = (Utils.getBooleanOption(options, 'monthGroupEnd', false))      ? '$' : '',
-                get             = (Utils.getBooleanOption(options, 'monthGroupGet', true))       ? ''  : '?:',
+            var end             = Utils.getBooleanOption(options, 'monthGroupEnd', false) ? '$' : '',
+                get             = Utils.getBooleanOption(options, 'monthGroupGet', true) ? '' : '?:',
                 mon             = monthName,
                 regex           = [],
                 letterRegEx     = null,
@@ -117,79 +118,81 @@ define('io.ox/office/tk/locale/parser', [
 
         // empty month-string means returning all months
         if (monthName === '') {
-            var returnVal = [];
-            _.each(DateUtils.getLocaleMonths(), function (monthName, i) {
-                returnVal[i] = generator(monthName, options);
-            });
-            return returnVal.join('|');
-        } else {
-            return generator(monthName, options);
+            return LocaleData.LONG_MONTHS.map(function (monthName) {
+                return generator(monthName, options);
+            }).join('|');
         }
-    }, function (monthName, options) {
-        var end         = (Utils.getBooleanOption(options, 'monthGroupEnd', false)) ? '$' : '_',
-            get         = (Utils.getBooleanOption(options, 'monthGroupGet', true)) ? '_' : '?:';
 
-        return monthName + end + get;
+        return generator(monthName, options);
+
+    }, function (monthName, options) {
+        var end = Utils.getBooleanOption(options, 'monthGroupEnd', false) ? 0 : 1;
+        var get = Utils.getBooleanOption(options, 'monthGroupGet', true) ? 0 : 1;
+        return monthName.toLowerCase() + ':' + end + ':' + get;
     });
 
-    //all codes for grammar 'op', this means the original english key
-    //and all codes for 'ui', this means all translated codes
+    // all codes for grammar 'op', this means the original english key
+    // and all codes for 'ui', this means all translated codes
     var CODES = (function () {
 
-        var op = {};
-        var ui = {};
+        var opDateTokens = {};
+        var uiDateTokens = {};
 
-        _.each(LocaleData.TOKENS, function (val, key) {
-            op[key] = key;
-            ui[key] = val;
+        _.each(LocaleData.DATE_TOKENS, function (val, key) {
+            opDateTokens[key] = key;
+            uiDateTokens[key] = val;
         });
 
-        function createRegexp(dec, group, localeCodes) {
+        function createRegExp(dec, group, general, dateTokens) {
 
             var codes = {};
 
             codes.dec = dec;
             codes.group = group;
+            codes.general = general;
+
+            // 'General' token
+            codes.expGeneral = new RegExp('^' + _.escapeRegExp(general), 'i');
 
             // date/time category: year
             // /^Y+/i
-            codes.expYear = new RegExp('^' + _.escapeRegExp(localeCodes.Y) + '+', 'i');
+            codes.expYear = new RegExp('^' + _.escapeRegExp(dateTokens.Y) + '+', 'i');
 
             // date/time category: month/minute; M... or m...
             // /^M+/i
-            codes.expMonthMinute = new RegExp('^' + _.escapeRegExp(localeCodes.M) + '+', 'i');
+            codes.expMonthMinute = new RegExp('^' + _.escapeRegExp(dateTokens.M) + '+', 'i');
 
             // date/time category: month
             // /^M{3,}/i
-            codes.expMonthLong = new RegExp('^' + _.escapeRegExp(localeCodes.M) + '{3,}', 'i');
+            codes.expMonthLong = new RegExp('^' + _.escapeRegExp(dateTokens.M) + '{3,}', 'i');
 
             // date/time category: day/weekday
             // /^D+/i
-            codes.expDay = new RegExp('^' + _.escapeRegExp(localeCodes.D) + '+', 'i');
+            codes.expDay = new RegExp('^' + _.escapeRegExp(dateTokens.D) + '+', 'i');
 
             // date/time category: total number of hours
             // /^\[(h+)\]/i
-            codes.expTotalHour = new RegExp('^\\[(' + _.escapeRegExp(localeCodes.h) + '+)\\]', 'i');
+            codes.expTotalHour = new RegExp('^\\[(' + _.escapeRegExp(dateTokens.h) + '+)\\]', 'i');
 
             // date/time category: total number of minutes
             // /^\[(m+)\]/
-            codes.expTotalMinute = new RegExp('^\\[(' + _.escapeRegExp(localeCodes.m) + '+)\\]', 'i');
+            codes.expTotalMinute = new RegExp('^\\[(' + _.escapeRegExp(dateTokens.m) + '+)\\]', 'i');
 
             // date/time category: total number of seconds
             // /^\[(s+)\]/i
-            codes.expTotalSecond = new RegExp('^\\[(' + _.escapeRegExp(localeCodes.s) + '+)\\]', 'i');
+            codes.expTotalSecond = new RegExp('^\\[(' + _.escapeRegExp(dateTokens.s) + '+)\\]', 'i');
 
             // date/time category: hour
             // /^h+/i
-            codes.expHour = new RegExp('^' + _.escapeRegExp(localeCodes.h) + '+', 'i');
+            codes.expHour = new RegExp('^' + _.escapeRegExp(dateTokens.h) + '+', 'i');
 
             // date/time category: minute together with seconds
             // /^(m+)(?=\W+s)/i
-            codes.expMinuteSecond = new RegExp('^(' + _.escapeRegExp(localeCodes.m) + '+)(?=\\W+' + _.escapeRegExp(localeCodes.s) + ')', 'i');
+            codes.expMinuteSecond = new RegExp('^(' + _.escapeRegExp(dateTokens.m) + '+)(?=\\W+' + _.escapeRegExp(dateTokens.s) + ')', 'i');
 
             // date/time category: second
             // /^s+/i
-            codes.expSecond = new RegExp('^' + _.escapeRegExp(localeCodes.s) + '+', 'i');
+            codes.expSecond = new RegExp('^' + _.escapeRegExp(dateTokens.s) + '+', 'i');
 
             // decimal fractional part
             // /^\.[0?#,]+/i
@@ -207,21 +210,21 @@ define('io.ox/office/tk/locale/parser', [
             // /,/g
             codes.expGroupAll = new RegExp(_.escapeRegExp(group), 'g');
 
-            // date/time category: weekday. Specifically for ODF
+            // date/time category: weekday. Specifically for ODF (TODO: translations)
             codes.expWeekdayODS = /^N{2,4}/i;
 
-            // date/time category: quarter. Specifically for ODF
+            // date/time category: quarter. Specifically for ODF (TODO: translations)
             codes.expQuarterODS = /^QQ?/i;
 
-            // date/time category: weeknumber. Specifically for ODF
+            // date/time category: weeknumber. Specifically for ODF (TODO: translations)
             codes.expWeeknumberODS = /^WW/i;
 
             return codes;
         }
 
         return {
-            op: createRegexp('.', ',', op),
-            ui: createRegexp(LocaleData.DEC, LocaleData.GROUP, ui)
+            op: createRegExp('.', ',', 'General', opDateTokens),
+            ui: createRegExp(LocaleData.DEC, LocaleData.GROUP, LocaleData.STD_TOKEN, uiDateTokens)
         };
     }());
 
@@ -258,7 +261,7 @@ define('io.ox/office/tk/locale/parser', [
      *
      * @constructor
      */
-    var FormatTokenArray = ArrayTemplate.create(FormatToken);
+    var FormatTokenArray = TypedArray.create(FormatToken);
 
     // class FormatSection ====================================================
 
@@ -280,6 +283,11 @@ define('io.ox/office/tk/locale/parser', [
      *  The identifier of the category this format section is associated to.
      *  See property ParsedFormat.category for details.
      *
+     * @property {Number|Null} lcid
+     *  The MS locale identifier (positive integer) of this section. May be
+     *  another predefiend internal identifier, e.g. 0xF800 specifying the long
+     *  system date format of the current locale.
+     *
      * @property {String|Null} colorName
      *  The lower-case name of the text color to be used, if this format
      *  section is used to format a value. The value null does not change the
@@ -346,6 +354,7 @@ define('io.ox/office/tk/locale/parser', [
         this.formatCode = '';
         this.tokens = new FormatTokenArray();
         this.category = 'custom';
+        this.lcid = null;
 
         this.colorName = null;
         this.rgbColor = null;
@@ -617,7 +626,7 @@ define('io.ox/office/tk/locale/parser', [
                 }
 
                 // 'General' format token
-                if ((matches = /^GENERAL/i.exec(formatCode))) {
+                if ((matches = grammarCodes.expGeneral.exec(formatCode))) {
                     section.pushToken('general');
                     flags.general = true;
                     continue;
@@ -809,7 +818,7 @@ define('io.ox/office/tk/locale/parser', [
                 }
 
                 // number interval
-                if ((matches = /^\[(<=?|>=?|<>|=)([^[\];]+)\]/.exec(formatCode))) {
+                if ((matches = /^\[(<=?|>=?|<>|=)([^[\];]+)]/.exec(formatCode))) {
                     var parseResult = Parser.parseLeadingNumber(matches[2], { dec: grammarCodes.dec, sign: true, complete: true });
                     if (parseResult && (parseResult.remaining.length === 0)) {
                         section.setInterval(matches[1], parseResult.number);
@@ -826,19 +835,29 @@ define('io.ox/office/tk/locale/parser', [
                 }
 
                 // locale data with hexadecimal LCID and calendar information
-                if ((matches = /^\[\$-([0-9a-f]+)\]/i.exec(formatCode))) {
+                if ((matches = /^\[\$-([0-9a-f]+)]/i.exec(formatCode))) {
+                    if (section.lcid !== null) {
+                        parseError = true;
+                    } else {
+                        section.lcid = parseInt(matches[1], 16);
+                    }
                     continue;
                 }
 
                 // currency symbol with hexadecimal LCID
-                if ((matches = /^\[\$([^[\];-]+)-([0-9a-f]+)\]/i.exec(formatCode))) {
+                if ((matches = /^\[\$([^[\];-]+)-([0-9a-f]+)]/i.exec(formatCode))) {
+                    if (section.lcid !== null) {
+                        parseError = true;
+                    } else {
+                        section.lcid = parseInt(matches[2], 16);
+                    }
                     section.pushLiteralToken(matches[1]);
                     flags.currency = true;
                     continue;
                 }
 
                 // currency symbol without hexadecimal LCID
-                if ((matches = /^\[\$([^[\];-]+)\]/i.exec(formatCode))) {
+                if ((matches = /^\[\$([^[\];-]+)]/i.exec(formatCode))) {
                     section.pushLiteralToken(matches[1]);
                     flags.currency = true;
                     continue;
@@ -852,7 +871,7 @@ define('io.ox/office/tk/locale/parser', [
                 }
 
                 // ignore other unsupported specifiers
-                if ((matches = /^(\[[^[\];]*\])/.exec(formatCode))) {
+                if ((matches = /^(\[[^[\];]*])/.exec(formatCode))) {
                     Utils.warn('FormatSection.parse(): unsupported section specifier "' + matches[1] + '"');
                     continue;
                 }
@@ -865,7 +884,13 @@ define('io.ox/office/tk/locale/parser', [
                 }
 
                 // unmatched double-quote, unmatched opening bracket, or incomplete escape sequence: syntax error
-                if (/^["\[\\_*]/.test(formatCode)) {
+                if ((matches = /^["[\\_*]/.exec(formatCode))) {
+                    parseError = true;
+                    continue;
+                }
+
+                // a few characters must result in a parse error in OOXML
+                if (!odf && (matches = /^[BENn]/.exec(formatCode))) {
                     parseError = true;
                     continue;
                 }
@@ -928,7 +953,7 @@ define('io.ox/office/tk/locale/parser', [
      *
      * @constructor
      */
-    var FormatSectionArray = ArrayTemplate.create(FormatSection);
+    var FormatSectionArray = TypedArray.create(FormatSection);
 
     // class ParsedFormat =====================================================
 
@@ -1852,7 +1877,7 @@ define('io.ox/office/tk/locale/parser', [
             var parsedFormat = new ParsedFormat(formatCode);
 
             // bug 46211: empty format code falls back to standard format
-            if (formatCode.length === 0) { formatCode = 'General'; }
+            if (formatCode.length === 0) { formatCode = CODES[grammarId].general; }
 
             // stop if the entire format code has been consumed, or a syntax error was found
             while (!parsedFormat.syntaxError && _.isString(formatCode)) {
@@ -1939,7 +1964,7 @@ define('io.ox/office/tk/locale/parser', [
                         rightNumbersCount = 0;
                         hasFraction = true;
                         // set if the token is a proper fraction or not
-                        token.isProperFraction = isProperFraction(section.tokens, t);
+                        section.isProperFraction = isProperFraction(section.tokens, t);
                     }
                 }
                 if (hasFraction) {
