@@ -6,19 +6,119 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/tk/object/baseobject', [
-    'io.ox/office/tk/utils'
-], function (Utils) {
+    'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/deferredutils'
+], function (Utils, DeferredUtils) {
 
     'use strict';
 
+    // a predicate function that matches everything
+    var ALL_MATCHER = _.constant(true);
+
     // private global functions ===============================================
 
+    /**
+     * Returns a matcher predicate function for the passed event source object.
+     */
+    function createEventSourceMatcher(source) {
+
+        // accept plain DOM elements, convert to jQuery collection
+        if (source instanceof HTMLElement) { source = $(source); }
+
+        // return the predicate function
+        return function sourceMatcher(s) {
+            // jQuery objects must be tested with is() method instead of equality operator
+            return (s instanceof $) ? s.is(source) : (s === source);
+        };
+    }
+
+    /**
+     * Returns a matcher predicate function for the passed event types (null to
+     * match all, or string list).
+     */
+    function createEventTypesMatcher(types) {
+
+        // all types will match for non-string value
+        if (!_.isString(types)) { return ALL_MATCHER; }
+
+        // convert space-separated string to a flag set of single event types
+        var typeSet = Utils.makeSet(types.split(/\s+/).filter(_.identity));
+
+        // return the predicate function
+        return function (t) { return t in typeSet; };
+    }
+
+    /**
+     * Returns a matcher predicate function for the passed event listener (null
+     * to match all, or function).
+     */
+    function createEventListenerMatcher(listener) {
+        return listener ? function (l) { return l === listener; } : ALL_MATCHER;
+    }
+
+    /**
+     * Unbinds the passed event type and/or listener (either parameter can be
+     * null).
+     */
+    function unbindEventListener(listeners, source, type, listener) {
+
+        // the matcher predicate for the passed event source object
+        var sourceMatcher = createEventSourceMatcher(source);
+        // a matcher predicate for an event type
+        var typeMatcher = createEventTypesMatcher(type);
+        // a matcher predicate for a listener callback function
+        var listenerMatcher = createEventListenerMatcher(listener);
+
+        // detach all matching event listeners for the passed object
+        listeners.forEach(function (data) {
+            if (sourceMatcher(data.source) && typeMatcher(data.type) && listenerMatcher(data.listener)) {
+                source.off(data.type, data.listener);
+            }
+        });
+    }
+
+    /**
+     * Registers and binds the passed event type and listener.
+     */
+    function bindEventListener(listeners, source, type, listener, once) {
+
+        // once mode: create a version of the listener that unbinds itself on first invocation
+        var listenerFunc = once ? function () {
+            unbindEventListener(listeners, source, type, listenerFunc);
+            return listener.apply(this, arguments);
+        } : listener;
+
+        // register and bind the listener
+        listeners.push({ source: source, type: type, listener: listenerFunc });
+        source.on(type, listenerFunc);
+    }
+
+    /**
+     * Registers and binds the passed event types and listeners.
+     */
+    function bindEventListeners(listeners, source, type, listener, once) {
+
+        // accept plain DOM elements, convert to jQuery collection
+        if (source instanceof HTMLElement) { source = $(source); }
+
+        // bug 36850: handle event maps and string/function parameters
+        var eventMap = _.isObject(type) ? type : Utils.makeSimpleObject(type, listener);
+        _.each(eventMap, function (evtListener, evtTypes) {
+            _.each(evtTypes.split(/\s+/), function (evtType) {
+                if (evtType.length > 0) {
+                    bindEventListener(listeners, source, evtType, evtListener, once);
+                }
+            });
+        });
+    }
+
     /**
      * Returns whether the passed value is a pending abortable promise.
      *
@@ -85,9 +185,9 @@ define('io.ox/office/tk/object/baseobject', [
     function overrideThenMethod(abortablePromise) {
 
         // the original then() method of the passed promise
-        var thenMethod = _.bind(abortablePromise.then, abortablePromise);
+        var thenMethod = abortablePromise.then.bind(abortablePromise);
         // the original abort() method of the passed promise
-        var abortMethod = _.bind(abortablePromise.abort, abortablePromise);
+        var abortMethod = abortablePromise.abort.bind(abortablePromise);
 
         // create the new then() method which returns an abortable promise
         abortablePromise.then = function (done, fail, notify, abort) {
@@ -113,7 +213,7 @@ define('io.ox/office/tk/object/baseobject', [
             // add a custom abort() method, that aborts the passed promise
             createAbortMethod(pipedPromise, abortMethod, function (cause) {
                 if (_.isFunction(abort)) { abort(cause); }
-                if (resultPromise) { resultPromise.abort(); }
+                if (resultPromise) { resultPromise.abort(cause); }
             });
 
             // override the then() method of the promise with an abortable version
@@ -238,27 +338,49 @@ define('io.ox/office/tk/object/baseobject', [
          */
         this.listenTo = function (source, type, listener) {
 
-            // the function that binds the listener to an event source or promise
-            function binderFunc(evtType, evtListener) {
-                listeners.push({ source: source, type: evtType, listener: evtListener });
-                source.on(evtType, evtListener);
-            }
+            // create the array of known listeners on demand
+            listeners = listeners || [];
+
+            // bind the listener to the event source
+            bindEventListeners(listeners, source, type, listener, false);
+
+            return this;
+        };
+
+        /**
+         * Registers an event listener at the specified event source object,
+         * that will be triggered exactly once, and will unregister itself
+         * afterwards. On destruction of this instance, all event listeners
+         * registered with this method will be removed from the source object.
+         *
+         * @param {Events|jQuery|HTMLElement} source
+         *  The event source object. Can be any object that provides a method
+         *  'on()' to register an event listener (for example, jQuery objects,
+         *  or any object extended with the core Events mix-in class).
+         *  Additionally, a plain DOM element instance can be passed, which
+         *  will be converted to a jQuery collection internally.
+         *
+         * @param {String|Object} type
+         *  The type of the event to listen to. Can be a space-separated list
+         *  of event type names. Alternatively, can be an object mapping event
+         *  types to listener callback functions.
+         *
+         * @param {Function} [listener]
+         *  The event listener that will be invoked for the events triggered by
+         *  the event source object. This parameter will be ignored, if the
+         *  parameter 'type' is an object mapping event types to listener
+         *  callback functions.
+         *
+         * @returns {BaseObject}
+         *  A reference to this instance.
+         */
+        this.listenOnceTo = function (source, type, listener) {
 
             // create the array of known listeners on demand
             listeners = listeners || [];
 
-            // accept plain DOM elements, convert to jQuery collection
-            if (source instanceof HTMLElement) { source = $(source); }
-
-            // bug 36850: handle event maps and string/function parameters
-            var eventMap = _.isObject(type) ? type : Utils.makeSimpleObject(type, listener);
-            _.each(eventMap, function (evtListener, evtTypes) {
-                _.each(evtTypes.split(/\s+/), function (evtType) {
-                    if (evtType.length > 0) {
-                        binderFunc.call(this, evtType, evtListener);
-                    }
-                }, this);
-            }, this);
+            // bind the listener to the event source
+            bindEventListeners(listeners, source, type, listener, true);
 
             return this;
         };
@@ -290,83 +412,25 @@ define('io.ox/office/tk/object/baseobject', [
          * @returns {BaseObject}
          *  A reference to this instance.
          */
-        this.stopListeningTo = (function () {
+        this.stopListeningTo = function (source, type, listener) {
 
-            // returns a matcher predicate function for the passed event source object
-            function createEventSourceMatcher(source) {
+            // nothing to do without registered listeners
+            if (!listeners) { return this; }
 
-                // accept plain DOM elements, convert to jQuery collection
-                if (source instanceof HTMLElement) { source = $(source); }
-
-                // return the predicate function
-                return function sourceMatcher(s) {
-                    // jQuery objects must be tested with is() method instead of equality operator
-                    return (s instanceof $) ? s.is(source) : (s === source);
-                };
-            }
-
-            // a predicate function that matches everything
-            var allMatcher = _.constant(true);
-
-            // returns a matcher predicate function for the passed event types (null to match all, or string list)
-            function createEventTypesMatcher(types) {
-
-                // all types will match for non-string value
-                if (!_.isString(types)) { return allMatcher; }
-
-                // convert space-separated string to a flag set of single event types
-                var typeSet = Utils.makeSet(types.split(/\s+/).filter(_.identity));
-
-                // return the predicate function
-                return function (t) { return t in typeSet; };
-            }
-
-            // returns a matcher predicate function for the passed event listener (null to match all, or function)
-            function createEventListenerMatcher(listener) {
-                return listener ? function (l) { return l === listener; } : allMatcher;
-            }
-
-            // unbinds the passed event type and/or listener (either parameter can be null)
-            function unbindEventListener(source, type, listener) {
-
-                // the matcher predicate for the passed event source object
-                var sourceMatcher = createEventSourceMatcher(source);
-                // a matcher predicate for an event type
-                var typeMatcher = createEventTypesMatcher(type);
-                // a matcher predicate for a listener callback function
-                var listenerMatcher = createEventListenerMatcher(listener);
-
-                // detach all matching event listeners for the passed object
-                listeners.forEach(function (data) {
-                    if (sourceMatcher(data.source) && typeMatcher(data.type) && listenerMatcher(data.listener)) {
-                        source.off(data.type, data.listener);
-                    }
+            if (_.isFunction(type) && _.isUndefined(listener)) {
+                // 'type' may be omitted completely (instead of being set to null)
+                unbindEventListener(listeners, source, null, type);
+            } else if (_.isObject(type)) {
+                // bug 36850: unbind all passed event types of an event map
+                _.each(type, function (listener2, type2) {
+                    unbindEventListener(listeners, source, type2, listener2);
                 });
+            } else {
+                unbindEventListener(listeners, source, type, listener);
             }
 
-            // the actual implementation of the public method
-            function stopListeningTo(source, type, listener) {
-
-                // nothing to do without registered listeners
-                if (!listeners) { return this; }
-
-                if (_.isFunction(type) && _.isUndefined(listener)) {
-                    // 'type' may be omitted completely (instead of being set to null)
-                    unbindEventListener(source, null, type);
-                } else if (_.isObject(type)) {
-                    // bug 36850: unbind all passed event types of an event map
-                    _.each(type, function (listener2, type2) {
-                        unbindEventListener(source, type2, listener2);
-                    });
-                } else {
-                    unbindEventListener(source, type, listener);
-                }
-
-                return this;
-            }
-
-            return stopListeningTo;
-        }());
+            return this;
+        };
 
         /**
          * Creates a promise for the passed deferred object representing code
@@ -376,7 +440,7 @@ define('io.ox/office/tk/object/baseobject', [
          * rejects the passed deferred object. Additionally, the promise will
          * be stored internally as long as it is in pending state. When this
          * instance will be destroyed, all pending promises will be aborted
-         * automatically.
+         * automatically with the value 'destroy'.
          *
          * @param {jQuery.Deferred} deferred
          *  The deferred object to create an abortable promise for.
@@ -388,8 +452,9 @@ define('io.ox/office/tk/object/baseobject', [
          *
          * @param {Number} [timeout]
          *  If specified and a positive number, the delay time in milliseconds
-         *  after the promise returned by this method will be rejected, if the
-         *  passed original deferred object is still pending.
+         *  after the promise returned by this method will be rejected with the
+         *  value 'timeout', if the passed original deferred object is still
+         *  pending.
          *
          * @returns {jQuery.Promise}
          *  A promise for the passed deferred object, with an additional method
@@ -401,7 +466,7 @@ define('io.ox/office/tk/object/baseobject', [
             var promise = deferred.promise();
 
             // add a custom abort() method to the promise, rejecting the passed deferred object
-            createAbortMethod(promise, _.bind(deferred.reject, deferred), callback);
+            createAbortMethod(promise, deferred.reject.bind(deferred), callback ? callback.bind(this) : null);
 
             // override the then() method of the promise with an abortable version
             overrideThenMethod(promise);
@@ -464,6 +529,41 @@ define('io.ox/office/tk/object/baseobject', [
             return this.createAbortablePromise($.Deferred().reject(result));
         };
 
+        /**
+         * Creates a new pending deferred object.
+         *
+         * @param {Object} [options]
+         *  Optional parameters:
+         *  @param {Number|Null} [timeout]
+         *      If specified and a positive number, the delay time in
+         *      milliseconds after the deferred object returned by this method
+         *      will be rejected automatically with the value 'timeout'.
+         *  @param {BaseApplication) [options.app]
+         *      app is needed for correct window-id
+         *  @param {String} [options.infoString]
+         *      If specified, this string is used for logging information about
+         *      run times of asynchronous operations. This option is only
+         *      evaluated, if debug mode is enabled.
+         *  @param {String} [options.priority]
+         *      If specified, this string is used for specifiy the priority of
+         *      the Deferred/Timer. It used by selenium tests to see if all
+         *      "jobs" are done.
+         *
+         * @returns {jQuery.Deferred}
+         *  A new pending deferred object.
+         */
+        this.createDeferredObject = function (options) {
+
+            var app = Utils.getOption(options, 'app');
+            var timeout = Utils.getOption(options, 'timeout');
+            var infoString = Utils.getStringOption(options, 'infoString');
+            var priority = Utils.getStringOption(options, 'priority');
+
+            var deferred = DeferredUtils.createDeferred(app, infoString, priority);
+            this.createAbortablePromise(deferred, null, timeout);
+            return deferred;
+        };
+
         /**
          * Returns a promise that will be resolved when the passed event source
          * object triggers the specified event.
@@ -491,22 +591,19 @@ define('io.ox/office/tk/object/baseobject', [
          */
         this.waitForEvent = function (source, type, timeout) {
 
-            // the event listener callback function, resolves the deferred object with the event data
-            function listener() {
-                stopListening();
-                def.resolve.apply(def, arguments);
-            }
-
             // the deferred object representing the event state
-            var def = $.Deferred();
-            // removes the event listener callback from the event source object
-            var stopListening = this.stopListeningTo.bind(this, source, type, listener);
+            var deferred = DeferredUtils.createDeferred(this, 'BaseObject: waitForEvent');
+
+            // the event listener callback function, resolves the deferred object with the event data
+            function listener() { deferred.resolve.apply(deferred, arguments); }
 
             // listen to the specified event, and resolve the deferred object
-            this.listenTo(source, type, listener);
+            this.listenOnceTo(source, type, listener);
 
             // the abortable promise for the deferred object
-            return this.createAbortablePromise(def, stopListening, timeout);
+            return this.createAbortablePromise(deferred, function () {
+                this.stopListeningTo(source, type, listener);
+            }, timeout);
         };
 
         /**
@@ -589,7 +686,7 @@ define('io.ox/office/tk/object/baseobject', [
             // dependent promises as well, therefore a while loop will be used that checks
             // the array length intentionally in each iteration.
             if (promises) {
-                while (promises.length > 0) { promises[0].abort(); }
+                while (promises.length > 0) { promises[0].abort('destroy'); }
                 promises = null;
             }
 
