@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -14,8 +15,9 @@
 define('io.ox/office/tk/object/timermixin', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/scheduler',
-    'io.ox/office/tk/utils/logger'
-], function (Utils, Scheduler, Logger) {
+    'io.ox/office/tk/utils/logger',
+    'io.ox/office/tk/utils/deferredutils'
+], function (Utils, Scheduler, Logger, DeferredUtils) {
 
     'use strict';
 
@@ -71,6 +73,16 @@ define('io.ox/office/tk/object/timermixin', [
          *      function will be delayed at least.
          *  Can also be a number, allowing to pass the value of the option
          *  'delay' directly.
+         *  @param {String} [options.infoString]
+         *      If specified, this string is used for logging information about
+         *      run times of asynchronous operations. This option is only
+         *      evaluated, if debug mode is enabled.
+         *  @param {String} [options.priority]
+         *      If specified, this string is used for specifiy the priority of the
+         *      Deferred/Timer. It used by selenium tests to see if all "jobs" are
+         *      done.
+         *  @param {BaseApplication) [options.app]
+         *      app is needed for correct window-id
          *
          * @returns {jQuery.Promise}
          *  A promise that will be resolved after the callback function has
@@ -86,36 +98,43 @@ define('io.ox/office/tk/object/timermixin', [
          *  promise will be rejected.
          */
         this.executeDelayed = function (callback, options) {
+            var app = DeferredUtils.getApp(self, options);
 
             // the delay time for the next execution of the callback
             var delay = _.isNumber(options) ? Math.max(0, options) : Utils.getIntegerOption(options, 'delay', 0, 0);
-            // the current timer identifier
-            var timerId = null;
-            // the deferred object representing the timer state
-            var def = $.Deferred();
             // a pending abortable result promise returned by the callback function
             var abortablePromise = null;
-            // the abortable promise for the deferred object
-            var promise = this.createAbortablePromise(def, function () {
-                if (timerId) { Scheduler.clearTimeout(timerId); timerId = null; }
-                if (abortablePromise) { abortablePromise.abort(); }
-            });
+
+            var infoString = Utils.getStringOption(options, 'infoString');
+            var priority = Utils.getStringOption(options, 'priority');
+
+            // the deferred object representing the timer state
+            var deferred = DeferredUtils.createDeferred(app, infoString, priority);
 
             // create a new synchronized timer
-            timerId = Scheduler.setTimeout(function () {
+            var timerId = Scheduler.setTimeout(function () {
+
+                // timer fired successfully: immediately clear the timer identifier
                 timerId = null;
+
                 // the result of the callback function
                 var result = callback.call(self);
+
                 // forward the result to the promise returned by this method
                 if (Utils.isPromise(result)) {
                     if ((result.state() === 'pending') && _.isFunction(result.abort)) { abortablePromise = result; }
-                    result.done(def.resolve.bind(def)).fail(def.reject.bind(def));
+                    result.done(deferred.resolve.bind(deferred));
+                    result.fail(deferred.reject.bind(deferred));
                 } else {
-                    def.resolve(result);
+                    deferred.resolve(result);
                 }
-            }, delay);
+            }, delay, app, infoString, priority);
 
-            return promise;
+            // the abortable promise for the deferred object
+            return this.createAbortablePromise(deferred, function () {
+                if (timerId) { Scheduler.clearTimeout(timerId); timerId = null; }
+                if (abortablePromise) { abortablePromise.abort(); }
+            });
         };
 
         /**
@@ -161,6 +180,16 @@ define('io.ox/office/tk/object/timermixin', [
          *      function will be reduced by the time the promise is pending. By
          *      default, the delay time always starts after the promise has
          *      been resolved.
+         *  @param {String} [options.infoString]
+         *      If specified, this string is used for logging information about
+         *      run times of asynchronous operations. This option is only
+         *      evaluated, if debug mode is enabled.
+         *  @param {String} [options.priority]
+         *      If specified, this string is used for specifiy the priority of the
+         *      Deferred/Timer. It used by selenium tests to see if all "jobs" are
+         *      done.
+         *  @param {BaseApplication) [options.app]
+         *      app is needed for correct window-id
          *  Can also be a number, allowing to pass the value of the option
          *  'delay' (and also 'repeatDelay' which defaults to the value of the
          *   option 'delay') directly.
@@ -179,7 +208,7 @@ define('io.ox/office/tk/object/timermixin', [
          *  the loop timer will be aborted automatically, and the promise will
          *  be rejected.
          */
-        this.repeatDelayed = function (callback, options, timerInfo) {
+        this.repeatDelayed = function (callback, options) {
 
             // the delay time for the first invocation of the callback
             var initDelay = _.isNumber(options) ? Math.max(0, options) : Utils.getIntegerOption(options, 'delay', 0, 0);
@@ -189,19 +218,20 @@ define('io.ox/office/tk/object/timermixin', [
             var cycles = Utils.getIntegerOption(options, 'cycles');
             // whether to reduce delay time after asynchronous callbacks
             var fastAsync = Utils.getBooleanOption(options, 'fastAsync');
+
+            var infoString = Utils.getStringOption(options, 'infoString');
+            var priority = Utils.getStringOption(options, 'priority');
+
+            var app = DeferredUtils.getApp(self, options);
+
             // the index of the next cycle
             var index = 0;
-            // the current timer before invoking the callback
+            // the current timer promise that defers invoking the callback
             var timer = null;
             // current pending abortable result promise returned by the callback function
             var abortablePromise = null;
             // the resulting deferred object
-            var def = $.Deferred();
-            // the abortable promise for the deferred object
-            var promise = this.createAbortablePromise(def, function () {
-                if (timer) { timer.abort(); timer = null; }
-                if (abortablePromise) { abortablePromise.abort(); }
-            });
+            var deferred = DeferredUtils.createDeferred(app, infoString, priority);
 
             // invokes the callback function
             function invokeCallback() {
@@ -209,7 +239,7 @@ define('io.ox/office/tk/object/timermixin', [
                 // the result of the callback, immediately break the loop if callback returns Utils.BREAK
                 var result = callback.call(self, index);
                 if (result === Utils.BREAK) {
-                    def.resolve(Utils.BREAK);
+                    deferred.resolve(Utils.BREAK);
                     return;
                 }
 
@@ -218,7 +248,7 @@ define('io.ox/office/tk/object/timermixin', [
                     if ((result.state() === 'pending') && _.isFunction(result.abort)) { abortablePromise = result; }
                     var t0 = (result.state() === 'pending') ? _.now() : -1;
                     result.done(function () { startNextTimer(t0); });
-                    result.fail(def.reject.bind(def));
+                    result.fail(deferred.reject.bind(deferred));
                 } else {
                     startNextTimer(-1);
                 }
@@ -227,18 +257,18 @@ define('io.ox/office/tk/object/timermixin', [
             // creates and registers a browser timeout that executes the callback
             function createTimer(delay) {
                 abortablePromise = null;
-                timer = self.executeDelayed(invokeCallback, delay, timerInfo);
+                timer = self.executeDelayed(invokeCallback, { delay: delay, infoString: infoString, app: app, priority: priority });
             }
 
             function startNextTimer(t0) {
                 // do not create a new timer if execution has been aborted while the asynchronous code was running
-                if (def.state() !== 'pending') { return; }
+                if (deferred.state() !== 'pending') { return; }
                 // decide whether to start the next iteration
                 index += 1;
                 if (!_.isNumber(cycles) || (index < cycles)) {
                     createTimer((fastAsync && (t0 > 0)) ? Math.max(0, repeatDelay - (_.now() - t0)) : repeatDelay);
                 } else {
-                    def.resolve();
+                    deferred.resolve(null);
                 }
             }
 
@@ -249,7 +279,11 @@ define('io.ox/office/tk/object/timermixin', [
                 createTimer(initDelay);
             }
 
-            return promise;
+            // the abortable promise for the deferred object
+            return this.createAbortablePromise(deferred, function () {
+                if (timer) { timer.abort(); timer = null; }
+                if (abortablePromise) { abortablePromise.abort(); }
+            });
         };
 
         /**
@@ -298,6 +332,12 @@ define('io.ox/office/tk/object/timermixin', [
          *      If specified, this string is used for logging information about
          *      run times of asynchronous operations. This option is only
          *      evaluated, if debug mode is enabled.
+         *  @param {String} [options.priority]
+         *      If specified, this string is used for specifiy the priority of the
+         *      Deferred/Timer. It used by selenium tests to see if all "jobs" are
+         *      done.
+         *  @param {BaseApplication) [options.app]
+         *      app is needed for correct window-id
          *
          * @returns {jQuery.Promise}
          *  A promise that will be resolved after the callback function returns
@@ -322,17 +362,15 @@ define('io.ox/office/tk/object/timermixin', [
             var infoString = Utils.getStringOption(options, 'infoString', '');
             // index of the next cycle
             var index = 0;
-            // the interval timer for the time slices
-            var timer = null;
+            var priority = Utils.getStringOption(options, 'priority');
+
+            var app = DeferredUtils.getApp(self, options);
+
             // the resulting deferred object
-            var def = $.Deferred();
-            // the abortable promise for the resulting deferred object
-            var promise = this.createAbortablePromise(def, function () {
-                if (timer) { timer.abort(); timer = null; }
-            });
+            var deferred = DeferredUtils.createDeferred(app, infoString, priority);
 
             // create the interval timer with the passed delay options
-            timer = this.repeatDelayed(function () {
+            var timer = this.repeatDelayed(function () {
 
                 // start time of this iteration
                 var start = _.now();
@@ -340,14 +378,14 @@ define('io.ox/office/tk/object/timermixin', [
                 var result = null;
 
                 // notify the own deferred object about the progress (once per time slice)
-                def.notify(index);
+                deferred.notify(index);
 
                 // time slice implementation: invoke callback repeatedly (loop body returns on any exit conditions)
                 while (true) {
 
                     // exit loop, if the specified number of cycles has been reached
                     if (_.isNumber(cycles) && (index >= cycles)) {
-                        def.resolve();
+                        deferred.resolve();
                         return Utils.BREAK;
                     }
 
@@ -358,7 +396,7 @@ define('io.ox/office/tk/object/timermixin', [
                     // callback has returned Utils.BREAK: resolve the own deferred
                     // object immediately, and break the background loop
                     if (result === Utils.BREAK) {
-                        def.resolve(Utils.BREAK);
+                        deferred.resolve(Utils.BREAK);
                         return Utils.BREAK;
                     }
 
@@ -377,13 +415,20 @@ define('io.ox/office/tk/object/timermixin', [
             }, {
                 delay: Utils.getOption(options, 'delay'),
                 repeatDelay: Utils.getIntegerOption(options, 'interval', 10, 10),
-                fastAsync: true
-            }, infoString);
+                fastAsync: true,
+                infoString: infoString,
+                app: app,
+                priority: priority
+            });
 
             // resolve/reject the own deferred object when the timer has finished
-            timer.done(def.resolve.bind(def)).fail(def.reject.bind(def));
+            timer.done(deferred.resolve.bind(deferred));
+            timer.fail(deferred.reject.bind(deferred));
 
-            return promise;
+            // the abortable promise for the resulting deferred object
+            return this.createAbortablePromise(deferred, function () {
+                if (timer) { timer.abort(); timer = null; }
+            });
         };
 
         /**
@@ -531,10 +576,6 @@ define('io.ox/office/tk/object/timermixin', [
          *      order. In reverse mode, the callback function may remove the
          *      array element currently visited, or elements that are following
          *      the visited element, from the array in-place.
-         *  @param {String} [options.infoString]
-         *      If specified, this string is used for logging information about
-         *      run times of asynchronous operations. This option is only
-         *      evaluated, if debug mode is enabled.
          *
          * @returns {jQuery.Promise}
          *  A promise that will be resolved after all array elements have been
@@ -554,27 +595,28 @@ define('io.ox/office/tk/object/timermixin', [
             var reverse = Utils.getBooleanOption(options, 'reverse', false);
             // current array index
             var arrayIndex = reverse ? (array.length - 1) : 0;
-            // promise representing the sliced loop
-            var timer = null;
+
+            var infoString = Utils.getStringOption(options, 'infoString', '');
+
+            var priority = Utils.getStringOption(options, 'priority');
+
+            var app = DeferredUtils.getApp(self, options);
+
             // the resulting deferred object
-            var def = $.Deferred();
-            // the abortable promise of the resulting deferred object
-            var promise = this.createAbortablePromise(def, function () {
-                if (timer) { timer.abort(); timer = null; }
-            });
+            var deferred = DeferredUtils.createDeferred(app, infoString, priority);
 
             // do nothing if passed array is empty
             if (array.length === 0) {
-                def.notify(1).resolve();
-                return promise;
+                deferred.notify(1).resolve();
+                return this.createAbortablePromise(deferred);
             }
 
             // start the sliced loop
-            timer = this.repeatSliced(function () {
+            var timer = this.repeatSliced(function () {
 
                 // end of array reached
                 if ((arrayIndex < 0) || (arrayIndex >= array.length)) {
-                    def.resolve();
+                    deferred.notify(1).resolve();
                     return Utils.BREAK;
                 }
 
@@ -586,7 +628,7 @@ define('io.ox/office/tk/object/timermixin', [
 
                 // immediately resolve after last element unless the result is a pending or rejected promise
                 if (((arrayIndex < 0) || (arrayIndex >= array.length)) && !(Utils.isPromise(result) && (result.state() !== 'resolved'))) {
-                    def.resolve();
+                    deferred.notify(1).resolve();
                     return Utils.BREAK;
                 }
 
@@ -594,13 +636,16 @@ define('io.ox/office/tk/object/timermixin', [
             }, options);
 
             // resolve/reject the own deferred object according to the timer result
-            timer.done(def.resolve.bind(def)).fail(def.reject.bind(def));
+            timer.done(deferred.resolve.bind(deferred));
+            timer.fail(deferred.reject.bind(deferred));
 
             // notify the own deferred object about the progress (once per time slice)
-            timer.progress(function (index) { def.notify(index / array.length); });
-            promise.done(function () { def.notify(1); });
+            timer.progress(function (index) { deferred.notify(index / array.length); });
 
-            return promise;
+            // the abortable promise of the resulting deferred object
+            return this.createAbortablePromise(deferred, function () {
+                if (timer) { timer.abort(); timer = null; }
+            });
         };
 
         /**
@@ -645,6 +690,7 @@ define('io.ox/office/tk/object/timermixin', [
          *  be aborted automatically, and the promise will be rejected.
          */
         this.iterateObjectSliced = function (object, callback, options) {
+
             return this.iterateArraySliced(_.keys(object), function (key) {
                 if (key in object) { return callback.call(this, object[key], key, object); }
             }, options);
@@ -669,9 +715,10 @@ define('io.ox/office/tk/object/timermixin', [
          *  All other return values will be interpreted as synchronous
          *  invocations of the callback function.
          *
-         * @param {String} [timerInfo]
-         *  An optional string that is used to debug run times of asynchronous
-         *  functions. This parameter is only used, if the debug mode is enabled.
+         * @param {Object} [options]
+         *  Optional parameters. See method TimerMixin.repeatSliced() for
+         *  details about all supported options. Additionally, the following
+         *  options are supported:
          *
          * @returns {Function}
          *  The synchronized method that can be called multiple times, and that
@@ -684,7 +731,12 @@ define('io.ox/office/tk/object/timermixin', [
          *  instance will be destroyed, processing the chain of pending method
          *  invocations will be aborted.
          */
-        this.createSynchronizedMethod = function (callback, timerInfo) {
+        this.createSynchronizedMethod = function (callback, options) {
+
+            var infoString = Utils.getStringOption(options, 'infoString', '');
+            var priority = Utils.getStringOption(options, 'priority');
+
+            var app = DeferredUtils.getApp(self, options);
 
             // arguments and returned promise of pending calls of the method
             var pendingInvocations = [];
@@ -702,13 +754,14 @@ define('io.ox/office/tk/object/timermixin', [
                 // create the promise representing the result of the callback function
                 var promise = $.when(callback.apply(invocationData.ctxt, invocationData.args));
                 // the deferred object bound to the result of the callback
-                var def = invocationData.def;
+                var deferred = invocationData.def;
 
                 // remove invocation data from array when the promise has been resolved/rejected
                 promise.always(function () { pendingInvocations.shift(); });
 
                 // forward result of the promise to the deferred object
-                promise.done(def.resolve.bind(def)).fail(def.reject.bind(def));
+                promise.done(deferred.resolve.bind(deferred));
+                promise.fail(deferred.reject.bind(deferred));
 
                 // return the promise (unless last callback was synchronous and is already resolved)
                 return (pendingInvocations.length === 0) ? Utils.BREAK : promise;
@@ -725,14 +778,14 @@ define('io.ox/office/tk/object/timermixin', [
             return function () {
 
                 // all data about the current invocation (arguments and returned deferred object)
-                var invocationData = { ctxt: this, args: arguments, def: $.Deferred() };
+                var invocationData = { ctxt: this, args: arguments, def: DeferredUtils.createDeferred(app, infoString, priority) };
 
                 // push new invocation to the end of the array
                 pendingInvocations.push(invocationData);
 
                 // if missing, start a new timer that processes the array
                 if (!timer) {
-                    timer = self.repeatDelayed(invokeCallback, { delay: 'immediate' }, timerInfo);
+                    timer = self.repeatSliced(invokeCallback, { delay: 'immediate', infoString: infoString, app: app, priority: priority });
                     // reject all pending promises on abort/destruction
                     timer.fail(rejectInvocations);
                     // forget the timer after the last callback invocation
@@ -779,6 +832,12 @@ define('io.ox/office/tk/object/timermixin', [
          *      If specified, this string is used for logging information about
          *      run times of asynchronous operations. This option is only
          *      evaluated, if debug mode is enabled.
+         *  @param {String} [options.priority]
+         *      If specified, this string is used for specifiy the priority of the
+         *      Deferred/Timer. It used by selenium tests to see if all "jobs" are
+         *      done.
+         *  @param {BaseApplication) [options.app]
+         *      app is needed for correct window-id
          *
          * @returns {Function}
          *  The debounced method that can be called multiple times, and that
@@ -799,6 +858,9 @@ define('io.ox/office/tk/object/timermixin', [
             var minTimer = null;
             // timer used for the maxDelay option
             var maxTimer = null;
+            var priority = Utils.getStringOption(options, 'priority');
+
+            var app = DeferredUtils.getApp(self, options);
 
             // aborts and clears all timers
             function clearTimers() {
@@ -825,12 +887,12 @@ define('io.ox/office/tk/object/timermixin', [
 
                 // create a new timeout executing the callback function
                 if (!minTimer) {
-                    minTimer = self.executeDelayed(timerCallback, delay, 'debounced (min) ' + infoString);
+                    minTimer = self.executeDelayed(timerCallback, { delay: delay, infoString: 'debounced (min) ' + infoString, app: app, priority: priority });
                 }
 
                 // on first call, create a timer for the maximum delay
                 if (!maxTimer && (maxDelay > 0)) {
-                    maxTimer = self.executeDelayed(timerCallback, maxDelay, 'debounced (max) ' + infoString);
+                    maxTimer = self.executeDelayed(timerCallback, { delay: maxDelay, infoString: 'debounced (max) ' + infoString, app: app, priority: priority });
                 }
             }
 
@@ -845,6 +907,47 @@ define('io.ox/office/tk/object/timermixin', [
             };
         };
 
+        /**
+         * Creates a debounced method that can be called multiple times during
+         * the current script execution. The deferred callback will be executed
+         * later once in browsers animation frame
+         *
+         * no optional timeout options, because it uses only the native animation frame
+         *
+         * @param {Function} directCallback
+         *  A function that will be called every time the debounced method has
+         *  been called. Will be called in the context the debounced method has
+         *  been called with, and receives all parameters that have been passed
+         *  to the created debounced method.
+         *
+         * @param {Function} deferredCallback
+         *  A function that will be called in a browser animationstep after the
+         *  debounced method has been called at least once during the execution
+         *  of the current script. Will be called in the context the debounced
+         *  method has been called with, and does not receive any parameters.
+         *
+         * @returns {Function}
+         *  The debounced method that can be called multiple times, and that
+         *  executes the deferred callback function once after execution of the
+         *  current script ends. Passes all arguments to the direct callback
+         *  function, and returns its result. If this instance will be
+         *  destroyed, pending debounced methods will not be invoked anymore.
+         */
+        this.createDebouncedAnimationFrameMethod = function (directCallback, deferredCallback) {
+            return function () {
+
+                // call the direct callback with the passed arguments
+                // directCallback MUST be called before deferredCallback is set to animation frame
+                // because the direct callback itself could trigger an animation frame
+                var direct = directCallback.apply(this, arguments);
+
+                // create a new timeout executing the callback function
+                window.requestAnimationFrame(deferredCallback.bind(this));
+
+                return direct;
+            };
+        };
+
         // initialization -----------------------------------------------------
 
         // logging overrides
