@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -129,7 +130,7 @@ define('io.ox/office/tk/popup/basemenu', [
         function hideMenuOnFocusNode(node) {
             if (autoClose && !(node && isFocusableNode(node))) {
                 // do not close the menu, if the debug URL flag 'office:sticky-popups' is set (but still return true)
-                if (!DEBUG_STICKY_POPUPS) { self.hide(); }
+                if (!DEBUG_STICKY_POPUPS) { self.hide(null, node); }
                 return true;
             }
             return false;
@@ -145,7 +146,7 @@ define('io.ox/office/tk/popup/basemenu', [
 
             if (autoFocus && (!Utils.isSoftKeyboardOpen() || Utils.shouldHideSoftKeyboard())) {
 
-                self.getContentNode().focus();
+                Utils.setFocus(self.getContentNode());
 
             }
         }
@@ -195,7 +196,7 @@ define('io.ox/office/tk/popup/basemenu', [
                 if (self.isVisible()) {
                     self.listenTo($(document), DOCUMENT_EVENTS, globalClickHandler);
                 }
-            }, undefined, 'TK: popupShowHandler');
+            }, { infoString: 'BaseMenu: popupShowHandler' });
         }
 
         /**
@@ -227,12 +228,12 @@ define('io.ox/office/tk/popup/basemenu', [
                 // should not be called on that destroyed object anymore
                 event.stopImmediatePropagation();
 
-                self.hide();
+                self.hide(event);
                 return false;
             }
 
             // we need to call preventDefault() because of focus traveling back to the document when this menu has no input fields
-            if (!$(event.target).is('input,textarea')) {
+            if (!$(event.target).is('input,textarea') && !KeyCodes.hasFunctionKeys(event)) {
                 event.preventDefault();
             }
         }
@@ -278,7 +279,7 @@ define('io.ox/office/tk/popup/basemenu', [
             if (preferredNodes.length === 0) {
                 preferredNodes = (focusNodes.length > 0) ? focusNodes : this.getContentNode();
             }
-            (bottom ? preferredNodes.last() : preferredNodes.first()).focus();
+            Utils.setFocus((bottom ? preferredNodes.last() : preferredNodes.first()));
             return this;
         };
 
