@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -240,6 +241,9 @@ define('io.ox/office/tk/popup/basepopup', [
      *          and 'height'.
      *      May return a custom content size object in order to influence the
      *      resulting size of the pop-up node.
+     *  @param {boolean} [initOptions.refreshNodeRepeatedDelayed=true]
+     *      If true refresh the node e.g. to update the position with repeatDelayed,
+     *      otherwise only on window resize the node will be refreshed
      */
     function BasePopup(initOptions) {
 
@@ -318,6 +322,12 @@ define('io.ox/office/tk/popup/basepopup', [
             // callback to influence position and size of the contents while layouting
             updateLayoutHandler = Utils.getFunctionOption(initOptions, 'updateLayoutHandler', $.noop),
 
+            // whether the pop-up node refreshed with repeatedDelayed or on window resize
+            refreshNodeRepeatedDelayed = Utils.getBooleanOption(initOptions, 'refreshNodeRepeatedDelayed', true),
+
+            // handler for windows resize to refresh the node
+            windowsResizeHandler,
+
             // whether the pop-up node will be aligned to the current anchor position
             isAnchored = true,
 
@@ -331,6 +341,8 @@ define('io.ox/office/tk/popup/basepopup', [
             // necessary data if the pop-up is anchored to the root anchor from its menu
             rootAnchoredMenuData = {};
 
+        var refreshTimerPrio = Utils.getStringOption(initOptions, 'refreshTimerPrio', 'default-proc');
+
         // base constructors --------------------------------------------------
 
         TriggerObject.call(this);
@@ -844,7 +856,7 @@ define('io.ox/office/tk/popup/basepopup', [
          * @returns {BasePopup}
          *  A reference to this instance.
          */
-        this.refresh = this.createDebouncedMethod(Utils.NOOP, this.refreshImmediately);
+        this.refresh = this.createDebouncedMethod(Utils.NOOP, this.refreshImmediately, { infoString: 'BasePopup: refresh()' });
 
         /**
          * Returns whether the pop-up node is currently visible.
@@ -918,7 +930,15 @@ define('io.ox/office/tk/popup/basepopup', [
 
             // start a timer that regularly refreshes the position of the pop-up node, and
             // hides the pop-up node automatically when the anchor node becomes inaccessible
-            refreshTimer = this.repeatDelayed(function () { refreshNode({ autoHide: true }); }, _.browser.Android ? 200 : 50);
+            if (refreshNodeRepeatedDelayed) {
+                refreshTimer = this.repeatDelayed(function () { refreshNode({ autoHide: true }); }, { delay: _.browser.Android ? 200 : 50, infoString: 'BasePopup: show().refreshNode', priority: refreshTimerPrio });
+            } else {
+                windowsResizeHandler = function () {
+                    refreshNode({ autoHide: true });
+                };
+
+                $(window).bind('resize', windowsResizeHandler);
+            }
 
             return this;
         };
@@ -929,17 +949,21 @@ define('io.ox/office/tk/popup/basepopup', [
          * @returns {BasePopup}
          *  A reference to this instance.
          */
-        this.hide = function () {
+        this.hide = function (event, node) {
 
             // do nothing if the pop-up node is not visible
             if (!this.isVisible()) { return this; }
 
             // stop the automatic refresh timer
-            refreshTimer.abort();
-            refreshTimer = null;
+            if (refreshTimer) {
+                refreshTimer.abort();
+                refreshTimer = null;
+            } else if (windowsResizeHandler) {
+                $(window).unbind('resize', windowsResizeHandler);
+            }
 
             // hide the pop-up node, notify all listeners
-            this.trigger('popup:beforehide');
+            this.trigger('popup:beforehide', event, node);
             rootNode.detach();
             this.trigger('popup:hide');
 
@@ -1283,6 +1307,9 @@ define('io.ox/office/tk/popup/basepopup', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
+            if (windowsResizeHandler) {
+                $(window).unbind('resize', windowsResizeHandler);
+            }
             rootNode.remove();
             self = rootNode = contentNode = boundingBoxSpec = anchorSpec = anchorBoxSpec = anchorAlignBoxSpec = refreshTimer = null;
         });
