@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -25,10 +26,10 @@ define('io.ox/office/tk/popup/listmenu', [
     var SECTION_CLASS = 'section-container';
 
     // The internal identifier for the title section
-    var TITLE_SECTION_ID = '\x00TITLE';
+    var TITLE_SECTION_ID = '__TITLE__';
 
     // The internal identifier for the most recently used section.
-    var MRU_SECTION_ID = '\x00MRU';
+    var MRU_SECTION_ID = '__MRU__';
 
     // class ListMenu =========================================================
 
@@ -146,6 +147,9 @@ define('io.ox/office/tk/popup/listmenu', [
         // values of all items not to be added to the MRU list
         var mruBlackList = Utils.getArrayOption(initOptions, 'mruBlackList', []);
 
+        // label text for the recently used section
+        var mruLabel = Utils.getStringOption(initOptions, 'mruLabel', '');
+
         // the actual list of most recently used items
         var mruList = null;
 
@@ -258,7 +262,7 @@ define('io.ox/office/tk/popup/listmenu', [
                 });
             }
 
-            return self.createDebouncedMethod(registerSectionNode, sortAllSectionNodes);
+            return self.createDebouncedMethod(registerSectionNode, sortAllSectionNodes, { infoString: 'ListMenu sortSectionNode()' });
         }());
 
         /**
@@ -271,7 +275,7 @@ define('io.ox/office/tk/popup/listmenu', [
 
             // stop event propagation for all supported keys
             if (targetNode.length > 0) {
-                targetNode.focus();
+                Utils.setFocus(targetNode);
                 self.scrollToChildNode(targetNode);
                 return false;
             }
@@ -321,7 +325,7 @@ define('io.ox/office/tk/popup/listmenu', [
         function addValueToMRUList(value, options) {
             if (mruList && value && !_.contains(mruBlackList, value) && !_.isEmpty(options) && !containsMostRecentlyItem(value)) {
                 options.section = MRU_SECTION_ID;
-
+                options.append = false;
                 if (mruList.length >= mruSize) {
                     self.deleteItemNodes(mruList.shift().value, MRU_SECTION_ID);
                 }
@@ -401,7 +405,7 @@ define('io.ox/office/tk/popup/listmenu', [
                 if (this.getItemNodes().filter(focusNode).length === 0) {
                     focusNode = this.findItemNodes(value);
                 }
-                focusNode.focus();
+                Utils.setFocus(focusNode);
             }
 
             return this;
@@ -504,6 +508,9 @@ define('io.ox/office/tk/popup/listmenu', [
          *      of the 'value' parameter will be used instead (all double-quote
          *      characters will be removed from the string though), unless the
          *      value is a function.
+         *  @param {Boolean} [options.append=true]
+         *      If TRUE append (default) append the Node to the list, otherwise
+         *      prepend the Node to the list.
          *
          * @returns {jQuery}
          *  The button element representing the new list item, as jQuery
@@ -514,7 +521,8 @@ define('io.ox/office/tk/popup/listmenu', [
             var // the root node of the menu section
                 sectionNode = this.createSectionNode(Utils.getStringOption(options, 'section', '')),
                 // create the button element representing the item
-                buttonNode = $(Forms.createButtonMarkup(options));
+                buttonNode = $(Forms.createButtonMarkup(options)),
+                append = Utils.getBooleanOption(options, 'append', true);
 
             // make section node visible (initially hidden)
             Forms.showNodes(sectionNode, true);
@@ -528,7 +536,11 @@ define('io.ox/office/tk/popup/listmenu', [
             // insert the new button according to the design mode
             switch (design) {
                 case 'list':
-                    sectionNode.append(buttonNode);
+                    if (append) {
+                        sectionNode.append(buttonNode);
+                    } else {
+                        sectionNode.prepend(buttonNode);
+                    }
                     break;
                 case 'grid':
                     // create a new row element for the button if required
@@ -538,7 +550,11 @@ define('io.ox/office/tk/popup/listmenu', [
                     }
                     // append the button to the row (wrap into a helper node for ARIA)
                     var cellNode = $('<div class="grid-cell" role="gridcell">').attr('aria-label', buttonNode.attr('aria-label') || '').append(buttonNode);
-                    rowNode.append(cellNode);
+                    if (append) {
+                        rowNode.append(cellNode);
+                    } else {
+                        rowNode.prepend(cellNode);
+                    }
                     break;
             }
 
@@ -576,7 +592,7 @@ define('io.ox/office/tk/popup/listmenu', [
             // collect modified section nodes, notify listeners
             buttonNodes = buttonNodes.filter(function () {
                 var buttonNode = $(this);
-                if (!_.isString(sectionId) || buttonNode.parent().filter('[data-section="' + sectionId + '"]').length > 0) {
+                if (!_.isString(sectionId) || buttonNode.parents().filter('[data-section="' + sectionId + '"]').length > 0) {
                     sectionNodes = sectionNodes.add(buttonNode.closest('.' + SECTION_CLASS));
                     self.trigger('delete:item', buttonNode, value);
                     return true;
@@ -885,7 +901,7 @@ define('io.ox/office/tk/popup/listmenu', [
 
         // initialize the MRU list
         if (mruSize > 0) {
-            this.createSectionNode(MRU_SECTION_ID);
+            this.createSectionNode(MRU_SECTION_ID, { label: mruLabel });
             multiSelect = false;
             this.one('popup:beforeshow', initializeMRUList);
             this.on('popup:beforehide', updateMRUList);
