@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -41,7 +42,9 @@ define('io.ox/office/tk/popup/tooltip', [
             restrictSize: 'width',
             minSize: 150,
             maxSize: 450,
-            anchorPadding: 3
+            anchorPadding: 3,
+            refreshNodeRepeatedDelayed: true,
+            refreshTimerPrio: 'background-proc'
         }, initOptions));
 
         // methods ------------------------------------------------------------
