@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -293,6 +294,16 @@ define('io.ox/office/tk/render/font', [
 
     // public methods ---------------------------------------------------------
 
+    /**
+     * Returns a clone of this font instance.
+     *
+     * @returns {Font}
+     *  A clone of this font instance.
+     */
+    Font.prototype.clone = function () {
+        return new Font(this.family, this.size, this.bold, this.italic);
+    };
+
     /**
      * Returns a unique string key for this font that can be used for example
      * as key in an associative map.
