@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  */
@@ -35,27 +36,6 @@ define('io.ox/office/tk/utils/dateutils', [
         zh: 'D-MMM'
     };
 
-    var SHORT_MONTHS = null;
-
-    // private global functions ===============================================
-
-    /**
-     * lazy init of short months list
-     *
-     * moment short months are not limited to 3 signs, and most have a dot in the string.
-     * both is not good to be compatible with other office programms, so we prepare the list!
-     *
-     */
-    function getShortMonths() {
-        if (!SHORT_MONTHS) {
-            SHORT_MONTHS = [];
-            _.each(moment.monthsShort(), function (month) {
-                SHORT_MONTHS.push(month.replace('.', '').substring(0, 3));
-            });
-        }
-        return SHORT_MONTHS;
-    }
-
     // static class DateUtils =================================================
 
     var DateUtils = {};
@@ -497,86 +477,6 @@ define('io.ox/office/tk/utils/dateutils', [
         return NO_YEARS[Config.LANGUAGE] || NO_YEARS.en;
     };
 
-    // locale arrays
-
-    /**
-     * @returns {Array<String>}
-     *  months of moment.js
-     */
-    DateUtils.getLocaleMonths = function () {
-        return moment.months('-'); // It's needed to get the nominative monthname in polish
-    };
-
-    /**
-     * @returns {Array<String>}
-     *  short months, max three signs without dots
-     */
-    DateUtils.getLocaleMonthsShort = function () {
-        return getShortMonths();
-    };
-
-    /**
-     * @returns {Array<String>}
-     *  weekDays of moment.js
-     */
-    DateUtils.getLocaleDays = function () {
-        return moment.weekdays();
-    };
-
-    /**
-     * @returns {Array<String>}
-     *  short weekDays of moment.js, means two or three sign without dots
-     */
-    DateUtils.getLocaleDaysShort = function () {
-        return moment.weekdaysMin();
-    };
-
-    // locale getter
-
-    /**
-     * @param {Number} month
-     *  as nr, by default January is 0 and December is 11
-     *
-     * @returns {String}
-     *  months of moment.js
-     */
-    DateUtils.getLocaleMonth = function (month) {
-        return moment.months('-', month); // It's needed to get the nominative monthname in polish
-    };
-
-    /**
-     * @param {Number} month
-     *  as nr, by default January (Jan) is 0 and December (Dec) is 11
-     *
-     * @returns {String}
-     *  months, means max three signs without dots
-     */
-    DateUtils.getLocaleMonthShort = function (month) {
-        return getShortMonths()[month];
-    };
-
-    /**
-     * @param {Number} day
-     *  as nr, by default Sunday is 0 and Saturday is 6
-     *
-     * @returns {String}
-     *  weekDays of moment.js
-     */
-    DateUtils.getLocaleDay = function (day) {
-        return moment.weekdays(day);
-    };
-
-    /**
-     * @param {Number} day
-     *  as nr, by default Sunday (Sun) is 0 and Saturday (Sat) is 6
-     *
-     * @returns {String}
-     *  weekDaysMin of moment.js, means two or three sign without dots
-     */
-    DateUtils.getLocaleDayShort = function (day) {
-        return moment.weekdaysMin(day);
-    };
-
     /**
      * Converts the UTC date time string to a date string in local time
      * (keeping the final letter 'Z', that indicates UTC).
@@ -642,7 +542,7 @@ define('io.ox/office/tk/utils/dateutils', [
 
         if (!useSeconds) {
             // replacing all digits before the trailing Z and after the final ':' with 0
-            d = d.replace(/:[\d\.]+?Z$/, ':00Z');
+            d = d.replace(/:[\d.]+?Z$/, ':00Z');
         }
 
         return d;
@@ -684,7 +584,7 @@ define('io.ox/office/tk/utils/dateutils', [
 
         if (!Utils.getBooleanOption(options, 'useSeconds', true)) {
             // replacing all digits before the trailing Z and after the final ':' with 0
-            isoDateString = isoDateString.replace(/:[\d\.]+?Z$/, ':00Z');
+            isoDateString = isoDateString.replace(/:[\d.]+?Z$/, ':00Z');
         }
 
         return isoDateString;
