@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  */
@@ -20,10 +21,10 @@ define('io.ox/office/tk/utils/driveutils', [
     'io.ox/core/permissions/permissions',
     'io.ox/office/tk/utils',
     'io.ox/office/tk/keycodes',
+    'io.ox/office/tk/utils/scheduler',
     'io.ox/office/tk/object/triggerobject',
-    'io.ox/core/capabilities',
     'settings!io.ox/files'
-], function (FilesAPI, FolderAPI, FolderNode, TreeView, Selection, Permissions, Utils, KeyCodes, TriggerObject, Capabilities, DriveSettings) {
+], function (FilesAPI, FolderAPI, FolderNode, TreeView, Selection, Permissions, Utils, KeyCodes, Scheduler, TriggerObject, DriveSettings) {
 
     'use strict';
 
@@ -79,6 +80,29 @@ define('io.ox/office/tk/utils/driveutils', [
         }
     }
 
+    /**
+     * disabled is different to "no write access" because
+     * children of disabled folders can be enabled!
+     */
+    function shouldBeDisabled(folder_id) {
+        if (/^virtual/.test(folder_id)) {
+            return true;
+        }
+
+        var folderModel = FolderAPI.pool.models[folder_id];
+        if (!folderModel) {
+            Utils.warn('DriveUtils.shouldBeDisabled() is called to early, folder is not cached yet. better call DriveUtils.getWriteState() folder_id: ' + folder_id);
+            return true;
+        }
+        var json = folderModel.toJSON();
+        if (!callState('can', 'write', json)) {
+            return true;
+        }
+        if (!callState('can', 'create', json)) {
+            return true;
+        }
+    }
+
     /**
      * instead of moving file in trash this function really deletes the assigned file
      *
@@ -137,7 +161,7 @@ define('io.ox/office/tk/utils/driveutils', [
      */
     DriveUtils.propagateChangeFile = function (file) {
         return FilesAPI.propagate('add:version', file).then(function () {
-            return DriveUtils.getFile(file, { cache: false, columns: '1,2,3,5,20,23,108,700,702,703,704,705,707,710,711' });
+            return DriveUtils.getFile(file, { cache: false, columns: '1,2,3,5,20,23,108,109,700,701,702,703,704,705,706,707,708,709,710,711,7010,7030' });
         });
     };
 
@@ -197,6 +221,44 @@ define('io.ox/office/tk/utils/driveutils', [
         });
     };
 
+    /**
+     * @param {Object} file is a file-descriptor
+     *  this can have:
+     *       {String} file.folder_id (parent folder)
+     *       {String} file.id
+     *
+     * @param {Object} options
+     *  directly assigned to FilesAPI
+     *
+     * @returns {Deferred}
+     *  Array of versions
+     *  can be empty if Drive does not support versions!
+     */
+    DriveUtils.getFileVersions = function (file, options) {
+        return FilesAPI.versions.load(file, options).then(function (versions) {
+            return versions;
+        }, generalFailHandler);
+    };
+
+    /**
+     * Returns a promise indicating if the given file descriptor represents
+     * the current version of the file.
+     *
+     * @param {Object} file
+     *  The file descriptor.
+     *
+     * @param {Object} options
+     *  directly assigned to FilesAPI
+     *
+     * @returns {jQuery.Promise}
+     *  A Promise that will resolve with a Boolean value,
+     *  specifying whether the file descriptor represents
+     *  the current version.
+     */
+    DriveUtils.getCurrentFileVersionState = function (file, options) {
+        return FilesAPI.versions.getCurrentState(file, options).fail(generalFailHandler);
+    };
+
     // subclasses -------------------------------------------------------------
 
     /**
@@ -344,11 +406,12 @@ define('io.ox/office/tk/utils/driveutils', [
         var folderTree = new TreeView({
             persistent: false,
             tabindex: 0,
-            root: '9',
+            root: DriveUtils.getRootId(),
             all: false,
             module: 'infostore',
             abs: false,
             filter: DriveUtils.getPickerFilter(),
+            customize: DriveUtils.getPickerCustomizer(),
             highlightclass: Utils.SMALL_DEVICE ? 'visible-selection-smartphone' : 'visible-selection'
         });
 
@@ -361,7 +424,11 @@ define('io.ox/office/tk/utils/driveutils', [
         treeNode.addClass('drive-folder-list');
 
         folderTree.on('change virtual', function (folder_id) {
-            selectedFolder = folder_id;
+            if (shouldBeDisabled(folder_id)) {
+                selectedFolder = null;
+            } else {
+                selectedFolder = folder_id;
+            }
             self.trigger('change');
         });
 
@@ -442,8 +509,8 @@ define('io.ox/office/tk/utils/driveutils', [
 
             el.addClass('selected');
             el.attr('aria-selected', true);
-            el.attr('tabindex', 1);
-            el.focus();
+            el.attr('tabindex', 0);
+            Utils.setFocus(el);
 
             node.trigger('select');
         });
@@ -532,7 +599,7 @@ define('io.ox/office/tk/utils/driveutils', [
         } else {
             var folderModel = FolderAPI.pool.models[model.get('folder_id')];
             if (!folderModel) {
-                Utils.warn('DriveUtils.canModify() is called to early, folder is not cached yet. better call DriveUtils.getWriteState() file: ' + file);
+                Utils.warn('DriveUtils.canModify() is called too early, folder is not cached yet. better call DriveUtils.getWriteState() file: ' + file);
                 return false;
             }
             return callState('can', 'write', folderModel.toJSON());
@@ -542,7 +609,7 @@ define('io.ox/office/tk/utils/driveutils', [
     DriveUtils.isShareable = function (file) {
         var folderModel = FolderAPI.pool.models[file.folder_id];
         if (!folderModel) {
-            Utils.warn('DriveUtils.isShareable() is called to early, folder is not cached yet. better call DriveUtils.getWriteState() file: ' + file);
+            Utils.warn('DriveUtils.isShareable() is called too early, folder is not cached yet. better call DriveUtils.getWriteState() file: ' + file);
             return false;
         }
         return folderModel.isShareable();
@@ -654,6 +721,17 @@ define('io.ox/office/tk/utils/driveutils', [
         return optString(FolderAPI.getDefaultFolder('infostore'));
     };
 
+    /**
+     * return real Drive-File-ID of root folder
+     * (parent of My Files or Public Files);
+     *
+     * @returns {String}
+     *  Drive-File-ID
+     */
+    DriveUtils.getRootId = function () {
+        return '9';
+    };
+
     /**
      * give a filter function, which is used by FolderPicker and its TreeView
      *
@@ -666,6 +744,14 @@ define('io.ox/office/tk/utils/driveutils', [
         };
     };
 
+    DriveUtils.getPickerCustomizer = function () {
+        return function (baton) {
+            if (shouldBeDisabled(baton.data.id)) {
+                this.addClass('disabled');
+            }
+        };
+    };
+
     /**
      * gives an extended FolderNode, which look similar like the FolderNode of
      * the FolderPicker and its TreeView.
@@ -835,14 +921,14 @@ define('io.ox/office/tk/utils/driveutils', [
                 var selection = treeView.selection;
                 if (selection) {
                     selection.updateIndex().selectFirst();
-                    treeView.$el.find('.selected').focus();
+                    Utils.setFocus(treeView.$el.find('.selected'));
                 }
             }
         }
 
-        //stupid hacks
+        //FIXME: stupid hacks
         treeView.once('appear', open);
-        timeout = window.setTimeout(open, 250);
+        timeout = Scheduler.setTimeout(open, 250, null, 'DriveUtils preselectFolder');
     };
 
     DriveUtils.preparePath = function (paths) {
@@ -854,16 +940,6 @@ define('io.ox/office/tk/utils/driveutils', [
         return path;
     };
 
-    /**
-     * Check if Contacts is enabled.
-     *
-     * @returns {Boolean}
-     *  true if contacts is enabled, otherwise false.
-     */
-    DriveUtils.isContactsEnabled = function () {
-        return  Capabilities.has('contacts');
-    };
-
     // exports ================================================================
 
     return DriveUtils;
