@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -201,7 +202,7 @@ define('io.ox/office/tk/utils/tracking', [
         }
 
         // compare this click with the previous detected click
-        var dblClickDelay = Utils.getIntegerOption(trackingOptions, 'dblClickDelay', 600);
+        var dblClickDelay = Utils.getIntegerOption(trackingOptions, 'dblClickDelay', Utils.DBL_CLICK_TIMEOUT);
         if (lastClickData) {
             var duration = _.now() - lastClickData.time;
             logger.log('total double-click duration: ' + duration + 'ms');
