@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -191,16 +192,16 @@ module.exports = function (grunt) {
             Utils.ensureObject(def, 'Invalid icon definition, expecting objects as array elements.');
             Utils.ensureStringNE(def.path, 'Invalid icon definition, missing path to source image.');
 
-            // validate classes property (may be a plain string)
-            def.classes = Utils.makeArray(def.classes);
-            Utils.ensureArrayNE(def.classes, 'Invalid icon definition, expecting string or array as "classes" property.');
-            def.classes.forEach(function (cls) { Utils.ensureStringNE(cls, 'Invalid icon definition, expecting strings in "classes" property.'); });
+            // validate class property (may be a plain string)
+            def.class = Utils.makeArray(def.class);
+            Utils.ensureArrayNE(def.class, 'Invalid icon definition, expecting string or array as "class" property.');
+            def.class.forEach(function (cls) { Utils.ensureStringNE(cls, 'Invalid icon definition, expecting strings in "class" property.'); });
 
-            // validate locales property (may be a plain string)
-            if ('locales' in def) {
-                def.locales = Utils.makeArray(def.locales);
-                Utils.ensureArrayNE(def.locales, 'Invalid icon definition, expecting string or array as "locales" property.');
-                def.locales.forEach(function (lc) { Utils.ensureStringNE(lc, 'Invalid icon definition, expecting strings in "locales" property.'); });
+            // validate locale property (may be a plain string)
+            if ('locale' in def) {
+                def.locale = Utils.makeArray(def.locale);
+                Utils.ensureArrayNE(def.locale, 'Invalid icon definition, expecting string or array as "locale" property.');
+                def.locale.forEach(function (lc) { Utils.ensureStringNE(lc, 'Invalid icon definition, expecting strings in "locale" property.'); });
             }
 
             // the source PNG images, mapped by icon set name ('desktop', 'retina')
@@ -275,12 +276,12 @@ module.exports = function (grunt) {
                 def.y = offsety;
 
                 // generate the text line for the current icon in the LESS file
-                var line = def.classes.map(function (cls) { return '&.docs-' + cls; }).join(', ');
-                if (def.locales) { line += ' { ' + def.locales.map(function (lc) { return '&.lc-' + lc; }).join(', '); }
+                var line = def.class.map(function (cls) { return '&.docs-' + cls; }).join(', ');
+                if (def.locale) { line += ' { ' + def.locale.map(function (lc) { return '&.lc-' + lc; }).join(', '); }
                 line += ' { background-position: ' + -offsetx + 'px ' + -offsety + 'px;';
                 if (def.width !== ICON_HEIGHT) { line += ' width: ' + (def.width + 2) + 'px;'; }
                 line += ' }';
-                if (def.locales) { line += ' }'; }
+                if (def.locale) { line += ' }'; }
                 iconLessLines.push(line);
 
                 // go to next offset position
