@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -29,7 +30,7 @@ module.exports = function (grunt) {
 
         options: {
             base: 'apps',
-            externals: ['io.ox/{backbone,contacts,core,files,mail,realtime,metrics}/**/*', 'static/3rd.party/**/*'],
+            externals: ['io.ox/{backbone,contacts,core,files,guard,mail,realtime,metrics}/**/*', 'static/3rd.party/**/*'],
             libs: 'io.ox/office/drawinglayer/lib/**/*',
             plugins: {
                 less: {
@@ -197,16 +198,14 @@ module.exports = function (grunt) {
     /**
      * Writes the specified source lines to the logger.
      *
-     * @param {Number} start
+     * @param {Number} line
      *  Zero-based index of the first line to be logged.
      *
      * @param {Number} count
      *  Number of lines to be logged.
      */
-    SourceModule.prototype.dumpLines = function (start, count) {
-        this.lines.slice(start, start + count).forEach(function (l, i) {
-            grunt.log.writeln(('     ' + (start + i + 1)).substr(-6) + ' |' + l);
-        });
+    SourceModule.prototype.dumpLines = function (line, count) {
+        Utils.dunpLines(this.lines, line, count);
     };
 
     /**
@@ -223,11 +222,9 @@ module.exports = function (grunt) {
      *  The constant value false.
      */
     SourceModule.prototype.dumpError = function (message, position) {
-        grunt.log.writeln(message + ' at ' + this.path.green + ' :');
+        Utils.printPathMessage(this.path, message);
         if (position) {
-            this.dumpLines(position.line - 3, 3);
-            grunt.log.writeln(new Array(position.column + 9).join('-') + '^');
-            this.dumpLines(position.line, 2);
+            Utils.dumpErrorInLines(this.lines, position.line - 1, position.column);
         }
         this.errors += 1;
         return false;
@@ -582,8 +579,6 @@ module.exports = function (grunt) {
             grunt.log.error(errors + ' module definition ' + grunt.util.pluralize(errors, 'error/errors') + ' found.');
             resolveTask(false);
         } else {
-            var files = this.filesSrc.length;
-            grunt.log.ok(files + ' ' + grunt.util.pluralize(files, 'file/files') + ' without module definition errors.');
             resolveTask(true);
         }
     });
