@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -15,8 +16,8 @@ define('globals/sheethelper', [
     'io.ox/office/tk/utils',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/utils/matrix',
-    'io.ox/office/spreadsheet/model/formula/utils/operand',
-    'io.ox/office/spreadsheet/model/formula/formulacontext'
+    'io.ox/office/spreadsheet/model/formula/interpret/operand',
+    'io.ox/office/spreadsheet/model/formula/interpret/formulacontext'
 ], function (Utils, SheetUtils, Matrix, Operand, FormulaContext) {
 
     'use strict';
@@ -104,7 +105,7 @@ define('globals/sheethelper', [
                     size: _.constant(operands.length),
                     get: function (i) { return operands[i]; },
                     resolve: function (i) { return operands[i]; }
-                }, 0, 0);
+                }, 'val', 0, 0);
 
                 // invoke the function implementation, return the result
                 var resolveFunc = descriptor.resolve;
@@ -131,6 +132,35 @@ define('globals/sheethelper', [
         return resolver;
     }
 
+    /**
+     * Generates a test implementation function that provides the additional
+     * function properties 'skip' and 'only', that can be forwarded to the
+     * methods 'describe.skip' and 'describe.only' respectively.
+     *
+     * @param {Function} implFunc
+     *  The implementation of the test function. The first parameter that will
+     *  be passed to this function is the actual describe() implementation
+     *  (either 'describe', 'describe.skip', or 'describe.only'). The remaining
+     *  parameters will be the ones that have been passed to the generated test
+     *  function.
+     *
+     * @returns {Function}
+     *  The generated test implementation function.
+     */
+    function createImplementation(implFunc) {
+
+        function createImpl(describeFunc) {
+            return function () {
+                return implFunc.apply(this, [describeFunc].concat(_.toArray(arguments)));
+            };
+        }
+
+        var defaultImpl = createImpl(describe);
+        defaultImpl.skip = createImpl(describe.skip);
+        defaultImpl.only = createImpl(describe.only);
+        return defaultImpl;
+    }
+
     // class FunctionModuleTester =============================================
 
     /**
@@ -190,13 +220,13 @@ define('globals/sheethelper', [
          *  returns the original value of the implementation (no conversion of
          *  instances of class Operand to the wrapped values).
          */
-        this.testFunction = function (funcKey, options, callback) {
+        this.testFunction = createImplementation(function (describeFunc, funcKey, options, callback) {
 
             // options can be omitted completely
             if (!callback) { callback = options; options = null; }
 
             // create a text particle for the function, and a context for the before() block
-            describe('function "' + funcKey + '"', function () {
+            describeFunc('function "' + funcKey + '"', function () {
 
                 // the function descriptor (add a few standard tests)
                 var descriptor = funcModule[funcKey];
@@ -231,7 +261,7 @@ define('globals/sheethelper', [
                     return invokeResolver;
                 }).concat([descriptor]));
             });
-        };
+        });
 
         /**
          * Creates a simple test that the specified spreadsheet function has
@@ -244,10 +274,10 @@ define('globals/sheethelper', [
          *  The resource key of the function the descriptor of the specified
          *  alias function should refer to.
          */
-        this.testAliasFunction = function (aliasFuncKey, implFuncKey) {
+        this.testAliasFunction = createImplementation(function (describeFunc, aliasFuncKey, implFuncKey) {
 
             // create a text particle for the function
-            describe('function "' + aliasFuncKey + '"', function () {
+            describeFunc('function "' + aliasFuncKey + '"', function () {
 
                 var descriptor = funcModule[aliasFuncKey];
                 it('should exist', function () {
@@ -257,7 +287,7 @@ define('globals/sheethelper', [
                     expect(descriptor).to.have.a.property('resolve', implFuncKey);
                 });
             });
-        };
+        });
 
         // initialization -----------------------------------------------------
 
