@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Michael Nimz <michael.nimz@open-xchange.com>
  */
@@ -145,6 +146,13 @@ define([
                 expect(Border.isEqual({}, {})).to.equal(true);
                 expect(Border.isEqual(noBorder, noBorder)).to.equal(true);
             });
+            it('should accept null values', function () {
+                expect(Border.isEqual(null, border)).to.equal(false);
+                expect(Border.isEqual(border, null)).to.equal(false);
+                expect(Border.isEqual(null, noBorder)).to.equal(true);
+                expect(Border.isEqual(noBorder, null)).to.equal(true);
+                expect(Border.isEqual(null, null)).to.equal(true);
+            });
         });
     });
 
