@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  * @author Michael Nimz <michael.nimz@open-xchange.com>
@@ -203,12 +204,23 @@ define([
                 expect(Color.parseCSS('#4080c0').toJSON()).to.deep.equal({ type: 'rgb', value: '4080c0' });
                 expect(Color.parseCSS('#4080C0').toJSON()).to.deep.equal({ type: 'rgb', value: '4080c0' });
                 expect(Color.parseCSS('#48c').toJSON()).to.deep.equal({ type: 'rgb', value: '4488cc' });
+            });
+            it('should parse hexadecimal RGB color with alpha channel', function () {
+                expect(Color.parseCSS('#4080c0cc').toJSON()).to.deep.equal({ type: 'rgb', value: '4080c0', transformations: [{ type: 'alpha', value: 80000 }] });
+                expect(Color.parseCSS('#4080C0CC').toJSON()).to.deep.equal({ type: 'rgb', value: '4080c0', transformations: [{ type: 'alpha', value: 80000 }] });
+                expect(Color.parseCSS('#4080C0FF').toJSON()).to.deep.equal({ type: 'rgb', value: '4080c0' });
+                expect(Color.parseCSS('#4080C000').toJSON()).to.deep.equal({ type: 'rgb', value: '4080c0', transformations: [{ type: 'alpha', value: 0 }] });
+                expect(Color.parseCSS('#48cc').toJSON()).to.deep.equal({ type: 'rgb', value: '4488cc', transformations: [{ type: 'alpha', value: 80000 }] });
+                expect(Color.parseCSS('#48cf').toJSON()).to.deep.equal({ type: 'rgb', value: '4488cc' });
+                expect(Color.parseCSS('#48c0').toJSON()).to.deep.equal({ type: 'rgb', value: '4488cc', transformations: [{ type: 'alpha', value: 0 }] });
+            });
+            it('should reject invalid hexadecimal RGB color', function () {
                 expect(Color.parseCSS('#')).to.equal(null);
                 expect(Color.parseCSS('#4')).to.equal(null);
                 expect(Color.parseCSS('#48')).to.equal(null);
-                expect(Color.parseCSS('#4080')).to.equal(null);
                 expect(Color.parseCSS('#4080c')).to.equal(null);
                 expect(Color.parseCSS('#4080c04')).to.equal(null);
+                expect(Color.parseCSS('#4080c0400')).to.equal(null);
                 expect(Color.parseCSS('#4080cg')).to.equal(null);
             });
             it('should parse function-style RGB(A) color', function () {
@@ -291,7 +303,8 @@ define([
                 expect(new Color('crgb', { r: 25000, g: 50000, b: 75000 }).equals(new Color('crgb', { r: 25000, g: 50000, b: 75000 }))).to.equal(true);
                 expect(new Color('system', 'menu').equals(new Color('system', 'Menu'))).to.equal(true);
                 expect(new Color('preset', 'black').equals(new Color('preset', 'Black'))).to.equal(true);
-                expect(new Color('scheme', 'accent1').equals(new Color('scheme', 'Accent1'))).to.equal(true);
+                expect(new Color('scheme', 'accent1').equals(new Color('scheme', 'Accent1'))).to.equal(false);
+                expect(new Color('scheme', 'accent1').equals(new Color('scheme', 'accent1'))).to.equal(true);
                 expect(new Color('rgb', '4080c0', [{ type: 'gray' }]).equals(new Color('rgb', '4080C0').transform('gray'))).to.equal(true);
             });
             it('should return false for different color types', function () {
@@ -366,7 +379,6 @@ define([
             });
             it('should return color descriptor for scheme colors', function () {
                 verifyColor('scheme', 'accent1', 0.310, 0.506, 0.741, 213, 0.455, 0.525, 1, 0.481, '4f81bd', '#4f81bd');
-                verifyColor('scheme', 'Accent1', 0.310, 0.506, 0.741, 213, 0.455, 0.525, 1, 0.481, '4f81bd', '#4f81bd');
                 verifyColor('scheme', 'accent2', 0.753, 0.314, 0.302, 2, 0.477, 0.527, 1, 0.406, 'c0504d', '#c0504d');
                 verifyColor('scheme', 'accent3', 0.608, 0.733, 0.349, 80, 0.419, 0.541, 1, 0.679, '9bbb59', '#9bbb59');
                 verifyColor('scheme', 'accent4', 0.502, 0.392, 0.635, 267, 0.25, 0.514, 1, 0.433, '8064a2', '#8064a2');
@@ -411,29 +423,29 @@ define([
                 verifyColor('crgb', { r: 25000, g: 50000, b: 75000 }, 0.543, 0.737, 0.881, 206, 0.587, 0.712, 1, 0.706, '8abce1', '#8abce1');
             });
             it('should return color descriptor for HSL colors', function () {
-                verifyColor('hsl', { h: 0, s: 0, l: 0 }, 0, 0, 0, 0, 0, 0, 1, 0, '000000', '#000000');
-                verifyColor('hsl', { h: 90000, s: 0, l: 0 }, 0, 0, 0, 90, 0, 0, 1, 0, '000000', '#000000');
-                verifyColor('hsl', { h: 180000, s: 0, l: 0 }, 0, 0, 0, 180, 0, 0, 1, 0, '000000', '#000000');
-                verifyColor('hsl', { h: 270000, s: 0, l: 0 }, 0, 0, 0, 270, 0, 0, 1, 0, '000000', '#000000');
-                verifyColor('hsl', { h: 0, s: 25000, l: 0 }, 0, 0, 0, 0, 0.25, 0, 1, 0, '000000', '#000000');
-                verifyColor('hsl', { h: 90000, s: 50000, l: 0 }, 0, 0, 0, 90, 0.5, 0, 1, 0, '000000', '#000000');
-                verifyColor('hsl', { h: 180000, s: 75000, l: 0 }, 0, 0, 0, 180, 0.75, 0, 1, 0, '000000', '#000000');
-                verifyColor('hsl', { h: 270000, s: 100000, l: 0 }, 0, 0, 0, 270, 1, 0, 1, 0, '000000', '#000000');
-                verifyColor('hsl', { h: 0, s: 0, l: 25000 }, 0.25, 0.25, 0.25, 0, 0, 0.25, 1, 0.25, '404040', '#404040');
-                verifyColor('hsl', { h: 90000, s: 0, l: 50000 }, 0.5, 0.5, 0.5, 90, 0, 0.5, 1, 0.5, '808080', '#808080');
-                verifyColor('hsl', { h: 180000, s: 0, l: 75000 }, 0.75, 0.75, 0.75, 180, 0, 0.75, 1, 0.75, 'bfbfbf', '#bfbfbf');
-                verifyColor('hsl', { h: 270000, s: 0, l: 100000 }, 1, 1, 1, 270, 0, 1, 1, 1, 'ffffff', '#ffffff');
-                verifyColor('hsl', { h: 0, s: 50000, l: 100000 }, 1, 1, 1, 0, 0.5, 1, 1, 1, 'ffffff', '#ffffff');
-                verifyColor('hsl', { h: 180000, s: 100000, l: 100000 }, 1, 1, 1, 180, 1, 1, 1, 1, 'ffffff', '#ffffff');
-                verifyColor('hsl', { h: 10000, s: 20000, l: 20000 }, 0.24, 0.173, 0.16, 10, 0.2, 0.2, 1, 0.187, '3d2c29', '#3d2c29');
-                verifyColor('hsl', { h: 50000, s: 20000, l: 50000 }, 0.6, 0.567, 0.4, 50, 0.2, 0.5, 1, 0.562, '999166', '#999166');
-                verifyColor('hsl', { h: 90000, s: 20000, l: 80000 }, 0.8, 0.84, 0.76, 90, 0.2, 0.8, 1, 0.826, 'ccd6c2', '#ccd6c2');
-                verifyColor('hsl', { h: 130000, s: 50000, l: 20000 }, 0.1, 0.3, 0.133, 130, 0.5, 0.2, 1, 0.245, '1a4d22', '#1a4d22');
-                verifyColor('hsl', { h: 170000, s: 50000, l: 50000 }, 0.25, 0.75, 0.667, 170, 0.5, 0.5, 1, 0.638, '40bfaa', '#40bfaa');
-                verifyColor('hsl', { h: 210000, s: 50000, l: 80000 }, 0.7, 0.8, 0.9, 210, 0.5, 0.8, 1, 0.786, 'b3cce6', '#b3cce6');
-                verifyColor('hsl', { h: 250000, s: 80000, l: 20000 }, 0.093, 0.04, 0.36, 250, 0.8, 0.2, 1, 0.074, '180a5c', '#180a5c');
-                verifyColor('hsl', { h: 290000, s: 80000, l: 50000 }, 0.767, 0.1, 0.9, 290, 0.8, 0.5, 1, 0.299, 'c41ae6', '#c41ae6');
-                verifyColor('hsl', { h: 330000, s: 80000, l: 80000 }, 0.96, 0.64, 0.8, 330, 0.8, 0.8, 1, 0.72, 'f5a3cc', '#f5a3cc');
+                verifyColor('hsl', { h: 0, s: 0, l: 0 }, 0, 0, 0, 0, 0, 0, 1, 0, '000000', 'hsl(0,0%,0%)');
+                verifyColor('hsl', { h: 90000, s: 0, l: 0 }, 0, 0, 0, 90, 0, 0, 1, 0, '000000', 'hsl(90,0%,0%)');
+                verifyColor('hsl', { h: 180000, s: 0, l: 0 }, 0, 0, 0, 180, 0, 0, 1, 0, '000000', 'hsl(180,0%,0%)');
+                verifyColor('hsl', { h: 270000, s: 0, l: 0 }, 0, 0, 0, 270, 0, 0, 1, 0, '000000', 'hsl(270,0%,0%)');
+                verifyColor('hsl', { h: 0, s: 25000, l: 0 }, 0, 0, 0, 0, 0.25, 0, 1, 0, '000000', 'hsl(0,25%,0%)');
+                verifyColor('hsl', { h: 90000, s: 50000, l: 0 }, 0, 0, 0, 90, 0.5, 0, 1, 0, '000000', 'hsl(90,50%,0%)');
+                verifyColor('hsl', { h: 180000, s: 75000, l: 0 }, 0, 0, 0, 180, 0.75, 0, 1, 0, '000000', 'hsl(180,75%,0%)');
+                verifyColor('hsl', { h: 270000, s: 100000, l: 0 }, 0, 0, 0, 270, 1, 0, 1, 0, '000000', 'hsl(270,100%,0%)');
+                verifyColor('hsl', { h: 0, s: 0, l: 25000 }, 0.25, 0.25, 0.25, 0, 0, 0.25, 1, 0.25, '404040', 'hsl(0,0%,25%)');
+                verifyColor('hsl', { h: 90000, s: 0, l: 50000 }, 0.5, 0.5, 0.5, 90, 0, 0.5, 1, 0.5, '808080', 'hsl(90,0%,50%)');
+                verifyColor('hsl', { h: 180000, s: 0, l: 75000 }, 0.75, 0.75, 0.75, 180, 0, 0.75, 1, 0.75, 'bfbfbf', 'hsl(180,0%,75%)');
+                verifyColor('hsl', { h: 270000, s: 0, l: 100000 }, 1, 1, 1, 270, 0, 1, 1, 1, 'ffffff', 'hsl(270,0%,100%)');
+                verifyColor('hsl', { h: 0, s: 50000, l: 100000 }, 1, 1, 1, 0, 0.5, 1, 1, 1, 'ffffff', 'hsl(0,50%,100%)');
+                verifyColor('hsl', { h: 180000, s: 100000, l: 100000 }, 1, 1, 1, 180, 1, 1, 1, 1, 'ffffff', 'hsl(180,100%,100%)');
+                verifyColor('hsl', { h: 10000, s: 20000, l: 20000 }, 0.24, 0.173, 0.16, 10, 0.2, 0.2, 1, 0.187, '3d2c29', 'hsl(10,20%,20%)');
+                verifyColor('hsl', { h: 50000, s: 20000, l: 50000 }, 0.6, 0.567, 0.4, 50, 0.2, 0.5, 1, 0.562, '999166', 'hsl(50,20%,50%)');
+                verifyColor('hsl', { h: 90000, s: 20000, l: 80000 }, 0.8, 0.84, 0.76, 90, 0.2, 0.8, 1, 0.826, 'ccd6c2', 'hsl(90,20%,80%)');
+                verifyColor('hsl', { h: 130000, s: 50000, l: 20000 }, 0.1, 0.3, 0.133, 130, 0.5, 0.2, 1, 0.245, '1a4d22', 'hsl(130,50%,20%)');
+                verifyColor('hsl', { h: 170000, s: 50000, l: 50000 }, 0.25, 0.75, 0.667, 170, 0.5, 0.5, 1, 0.638, '40bfaa', 'hsl(170,50%,50%)');
+                verifyColor('hsl', { h: 210000, s: 50000, l: 80000 }, 0.7, 0.8, 0.9, 210, 0.5, 0.8, 1, 0.786, 'b3cce6', 'hsl(210,50%,80%)');
+                verifyColor('hsl', { h: 250000, s: 80000, l: 20000 }, 0.093, 0.04, 0.36, 250, 0.8, 0.2, 1, 0.074, '180a5c', 'hsl(250,80%,20%)');
+                verifyColor('hsl', { h: 290000, s: 80000, l: 50000 }, 0.767, 0.1, 0.9, 290, 0.8, 0.5, 1, 0.299, 'c41ae6', 'hsl(290,80%,50%)');
+                verifyColor('hsl', { h: 330000, s: 80000, l: 80000 }, 0.96, 0.64, 0.8, 330, 0.8, 0.8, 1, 0.72, 'f5a3cc', 'hsl(330,80%,80%)');
             });
             it('should return "dark" flag', function () {
                 expect(new Color('preset', 'black').resolve('')).to.have.a.property('dark', true);
@@ -547,106 +559,106 @@ define([
                 verifyTransformedColor('#666666', 'blueOff', 80000, 0.4, 0.4, 1, 240, 1, 0.7, 1, 0.443, '6666ff', '#6666ff');
             });
             it('should resolve color with "hue" transformation', function () {
-                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 0, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', '#8f3d3d');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 60000, 0.56, 0.56, 0.24, 60, 0.4, 0.4, 1, 0.537, '8f8f3d', '#8f8f3d');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 120000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', '#3d8f3d');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 180000, 0.24, 0.56, 0.56, 180, 0.4, 0.4, 1, 0.492, '3d8f8f', '#3d8f8f');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 240000, 0.24, 0.24, 0.56, 240, 0.4, 0.4, 1, 0.263, '3d3d8f', '#3d3d8f');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 300000, 0.56, 0.24, 0.56, 300, 0.4, 0.4, 1, 0.331, '8f3d8f', '#8f3d8f');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 360000, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', '#8f3d3d');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 0, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', 'hsl(0,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 60000, 0.56, 0.56, 0.24, 60, 0.4, 0.4, 1, 0.537, '8f8f3d', 'hsl(60,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 120000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', 'hsl(120,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 180000, 0.24, 0.56, 0.56, 180, 0.4, 0.4, 1, 0.492, '3d8f8f', 'hsl(180,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 240000, 0.24, 0.24, 0.56, 240, 0.4, 0.4, 1, 0.263, '3d3d8f', 'hsl(240,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 300000, 0.56, 0.24, 0.56, 300, 0.4, 0.4, 1, 0.331, '8f3d8f', 'hsl(300,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hue', 360000, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', 'hsl(0,40%,40%)');
             });
             it('should resolve color with "hueMod" transformation', function () {
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 0, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', '#8f3d3d');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 50000, 0.56, 0.56, 0.24, 60, 0.4, 0.4, 1, 0.537, '8f8f3d', '#8f8f3d');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 100000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', '#3d8f3d');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 150000, 0.24, 0.56, 0.56, 180, 0.4, 0.4, 1, 0.492, '3d8f8f', '#3d8f8f');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 200000, 0.24, 0.24, 0.56, 240, 0.4, 0.4, 1, 0.263, '3d3d8f', '#3d3d8f');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 250000, 0.56, 0.24, 0.56, 300, 0.4, 0.4, 1, 0.331, '8f3d8f', '#8f3d8f');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 300000, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', '#8f3d3d');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 350000, 0.56, 0.56, 0.24, 60, 0.4, 0.4, 1, 0.537, '8f8f3d', '#8f8f3d');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 0, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', 'hsl(0,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 50000, 0.56, 0.56, 0.24, 60, 0.4, 0.4, 1, 0.537, '8f8f3d', 'hsl(60,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 100000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', 'hsl(120,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 150000, 0.24, 0.56, 0.56, 180, 0.4, 0.4, 1, 0.492, '3d8f8f', 'hsl(180,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 200000, 0.24, 0.24, 0.56, 240, 0.4, 0.4, 1, 0.263, '3d3d8f', 'hsl(240,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 250000, 0.56, 0.24, 0.56, 300, 0.4, 0.4, 1, 0.331, '8f3d8f', 'hsl(300,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 300000, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', 'hsl(0,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueMod', 350000, 0.56, 0.56, 0.24, 60, 0.4, 0.4, 1, 0.537, '8f8f3d', 'hsl(60,40%,40%)');
             });
             it('should resolve color with "hueOff" transformation', function () {
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', -300000, 0.24, 0.56, 0.56, 180, 0.4, 0.4, 1, 0.492, '3d8f8f', '#3d8f8f');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', -240000, 0.24, 0.24, 0.56, 240, 0.4, 0.4, 1, 0.263, '3d3d8f', '#3d3d8f');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', -180000, 0.56, 0.24, 0.56, 300, 0.4, 0.4, 1, 0.331, '8f3d8f', '#8f3d8f');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', -120000, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', '#8f3d3d');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', -60000, 0.56, 0.56, 0.24, 60, 0.4, 0.4, 1, 0.537, '8f8f3d', '#8f8f3d');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 0, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', '#3d8f3d');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 60000, 0.24, 0.56, 0.56, 180, 0.4, 0.4, 1, 0.492, '3d8f8f', '#3d8f8f');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 120000, 0.24, 0.24, 0.56, 240, 0.4, 0.4, 1, 0.263, '3d3d8f', '#3d3d8f');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 180000, 0.56, 0.24, 0.56, 300, 0.4, 0.4, 1, 0.331, '8f3d8f', '#8f3d8f');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 240000, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', '#8f3d3d');
-                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 300000, 0.56, 0.56, 0.24, 60, 0.4, 0.4, 1, 0.537, '8f8f3d', '#8f8f3d');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', -300000, 0.24, 0.56, 0.56, 180, 0.4, 0.4, 1, 0.492, '3d8f8f', 'hsl(180,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', -240000, 0.24, 0.24, 0.56, 240, 0.4, 0.4, 1, 0.263, '3d3d8f', 'hsl(240,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', -180000, 0.56, 0.24, 0.56, 300, 0.4, 0.4, 1, 0.331, '8f3d8f', 'hsl(300,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', -120000, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', 'hsl(0,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', -60000, 0.56, 0.56, 0.24, 60, 0.4, 0.4, 1, 0.537, '8f8f3d', 'hsl(60,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 0, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', 'hsl(120,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 60000, 0.24, 0.56, 0.56, 180, 0.4, 0.4, 1, 0.492, '3d8f8f', 'hsl(180,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 120000, 0.24, 0.24, 0.56, 240, 0.4, 0.4, 1, 0.263, '3d3d8f', 'hsl(240,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 180000, 0.56, 0.24, 0.56, 300, 0.4, 0.4, 1, 0.331, '8f3d8f', 'hsl(300,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 240000, 0.56, 0.24, 0.24, 0, 0.4, 0.4, 1, 0.308, '8f3d3d', 'hsl(0,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'hueOff', 300000, 0.56, 0.56, 0.24, 60, 0.4, 0.4, 1, 0.537, '8f8f3d', 'hsl(60,40%,40%)');
             });
             it('should resolve color with "sat" transformation', function () {
-                verifyTransformedColor('hsl(120,40%,40%)', 'sat', 0, 0.4, 0.4, 0.4, 120, 0, 0.4, 1, 0.4, '666666', '#666666');
-                verifyTransformedColor('hsl(120,40%,40%)', 'sat', 20000, 0.32, 0.48, 0.32, 120, 0.2, 0.4, 1, 0.434, '527a52', '#527a52');
-                verifyTransformedColor('hsl(120,40%,40%)', 'sat', 40000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', '#3d8f3d');
-                verifyTransformedColor('hsl(120,40%,40%)', 'sat', 60000, 0.16, 0.64, 0.16, 120, 0.6, 0.4, 1, 0.503, '29a329', '#29a329');
-                verifyTransformedColor('hsl(120,40%,40%)', 'sat', 80000, 0.08, 0.72, 0.08, 120, 0.8, 0.4, 1, 0.538, '14b814', '#14b814');
-                verifyTransformedColor('hsl(120,40%,40%)', 'sat', 100000, 0, 0.8, 0, 120, 1, 0.4, 1, 0.572, '00cc00', '#00cc00');
+                verifyTransformedColor('hsl(120,40%,40%)', 'sat', 0, 0.4, 0.4, 0.4, 120, 0, 0.4, 1, 0.4, '666666', 'hsl(120,0%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'sat', 20000, 0.32, 0.48, 0.32, 120, 0.2, 0.4, 1, 0.434, '527a52', 'hsl(120,20%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'sat', 40000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', 'hsl(120,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'sat', 60000, 0.16, 0.64, 0.16, 120, 0.6, 0.4, 1, 0.503, '29a329', 'hsl(120,60%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'sat', 80000, 0.08, 0.72, 0.08, 120, 0.8, 0.4, 1, 0.538, '14b814', 'hsl(120,80%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'sat', 100000, 0, 0.8, 0, 120, 1, 0.4, 1, 0.572, '00cc00', 'hsl(120,100%,40%)');
             });
             it('should resolve color with "satMod" transformation', function () {
-                verifyTransformedColor('hsl(120,40%,40%)', 'satMod', 0, 0.4, 0.4, 0.4, 120, 0, 0.4, 1, 0.4, '666666', '#666666');
-                verifyTransformedColor('hsl(120,40%,40%)', 'satMod', 50000, 0.32, 0.48, 0.32, 120, 0.2, 0.4, 1, 0.434, '527a52', '#527a52');
-                verifyTransformedColor('hsl(120,40%,40%)', 'satMod', 100000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', '#3d8f3d');
-                verifyTransformedColor('hsl(120,40%,40%)', 'satMod', 150000, 0.16, 0.64, 0.16, 120, 0.6, 0.4, 1, 0.503, '29a329', '#29a329');
-                verifyTransformedColor('hsl(120,40%,40%)', 'satMod', 200000, 0.08, 0.72, 0.08, 120, 0.8, 0.4, 1, 0.538, '14b814', '#14b814');
-                verifyTransformedColor('hsl(120,40%,40%)', 'satMod', 250000, 0, 0.8, 0, 120, 1, 0.4, 1, 0.572, '00cc00', '#00cc00');
-                verifyTransformedColor('hsl(120,40%,40%)', 'satMod', 300000, 0, 0.8, 0, 120, 1, 0.4, 1, 0.572, '00cc00', '#00cc00');
+                verifyTransformedColor('hsl(120,40%,40%)', 'satMod', 0, 0.4, 0.4, 0.4, 120, 0, 0.4, 1, 0.4, '666666', 'hsl(120,0%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'satMod', 50000, 0.32, 0.48, 0.32, 120, 0.2, 0.4, 1, 0.434, '527a52', 'hsl(120,20%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'satMod', 100000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', 'hsl(120,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'satMod', 150000, 0.16, 0.64, 0.16, 120, 0.6, 0.4, 1, 0.503, '29a329', 'hsl(120,60%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'satMod', 200000, 0.08, 0.72, 0.08, 120, 0.8, 0.4, 1, 0.538, '14b814', 'hsl(120,80%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'satMod', 250000, 0, 0.8, 0, 120, 1, 0.4, 1, 0.572, '00cc00', 'hsl(120,100%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'satMod', 300000, 0, 0.8, 0, 120, 1, 0.4, 1, 0.572, '00cc00', 'hsl(120,100%,40%)');
             });
             it('should resolve color with "satOff" transformation', function () {
-                verifyTransformedColor('hsl(120,40%,40%)', 'satOff', -60000, 0.4, 0.4, 0.4, 120, 0, 0.4, 1, 0.4, '666666', '#666666');
-                verifyTransformedColor('hsl(120,40%,40%)', 'satOff', -40000, 0.4, 0.4, 0.4, 120, 0, 0.4, 1, 0.4, '666666', '#666666');
-                verifyTransformedColor('hsl(120,40%,40%)', 'satOff', -20000, 0.32, 0.48, 0.32, 120, 0.2, 0.4, 1, 0.434, '527a52', '#527a52');
-                verifyTransformedColor('hsl(120,40%,40%)', 'satOff', 0, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', '#3d8f3d');
-                verifyTransformedColor('hsl(120,40%,40%)', 'satOff', 20000, 0.16, 0.64, 0.16, 120, 0.6, 0.4, 1, 0.503, '29a329', '#29a329');
-                verifyTransformedColor('hsl(120,40%,40%)', 'satOff', 40000, 0.08, 0.72, 0.08, 120, 0.8, 0.4, 1, 0.538, '14b814', '#14b814');
-                verifyTransformedColor('hsl(120,40%,40%)', 'satOff', 60000, 0, 0.8, 0, 120, 1, 0.4, 1, 0.572, '00cc00', '#00cc00');
-                verifyTransformedColor('hsl(120,40%,40%)', 'satOff', 80000, 0, 0.8, 0, 120, 1, 0.4, 1, 0.572, '00cc00', '#00cc00');
+                verifyTransformedColor('hsl(120,40%,40%)', 'satOff', -60000, 0.4, 0.4, 0.4, 120, 0, 0.4, 1, 0.4, '666666', 'hsl(120,0%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'satOff', -40000, 0.4, 0.4, 0.4, 120, 0, 0.4, 1, 0.4, '666666', 'hsl(120,0%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'satOff', -20000, 0.32, 0.48, 0.32, 120, 0.2, 0.4, 1, 0.434, '527a52', 'hsl(120,20%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'satOff', 0, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', 'hsl(120,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'satOff', 20000, 0.16, 0.64, 0.16, 120, 0.6, 0.4, 1, 0.503, '29a329', 'hsl(120,60%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'satOff', 40000, 0.08, 0.72, 0.08, 120, 0.8, 0.4, 1, 0.538, '14b814', 'hsl(120,80%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'satOff', 60000, 0, 0.8, 0, 120, 1, 0.4, 1, 0.572, '00cc00', 'hsl(120,100%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'satOff', 80000, 0, 0.8, 0, 120, 1, 0.4, 1, 0.572, '00cc00', 'hsl(120,100%,40%)');
             });
             it('should resolve color with "lum" transformation', function () {
-                verifyTransformedColor('hsl(120,40%,40%)', 'lum', 0, 0, 0, 0, 120, 0.4, 0, 1, 0, '000000', '#000000');
-                verifyTransformedColor('hsl(120,40%,40%)', 'lum', 20000, 0.12, 0.28, 0.12, 120, 0.4, 0.2, 1, 0.234, '1f471f', '#1f471f');
-                verifyTransformedColor('hsl(120,40%,40%)', 'lum', 40000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', '#3d8f3d');
-                verifyTransformedColor('hsl(120,40%,40%)', 'lum', 60000, 0.44, 0.76, 0.44, 120, 0.4, 0.6, 1, 0.669, '70c270', '#70c270');
-                verifyTransformedColor('hsl(120,40%,40%)', 'lum', 80000, 0.72, 0.88, 0.72, 120, 0.4, 0.8, 1, 0.834, 'b8e0b8', '#b8e0b8');
-                verifyTransformedColor('hsl(120,40%,40%)', 'lum', 100000, 1, 1, 1, 120, 0.4, 1, 1, 1, 'ffffff', '#ffffff');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lum', 0, 0, 0, 0, 120, 0.4, 0, 1, 0, '000000', 'hsl(120,40%,0%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lum', 20000, 0.12, 0.28, 0.12, 120, 0.4, 0.2, 1, 0.234, '1f471f', 'hsl(120,40%,20%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lum', 40000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', 'hsl(120,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lum', 60000, 0.44, 0.76, 0.44, 120, 0.4, 0.6, 1, 0.669, '70c270', 'hsl(120,40%,60%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lum', 80000, 0.72, 0.88, 0.72, 120, 0.4, 0.8, 1, 0.834, 'b8e0b8', 'hsl(120,40%,80%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lum', 100000, 1, 1, 1, 120, 0.4, 1, 1, 1, 'ffffff', 'hsl(120,40%,100%)');
             });
             it('should resolve color with "lumMod" transformation', function () {
-                verifyTransformedColor('hsl(120,40%,40%)', 'lumMod', 0, 0, 0, 0, 120, 0.4, 0, 1, 0, '000000', '#000000');
-                verifyTransformedColor('hsl(120,40%,40%)', 'lumMod', 50000, 0.12, 0.28, 0.12, 120, 0.4, 0.2, 1, 0.234, '1f471f', '#1f471f');
-                verifyTransformedColor('hsl(120,40%,40%)', 'lumMod', 100000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', '#3d8f3d');
-                verifyTransformedColor('hsl(120,40%,40%)', 'lumMod', 150000, 0.44, 0.76, 0.44, 120, 0.4, 0.6, 1, 0.669, '70c270', '#70c270');
-                verifyTransformedColor('hsl(120,40%,40%)', 'lumMod', 200000, 0.72, 0.88, 0.72, 120, 0.4, 0.8, 1, 0.834, 'b8e0b8', '#b8e0b8');
-                verifyTransformedColor('hsl(120,40%,40%)', 'lumMod', 250000, 1, 1, 1, 120, 0.4, 1, 1, 1, 'ffffff', '#ffffff');
-                verifyTransformedColor('hsl(120,40%,40%)', 'lumMod', 300000, 1, 1, 1, 120, 0.4, 1, 1, 1, 'ffffff', '#ffffff');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lumMod', 0, 0, 0, 0, 120, 0.4, 0, 1, 0, '000000', 'hsl(120,40%,0%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lumMod', 50000, 0.12, 0.28, 0.12, 120, 0.4, 0.2, 1, 0.234, '1f471f', 'hsl(120,40%,20%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lumMod', 100000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', 'hsl(120,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lumMod', 150000, 0.44, 0.76, 0.44, 120, 0.4, 0.6, 1, 0.669, '70c270', 'hsl(120,40%,60%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lumMod', 200000, 0.72, 0.88, 0.72, 120, 0.4, 0.8, 1, 0.834, 'b8e0b8', 'hsl(120,40%,80%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lumMod', 250000, 1, 1, 1, 120, 0.4, 1, 1, 1, 'ffffff', 'hsl(120,40%,100%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lumMod', 300000, 1, 1, 1, 120, 0.4, 1, 1, 1, 'ffffff', 'hsl(120,40%,100%)');
             });
             it('should resolve color with "lumOff" transformation', function () {
-                verifyTransformedColor('hsl(120,40%,40%)', 'lumOff', -60000, 0, 0, 0, 120, 0.4, 0, 1, 0, '000000', '#000000');
-                verifyTransformedColor('hsl(120,40%,40%)', 'lumOff', -40000, 0, 0, 0, 120, 0.4, 0, 1, 0, '000000', '#000000');
-                verifyTransformedColor('hsl(120,40%,40%)', 'lumOff', -20000, 0.12, 0.28, 0.12, 120, 0.4, 0.2, 1, 0.234, '1f471f', '#1f471f');
-                verifyTransformedColor('hsl(120,40%,40%)', 'lumOff', 0, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', '#3d8f3d');
-                verifyTransformedColor('hsl(120,40%,40%)', 'lumOff', 20000, 0.44, 0.76, 0.44, 120, 0.4, 0.6, 1, 0.669, '70c270', '#70c270');
-                verifyTransformedColor('hsl(120,40%,40%)', 'lumOff', 40000, 0.72, 0.88, 0.72, 120, 0.4, 0.8, 1, 0.834, 'b8e0b8', '#b8e0b8');
-                verifyTransformedColor('hsl(120,40%,40%)', 'lumOff', 60000, 1, 1, 1, 120, 0.4, 1, 1, 1, 'ffffff', '#ffffff');
-                verifyTransformedColor('hsl(120,40%,40%)', 'lumOff', 80000, 1, 1, 1, 120, 0.4, 1, 1, 1, 'ffffff', '#ffffff');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lumOff', -60000, 0, 0, 0, 120, 0.4, 0, 1, 0, '000000', 'hsl(120,40%,0%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lumOff', -40000, 0, 0, 0, 120, 0.4, 0, 1, 0, '000000', 'hsl(120,40%,0%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lumOff', -20000, 0.12, 0.28, 0.12, 120, 0.4, 0.2, 1, 0.234, '1f471f', 'hsl(120,40%,20%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lumOff', 0, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', 'hsl(120,40%,40%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lumOff', 20000, 0.44, 0.76, 0.44, 120, 0.4, 0.6, 1, 0.669, '70c270', 'hsl(120,40%,60%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lumOff', 40000, 0.72, 0.88, 0.72, 120, 0.4, 0.8, 1, 0.834, 'b8e0b8', 'hsl(120,40%,80%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lumOff', 60000, 1, 1, 1, 120, 0.4, 1, 1, 1, 'ffffff', 'hsl(120,40%,100%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'lumOff', 80000, 1, 1, 1, 120, 0.4, 1, 1, 1, 'ffffff', 'hsl(120,40%,100%)');
             });
             it('should resolve color with "shade" transformation', function () {
-                verifyTransformedColor('hsl(120,40%,40%)', 'shade', 0, 0, 0, 0, 120, 0.4, 0, 1, 0, '000000', '#000000');
-                verifyTransformedColor('hsl(120,40%,40%)', 'shade', 25000, 0.06, 0.14, 0.06, 120, 0.4, 0.1, 1, 0.117, '0f240f', '#0f240f');
-                verifyTransformedColor('hsl(120,40%,40%)', 'shade', 50000, 0.12, 0.28, 0.12, 120, 0.4, 0.2, 1, 0.234, '1f471f', '#1f471f');
-                verifyTransformedColor('hsl(120,40%,40%)', 'shade', 75000, 0.18, 0.42, 0.18, 120, 0.4, 0.3, 1, 0.352, '2e6b2e', '#2e6b2e');
-                verifyTransformedColor('hsl(120,40%,40%)', 'shade', 100000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', '#3d8f3d');
-                verifyTransformedColor('orange', 'shade', 50000, 0.5, 0.324, 0, 39, 1, 0.25, 1, 0.338, '805300', '#805300');
+                verifyTransformedColor('hsl(120,40%,40%)', 'shade', 0, 0, 0, 0, 120, 0.4, 0, 1, 0, '000000', 'hsl(120,40%,0%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'shade', 25000, 0.06, 0.14, 0.06, 120, 0.4, 0.1, 1, 0.117, '0f240f', 'hsl(120,40%,10%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'shade', 50000, 0.12, 0.28, 0.12, 120, 0.4, 0.2, 1, 0.234, '1f471f', 'hsl(120,40%,20%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'shade', 75000, 0.18, 0.42, 0.18, 120, 0.4, 0.3, 1, 0.352, '2e6b2e', 'hsl(120,40%,30%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'shade', 100000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', 'hsl(120,40%,40%)');
+                verifyTransformedColor('orange', 'shade', 50000, 0.5, 0.324, 0, 39, 1, 0.25, 1, 0.338, '805300', 'hsl(39,100%,25%)');
             });
             it('should resolve color with "tint" transformation', function () {
-                verifyTransformedColor('hsl(120,40%,40%)', 'tint', 0, 1, 1, 1, 120, 0.4, 1, 1, 1, 'ffffff', '#ffffff');
-                verifyTransformedColor('hsl(120,40%,40%)', 'tint', 25000, 0.79, 0.91, 0.79, 120, 0.4, 0.85, 1, 0.876, 'c9e8c9', '#c9e8c9');
-                verifyTransformedColor('hsl(120,40%,40%)', 'tint', 50000, 0.58, 0.82, 0.58, 120, 0.4, 0.7, 1, 0.752, '94d194', '#94d194');
-                verifyTransformedColor('hsl(120,40%,40%)', 'tint', 75000, 0.37, 0.73, 0.37, 120, 0.4, 0.55, 1, 0.627, '5eba5e', '#5eba5e');
-                verifyTransformedColor('hsl(120,40%,40%)', 'tint', 100000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', '#3d8f3d');
-                verifyTransformedColor('orange', 'tint', 50000, 1, 0.824, 0.5, 39, 1, 0.75, 1, 0.838, 'ffd280', '#ffd280');
+                verifyTransformedColor('hsl(120,40%,40%)', 'tint', 0, 1, 1, 1, 120, 0.4, 1, 1, 1, 'ffffff', 'hsl(120,40%,100%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'tint', 25000, 0.79, 0.91, 0.79, 120, 0.4, 0.85, 1, 0.876, 'c9e8c9', 'hsl(120,40%,85%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'tint', 50000, 0.58, 0.82, 0.58, 120, 0.4, 0.7, 1, 0.752, '94d194', 'hsl(120,40%,70%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'tint', 75000, 0.37, 0.73, 0.37, 120, 0.4, 0.55, 1, 0.627, '5eba5e', 'hsl(120,40%,55%)');
+                verifyTransformedColor('hsl(120,40%,40%)', 'tint', 100000, 0.24, 0.56, 0.24, 120, 0.4, 0.4, 1, 0.469, '3d8f3d', 'hsl(120,40%,40%)');
+                verifyTransformedColor('orange', 'tint', 50000, 1, 0.824, 0.5, 39, 1, 0.75, 1, 0.838, 'ffd280', 'hsl(39,100%,75%)');
             });
             it('should resolve color with "gamma" transformation', function () {
                 verifyTransformedColor('rgb(200,100,50)', 'gamma', null, 0.899, 0.662, 0.488, 25, 0.669, 0.693, 1, 0.7, 'e5a97c', '#e5a97c');
@@ -657,8 +669,8 @@ define([
                 verifyTransformedColor('hsl(135,40%,40%)', 'invGamma', null, 0.039, 0.268, 0.075, 129, 0.745, 0.154, 1, 0.206, '0a4413', '#0a4413');
             });
             it('should resolve color with "comp" transformation', function () {
-                verifyTransformedColor('rgb(200,100,50)', 'comp', null, 0.196, 0.588, 0.784, 200, 0.6, 0.49, 1, 0.519, '3296c8', '#3296c8');
-                verifyTransformedColor('hsl(135,40%,40%)', 'comp', null, 0.56, 0.24, 0.48, 315, 0.4, 0.4, 1, 0.325, '8f3d7a', '#8f3d7a');
+                verifyTransformedColor('rgb(200,100,50)', 'comp', null, 0.196, 0.588, 0.784, 200, 0.6, 0.49, 1, 0.519, '3296c8', 'hsl(200,60%,49%)');
+                verifyTransformedColor('hsl(135,40%,40%)', 'comp', null, 0.56, 0.24, 0.48, 315, 0.4, 0.4, 1, 0.325, '8f3d7a', 'hsl(315,40%,40%)');
             });
             it('should resolve color with "inv" transformation', function () {
                 verifyTransformedColor('rgb(200,100,50)', 'inv', null, 0.216, 0.608, 0.804, 200, 0.6, 0.51, 1, 0.539, '379bcd', '#379bcd');
