@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -56,90 +57,94 @@ define([
                         }
                     }
                 },
-                { name: 'insertMasterSlide', id: masterId_1, attrs:
-                    { listStyles: {
-                        title: { l1: {
-                            character: { fontSize: 44, fontName: '+mj-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                            paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'percent', value: 0 }, defaultTabSize: 2540, bullet: { type: 'none' }, alignment: 'left' } }
-                        },
-                        body: {
-                            l1: {
-                                character: { fontSize: 28, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                                paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'fixed', value: 35 }, defaultTabSize: 2540, bullet: { type: 'character', character: '-' }, bulletFont: { followText: false, name: 'Arial' }, alignment: 'left', indentLeft: 635, indentFirstLine: -634 }
+                {
+                    name: 'insertMasterSlide', id: masterId_1, attrs: {
+                        listStyles: {
+                            title: {
+                                l1: {
+                                    character: { fontSize: 44, fontName: '+mj-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'percent', value: 0 }, defaultTabSize: 2540, bullet: { type: 'none' }, alignment: 'left' }
+                                }
                             },
-                            l2: {
-                                character: { fontSize: 24, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                                paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'fixed', value: 17 }, defaultTabSize: 2540, bullet: { type: 'character', character: '•' }, bulletFont: { followText: false, name: 'Arial' }, alignment: 'left', indentLeft: 1905, indentFirstLine: -634 }
+                            body: {
+                                l1: {
+                                    character: { fontSize: 28, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'fixed', value: 35 }, defaultTabSize: 2540, bullet: { type: 'character', character: '-' }, bulletFont: { followText: false, name: 'Arial' }, alignment: 'left', indentLeft: 635, indentFirstLine: -634 }
+                                },
+                                l2: {
+                                    character: { fontSize: 24, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'fixed', value: 17 }, defaultTabSize: 2540, bullet: { type: 'character', character: '\u2022' }, bulletFont: { followText: false, name: 'Arial' }, alignment: 'left', indentLeft: 1905, indentFirstLine: -634 }
+                                },
+                                l3: {
+                                    character: { fontSize: 20, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'fixed', value: 17 }, defaultTabSize: 2540, bullet: { type: 'character', character: '\u2022' }, bulletFont: { followText: false, name: 'Arial' }, alignment: 'left', indentLeft: 3175, indentFirstLine: -634 }
+                                },
+                                l4: {
+                                    character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'fixed', value: 17 }, defaultTabSize: 2540, bullet: { type: 'character', character: '\u2022' }, bulletFont: { followText: false, name: 'Arial' }, alignment: 'left', indentLeft: 4445, indentFirstLine: -634 }
+                                },
+                                l5: {
+                                    character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'fixed', value: 17 }, defaultTabSize: 2540, bullet: { type: 'character', character: '\u2022' }, bulletFont: { followText: false, name: 'Arial' }, alignment: 'left', indentLeft: 5715, indentFirstLine: -634 }
+                                },
+                                l6: {
+                                    character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'fixed', value: 17 }, defaultTabSize: 2540, bullet: { type: 'character', character: '\u2022' }, bulletFont: { followText: false, name: 'Arial' }, alignment: 'left', indentLeft: 6985, indentFirstLine: -634 }
+                                },
+                                l7: {
+                                    character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'fixed', value: 17 }, defaultTabSize: 2540, bullet: { type: 'character', character: '\u2022' }, bulletFont: { followText: false, name: 'Arial' }, alignment: 'left', indentLeft: 8255, indentFirstLine: -634 }
+                                },
+                                l8: {
+                                    character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'fixed', value: 17 }, defaultTabSize: 2540, bullet: { type: 'character', character: '\u2022' }, bulletFont: { followText: false, name: 'Arial' }, alignment: 'left', indentLeft: 9525, indentFirstLine: -634 }
+                                },
+                                l9: {
+                                    character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'fixed', value: 17 }, defaultTabSize: 2540, bullet: { type: 'character', character: '\u2022' }, bulletFont: { followText: false, name: 'Arial' }, alignment: 'left', indentLeft: 10795, indentFirstLine: -634 }
+                                }
                             },
-                            l3: {
-                                character: { fontSize: 20, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                                paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'fixed', value: 17 }, defaultTabSize: 2540, bullet: { type: 'character', character: '•' }, bulletFont: { followText: false, name: 'Arial' }, alignment: 'left', indentLeft: 3175, indentFirstLine: -634 }
-                            },
-                            l4: {
-                                character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                                paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'fixed', value: 17 }, defaultTabSize: 2540, bullet: { type: 'character', character: '•' }, bulletFont: { followText: false, name: 'Arial' }, alignment: 'left', indentLeft: 4445, indentFirstLine: -634 }
-                            },
-                            l5: {
-                                character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                                paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'fixed', value: 17 }, defaultTabSize: 2540, bullet: { type: 'character', character: '•' }, bulletFont: { followText: false, name: 'Arial' }, alignment: 'left', indentLeft: 5715, indentFirstLine: -634 }
-                            },
-                            l6: {
-                                character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                                paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'fixed', value: 17 }, defaultTabSize: 2540, bullet: { type: 'character', character: '•' }, bulletFont: { followText: false, name: 'Arial' }, alignment: 'left', indentLeft: 6985, indentFirstLine: -634 }
-                            },
-                            l7: {
-                                character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                                paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'fixed', value: 17 }, defaultTabSize: 2540, bullet: { type: 'character', character: '•' }, bulletFont: { followText: false, name: 'Arial' }, alignment: 'left', indentLeft: 8255, indentFirstLine: -634 }
-                            },
-                            l8: {
-                                character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                                paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'fixed', value: 17 }, defaultTabSize: 2540, bullet: { type: 'character', character: '•' }, bulletFont: { followText: false, name: 'Arial' }, alignment: 'left', indentLeft: 9525, indentFirstLine: -634 }
-                            },
-                            l9: {
-                                character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                                paragraph: { lineHeight: { type: 'percent', value: 90 }, spacingBefore: { type: 'fixed', value: 17 }, defaultTabSize: 2540, bullet: { type: 'character', character: '•' }, bulletFont: { followText: false, name: 'Arial' }, alignment: 'left', indentLeft: 10795, indentFirstLine: -634 }
-                            }
-                        },
-                        other: {
-                            l1: {
-                                character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                                paragraph: { defaultTabSize: 2540, alignment: 'left', indentLeft: 0 }
-                            },
-                            l2: {
-                                character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                                paragraph: { defaultTabSize: 2540, alignment: 'left', indentLeft: 1270 }
-                            },
-                            l3: {
-                                character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                                paragraph: { defaultTabSize: 2540, alignment: 'left', indentLeft: 2540 }
-                            },
-                            l4: {
-                                character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                                paragraph: { defaultTabSize: 2540, alignment: 'left', indentLeft: 3810 }
-                            },
-                            l5: {
-                                character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                                paragraph: { defaultTabSize: 2540, alignment: 'left', indentLeft: 5080 }
-                            },
-                            l6: {
-                                character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                                paragraph: { defaultTabSize: 2540, alignment: 'left', indentLeft: 6350 }
-                            },
-                            l7: {
-                                character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                                paragraph: { defaultTabSize: 2540, alignment: 'left', indentLeft: 7620 }
-                            },
-                            l8: {
-                                character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                                paragraph: { defaultTabSize: 2540, alignment: 'left', indentLeft: 8890 }
-                            },
-                            l9: {
-                                character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
-                                paragraph: { defaultTabSize: 2540, alignment: 'left', indentLeft: 10160 }
+                            other: {
+                                l1: {
+                                    character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { defaultTabSize: 2540, alignment: 'left', indentLeft: 0 }
+                                },
+                                l2: {
+                                    character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { defaultTabSize: 2540, alignment: 'left', indentLeft: 1270 }
+                                },
+                                l3: {
+                                    character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { defaultTabSize: 2540, alignment: 'left', indentLeft: 2540 }
+                                },
+                                l4: {
+                                    character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { defaultTabSize: 2540, alignment: 'left', indentLeft: 3810 }
+                                },
+                                l5: {
+                                    character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { defaultTabSize: 2540, alignment: 'left', indentLeft: 5080 }
+                                },
+                                l6: {
+                                    character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { defaultTabSize: 2540, alignment: 'left', indentLeft: 6350 }
+                                },
+                                l7: {
+                                    character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { defaultTabSize: 2540, alignment: 'left', indentLeft: 7620 }
+                                },
+                                l8: {
+                                    character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { defaultTabSize: 2540, alignment: 'left', indentLeft: 8890 }
+                                },
+                                l9: {
+                                    character: { fontSize: 18, fontName: '+mn-lt', type: 'solid', color: { type: 'scheme', value: 'text1' } },
+                                    paragraph: { defaultTabSize: 2540, alignment: 'left', indentLeft: 10160 }
+                                }
                             }
                         }
                     }
-                } },
+                },
 //                { name: 'insertTheme', themeName: 'Office', target: masterId_1, attrs: { colorScheme: { dark1: '000000', dark2: '44546a', light1: 'ffffff', light2: 'e7e6e6', text1: '000000', text2: '44546a', background1: 'ffffff', background2: 'e7e6e6', accent1: '5b9bd5', accent2: 'ed7d31', accent3: 'a5a5a5', accent4: 'ffc000', accent5: '4472c4', accent6: '70ad47', hyperlink: '0563c1', followedHyperlink: '954f72' }}},
 //                { name: 'insertDrawing', start: [0, 0], target: masterId_1, type: 'shape', attrs: { presentation: { phType: 'title' }, shape: { anchor: 'centered', paddingLeft: 254, paddingRight: 254, paddingTop: 127, paddingBottom: 127 }, drawing: { name: 'T1', left: 2328, top: 1014, width: 29210, height: 3682 }, geometry: { presetShape: 'rect', avList: {} }}},
 //                { name: 'insertParagraph', start: [0, 0, 0], target: masterId_1 },
@@ -256,7 +261,7 @@ define([
                 expect(secondStandardDrawing.length).to.equal(1);
                 secondStandardParagraphs = secondStandardDrawing.find(DOM.PARAGRAPH_NODE_SELECTOR);
                 expect(secondStandardParagraphs.length).to.equal(6);
-                expect(DOM.isListParagraphNode(firstStandardParagraphs)).to.equal(true);
+                expect(DOM.isListParagraphNode(firstStandardParagraphs[0])).to.equal(false);
                 expect(DOM.isListParagraphNode(secondStandardParagraphs[0])).to.equal(true);
             });
         });
@@ -266,7 +271,7 @@ define([
                 expect(DOM).to.respondTo('isListLabelNode');
             });
             it('should check whether the specified node is a list label in a list paragraph', function () {
-                expect(DOM.isListLabelNode(firstStandardParagraphs[0].childNodes[0])).to.equal(true);
+                expect(DOM.isListLabelNode(firstStandardParagraphs[0].childNodes[0])).to.equal(false);
                 expect(DOM.isListLabelNode(secondStandardParagraphs[0].childNodes[0])).to.equal(true);
             });
         });
@@ -301,9 +306,7 @@ define([
             });
             it('should change the level of list indent for the specified paragraph', function () {
 
-                expect(firstStandardParagraphs[0].childNodes.length).to.equal(2);
-                expect($(firstStandardParagraphs[0].childNodes[0]).text()).to.equal('');
-                expect($(firstStandardParagraphs[0].childNodes[1]).text()).to.equal('Title');
+                expect($(firstStandardParagraphs[0].childNodes[0]).text()).to.equal('Title');
 
                 expect(secondStandardParagraphs[0].childNodes.length).to.equal(2);
                 expect($(secondStandardParagraphs[0].childNodes[0]).text()).to.equal('-');
