@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Michael Nimz <michael.nimz@open-xchange.com>
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
@@ -171,7 +172,7 @@ define([
                 expect(model.getSlideById(slideDefaultName).data('attributes').fill.type).to.equal('solid');
                 expect(model.getSlideById(slideDefaultName).css('background-color')).to.be.a('string').and.not.to.be.empty;
                 model.resetBackground();
-                expect(model.getSlideById(slideDefaultName).data('attributes').fill).to.equal(undefined);
+                expect(model.getSlideById(slideDefaultName).data('attributes').fill).to.be.undefined;
                 expect(model.getSlideById(slideDefaultName).css('background-color')).to.equal('');
             });
         });
@@ -181,7 +182,7 @@ define([
                 expect(model).to.respondTo('setBackgroundColor');
             });
             it('should set the slide background color', function () {
-                expect(model.getSlideById(slideDefaultName).data('attributes').fill).to.equal(undefined);
+                expect(model.getSlideById(slideDefaultName).data('attributes').fill).to.be.undefined;
                 expect(model.getSlideById(slideDefaultName).css('background-color')).to.equal('');
                 model.setBackgroundColor(backgroundColor);
                 expect(model.getSlideById(slideDefaultName).data('attributes').fill.type).to.equal('solid');
