@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Michael Nimz <michael.nimz@open-xchange.com>
  */
@@ -60,8 +61,8 @@ define([
             return { attributeSet: { cell: { fillColor: { type: type, value: value } } }, renderProps: null };
         }
 
-        function getDataBarResult(dataBarProps) {
-            return { attributeSet: null, renderProps: { dataBar: dataBarProps } };
+        function getDataBarResult(showValue, dataBarProps) {
+            return { attributeSet: null, renderProps: { showValue: showValue, dataBar: dataBarProps } };
         }
 
         // the operations to be applied at the test document
@@ -128,12 +129,15 @@ define([
                 [-80, -40, 0, 'a', true, null, 40, 80],
                 [-80, -40, 0, 40,  80],
                 [-80, -40, 0, 40,  80],
+                [-80, -40, 0, 40,  80],
                 [-80, -40, 0, 40,  80]
             ] },
             { name: 'insertCFRule', sheet: 2, id: '0000', ranges: 'A1:H1', type: 'dataBar', dataBar: { r1: { t: 'min' }, r2: { t: 'max' }, c: RED, s: true } },
             { name: 'insertCFRule', sheet: 2, id: '0001', ranges: 'A2:E2', type: 'dataBar', dataBar: { r1: { t: 'formula', v: '-60' }, r2: { t: 'formula', v: '$H$1*0.75' }, c: RED, s: false } },
             { name: 'insertCFRule', sheet: 2, id: '0002', ranges: 'A3:E3', type: 'dataBar', dataBar: { r1: { t: 'percent', v: '25' }, r2: { t: 'percent', v: '$H$1-5' }, c: RED, s: true } },
-            { name: 'insertCFRule', sheet: 2, id: '0003', ranges: 'A4:E4', type: 'dataBar', dataBar: { r1: { t: 'percentile', v: '25' }, r2: { t: 'percentile', v: '$H$1-5' }, c: RED, s: true } }
+            { name: 'insertCFRule', sheet: 2, id: '0003', ranges: 'A4:E4', type: 'dataBar', dataBar: { r1: { t: 'percentile', v: '25' }, r2: { t: 'percentile', v: '$H$1-5' }, c: RED, s: true } },
+            { name: 'insertCFRule', sheet: 2, id: '0004', ranges: 'A5:E5', type: 'dataBar', dataBar: { r1: { t: 'percentile', v: '25' }, r2: { t: 'percentile', v: '$H$1-5' }, c: RED, s: true, g: true } }
+
         ];
 
         // initialize test document
@@ -269,21 +273,22 @@ define([
 
         it('should resolve data bar rules', function () {
             var collection = docModel.getSheetModel(2).getCondFormatCollection();
-            expect(collection.resolveRules(a('A1'))).to.deep.equal(getDataBarResult({ min: -80, max: 80, num: -80, color: RED, showValue: true }));
-            expect(collection.resolveRules(a('B1'))).to.deep.equal(getDataBarResult({ min: -80, max: 80, num: -40, color: RED, showValue: true }));
-            expect(collection.resolveRules(a('C1'))).to.deep.equal(getDataBarResult({ min: -80, max: 80, num: 0, color: RED, showValue: true }));
+            expect(collection.resolveRules(a('A1'))).to.deep.equal(getDataBarResult(true, { min: -80, max: 80, num: -80, color1: '#ff0000', color2: null }));
+            expect(collection.resolveRules(a('B1'))).to.deep.equal(getDataBarResult(true, { min: -80, max: 80, num: -40, color1: '#ff0000', color2: null }));
+            expect(collection.resolveRules(a('C1'))).to.deep.equal(getDataBarResult(true, { min: -80, max: 80, num: 0, color1: '#ff0000', color2: null }));
             expect(collection.resolveRules(a('D1'))).to.equal(null);
             expect(collection.resolveRules(a('E1'))).to.equal(null);
             expect(collection.resolveRules(a('F1'))).to.equal(null);
-            expect(collection.resolveRules(a('G1'))).to.deep.equal(getDataBarResult({ min: -80, max: 80, num: 40, color: RED, showValue: true }));
-            expect(collection.resolveRules(a('H1'))).to.deep.equal(getDataBarResult({ min: -80, max: 80, num: 80, color: RED, showValue: true }));
+            expect(collection.resolveRules(a('G1'))).to.deep.equal(getDataBarResult(true, { min: -80, max: 80, num: 40, color1: '#ff0000', color2: null }));
+            expect(collection.resolveRules(a('H1'))).to.deep.equal(getDataBarResult(true, { min: -80, max: 80, num: 80, color1: '#ff0000', color2: null }));
             expect(collection.resolveRules(a('I1'))).to.equal(null);
-            expect(collection.resolveRules(a('A2'))).to.deep.equal(getDataBarResult({ min: -60, max: 60, num: -80, color: RED, showValue: false }));
-            expect(collection.resolveRules(a('E2'))).to.deep.equal(getDataBarResult({ min: -60, max: 60, num: 80, color: RED, showValue: false }));
-            expect(collection.resolveRules(a('A3'))).to.deep.equal(getDataBarResult({ min: -40, max: 40, num: -80, color: RED, showValue: true }));
-            expect(collection.resolveRules(a('E3'))).to.deep.equal(getDataBarResult({ min: -40, max: 40, num: 80, color: RED, showValue: true }));
-            expect(collection.resolveRules(a('A4'))).to.deep.equal(getDataBarResult({ min: -40, max: 40, num: -80, color: RED, showValue: true }));
-            expect(collection.resolveRules(a('E4'))).to.deep.equal(getDataBarResult({ min: -40, max: 40, num: 80, color: RED, showValue: true }));
+            expect(collection.resolveRules(a('A2'))).to.deep.equal(getDataBarResult(false, { min: -60, max: 60, num: -80, color1: '#ff0000', color2: null }));
+            expect(collection.resolveRules(a('E2'))).to.deep.equal(getDataBarResult(false, { min: -60, max: 60, num: 80, color1: '#ff0000', color2: null }));
+            expect(collection.resolveRules(a('A3'))).to.deep.equal(getDataBarResult(true, { min: -40, max: 40, num: -80, color1: '#ff0000', color2: null }));
+            expect(collection.resolveRules(a('E3'))).to.deep.equal(getDataBarResult(true, { min: -40, max: 40, num: 80, color1: '#ff0000', color2: null }));
+            expect(collection.resolveRules(a('A4'))).to.deep.equal(getDataBarResult(true, { min: -40, max: 40, num: -80, color1: '#ff0000', color2: null }));
+            expect(collection.resolveRules(a('E4'))).to.deep.equal(getDataBarResult(true, { min: -40, max: 40, num: 80, color1: '#ff0000', color2: null }));
+            expect(collection.resolveRules(a('E5'))).to.deep.equal(getDataBarResult(true, { min: -40, max: 40, num: 80, color1: '#ff0000', color2: 'hsl(0,100%,85%)' }));
         });
     });
 
