@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Michael Nimz <michael.nimz@open-xchange.com>
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
@@ -182,6 +183,29 @@ define([
             });
         });
 
+        moduleTester.testFunction('COLOR', function (COLOR) {
+            it('should return RGB color values', function () {
+                expect(COLOR(0, 0, 0)).to.equal(0);
+                expect(COLOR(1, 2, 3)).to.equal(0x00010203);
+                expect(COLOR(252, 253, 254)).to.equal(0x00fcfdfe);
+            });
+            it('should return RGBA color values', function () {
+                expect(COLOR(0, 0, 0, 0)).to.equal(0);
+                expect(COLOR(1, 2, 3, 4)).to.equal(0x04010203);
+                expect(COLOR(252, 253, 254, 255)).to.equal(0xfffcfdfe);
+            });
+            it('should throw error code for invalid arguments', function () {
+                expect(COLOR(-1, 0, 0, 0)).to.equal(ErrorCode.VALUE);
+                expect(COLOR(256, 0, 0, 0)).to.equal(ErrorCode.VALUE);
+                expect(COLOR(0, -1, 0, 0)).to.equal(ErrorCode.VALUE);
+                expect(COLOR(0, 256, 0, 0)).to.equal(ErrorCode.VALUE);
+                expect(COLOR(0, 0, -1, 0)).to.equal(ErrorCode.VALUE);
+                expect(COLOR(0, 0, 256, 0)).to.equal(ErrorCode.VALUE);
+                expect(COLOR(0, 0, 0, -1)).to.equal(ErrorCode.VALUE);
+                expect(COLOR(0, 0, 0, 256)).to.equal(ErrorCode.VALUE);
+            });
+        });
+
         moduleTester.testFunction('CONVERT', function (CONVERT) {
             it('should return correct results for length', function () {
                 expect(CONVERT(1, 'm', 'm')).to.equal(1);
