@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Michael Nimz <michael.nimz@open-xchange.com>
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
@@ -36,11 +37,16 @@ define([
         // the operations to be applied at the test document
         var OPERATIONS = [
             { name: 'setDocumentAttributes', attrs: { document: { cols: 16384, rows: 1048576 } } },
+
             { name: 'insertSheet', sheet: 0, sheetName: 'Sheet1' },
-            { name: 'changeCells', sheet: 0, start: 'A2', contents: [[3, 3, 'abc']] },
+            { name: 'changeCells', sheet: 0, start: 'A2', contents: [
+                [2, { v: 3, f: 'SUM(1,2)' }, 'abc'],
+                [{ v: 2, f: 'A2', si: 0, sr: 'A3:B3' }, { v: 3, si: 0 }],
+                [{ v: 4, f: 'A3:B3*2', mr: 'A4:B4' }, 6]
+            ] },
 
             //horizontal data
-            { name: 'insertSheet', sheet: 1, sheetName: 'NewSheet1' },
+            { name: 'insertSheet', sheet: 1, sheetName: 'Sheet2' },
             { name: 'changeCells', sheet: 1, start: 'A1', contents: [
                 [4.14, 4.19, 5.17, 5.77, 6.39],
                 [],
@@ -52,7 +58,7 @@ define([
             ] },
 
             //vertical data
-            { name: 'insertSheet', sheet: 2, sheetName: 'NewSheet2' },
+            { name: 'insertSheet', sheet: 2, sheetName: 'Sheet3' },
             { name: 'changeCells', sheet: 2, start: 'A1', contents: [
                 [4.14, null, 'Rot'],
                 [4.19, null, 'Orange'],
@@ -62,8 +68,8 @@ define([
             ] },
 
             //indirect data
-            { name: 'insertSheet', sheet: 3, sheetName: 'NewSheet3' },
-            { name: 'insertName', formula: 'NewSheet3!$C$2:$D$3', label: 'hallo_welt' },
+            { name: 'insertSheet', sheet: 3, sheetName: 'Sheet4' },
+            { name: 'insertName', formula: 'Sheet4!$C$2:$D$3', label: 'name1' },
             { name: 'changeCells', sheet: 3, start: 'A1', contents: [
                 ['B1',     null, 1333],
                 ['B2',     null, 45],
@@ -72,7 +78,7 @@ define([
             ] },
 
             //unsorted match
-            { name: 'insertSheet', sheet: 4, sheetName: 'NewSheet4' },
+            { name: 'insertSheet', sheet: 4, sheetName: 'Sheet5' },
             { name: 'changeCells', sheet: 4, start: 'A1', contents: [
                 ['a'],
                 ['c'],
@@ -113,38 +119,46 @@ define([
 
         moduleTester.testFunction('COLUMN', { targetAddress: 'E6' }, function (COLUMN) {
             it('should return the column index', function () {
-                expect(COLUMN(r3d('0:0!B3:D5')), 2);
-                expect(COLUMN(), 5);
+                expect(COLUMN(r3d('0:0!B3:D5'))).to.equal(2);
+                expect(COLUMN()).to.equal(5);
             });
         });
 
         moduleTester.testFunction('COLUMNS', { toOperand: 0 }, function (COLUMNS) {
             it('should return the width of the operand', function () {
-                expect(COLUMNS(42), 1);
-                expect(COLUMNS(mat([[1, 2, 3], [4, 5, 6]])), 3);
-                expect(COLUMNS(r3d('0:0!B2:C4')), 2);
+                expect(COLUMNS(42)).to.equal(1);
+                expect(COLUMNS(mat([[1, 2, 3], [4, 5, 6]]))).to.equal(3);
+                expect(COLUMNS(r3d('0:0!B2:C4'))).to.equal(2);
             });
             it('should throw errors for complex ranges', function () {
-                expect(COLUMNS(r3d('0:1!B2:C4')), ErrorCode.VALUE);
-                expect(COLUMNS(r3da('0:0!B2:C4 0:0!B2:C4')), ErrorCode.REF);
+                expect(COLUMNS(r3d('0:1!B2:C4'))).to.equal(ErrorCode.VALUE);
+                expect(COLUMNS(r3da('0:0!B2:C4 0:0!B2:C4'))).to.equal(ErrorCode.REF);
             });
         });
 
         moduleTester.testFunction('FORMULATEXT', function (FORMULATEXT) {
-            it('should return the formula expression', function () {
-                expect(FORMULATEXT(r3d('0:0!B2:B2')), '=SUMME(1;2)');
+            it('should return the formula expression for normal formula cells', function () {
+                expect(FORMULATEXT(r3d('0:0!B2:B2'))).to.equal('=SUMME(1;2)');
+            });
+            it('should return the formula expression for shared formulas', function () {
+                expect(FORMULATEXT(r3d('0:0!A3:A3'))).to.equal('=A2');
+                expect(FORMULATEXT(r3d('0:0!B3:B3'))).to.equal('=B2');
+            });
+            it('should return the formula expression for matrix formulas', function () {
+                expect(FORMULATEXT(r3d('0:0!A4:A4'))).to.equal('{=A3:B3*2}');
+                expect(FORMULATEXT(r3d('0:0!B4:B4'))).to.equal('{=A3:B3*2}');
             });
             it('should return #N/A for simple cells', function () {
-                expect(FORMULATEXT(r3d('0:0!A2:A2')), ErrorCode.NA);
-                expect(FORMULATEXT(r3d('0:0!C2:C2')), ErrorCode.NA);
-                expect(FORMULATEXT(r3d('0:0!IV99:IV99')), ErrorCode.NA);
+                expect(FORMULATEXT(r3d('0:0!A2:A2'))).to.equal(ErrorCode.NA);
+                expect(FORMULATEXT(r3d('0:0!C2:C2'))).to.equal(ErrorCode.NA);
+                expect(FORMULATEXT(r3d('0:0!IV99:IV99'))).to.equal(ErrorCode.NA);
             });
             it('should use the start address of a range', function () {
-                expect(FORMULATEXT(r3d('0:0!B2:C3')), '=SUMME(1;2)');
+                expect(FORMULATEXT(r3d('0:0!B2:C3'))).to.equal('=SUMME(1;2)');
             });
         });
 
-        moduleTester.testFunction('HLOOKUP', { refSheet: 1, refAddress: 'A4', toOperand: [1] }, function (HLOOKUP) {
+        moduleTester.testFunction('HLOOKUP', { refSheet: 1, targetAddress: 'A4', toOperand: [1] }, function (HLOOKUP) {
 
             var stringMatrix = mat([['Achsen', 'Getriebe', 'Schrauben'], [4, 4, 9], [5, 7, 10], [6, 8, 11]]);
             var numberMatrix = mat([[1, 2, 3], ['a', 'b', 'c'], ['d', 'e', 'f']]);
@@ -178,7 +192,7 @@ define([
             });
         });
 
-        moduleTester.testFunction('INDEX', { refSheet: 1, refAddress: 'Z26', toOperand: [0] }, function (INDEX) {
+        moduleTester.testFunction('INDEX', { refSheet: 1, targetAddress: 'Z26', toOperand: [0] }, function (INDEX) {
             it('should return the result of the INDEX on arrays/matrices', function () {
                 expect(INDEX(mat([[1, 2], [3, 4]]), 0, 2)).to.deep.equal(mat([[2], [4]]));
             });
@@ -202,24 +216,43 @@ define([
             });
         });
 
-        moduleTester.testFunction('INDIRECT', { refSheet: 3, refAddress: 'A1' }, function (INDIRECT) {
-            it('should return the result', function () {
+        moduleTester.testFunction('INDIRECT', { refSheet: 3, targetAddress: 'B2' }, function (INDIRECT) {
+            it('should return the result for A1 notation', function () {
                 expect(INDIRECT('A1')).to.deep.equal(r3d('3:3!A1:A1'));
-                expect(INDIRECT('A2')).to.deep.equal(r3d('3:3!A2:A2'));
+                expect(INDIRECT('A2', true)).to.deep.equal(r3d('3:3!A2:A2'));
                 expect(INDIRECT('A:A')).to.deep.equal(r3d('3:3!A1:A1048576'));
                 expect(INDIRECT('1:1')).to.deep.equal(r3d('3:3!A1:XFD1'));
-                expect(INDIRECT('NewSheet1!A3')).to.deep.equal(r3d('1:1!A3:A3'));
+                expect(INDIRECT('Sheet2!A3')).to.deep.equal(r3d('1:1!A3:A3'));
                 expect(INDIRECT('A2:B3')).to.deep.equal(r3d('3:3!A2:B3'));
-                expect(INDIRECT('hallo_welt')).to.deep.equal(r3d('3:3!C2:D3'));
+                expect(INDIRECT('name1')).to.deep.equal(r3d('3:3!C2:D3'));
             });
-            it('should throw error', function () {
-                expect(INDIRECT('1')).to.equal(ErrorCode.REF);
-                expect(INDIRECT('A')).to.equal(ErrorCode.REF);
-                expect(INDIRECT('')).to.equal(ErrorCode.REF);
+            it('should return the result for R1C1 notation', function () {
+                expect(INDIRECT('Z2S1', false)).to.deep.equal(r3d('3:3!A2:A2'));
+                expect(INDIRECT('ZS', false)).to.deep.equal(r3d('3:3!B2:B2'));
+                expect(INDIRECT('Z[1]S[-1]', false)).to.deep.equal(r3d('3:3!A3:A3'));
+                expect(INDIRECT('Z1:Z2', false)).to.deep.equal(r3d('3:3!A1:XFD2'));
+                expect(INDIRECT('Z', false)).to.deep.equal(r3d('3:3!A2:XFD2'));
+                expect(INDIRECT('S1:S2', false)).to.deep.equal(r3d('3:3!A1:B1048576'));
+                expect(INDIRECT('S', false)).to.deep.equal(r3d('3:3!B1:B1048576'));
+                expect(INDIRECT('Sheet2!Z3S1', false)).to.deep.equal(r3d('1:1!A3:A3'));
+                expect(INDIRECT('Z2S1:Z3S2', false)).to.deep.equal(r3d('3:3!A2:B3'));
+                expect(INDIRECT('name1', false)).to.deep.equal(r3d('3:3!C2:D3'));
+            });
+            it('should throw #REF! error for invalid parameter', function () {
+                expect(INDIRECT('1', true)).to.equal(ErrorCode.REF);
+                expect(INDIRECT('1', false)).to.equal(ErrorCode.REF);
+                expect(INDIRECT('A', true)).to.equal(ErrorCode.REF);
+                expect(INDIRECT('A', false)).to.equal(ErrorCode.REF);
+                expect(INDIRECT('', true)).to.equal(ErrorCode.REF);
+                expect(INDIRECT('', false)).to.equal(ErrorCode.REF);
+                expect(INDIRECT('Z2S1', true)).to.equal(ErrorCode.REF);
+                expect(INDIRECT('A1', false)).to.equal(ErrorCode.REF);
+                expect(INDIRECT('InvalidSheet!A1')).to.equal(ErrorCode.REF);
+                expect(INDIRECT('Sheet1:Sheet2!A1')).to.equal(ErrorCode.REF);
             });
         });
 
-        moduleTester.testFunction('LOOKUP', { refSheet: 1, refAddress: 'A4', toOperand: [1, 2] }, function (LOOKUP) {
+        moduleTester.testFunction('LOOKUP', { refSheet: 1, targetAddress: 'A4', toOperand: [1, 2] }, function (LOOKUP) {
 
             var rateData = [4.14, 4.19, 5.17, 5.77, 6.39];
             var colorData = ['Rot', 'Orange', 'Gelb', 'Gruen', 'Blau'];
@@ -238,7 +271,7 @@ define([
 
             it('should return the result of the search in unsorted matrix', function () {
                 var unsorted = mat([[4.14, 4.19, 15.17, 5.77, 6.39], colorData]);
-                expect(LOOKUP(7.66, unsorted), 'Orange');
+                expect(LOOKUP(7.66, unsorted)).to.equal('Orange');
             });
 
             var rateMatrix2 = mat([['rate', null, 4.14, 4.19, 5.17]]);
@@ -286,24 +319,26 @@ define([
         moduleTester.testFunction('MATCH', { toOperand: [1] }, function (MATCH) {
             var count = mat([[25, 38, 40, 41]]);
             var countRevers = mat([[41, 40, 38, 25]]);
+
             it('should return the result of the match', function () {
-                expect(MATCH(39, count, 1), 2);
-                expect(MATCH(41, count, 0), 4);
-                expect(MATCH(41, count, 1), 4);
+                expect(MATCH(39, count, 1)).to.equal(2);
+                expect(MATCH(41, count, 0)).to.equal(4);
+                expect(MATCH(41, count, 1)).to.equal(4);
             });
             it('should throw for invalid parameters', function () {
-                expect(MATCH(39, count, 0), ErrorCode.NA);
-                expect(MATCH(39, count, -1), ErrorCode.NA);
-                expect(MATCH(41, count, -1), ErrorCode.NA);
+                expect(MATCH(39, count, 0)).to.equal(ErrorCode.NA);
+                expect(MATCH(39, count, -1)).to.equal(ErrorCode.NA);
+                expect(MATCH(41, count, -1)).to.equal(ErrorCode.NA);
             });
+
             it('should return the result of the match with reverse order', function () {
-                expect(MATCH(39, countRevers, -1), 2);
-                expect(MATCH(41, countRevers, 0), 1);
-                expect(MATCH(41, countRevers, -1), 1);
+                expect(MATCH(39, countRevers, -1)).to.equal(2);
+                expect(MATCH(41, countRevers, 0)).to.equal(1);
+                expect(MATCH(41, countRevers, -1)).to.equal(1);
             });
 
             it('should return the result of the last entry without match', function () {
-                expect(MATCH('z', mat([['a'], ['c'], ['b'], ['d']])), 4);
+                expect(MATCH('z', mat([['a'], ['c'], ['b'], ['d']]))).to.equal(4);
 
                 expect(MATCH('z', r3d('4:4!A1:A4'))).to.equal(4);
                 expect(MATCH('z', r3d('4:4!A1:A50'))).to.equal(4);
@@ -314,28 +349,35 @@ define([
 
             it('match without solid order', function () {
                 expect(MATCH('Bagels', mat([['[  BREAKFAST ]', 'haha', 'Bagels', 'Breakfast Burrito', 'Cold cereal']]))).to.equal(3);
-                expect(MATCH('zzzzzzzzzzzzzzzzzzzz', mat([['[  BREAKFAST ]', null, 'Bagels', 'Breakfast Burrito', 'Cold cereal', 'Cream of wheat', 'Eggs and …', 'French Toast', 'Oatmeal', 'Omelettes', 'Pancakes', 'Waffles', null, null, null]]))).to.equal(12);
+                expect(MATCH('zzzzzzzzzzzzzzzzzzzz', mat([['[  BREAKFAST ]', null, 'Bagels', 'Breakfast Burrito', 'Cold cereal', 'Cream of wheat', 'Eggs and', 'French Toast', 'Oatmeal', 'Omelettes', 'Pancakes', 'Waffles', null, null, null]]))).to.equal(12);
 
-                // expect(MATCH('zzzzzzzzzzzzzzzzzzzz', mat([['[  BREAKFAST ]', null, 'Bagels', 'Breakfast Burrito', 'Cold cereal', null, null, 'Cream of wheat', 'Eggs and …', 'French Toast', 'Oatmeal', 'Omelettes', 'Pancakes', 'Waffles', null, null, null]]))).to.equal(14);
+                expect(MATCH('zzzzzzzzzzzzzzzzzzzz', mat([['[  BREAKFAST ]', null, 'Bagels', 'Breakfast Burrito', 'Cold cereal', null, null, 'Cream of wheat', 'Eggs and', 'French Toast', 'Oatmeal', 'Omelettes', 'Pancakes', 'Waffles', null, null, null]]))).to.equal(14);
             });
+
+            it('match with alphabetic order', function () {
+                expect(MATCH('Pants', mat([[0, 'Sweater', 'Jacket', 'Pants']]))).to.equal(4);
+                expect(MATCH('Med', mat([[0, 'Small', 'Med', 'Large']]))).to.equal(3);
+
+            });
+
         });
 
         moduleTester.testFunction('ROW', { targetAddress: 'E6' }, function (ROW) {
             it('should return the row index', function () {
-                expect(ROW(r3d('0:0!B3:D5')), 3);
-                expect(ROW(), 6);
+                expect(ROW(r3d('0:0!B3:D5'))).to.equal(3);
+                expect(ROW()).to.equal(6);
             });
         });
 
         moduleTester.testFunction('ROWS', { toOperand: 0 }, function (ROWS) {
             it('should return the width of the operand', function () {
-                expect(ROWS(42), 1);
-                expect(ROWS(mat([[1, 2, 3], [4, 5, 6]])), 2);
-                expect(ROWS(r3d('0:0!B2:C4')), 3);
+                expect(ROWS(42)).to.equal(1);
+                expect(ROWS(mat([[1, 2, 3], [4, 5, 6]]))).to.equal(2);
+                expect(ROWS(r3d('0:0!B2:C4'))).to.equal(3);
             });
             it('should throw errors for complex ranges', function () {
-                expect(ROWS(r3d('0:1!B2:C4')), ErrorCode.VALUE);
-                expect(ROWS(r3da('0:0!B2:C4 0:0!B2:C4')), ErrorCode.REF);
+                expect(ROWS(r3d('0:1!B2:C4'))).to.equal(ErrorCode.VALUE);
+                expect(ROWS(r3da('0:0!B2:C4 0:0!B2:C4'))).to.equal(ErrorCode.REF);
             });
         });
 
@@ -366,7 +408,7 @@ define([
             });
         });
 
-        moduleTester.testFunction('VLOOKUP', { refSheet: 2, refAddress: 'D1', toOperand: [1] }, function (VLOOKUP) {
+        moduleTester.testFunction('VLOOKUP', { refSheet: 2, targetAddress: 'D1', toOperand: [1] }, function (VLOOKUP) {
 
             var stringMatrix = mat([['Achsen', 4, 5, 6], ['Getriebe', 4, 7, 8], ['Schrauben', 9, 10, 11]]);
             var numberMatrix = mat([[1, 'a', 'd'], [2, 'b', 'e'], [3, 'c', 'f']]);
