@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Michael Nimz <michael.nimz@open-xchange.com>
  * @author Miroslav Dzunic <miroslav.dzunic@open-xchange.com>
@@ -78,74 +79,6 @@ define([
             });
         });
 
-        moduleTester.testFunction('PERMUT', function (PERMUT) {
-            it('should return the permutation of assigned integers', function () {
-                expect(PERMUT(100, 3)).to.equal(970200);
-                expect(PERMUT(3, 2)).to.almostEqual(6);
-            });
-            it('should return error code for invalid data', function () {
-                expect(PERMUT(0, 1)).to.equal(ErrorCode.NUM);
-                expect(PERMUT(2, -1)).to.equal(ErrorCode.NUM);
-                expect(PERMUT(1, 2)).to.equal(ErrorCode.NUM);
-            });
-        });
-
-        moduleTester.testFunction('PERMUTATIONA', function (PERMUTATIONA) {
-            it('should return the permutation of assigned integers', function () {
-                expect(PERMUTATIONA(4, 3)).to.equal(64);
-                expect(PERMUTATIONA(0, 0)).to.almostEqual(1);
-            });
-            it('should return error code for invalid data', function () {
-                expect(PERMUTATIONA(-1, 1)).to.equal(ErrorCode.NUM);
-                expect(PERMUTATIONA(1, -1)).to.equal(ErrorCode.NUM);
-                expect(PERMUTATIONA(-1, -1)).to.equal(ErrorCode.NUM);
-            });
-        });
-
-        moduleTester.testFunction('FISHER', function (FISHER) {
-            it('should return the Fisher statistical transformation of x', function () {
-                expect(FISHER(0.75)).to.be.closeTo(0.972955075, 1e-9);
-                expect(FISHER(0.55)).to.be.closeTo(0.618381314, 1e-9);
-                expect(FISHER(-0.75)).to.be.closeTo(-0.972955075, 1e-9);
-                expect(FISHER(-0.55)).to.be.closeTo(-0.618381314, 1e-9);
-            });
-            it('should throw #NUM! error for invalid arguments', function () {
-                expect(FISHER(-1)).to.equal(ErrorCode.NUM);
-                expect(FISHER(1)).to.equal(ErrorCode.NUM);
-                expect(FISHER(5.0)).to.equal(ErrorCode.NUM);
-                expect(FISHER(-5.0)).to.equal(ErrorCode.NUM);
-            });
-        });
-
-        moduleTester.testAliasFunction('FISHERINV', 'TANH');
-
-        moduleTester.testFunction('GAUSS', function (GAUSS) {
-            it('should return the Gauss statistical probability of x', function () {
-                expect(GAUSS(2)).to.be.closeTo(0.477249868, 1e-9);
-                expect(GAUSS(2.22)).to.be.closeTo(0.486790616, 1e-9);
-                expect(GAUSS(-0.5)).to.be.closeTo(-0.191462461, 1e-9);
-            });
-        });
-
-        moduleTester.testFunction('GROWTH', { toOperand: [0, 1, 2] }, function (GROWTH) {
-            it('should return the GROWTH statistical result', function () {
-                var knownY = mat([[33100, 47300, 69000, 102000, 150000, 220000]]);
-                var knownX = mat([[11, 12, 13, 14, 15, 16]]);
-                var newX =  mat([[17, 18]]);
-
-                var expectedResult = mat([[32618.2037735397], [47729.4226147478], [69841.3008562175], [102197.0733788320], [149542.4867400460], [218821.8762145950]]);
-
-                SheetHelper.assertMatrixCloseTo(GROWTH(knownY), expectedResult, 1e-7);
-                SheetHelper.assertMatrixCloseTo(GROWTH(knownY, knownX), expectedResult, 1e-7);
-                SheetHelper.assertMatrixCloseTo(GROWTH(knownY, knownX, newX), mat([[320196.718363472], [468536.054184048]]), 1e-7);
-                SheetHelper.assertMatrixCloseTo(GROWTH(knownY, knownX, knownX), expectedResult, 1e-7);
-
-                expect(GROWTH(knownY, newX)).to.equal(ErrorCode.REF);
-                expect(GROWTH(mat([[17, 0]]))).to.equal(ErrorCode.NUM);
-                expect(GROWTH(mat([[17, '18']]))).to.equal(ErrorCode.VALUE);
-            });
-        });
-
         moduleTester.testFunction('BETA.DIST', function (BETADIST, BETADIST_ODF) {
             it('should return the statistical BETA distribution', function () {
                 expect(BETADIST(2, 8, 10, true, 1, 3)).to.be.closeTo(0.6854706, 1e-7);
@@ -323,18 +256,27 @@ define([
                 expect(COUNTBLANK(r3da('0:0!A2:K2'))).to.equal(3);
                 expect(COUNTBLANK(r3da('0:0!A2:K10000'))).to.equal(109970);
             });
-            it('should not accept multiple references', function () {
-                expect(COUNTBLANK(r3da('0:0!A2:K2 0:0!A3:K3'))).to.equal(ErrorCode.VALUE);
-            });
         });
 
         moduleTester.testFunction('COUNTIF', function (COUNTIF) {
             it('should return the number of matching cells', function () {
-                expect(COUNTIF(r3da('0:0!A2:K2'), '>2')).to.equal(2);
+                expect(COUNTIF(r3d('0:0!A2:K2'), '>2')).to.equal(2);
             });
-            it('should count enpty cells and empty string results', function () {
-                expect(COUNTIF(r3da('0:0!A2:K2'), '')).to.equal(3);
-                expect(COUNTIF(r3da('0:0!A2:K2'), '=')).to.equal(2);
+            it('should count empty cells and empty string results', function () {
+                expect(COUNTIF(r3d('0:0!A2:K2'), '')).to.equal(3);
+                expect(COUNTIF(r3d('0:0!A2:K2'), '=')).to.equal(2);
+                expect(COUNTIF(r3d('0:0!ZZ1:ZZ1000000'), '')).to.equal(1000000);
+                expect(COUNTIF(r3d('0:0!ZZ1:ZZ1000000'), '=')).to.equal(1000000);
+            });
+        });
+
+        moduleTester.testFunction('COUNTIFS', function (COUNTIFS) {
+            it('should return the number of matching cells', function () {
+                expect(COUNTIFS(r3d('0:0!A2:K2'), '<4', r3d('0:0!A3:K3'), '>1')).to.equal(2);
+            });
+            it('should count empty cells and empty string results', function () {
+                expect(COUNTIFS(r3d('0:0!A2:K2'), '')).to.equal(3);
+                expect(COUNTIFS(r3d('0:0!ZZ1:ZZ1000000'), '', r3d('0:0!ZZ1:ZZ1000000'), '=')).to.equal(1000000);
             });
         });
 
@@ -424,6 +366,23 @@ define([
             });
         });
 
+        moduleTester.testFunction('FISHER', function (FISHER) {
+            it('should return the Fisher statistical transformation of x', function () {
+                expect(FISHER(0.75)).to.be.closeTo(0.972955075, 1e-9);
+                expect(FISHER(0.55)).to.be.closeTo(0.618381314, 1e-9);
+                expect(FISHER(-0.75)).to.be.closeTo(-0.972955075, 1e-9);
+                expect(FISHER(-0.55)).to.be.closeTo(-0.618381314, 1e-9);
+            });
+            it('should throw #NUM! error for invalid arguments', function () {
+                expect(FISHER(-1)).to.equal(ErrorCode.NUM);
+                expect(FISHER(1)).to.equal(ErrorCode.NUM);
+                expect(FISHER(5.0)).to.equal(ErrorCode.NUM);
+                expect(FISHER(-5.0)).to.equal(ErrorCode.NUM);
+            });
+        });
+
+        moduleTester.testAliasFunction('FISHERINV', 'TANH');
+
         moduleTester.testAliasFunction('FORECAST', 'FORECAST.LINEAR');
 
         moduleTester.testFunction('FORECAST.LINEAR', function (FORECAST_LINEAR) {
@@ -498,6 +457,33 @@ define([
             });
         });
 
+        moduleTester.testFunction('GAUSS', function (GAUSS) {
+            it('should return the Gauss statistical probability of x', function () {
+                expect(GAUSS(2)).to.be.closeTo(0.477249868, 1e-9);
+                expect(GAUSS(2.22)).to.be.closeTo(0.486790616, 1e-9);
+                expect(GAUSS(-0.5)).to.be.closeTo(-0.191462461, 1e-9);
+            });
+        });
+
+        moduleTester.testFunction('GROWTH', { toOperand: [0, 1, 2] }, function (GROWTH) {
+            it('should return the GROWTH statistical result', function () {
+                var knownY = mat([[33100, 47300, 69000, 102000, 150000, 220000]]);
+                var knownX = mat([[11, 12, 13, 14, 15, 16]]);
+                var newX =  mat([[17, 18]]);
+
+                var expectedResult = mat([[32618.2037735397], [47729.4226147478], [69841.3008562175], [102197.0733788320], [149542.4867400460], [218821.8762145950]]);
+
+                SheetHelper.assertMatrixCloseTo(GROWTH(knownY), expectedResult, 1e-7);
+                SheetHelper.assertMatrixCloseTo(GROWTH(knownY, knownX), expectedResult, 1e-7);
+                SheetHelper.assertMatrixCloseTo(GROWTH(knownY, knownX, newX), mat([[320196.718363472], [468536.054184048]]), 1e-7);
+                SheetHelper.assertMatrixCloseTo(GROWTH(knownY, knownX, knownX), expectedResult, 1e-7);
+
+                expect(GROWTH(knownY, newX)).to.equal(ErrorCode.REF);
+                expect(GROWTH(mat([[17, 0]]))).to.equal(ErrorCode.NUM);
+                expect(GROWTH(mat([[17, '18']]))).to.equal(ErrorCode.VALUE);
+            });
+        });
+
         moduleTester.testFunction('HYPGEOM.DIST', function (HYPGEOMDIST) {
             it('should return the correct result', function () {
                 expect(HYPGEOMDIST(1, 4, 8, 20, true)).to.be.closeTo(0.465428277, 1e-7);
@@ -536,7 +522,7 @@ define([
             });
         });
 
-        moduleTester.testFunction('LARGE', { toOperand: true }, function (LARGE) {
+        moduleTester.testFunction('LARGE', { toOperand: 0 }, function (LARGE) {
             var mat1 = mat([[3, 5, 3, 5, 4], [4, 2, 4, 6, 7]]);
             it('should return the 3rd and 7th largest numbers from set', function () {
                 expect(LARGE(mat1, 3)).to.equal(5);
@@ -779,6 +765,30 @@ define([
             });
         });
 
+        moduleTester.testFunction('PERMUT', function (PERMUT) {
+            it('should return the permutation of assigned integers', function () {
+                expect(PERMUT(100, 3)).to.equal(970200);
+                expect(PERMUT(3, 2)).to.almostEqual(6);
+            });
+            it('should return error code for invalid data', function () {
+                expect(PERMUT(0, 1)).to.equal(ErrorCode.NUM);
+                expect(PERMUT(2, -1)).to.equal(ErrorCode.NUM);
+                expect(PERMUT(1, 2)).to.equal(ErrorCode.NUM);
+            });
+        });
+
+        moduleTester.testFunction('PERMUTATIONA', function (PERMUTATIONA) {
+            it('should return the permutation of assigned integers', function () {
+                expect(PERMUTATIONA(4, 3)).to.equal(64);
+                expect(PERMUTATIONA(0, 0)).to.almostEqual(1);
+            });
+            it('should return error code for invalid data', function () {
+                expect(PERMUTATIONA(-1, 1)).to.equal(ErrorCode.NUM);
+                expect(PERMUTATIONA(1, -1)).to.equal(ErrorCode.NUM);
+                expect(PERMUTATIONA(-1, -1)).to.equal(ErrorCode.NUM);
+            });
+        });
+
         moduleTester.testFunction('PHI', function (PHI) {
             it('should return the value of the density function for a standard normal distribution', function () {
                 expect(PHI(0.75)).to.be.closeTo(0.301137432, 1e-9);
@@ -968,7 +978,7 @@ define([
             });
         });
 
-        moduleTester.testFunction('SMALL', { toOperand: true }, function (SMALL) {
+        moduleTester.testFunction('SMALL', { toOperand: 0 }, function (SMALL) {
             var mat1 = mat([[3, 5, 3, 5, 4], [4, 2, 4, 6, 7]]);
             it('should return the 3rd and 7th smallest numbers from set', function () {
                 expect(SMALL(mat1, 1)).to.equal(2);
