@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Michael Nimz <michael.nimz@open-xchange.com>
  */
@@ -308,7 +309,7 @@ define([
                 expect(TEXT(39300.63, 't.M.jjjj h:mm AM/PM')).to.equal('6.8.2007 3:07 pm');
                 expect(TEXT(39300.63, 't.m.jjjj h:mm AM/PM')).to.equal('6.8.2007 3:07 pm');
                 expect(TEXT(39300.63, '0,00E+00')).to.equal('3,93E+04');
-                expect(TEXT(39300.63, '#.##0,00 \u20AC')).to.equal('39.300,63 \u20AC');
+                expect(TEXT(39300.63, '#.##0,00 \u20ac')).to.equal('39.300,63 \u20ac');
             });
         });
 
