@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -517,41 +518,41 @@ define([
 
             it('should ignore sheet names if specified', function () {
                 // native OOXML
-                expect(ooxParser.parseRangeList('op', 'A2 Sheet1!B3 Sheet1:Sheet2!C4')).to.equal(null);
-                expect(ooxParser.parseRangeList('op', 'A2:B3 Sheet1!B3:C4 Sheet1:Sheet2!C4:D5')).to.equal(null);
-                expect(ooxParser.parseRangeList('op', 'A:B Sheet1!B:C Sheet1:Sheet2!C:D')).to.equal(null);
-                expect(ooxParser.parseRangeList('op', '2:3 Sheet1!3:4 Sheet1:Sheet2!4:5')).to.equal(null);
-                expect(ooxParser.parseRangeList('op', 'A2 Sheet1!B3 Sheet1:Sheet2!C4', { skipSheets: true })).to.stringifyTo('A2:A2,B3:B3,C4:C4');
-                expect(ooxParser.parseRangeList('op', 'A2:B3 Sheet1!B3:C4 Sheet1:Sheet2!C4:D5', { skipSheets: true })).to.stringifyTo('A2:B3,B3:C4,C4:D5');
-                expect(ooxParser.parseRangeList('op', 'A:B Sheet1!B:C Sheet1:Sheet2!C:D', { skipSheets: true })).to.stringifyTo('A1:B1048576,B1:C1048576,C1:D1048576');
-                expect(ooxParser.parseRangeList('op', '2:3 Sheet1!3:4 Sheet1:Sheet2!4:5', { skipSheets: true })).to.stringifyTo('A2:XFD3,A3:XFD4,A4:XFD5');
+                expect(ooxParser.parseRangeList('op', 'A2 Sheet1!B3')).to.equal(null);
+                expect(ooxParser.parseRangeList('op', 'A2:B3 Sheet1!B3:C4')).to.equal(null);
+                expect(ooxParser.parseRangeList('op', 'A:B Sheet1!B:C')).to.equal(null);
+                expect(ooxParser.parseRangeList('op', '2:3 Sheet1!3:4')).to.equal(null);
+                expect(ooxParser.parseRangeList('op', 'A2 Sheet1!B3', { skipSheets: true })).to.stringifyTo('A2:A2,B3:B3');
+                expect(ooxParser.parseRangeList('op', 'A2:B3 Sheet1!B3:C4', { skipSheets: true })).to.stringifyTo('A2:B3,B3:C4');
+                expect(ooxParser.parseRangeList('op', 'A:B Sheet1!B:C', { skipSheets: true })).to.stringifyTo('A1:B1048576,B1:C1048576');
+                expect(ooxParser.parseRangeList('op', '2:3 Sheet1!3:4', { skipSheets: true })).to.stringifyTo('A2:XFD3,A3:XFD4');
                 // localized OOXML
-                expect(ooxParser.parseRangeList('ui', 'A2 Sheet1!B3 Sheet1:Sheet2!C4')).to.equal(null);
-                expect(ooxParser.parseRangeList('ui', 'A2:B3 Sheet1!B3:C4 Sheet1:Sheet2!C4:D5')).to.equal(null);
-                expect(ooxParser.parseRangeList('ui', 'A:B Sheet1!B:C Sheet1:Sheet2!C:D')).to.equal(null);
-                expect(ooxParser.parseRangeList('ui', '2:3 Sheet1!3:4 Sheet1:Sheet2!4:5')).to.equal(null);
-                expect(ooxParser.parseRangeList('ui', 'A2 Sheet1!B3 Sheet1:Sheet2!C4', { skipSheets: true })).to.stringifyTo('A2:A2,B3:B3,C4:C4');
-                expect(ooxParser.parseRangeList('ui', 'A2:B3 Sheet1!B3:C4 Sheet1:Sheet2!C4:D5', { skipSheets: true })).to.stringifyTo('A2:B3,B3:C4,C4:D5');
-                expect(ooxParser.parseRangeList('ui', 'A:B Sheet1!B:C Sheet1:Sheet2!C:D', { skipSheets: true })).to.stringifyTo('A1:B1048576,B1:C1048576,C1:D1048576');
-                expect(ooxParser.parseRangeList('ui', '2:3 Sheet1!3:4 Sheet1:Sheet2!4:5', { skipSheets: true })).to.stringifyTo('A2:XFD3,A3:XFD4,A4:XFD5');
+                expect(ooxParser.parseRangeList('ui', 'A2 Sheet1!B3')).to.equal(null);
+                expect(ooxParser.parseRangeList('ui', 'A2:B3 Sheet1!B3:C4')).to.equal(null);
+                expect(ooxParser.parseRangeList('ui', 'A:B Sheet1!B:C')).to.equal(null);
+                expect(ooxParser.parseRangeList('ui', '2:3 Sheet1!3:4')).to.equal(null);
+                expect(ooxParser.parseRangeList('ui', 'A2 Sheet1!B3', { skipSheets: true })).to.stringifyTo('A2:A2,B3:B3');
+                expect(ooxParser.parseRangeList('ui', 'A2:B3 Sheet1!B3:C4', { skipSheets: true })).to.stringifyTo('A2:B3,B3:C4');
+                expect(ooxParser.parseRangeList('ui', 'A:B Sheet1!B:C', { skipSheets: true })).to.stringifyTo('A1:B1048576,B1:C1048576');
+                expect(ooxParser.parseRangeList('ui', '2:3 Sheet1!3:4', { skipSheets: true })).to.stringifyTo('A2:XFD3,A3:XFD4');
                 // native ODF (no support for column/row intervals)
                 expect(odfParser.parseRangeList('op', 'A2 Sheet1.B3')).to.equal(null);
-                expect(odfParser.parseRangeList('op', 'A2:B3 Sheet1.B3:C4 Sheet1.C4:Sheet2.D5')).to.equal(null);
-                expect(odfParser.parseRangeList('op', 'A:B Sheet1.B:C Sheet1:Sheet2.C:D')).to.equal(null);
-                expect(odfParser.parseRangeList('op', '2:3 Sheet1.3:4 Sheet1:Sheet2.4:5')).to.equal(null);
+                expect(odfParser.parseRangeList('op', 'A2:B3 Sheet1.B3:C4')).to.equal(null);
+                expect(odfParser.parseRangeList('op', 'A:B Sheet1.B:C')).to.equal(null);
+                expect(odfParser.parseRangeList('op', '2:3 Sheet1.3:4')).to.equal(null);
                 expect(odfParser.parseRangeList('op', 'A2 Sheet1.B3', { skipSheets: true })).to.stringifyTo('A2:A2,B3:B3');
                 expect(odfParser.parseRangeList('op', 'A2:B3 Sheet1.B3:C4 Sheet1.C4:Sheet2.D5', { skipSheets: true })).to.stringifyTo('A2:B3,B3:C4,C4:D5');
                 expect(odfParser.parseRangeList('op', 'A:B Sheet1.B:C Sheet1.C:Sheet2.D', { skipSheets: true })).to.equal(null);
                 expect(odfParser.parseRangeList('op', '2:3 Sheet1.3:4 Sheet1.4:Sheet2.5', { skipSheets: true })).to.equal(null);
                 // localized ODF
-                expect(odfParser.parseRangeList('ui', 'A2 Sheet1!B3 Sheet1:Sheet2!C4')).to.equal(null);
-                expect(odfParser.parseRangeList('ui', 'A2:B3 Sheet1!B3:C4 Sheet1:Sheet2!C4:D5')).to.equal(null);
-                expect(odfParser.parseRangeList('ui', 'A:B Sheet1!B:C Sheet1:Sheet2!C:D')).to.equal(null);
-                expect(odfParser.parseRangeList('ui', '2:3 Sheet1!3:4 Sheet1:Sheet2!4:5')).to.equal(null);
-                expect(odfParser.parseRangeList('ui', 'A2 Sheet1!B3 Sheet1:Sheet2!C4', { skipSheets: true })).to.stringifyTo('A2:A2,B3:B3,C4:C4');
-                expect(odfParser.parseRangeList('ui', 'A2:B3 Sheet1!B3:C4 Sheet1:Sheet2!C4:D5', { skipSheets: true })).to.stringifyTo('A2:B3,B3:C4,C4:D5');
-                expect(odfParser.parseRangeList('ui', 'A:B Sheet1!B:C Sheet1:Sheet2!C:D', { skipSheets: true })).to.stringifyTo('A1:B1048576,B1:C1048576,C1:D1048576');
-                expect(odfParser.parseRangeList('ui', '2:3 Sheet1!3:4 Sheet1:Sheet2!4:5', { skipSheets: true })).to.stringifyTo('A2:AMJ3,A3:AMJ4,A4:AMJ5');
+                expect(odfParser.parseRangeList('ui', 'A2 Sheet1!B3')).to.equal(null);
+                expect(odfParser.parseRangeList('ui', 'A2:B3 Sheet1!B3:C4')).to.equal(null);
+                expect(odfParser.parseRangeList('ui', 'A:B Sheet1!B:C')).to.equal(null);
+                expect(odfParser.parseRangeList('ui', '2:3 Sheet1!3:4')).to.equal(null);
+                expect(odfParser.parseRangeList('ui', 'A2 Sheet1!B3', { skipSheets: true })).to.stringifyTo('A2:A2,B3:B3');
+                expect(odfParser.parseRangeList('ui', 'A2:B3 Sheet1!B3:C4', { skipSheets: true })).to.stringifyTo('A2:B3,B3:C4');
+                expect(odfParser.parseRangeList('ui', 'A:B Sheet1!B:C', { skipSheets: true })).to.stringifyTo('A1:B1048576,B1:C1048576');
+                expect(odfParser.parseRangeList('ui', '2:3 Sheet1!3:4', { skipSheets: true })).to.stringifyTo('A2:AMJ3,A3:AMJ4');
             });
         });
 
