@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Michael Nimz <michael.nimz@open-xchange.com>
  * @author York Richter <york.richter@open-xchange.com>
@@ -132,10 +133,21 @@ define([
                 expect(docModel).to.respondTo('getFormulaGrammar');
             });
             it('should return the formula grammar', function () {
-                expect(docModel.getFormulaGrammar('op')).to.be.an('object');
-                expect(docModel.getFormulaGrammar('op').GRAMMAR).to.equal('op');
-                expect(docModel.getFormulaGrammar('ui')).to.be.an('object');
-                expect(docModel.getFormulaGrammar('ui').GRAMMAR).to.equal('ui');
+                var opGrammar = docModel.getFormulaGrammar('op');
+                expect(opGrammar).to.be.an('object');
+                expect(opGrammar).to.have.a.property('GRAMMAR', 'op');
+                expect(opGrammar).to.have.a.property('REF_SYNTAX', 'ooxml');
+                var uiGrammar = docModel.getFormulaGrammar('ui');
+                expect(uiGrammar).to.be.an('object');
+                expect(uiGrammar).to.have.a.property('GRAMMAR', 'ui');
+                expect(uiGrammar).to.have.a.property('REF_SYNTAX', 'ooxml');
+                var opOoxGrammar = docModel.getFormulaGrammar('op:ooxml');
+                expect(opOoxGrammar).to.be.an('object');
+                expect(opOoxGrammar).to.equal(opGrammar);
+                var opOdfGrammar = docModel.getFormulaGrammar('op:odf');
+                expect(opOdfGrammar).to.be.an('object');
+                expect(opOdfGrammar).to.have.a.property('GRAMMAR', 'op');
+                expect(opOdfGrammar).to.have.a.property('REF_SYNTAX', 'of');
             });
         });
 
@@ -247,22 +259,22 @@ define([
                 var sheetModel = docModel.getSheetModel(1);
                 var cellCollection = sheetModel.getCellCollection();
                 // Cell formula
-                expect(cellCollection.getCellFormula(a('A1'), 'op')).to.equal('Sheet1!$A$1');
-                expect(cellCollection.getCellFormula(a('A5'), 'op')).to.equal('Sheet2!$A$3');
+                expect(cellCollection.getFormula(a('A1'), 'op')).to.equal('Sheet1!$A$1');
+                expect(cellCollection.getFormula(a('A5'), 'op')).to.equal('Sheet2!$A$3');
 
                 // Named range
                 var nameCollection = docModel.getNameCollection();
-                expect(cellCollection.getCellFormula(a('C1'), 'op')).to.equal('COUNT(ObstPreisGlobal)');
+                expect(cellCollection.getFormula(a('C1'), 'op')).to.equal('COUNT(ObstPreisGlobal)');
                 expect(nameCollection.getName('ObstGlobal').getFormula('op', a('C1'))).to.equal('Sheet1!$A$5:$A$7');
                 expect(nameCollection.getName('ObstPreisGlobal').getFormula('op', a('C1'))).to.equal('Sheet1!$B$5:$B$7');
 
                 nameCollection = docModel.getSheetModel(0).getNameCollection();
-                expect(cellCollection.getCellFormula(a('C3'), 'op')).to.equal('COUNT(Sheet1!ObstPreis)');
+                expect(cellCollection.getFormula(a('C3'), 'op')).to.equal('COUNT(Sheet1!ObstPreis)');
                 expect(nameCollection.getName('ObstPreis').getFormula('op', a('C1'))).to.equal('Sheet1!$B$5:$B$7');
 
                 // Named range on sheet2
                 nameCollection = docModel.getSheetModel(1).getNameCollection();
-                expect(cellCollection.getCellFormula(a('C8'), 'op')).to.equal('COUNT(Sheet2!TestRangeSheet2)');
+                expect(cellCollection.getFormula(a('C8'), 'op')).to.equal('COUNT(Sheet2!TestRangeSheet2)');
                 expect(nameCollection.getName('TestRangeSheet2').getFormula('op', a('C1'))).to.equal('Sheet2!$C$5:$C$6');
 
                 // Chart Drawing
@@ -287,33 +299,33 @@ define([
                     expect(promise.state()).to.equal('resolved');
 
                     // Cell formula
-                    expect(cellCollection.getCellFormula(a('A1'), 'op')).to.equal('#REF!!$A$1');
-                    expect(cellCollection.getCellFormula(a('A5'), 'op')).to.equal('Sheet2!$A$3');
+                    expect(cellCollection.getFormula(a('A1'), 'op')).to.equal('#REF!');
+                    expect(cellCollection.getFormula(a('A5'), 'op')).to.equal('Sheet2!$A$3');
 
                     // Named range
                     nameCollection = docModel.getNameCollection();
-                    expect(cellCollection.getCellFormula(a('C1'), 'op')).to.equal('COUNT(ObstPreisGlobal)');
-                    expect(nameCollection.getName('ObstGlobal').getFormula('op', a('C1'))).to.equal('#REF!!$A$5:$A$7');
-                    expect(nameCollection.getName('ObstPreisGlobal').getFormula('op', a('C1'))).to.equal('#REF!!$B$5:$B$7');
+                    expect(cellCollection.getFormula(a('C1'), 'op')).to.equal('COUNT(ObstPreisGlobal)');
+                    expect(nameCollection.getName('ObstGlobal').getFormula('op', a('C1'))).to.equal('#REF!');
+                    expect(nameCollection.getName('ObstPreisGlobal').getFormula('op', a('C1'))).to.equal('#REF!');
 
-                    expect(cellCollection.getCellFormula(a('C3'), 'op')).to.equal('COUNT(#REF!!ObstPreis)');
+                    expect(cellCollection.getFormula(a('C3'), 'op')).to.equal('COUNT([0]!ObstPreis)');
 
                     // Named range on sheet2
                     nameCollection = docModel.getSheetModel(0).getNameCollection();
-                    expect(cellCollection.getCellFormula(a('C8'), 'op')).to.equal('COUNT(Sheet2!TestRangeSheet2)');
+                    expect(cellCollection.getFormula(a('C8'), 'op')).to.equal('COUNT(Sheet2!TestRangeSheet2)');
                     expect(nameCollection.getName('TestRangeSheet2').getFormula('op', a('C1'))).to.equal('Sheet2!$C$5:$C$6');
 
                     // Chart Drawing
                     drawingCollection = sheetModel.getDrawingCollection();
                     chartModel = drawingCollection.findModel([0]);
-                    testChartModel(chartModel, { title: '#REF!!$B$4', names: '#REF!!$A$5:$A$7', values: '#REF!!$B$5:$B$7' }, { title: '#REF!!$C$4', names: '#REF!!$A$5:$A$7', values: '#REF!!$C$5:$C$7' });
+                    testChartModel(chartModel, { title: '#REF!', names: '#REF!', values: '#REF!' }, { title: '#REF!', names: '#REF!', values: '#REF!' });
 
                     chartModel = drawingCollection.findModel([1]);
                     testChartModel(chartModel, { title: 'Sheet2!$O$2', names: 'Sheet2!$N$3:$N$5', values: 'Sheet2!$O$3:$O$5' }, { title: 'Sheet2!$P$2', names: 'Sheet2!$N$3:$N$5', values: 'Sheet2!$P$3:$P$5' });
 
                     // Data validation
                     validationCollection = sheetModel.getValidationCollection();
-                    expect(validationCollection.getValidationSettings(a('E1')).attributes.value1).to.equal('#REF!!$A$5:$A$7');
+                    expect(validationCollection.getValidationSettings(a('E1')).attributes.value1).to.equal('#REF!');
                     expect(validationCollection.getValidationSettings(a('E6')).attributes.value1).to.equal('$E$3:$E$4');
                     done();
                 });
