@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -210,6 +211,48 @@ define([
 
         // public methods -----------------------------------------------------
 
+        describe('method "containsAddress"', function () {
+            it('should exist', function () {
+                expect(MoveDescriptor).to.respondTo('containsAddress');
+            });
+            it('should return whether the address is covered', function () {
+                expect(insColMoveDesc.containsAddress(a('A1'))).to.equal(false);
+                expect(insColMoveDesc.containsAddress(a('A2'))).to.equal(true);
+                expect(insColMoveDesc.containsAddress(a('A3'))).to.equal(true);
+                expect(insColMoveDesc.containsAddress(a('A4'))).to.equal(false);
+
+                expect(insRowMoveDesc.containsAddress(a('A1'))).to.equal(false);
+                expect(insRowMoveDesc.containsAddress(a('B1'))).to.equal(true);
+                expect(insRowMoveDesc.containsAddress(a('C1'))).to.equal(true);
+                expect(insRowMoveDesc.containsAddress(a('D1'))).to.equal(false);
+            });
+        });
+
+        describe('method "containsRange"', function () {
+            it('should exist', function () {
+                expect(MoveDescriptor).to.respondTo('containsRange');
+            });
+            it('should return whether the range is covered', function () {
+                expect(insColMoveDesc.containsRange(r('A1:A4'))).to.equal(false);
+                expect(insColMoveDesc.containsRange(r('A1:A2'))).to.equal(false);
+                expect(insColMoveDesc.containsRange(r('A2:A3'))).to.equal(true);
+                expect(insColMoveDesc.containsRange(r('A3:A4'))).to.equal(false);
+                expect(insColMoveDesc.containsRange(r('A1:A1'))).to.equal(false);
+                expect(insColMoveDesc.containsRange(r('A2:A2'))).to.equal(true);
+                expect(insColMoveDesc.containsRange(r('A3:A3'))).to.equal(true);
+                expect(insColMoveDesc.containsRange(r('A4:A4'))).to.equal(false);
+
+                expect(insRowMoveDesc.containsRange(r('A1:D1'))).to.equal(false);
+                expect(insRowMoveDesc.containsRange(r('A1:B1'))).to.equal(false);
+                expect(insRowMoveDesc.containsRange(r('B1:C1'))).to.equal(true);
+                expect(insRowMoveDesc.containsRange(r('C1:D1'))).to.equal(false);
+                expect(insRowMoveDesc.containsRange(r('A1:A1'))).to.equal(false);
+                expect(insRowMoveDesc.containsRange(r('B1:B1'))).to.equal(true);
+                expect(insRowMoveDesc.containsRange(r('C1:C1'))).to.equal(true);
+                expect(insRowMoveDesc.containsRange(r('D1:D1'))).to.equal(false);
+            });
+        });
+
         describe('method "createLineRange"', function () {
             it('should exist', function () {
                 expect(MoveDescriptor).to.respondTo('createLineRange');
@@ -252,33 +295,6 @@ define([
             });
         });
 
-        describe('method "coversAddress"', function () {
-            it('should exist', function () {
-                expect(MoveDescriptor).to.respondTo('coversAddress');
-            });
-            it('should return whether the address is covered', function () {
-                expect(insColMoveDesc.coversAddress(a('A1'))).to.equal(false);
-                expect(insColMoveDesc.coversAddress(a('A2'))).to.equal(false);
-                expect(insColMoveDesc.coversAddress(a('A3'))).to.equal(false);
-                expect(insColMoveDesc.coversAddress(a('A4'))).to.equal(false);
-                expect(insColMoveDesc.coversAddress(a('B1'))).to.equal(false);
-                expect(insColMoveDesc.coversAddress(a('B2'))).to.equal(true);
-                expect(insColMoveDesc.coversAddress(a('B3'))).to.equal(true);
-                expect(insColMoveDesc.coversAddress(a('B4'))).to.equal(false);
-                expect(insColMoveDesc.coversAddress(a('A2'))).to.equal(false);
-
-                expect(insRowMoveDesc.coversAddress(a('A1'))).to.equal(false);
-                expect(insRowMoveDesc.coversAddress(a('B1'))).to.equal(false);
-                expect(insRowMoveDesc.coversAddress(a('C1'))).to.equal(false);
-                expect(insRowMoveDesc.coversAddress(a('D1'))).to.equal(false);
-                expect(insRowMoveDesc.coversAddress(a('A2'))).to.equal(false);
-                expect(insRowMoveDesc.coversAddress(a('B2'))).to.equal(true);
-                expect(insRowMoveDesc.coversAddress(a('C2'))).to.equal(true);
-                expect(insRowMoveDesc.coversAddress(a('D2'))).to.equal(false);
-                expect(insRowMoveDesc.coversAddress(a('B1'))).to.equal(false);
-            });
-        });
-
         describe('method "transformAddress"', function () {
             it('should exist', function () {
                 expect(MoveDescriptor).to.respondTo('transformAddress');
@@ -340,35 +356,6 @@ define([
             });
         });
 
-        describe('method "coversRange"', function () {
-            it('should exist', function () {
-                expect(MoveDescriptor).to.respondTo('coversRange');
-            });
-            it('should return whether the range is covered', function () {
-                expect(insColMoveDesc.coversRange(r('A1:A4'))).to.equal(false);
-                expect(insColMoveDesc.coversRange(r('B1:B4'))).to.equal(false);
-                expect(insColMoveDesc.coversRange(r('B1:B2'))).to.equal(false);
-                expect(insColMoveDesc.coversRange(r('B2:B3'))).to.equal(true);
-                expect(insColMoveDesc.coversRange(r('B3:B4'))).to.equal(false);
-                expect(insColMoveDesc.coversRange(r('C1:D4'))).to.equal(false);
-                expect(insColMoveDesc.coversRange(r('C1:D2'))).to.equal(false);
-                expect(insColMoveDesc.coversRange(r('C2:D3'))).to.equal(true);
-                expect(insColMoveDesc.coversRange(r('C3:D4'))).to.equal(false);
-                expect(insColMoveDesc.coversRange(r('A2:A3'))).to.equal(true);
-
-                expect(insRowMoveDesc.coversRange(r('A1:D1'))).to.equal(false);
-                expect(insRowMoveDesc.coversRange(r('A2:D2'))).to.equal(false);
-                expect(insRowMoveDesc.coversRange(r('A2:B2'))).to.equal(false);
-                expect(insRowMoveDesc.coversRange(r('B2:C2'))).to.equal(true);
-                expect(insRowMoveDesc.coversRange(r('C2:D2'))).to.equal(false);
-                expect(insRowMoveDesc.coversRange(r('A3:D4'))).to.equal(false);
-                expect(insRowMoveDesc.coversRange(r('A3:B4'))).to.equal(false);
-                expect(insRowMoveDesc.coversRange(r('B3:C4'))).to.equal(true);
-                expect(insRowMoveDesc.coversRange(r('C3:D4'))).to.equal(false);
-                expect(insRowMoveDesc.coversRange(r('B1:C1'))).to.equal(true);
-            });
-        });
-
         describe('method "transformRange"', function () {
             it('should exist', function () {
                 expect(MoveDescriptor).to.respondTo('transformRange');
