@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -388,6 +389,22 @@ define([
             });
         });
 
+        describe('method "equalSize"', function () {
+            it('should exist', function () {
+                expect(Range).to.respondTo('equalSize');
+            });
+            it('should return the correct result', function () {
+                var r1 = r('B3:D5');
+                expect(r1.equalSize(r('B3:D5'))).to.equal(true);
+                expect(r1.equalSize(r('C3:E5'))).to.equal(true);
+                expect(r1.equalSize(r('B4:D6'))).to.equal(true);
+                expect(r1.equalSize(r('B3:C5'))).to.equal(false);
+                expect(r1.equalSize(r('B3:E5'))).to.equal(false);
+                expect(r1.equalSize(r('B3:D4'))).to.equal(false);
+                expect(r1.equalSize(r('B3:D6'))).to.equal(false);
+            });
+        });
+
         describe('method "startsAt"', function () {
             it('should exist', function () {
                 expect(Range).to.respondTo('startsAt');
