@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -393,6 +394,26 @@ define([
             });
         });
 
+        describe('method "getTextPadding"', function () {
+            it('should exist', function () {
+                expect(SheetUtils).itself.to.respondTo('getTextPadding');
+            });
+            it('should return text padding according to zoom factor', function () {
+                expect(SheetUtils.getTextPadding(1)).to.equal(2);
+                expect(SheetUtils.getTextPadding(2)).to.be.above(2);
+            });
+        });
+
+        describe('method "getTotalCellPadding"', function () {
+            it('should exist', function () {
+                expect(SheetUtils).itself.to.respondTo('getTotalCellPadding');
+            });
+            it('should return text padding according to zoom factor', function () {
+                expect(SheetUtils.getTotalCellPadding(1)).to.equal(5);
+                expect(SheetUtils.getTotalCellPadding(2)).to.be.above(5);
+            });
+        });
+
         describe('method "isDynamicSplit"', function () {
             it('should exist', function () {
                 expect(SheetUtils).itself.to.respondTo('isDynamicSplit');
