@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Miroslav Dzunic <miroslav.dzunic@open-xchange.com>
  */
@@ -43,8 +44,8 @@ define([
         // the ODF operations to be applied by the document model
         var ODF_OPERATIONS = [
             { name: 'insertParagraph', start: [0] },
-            { name: 'insertField',	start: [0, 0], type: 'date', representation: '1/12/2016', attrs: { field: { dateFormat: 'M/D/YYYY' } } },
-            { name: 'updateField',	start: [0, 0], type: 'date', representation: '1/12/2016', attrs: { field: { dateFormat: 'M/D/YYYY', fixed: 'true' } } }
+            { name: 'insertField', start: [0, 0], type: 'date', representation: '1/12/2016', attrs: { character: { field: { dateFormat: 'M/D/YYYY' } } } },
+            { name: 'updateField', start: [0, 0], type: 'date', representation: '1/12/2016', attrs: { character: { field: { dateFormat: 'M/D/YYYY', 'text:fixed': 'true' } } } }
         ];
 
         var model, selection, fieldManager;
