@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -47,12 +48,12 @@ define([
                     document:  { defaultTabStop: 1270, zoom: { value: 100 } },
                     page:      { width: 21590, height: 27940, marginLeft: 2540, marginTop: 2540, marginRight: 2540, marginBottom: 2540, marginHeader: 1248, marginFooter: 1248 },
                     character: { fontName: 'Arial', fontSize: 11, language: 'en-US', languageEa: 'en-US', languageBidi: 'ar-SA' },
-                    paragraph: { lineHeight: { type: 'percent', value: 115 }, marginBottom: 352 }
+                    paragraph: { lineHeight: { type: 'percent', value: 119 }, marginBottom: 352 }
                 }
             },
-            { name: 'insertStyleSheet', type: 'paragraph', styleId: 'Heading1', styleName: 'heading·1',
+            { name: 'insertStyleSheet', type: 'paragraph', styleId: 'Heading1', styleName: 'heading 1',
                 attrs: {
-                    character: { bold: true, fontName: 'Times·New·Roman', fontSize: 14, color: { transformations: [{ type: 'shade', value: 74902 }], type: 'scheme', value: 'accent1' } },
+                    character: { bold: true, fontName: 'Times New Roman', fontSize: 14, color: { transformations: [{ type: 'shade', value: 74902 }], type: 'scheme', value: 'accent1' } },
                     paragraph: { marginTop: 846, outlineLevel: 0, nextStyleId: 'Normal' }
                 },
                 parent: 'Normal',
@@ -148,9 +149,9 @@ define([
                 model.setAttribute('paragraph', 'lineHeight', LINEHEIGHT___115);
                 model.setAttribute('paragraph', 'marginBottom', (PARAGRAPHSPACING__WIDE * defaultMarginBottom));
 
-                expect(parseInt($(secondParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(115);
-                expect(parseInt($(thirdParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(115);
-                expect(parseInt($(fourthParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(115);
+                expect(parseInt($(secondParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(139);
+                expect(parseInt($(thirdParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(139);
+                expect(parseInt($(fourthParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(139);
 
                 model.getSelection().setTextSelection([1, 0]);
                 attributes = ((model.getAttributes('paragraph', { maxIterations: 10 }) || {}).paragraph || {});
@@ -174,9 +175,9 @@ define([
                 model.setAttribute('paragraph', 'lineHeight', LINEHEIGHT__ONE_HALF);
                 model.setAttribute('paragraph', 'marginBottom', (PARAGRAPHSPACING__NONE * defaultMarginBottom));
 
-                expect(parseInt($(secondParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(150);
-                expect(parseInt($(thirdParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(150);
-                expect(parseInt($(fourthParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(115);
+                expect(parseInt($(secondParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(180);
+                expect(parseInt($(thirdParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(180);
+                expect(parseInt($(fourthParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(139);
 
                 model.getSelection().setTextSelection([1, 0]);
                 attributes = ((model.getAttributes('paragraph', { maxIterations: 10 }) || {}).paragraph || {});
@@ -200,9 +201,10 @@ define([
                 model.setAttribute('paragraph', 'lineHeight', LINEHEIGHT__SINGLE);
                 model.setAttribute('paragraph', 'marginBottom', (PARAGRAPHSPACING__NORMAL * defaultMarginBottom));
 
-                expect(parseInt($(secondParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(150);
-                expect(parseInt($(thirdParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(100);
-                expect(parseInt($(fourthParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(100);
+                expect(parseInt($(secondParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(180);
+                // fontCollection.getNormalLineHeight() in characterStyles.updateElementLineHeight() causes 119 or 126 to be possible (1pt difference)
+                expect(parseInt($(thirdParagraph).find('span')[0].style.lineHeight, 10)).to.be.oneOf([119, 126]);
+                expect(parseInt($(fourthParagraph).find('span')[0].style.lineHeight, 10)).to.be.oneOf([119, 126]);
 
                 model.getSelection().setTextSelection([1, 0]);
                 attributes = ((model.getAttributes('paragraph', { maxIterations: 10 }) || {}).paragraph || {});
@@ -226,9 +228,10 @@ define([
                 model.setAttribute('paragraph', 'lineHeight', LINEHEIGHT__DOUBLE);
                 model.setAttribute('paragraph', 'marginBottom', (PARAGRAPHSPACING__WIDE * defaultMarginBottom));
 
-                expect(parseInt($(secondParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(200);
-                expect(parseInt($(thirdParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(100);
-                expect(parseInt($(fourthParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(100);
+                // fontCollection.getNormalLineHeight() in characterStyles.updateElementLineHeight() causes 119 or 126 (235 or 242) to be possible (1pt difference)
+                expect(parseInt($(secondParagraph).find('span')[0].style.lineHeight, 10)).to.be.oneOf([235, 242]);
+                expect(parseInt($(thirdParagraph).find('span')[0].style.lineHeight, 10)).to.be.oneOf([119, 126]);
+                expect(parseInt($(fourthParagraph).find('span')[0].style.lineHeight, 10)).to.be.oneOf([119, 126]);
 
                 model.getSelection().setTextSelection([1, 0]);
                 attributes = ((model.getAttributes('paragraph', { maxIterations: 10 }) || {}).paragraph || {});
@@ -252,9 +255,10 @@ define([
                 model.setAttribute('paragraph', 'lineHeight', LINEHEIGHT__NORMAL);
                 model.setAttribute('paragraph', 'marginBottom', (PARAGRAPHSPACING__NONE * defaultMarginBottom));
 
-                expect(parseInt($(secondParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(100);
-                expect(parseInt($(thirdParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(100);
-                expect(parseInt($(fourthParagraph).find('span')[0].style.lineHeight, 10)).to.be.equal(100);
+                // fontCollection.getNormalLineHeight() in characterStyles.updateElementLineHeight() causes 119 or 126 to be possible (1pt difference)
+                expect(parseInt($(secondParagraph).find('span')[0].style.lineHeight, 10)).to.be.oneOf([119, 126]);
+                expect(parseInt($(thirdParagraph).find('span')[0].style.lineHeight, 10)).to.be.oneOf([119, 126]);
+                expect(parseInt($(fourthParagraph).find('span')[0].style.lineHeight, 10)).to.be.oneOf([119, 126]);
 
                 model.getSelection().setTextSelection([1, 0]);
                 attributes = ((model.getAttributes('paragraph', { maxIterations: 10 }) || {}).paragraph || {});
@@ -273,6 +277,35 @@ define([
                 //
                 // END OF 'Paragraph and LineHeight spacing' test
             });
+
+            it('should avoid setting character attributes to trailing whitespace(s)', function () {
+                expect($(firstParagraph).find('span')[0].style.textDecoration).to.equal('none');
+
+                model.getSelection().setTextSelection([0, 0], [0, 6]);
+                model.setAttribute('character', 'underline', true);
+
+                expect($(firstParagraph).find('span')[0].style.textDecoration).to.equal('underline');
+                expect($(firstParagraph).find('span').first().text().length).to.be.equal(5);
+                expect($(firstParagraph).find('span').first().text()).to.equal('Hello');
+            });
+
+            it('should expand character attributes to whole surrounding word', function () {
+                expect($(firstParagraph).find('span')[1].style.textDecoration).to.equal('none');
+
+                // first setting cursor at the begining of word - should not expand
+                model.getSelection().setTextSelection([0, 6]);
+                model.setAttribute('character', 'underline', true);
+
+                expect($(firstParagraph).find('span')[1].style.textDecoration).to.equal('none');
+
+                // now setting cursor inside word - should expand
+                model.getSelection().setTextSelection([0, 7]);
+                model.setAttribute('character', 'underline', true);
+
+                expect($(firstParagraph).find('span').last()[0].style.textDecoration).to.equal('underline');
+                expect($(firstParagraph).find('span').last().text().length).to.be.equal(5);
+                expect($(firstParagraph).find('span').last().text()).to.equal('World');
+            });
         });
     });
 
