@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH.
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -73,7 +74,7 @@ define([
                 { name: 'insertText', start: [0, 1, 0, 0], target: layoutId_2, text: 'Mastertextformat bearbeiten' },
                 { name: 'insertDrawing', start: [0, 2], target: layoutId_2, type: 'shape', attrs: { presentation: { phIndex: 2 }, drawing: { name: 'Drawing 3', left: 12912, top: 4445, width: 11218, height: 12572 } } },
                 { name: 'insertParagraph', start: [0, 2, 0], target: layoutId_2, attrs: { paragraph: { level: 0 } } },
-                { name: 'insertText', start: [0, 2, 0, 0], target: layoutId_2, text: 'Mastertextformat·bearbeiten' },
+                { name: 'insertText', start: [0, 2, 0, 0], target: layoutId_2, text: 'Mastertextformat bearbeiten' },
 
                 { name: 'insertSlide', start: [0], target: layoutId_1 },
                 { name: 'insertDrawing', start: [0, 0], type: 'shape', attrs: { presentation: { phType: 'ctrTitle' }, drawing: { name: 'Titel 1' } } },
@@ -248,6 +249,13 @@ define([
 
             it('should delete all selected drawings in a multiple drawing selection', function (done) {
 
+                activeSlide = model.getSlideById(model.getActiveSlideId());
+
+                var // the delete promise
+                    delPromise = null,
+                    // the undo promise
+                    undoPromise = null;
+
                 selection.setTextSelection([0, 0, 0, 0]);  // selecting the text position again -> no more multiple selection
                 expect(selection.isMultiSelection()).to.equal(false);
                 expect(selection.getMultiSelection().length).to.equal(0);
@@ -257,28 +265,77 @@ define([
                 expect(selection.isMultiSelection()).to.equal(true);
                 expect(selection.getMultiSelection().length).to.equal(3);
 
-                model.deleteSelected({ deleteKey: true }); // deleting all selected drawings with 'delete' or 'backspace'
-
-                activeSlide = model.getSlideById(model.getActiveSlideId());
                 drawingsOnSlide = activeSlide.children(DOM.ABSOLUTE_DRAWING_SELECTOR);
+                expect(model.isEmptyPlaceHolderDrawing(drawingsOnSlide[0])).to.equal(false);
+                expect(model.isEmptyPlaceHolderDrawing(drawingsOnSlide[1])).to.equal(false);
+                expect(model.isEmptyPlaceHolderDrawing(drawingsOnSlide[2])).to.equal(false);
 
-                expect(selection.isMultiSelection()).to.equal(false);
-                expect(drawingsOnSlide.length).to.equal(0);
+                delPromise = model.deleteSelected({ deleteKey: true }); // deleting all selected drawings with 'delete' or 'backspace'
 
-                // restoring the drawings again
-                var promise = model.getUndoManager().undo();
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                delPromise.always(function () {
+
+                    expect(delPromise.state()).to.equal('resolved');
 
                     drawingsOnSlide = activeSlide.children(DOM.ABSOLUTE_DRAWING_SELECTOR);
+                    expect(drawingsOnSlide.length).to.equal(3);  // all non-empty place holder drawing are replaced by empty place holder drawings
+
+                    expect(model.isEmptyPlaceHolderDrawing(drawingsOnSlide[0])).to.equal(true);
+                    expect(model.isEmptyPlaceHolderDrawing(drawingsOnSlide[1])).to.equal(true);
+                    expect(model.isEmptyPlaceHolderDrawing(drawingsOnSlide[2])).to.equal(true);
 
                     selection.selectAllDrawingsOnSlide();
 
-                    expect(drawingsOnSlide.length).to.equal(3);
-                    expect(selection.isMultiSelection()).to.equal(true);
-                    expect(selection.getMultiSelection().length).to.equal(3);
+                    delPromise = model.deleteSelected({ deleteKey: true }); // deleting all selected drawings with 'delete' or 'backspace'
 
-                    done();
+                    delPromise.always(function () {
+
+                        expect(delPromise.state()).to.equal('resolved');
+
+                        drawingsOnSlide = activeSlide.children(DOM.ABSOLUTE_DRAWING_SELECTOR);
+                        expect(drawingsOnSlide.length).to.equal(0);  // all empty place holder drawing are removed
+
+                        // restoring the drawings again
+                        undoPromise = model.getUndoManager().undo();
+
+                        undoPromise.always(function () {
+
+                            expect(undoPromise.state()).to.equal('resolved');
+
+                            drawingsOnSlide = activeSlide.children(DOM.ABSOLUTE_DRAWING_SELECTOR);
+
+                            selection.selectAllDrawingsOnSlide();
+
+                            expect(drawingsOnSlide.length).to.equal(3);
+                            expect(selection.isMultiSelection()).to.equal(true);
+                            expect(selection.getMultiSelection().length).to.equal(3);
+
+                            expect(model.isEmptyPlaceHolderDrawing(drawingsOnSlide[0])).to.equal(true);
+                            expect(model.isEmptyPlaceHolderDrawing(drawingsOnSlide[1])).to.equal(true);
+                            expect(model.isEmptyPlaceHolderDrawing(drawingsOnSlide[2])).to.equal(true);
+
+                            // restoring the drawings again
+                            undoPromise = model.getUndoManager().undo();
+
+                            undoPromise.always(function () {
+
+                                expect(undoPromise.state()).to.equal('resolved');
+
+                                drawingsOnSlide = activeSlide.children(DOM.ABSOLUTE_DRAWING_SELECTOR);
+
+                                selection.selectAllDrawingsOnSlide();
+
+                                expect(drawingsOnSlide.length).to.equal(3);
+                                expect(selection.isMultiSelection()).to.equal(true);
+                                expect(selection.getMultiSelection().length).to.equal(3);
+
+                                expect(model.isEmptyPlaceHolderDrawing(drawingsOnSlide[0])).to.equal(false);
+                                expect(model.isEmptyPlaceHolderDrawing(drawingsOnSlide[1])).to.equal(false);
+                                expect(model.isEmptyPlaceHolderDrawing(drawingsOnSlide[2])).to.equal(false);
+
+                                done();
+                            });
+                        });
+                    });
                 });
             });
         });
@@ -345,9 +402,9 @@ define([
 
                 expect(drawingsOnSlide.length).to.equal(3);
 
-                // reading the drawing attributes for 'top' and 'height' -> no explicit attributes set at drawing node (except for one drawing)
-                expect($(drawingsOnSlide[0]).data('attributes').drawing.top).to.equal(undefined);
-                expect($(drawingsOnSlide[1]).data('attributes').drawing.top).to.equal(undefined);
+                // reading the drawing attributes for 'top' and 'height' -> get explicit attributes because there position is not longer extended by their placeholder
+                expect($(drawingsOnSlide[0]).data('attributes').drawing.top).to.equal(ctrTitleTop);
+                expect($(drawingsOnSlide[1]).data('attributes').drawing.top).to.equal(subTitleTop);
                 expect($(drawingsOnSlide[2]).data('attributes').drawing.top).to.equal(drawing1Top);
 
                 model.handleDrawingOperations({ ctrlKey: false, shiftKey: true, metaKey: false, keyCode: 38 }); // cursor top + shift key
@@ -392,9 +449,9 @@ define([
 
                 expect(drawingsOnSlide.length).to.equal(3);
 
-                expect($(drawingsOnSlide[0]).data('attributes').drawing.rotation).to.equal(undefined);
-                expect($(drawingsOnSlide[1]).data('attributes').drawing.rotation).to.equal(undefined);
-                expect($(drawingsOnSlide[2]).data('attributes').drawing.rotation).to.equal(undefined);
+                expect($(drawingsOnSlide[0]).data('attributes').drawing.rotation).to.equal(0);
+                expect($(drawingsOnSlide[1]).data('attributes').drawing.rotation).to.equal(0);
+                expect($(drawingsOnSlide[2]).data('attributes').drawing.rotation).to.equal(0);
 
                 model.handleDrawingOperations({ ctrlKey: false, shiftKey: false, metaKey: false, altKey: true, keyCode: 39 }); // alt + right
 
