@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Michael Nimz <michael.nimz@open-xchange.com>
  */
@@ -25,6 +26,46 @@ define([
             expect(Config).to.be.an('object');
         });
 
+        // constants ----------------------------------------------------------
+
+        describe('constant "LOCALE"', function () {
+            it('should exist', function () {
+                expect(Config).to.have.a.property('LOCALE').that.is.a('string');
+            });
+        });
+
+        describe('constant "LANGUAGE"', function () {
+            it('should exist', function () {
+                expect(Config).to.have.a.property('LANGUAGE').that.matches(/^[a-z]{2,}$/);
+                expect(Config.LANGUAGE).to.equal(Config.LOCALE.substr(0, Config.LANGUAGE.length));
+            });
+        });
+
+        describe('constant "COUNTRY"', function () {
+            it('should exist', function () {
+                expect(Config).to.have.a.property('COUNTRY').that.matches(/^[A-Z]{2,}$/);
+                expect(Config.COUNTRY).to.equal(Config.LOCALE.substr(-Config.COUNTRY.length));
+            });
+        });
+
+        describe('constant "DEBUG"', function () {
+            it('should exist', function () {
+                expect(Config).to.have.a.property('DEBUG').that.is.a('boolean');
+            });
+        });
+
+        describe('constant "AUTOTEST"', function () {
+            it('should exist', function () {
+                expect(Config).to.have.a.property('AUTOTEST').that.is.a('boolean');
+            });
+        });
+
+        describe('constant "UNITTEST"', function () {
+            it('should exist', function () {
+                expect(Config).to.have.a.property('UNITTEST', true);
+            });
+        });
+
         // static methods -----------------------------------------------------
 
         describe('method "get"', function () {
@@ -36,6 +77,12 @@ define([
             });
         });
 
+        describe('method "set"', function () {
+            it('should exist', function () {
+                expect(Config).itself.to.respondTo('set');
+            });
+        });
+
         describe('method "getFlag"', function () {
             it('should exist', function () {
                 expect(Config).itself.to.respondTo('getFlag');
