@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -520,18 +521,19 @@ define([
                 expect(formatter).to.respondTo('formatValue');
             });
 
-            function expectFormattedValue(formatCode, value, exp) {
-                var parsedFormat = Parser.parseFormatCode('ooxml', 'op', formatCode);
-                expect(formatter.formatValue(parsedFormat, value)).to.equal(exp);
-            }
-
-            function expectFormattedValueODF(formatCode, value, expOOX, expODF) {
+            function expectFormattedValue(formatCode, value, expOOX, expODF) {
                 var parsedFormatOOX = Parser.parseFormatCode('ooxml', 'op', formatCode);
                 expect(formatter.formatValue(parsedFormatOOX, value)).to.equal(expOOX);
                 var parsedFormatODF = Parser.parseFormatCode('odf', 'op', formatCode);
-                expect(formatter.formatValue(parsedFormatODF, value)).to.equal(expODF);
+                expect(formatter.formatValue(parsedFormatODF, value)).to.equal(_.isUndefined(expODF) ? expOOX : expODF);
             }
 
+            // bug 48011: special LCIDs for system date and time formats
+            it('should use the current long system formats for special LCIDs', function () {
+                expectFormattedValue('[$-F800]M/D/Y', 36617.25, 'Samstag, 1. April 2000');
+                expectFormattedValue('[$-F400]h:m:s', 36617.25, '06:00:00');
+            });
+
             it('should use the special number format: ???-??-#-0', function () {
                 expectFormattedValue('???-??-#-0', 123456789, '12345-67-8-9');
                 expectFormattedValue('???-??-#-0', 123450000, '12345-00-0-0');
@@ -545,22 +547,45 @@ define([
 
             // special ODF format codes
             it('should use quarter date format', function () {
-                expectFormattedValueODF('Q', 36617, 'Q', 'Q2');
-                expectFormattedValueODF('QQ', 36617, 'QQ', '2. Quartal');
-                expectFormattedValueODF('QQQ', 36617, 'QQQ', '2. QuartalQ2');
+                expectFormattedValue('Q', 36617, 'Q', 'Q2');
+                expectFormattedValue('QQ', 36617, 'QQ', '2. Quartal');
+                expectFormattedValue('QQQ', 36617, 'QQQ', '2. QuartalQ2');
             });
             it('should use weekday format for ODF', function () {
-                expectFormattedValueODF('N', 36617, 'N', 'N');
-                expectFormattedValueODF('NN', 36617, 'NN', 'Sa');
-                expectFormattedValueODF('NNN', 36617, 'NNN', 'Saturday');
+                expectFormattedValue('N', 36617, null, 'N');
+                expectFormattedValue('NN', 36617, null, 'Sa');
+                expectFormattedValue('NNN', 36617, null, 'Samstag');
 // TODO!
-//                expectFormattedValueODF('NNNN', 36617, 'NNNN', 'Saturday, ');
-//                expectFormattedValueODF('NNNNN', 36617, 'NNNN', 'Saturday, N');
+//                expectFormattedValue('NNNN', 36617, 'NNNN', 'Saturday, ');
+//                expectFormattedValue('NNNNN', 36617, 'NNNN', 'Saturday, N');
             });
             it('should use week number format for ODF', function () {
-                expectFormattedValueODF('W', 36547, 'W', 'W');
-                expectFormattedValueODF('WW', 36547, 'WW', '4');
-                expectFormattedValueODF('WWW', 36547, 'WWW', '4W');
+                expectFormattedValue('W', 36547, 'W', 'W');
+                expectFormattedValue('WW', 36547, 'WW', '4');
+                expectFormattedValue('WWW', 36547, 'WWW', '4W');
+            });
+
+            it('should handle number formats correctly', function () {
+                expectFormattedValue('0.00', 9.99999999, '10,00');// Bug 41434
+
+            });
+
+            it('should handle fraction formats correctly', function () {
+
+                function expectFormattedFraction(number, exp1, exp2, exp3) {
+                    expectFormattedValue('# ?/?', number, exp1);
+                    expectFormattedValue('# ??/??', number, exp2);
+                    expectFormattedValue('# ???/???', number, exp3);
+                }
+
+                expectFormattedFraction(0,    '0    ', '0      ', '0        ');
+                expectFormattedFraction(0.01, '0    ', '0      ', '   1/100');
+                expectFormattedFraction(0.98, '1    ', ' 49/50',  '  49/50 ');
+                expectFormattedFraction(0.99, '1    ', ' 98/99',  '  99/100');
+                expectFormattedFraction(1.01, '1    ', '1      ', '1   1/100');
+                expectFormattedFraction(1.02, '1    ', '1  1/50', '1   1/50 ');
+                expectFormattedFraction(1.99, '2    ', '1 98/99', '1  99/100');
+                expectFormattedFraction(2.75, '2 3/4', '2  3/4 ', '2   3/4  ');
             });
         });
     });
