@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -86,9 +87,9 @@ define([
                 expect(Parser.parseLeadingNumber('42')).to.deep.equal({ number: 42, text: '42', sign: '', dec: false, scientific: false, grouped: false, remaining: '' });
                 expect(Parser.parseLeadingNumber('-42', { sign: true })).to.deep.equal({ number: -42, text: '-42', sign: '-', dec: false, scientific: false, grouped: false, remaining: '' });
 
-                expect(Parser.parseLeadingNumber('42 ' + LocaleData.CURRENCY)).to.deep.equal({ number: 42, text: '42', sign: '', dec: false, scientific: false, grouped: false, remaining: ' €' });
-                expect(Parser.parseLeadingNumber('42 ' + LocaleData.ISO_CURRENCY)).to.deep.equal({ number: 42, text: '42', sign: '', dec: false, scientific: false, grouped: false, remaining: ' EUR' });
-                expect(Parser.parseLeadingNumber('-42 ' + LocaleData.CURRENCY, { sign: true })).to.deep.equal({ number: -42, text: '-42', sign: '-', dec: false, scientific: false, grouped: false, remaining: ' €' });
+                expect(Parser.parseLeadingNumber('42 \u20ac')).to.deep.equal({ number: 42, text: '42', sign: '', dec: false, scientific: false, grouped: false, remaining: ' \u20ac' });
+                expect(Parser.parseLeadingNumber('42 EUR')).to.deep.equal({ number: 42, text: '42', sign: '', dec: false, scientific: false, grouped: false, remaining: ' EUR' });
+                expect(Parser.parseLeadingNumber('-42 \u20ac', { sign: true })).to.deep.equal({ number: -42, text: '-42', sign: '-', dec: false, scientific: false, grouped: false, remaining: ' \u20ac' });
 
                 expect(Parser.parseLeadingNumber('42 %')).to.deep.equal({ number: 42, text: '42', sign: '', dec: false, scientific: false, grouped: false, remaining: ' %' });
                 expect(Parser.parseLeadingNumber('-42 %', { sign: true })).to.deep.equal({ number: -42, text: '-42', sign: '-', dec: false, scientific: false, grouped: false, remaining: ' %' });
@@ -262,19 +263,19 @@ define([
                 expect(Parser).itself.to.respondTo('parseLeadingCurrency');
             });
             it('should parse currency numbers using local decimal separator', function () {
-                expect(Parser.parseLeadingCurrency(LocaleData.CURRENCY + '42')).to.deep.equal(['€42', '42', '€']);
+                expect(Parser.parseLeadingCurrency(LocaleData.CURRENCY + '42')).to.deep.equal(['\u20ac42', '42', '\u20ac']);
                 expect(Parser.parseLeadingCurrency(LocaleData.ISO_CURRENCY + '42')).to.deep.equal(['EUR42', '42', 'EUR']);
-                expect(Parser.parseLeadingCurrency(LocaleData.CURRENCY + '42' + LocaleData.DEC + '33')).to.deep.equal(['€42,33', '42,33', '€']);
+                expect(Parser.parseLeadingCurrency(LocaleData.CURRENCY + '42' + LocaleData.DEC + '33')).to.deep.equal(['\u20ac42,33', '42,33', '\u20ac']);
                 expect(Parser.parseLeadingCurrency(LocaleData.ISO_CURRENCY + '42' + LocaleData.DEC + '33')).to.deep.equal(['EUR42,33', '42,33', 'EUR']);
 
-                expect(Parser.parseLeadingCurrency('-' + LocaleData.CURRENCY + '42')).to.deep.equal(['-€42', '-42', '€']);
+                expect(Parser.parseLeadingCurrency('-' + LocaleData.CURRENCY + '42')).to.deep.equal(['-\u20ac42', '-42', '\u20ac']);
                 expect(Parser.parseLeadingCurrency('-' + LocaleData.ISO_CURRENCY + '42')).to.deep.equal(['-EUR42', '-42', 'EUR']);
-                expect(Parser.parseLeadingCurrency('-' + LocaleData.CURRENCY + '42' + LocaleData.DEC + '33')).to.deep.equal(['-€42,33', '-42,33', '€']);
+                expect(Parser.parseLeadingCurrency('-' + LocaleData.CURRENCY + '42' + LocaleData.DEC + '33')).to.deep.equal(['-\u20ac42,33', '-42,33', '\u20ac']);
                 expect(Parser.parseLeadingCurrency('-' + LocaleData.ISO_CURRENCY + '42' + LocaleData.DEC + '33')).to.deep.equal(['-EUR42,33', '-42,33', 'EUR']);
 
-                expect(Parser.parseLeadingCurrency(LocaleData.CURRENCY + '-42')).to.deep.equal(['€-42', '-42', '€']);
+                expect(Parser.parseLeadingCurrency(LocaleData.CURRENCY + '-42')).to.deep.equal(['\u20ac-42', '-42', '\u20ac']);
                 expect(Parser.parseLeadingCurrency(LocaleData.ISO_CURRENCY + '-42')).to.deep.equal(['EUR-42', '-42', 'EUR']);
-                expect(Parser.parseLeadingCurrency(LocaleData.CURRENCY + '-42' + LocaleData.DEC + '33')).to.deep.equal(['€-42,33', '-42,33', '€']);
+                expect(Parser.parseLeadingCurrency(LocaleData.CURRENCY + '-42' + LocaleData.DEC + '33')).to.deep.equal(['\u20ac-42,33', '-42,33', '\u20ac']);
                 expect(Parser.parseLeadingCurrency(LocaleData.ISO_CURRENCY + '-42' + LocaleData.DEC + '33')).to.deep.equal(['EUR-42,33', '-42,33', 'EUR']);
             });
             // TODO: more
@@ -336,9 +337,9 @@ define([
             });
             it('should recognize "standard" category', function () {
                 expect(Parser.parseFormatCode('ooxml', 'op', 'General')).to.have.a.property('category', 'standard');
-                expect(Parser.parseFormatCode('ooxml', 'ui', 'General')).to.have.a.property('category', 'standard');
+                expect(Parser.parseFormatCode('ooxml', 'ui', 'Standard')).to.have.a.property('category', 'standard');
                 expect(Parser.parseFormatCode('odf', 'op', 'General')).to.have.a.property('category', 'standard');
-                expect(Parser.parseFormatCode('odf', 'ui', 'General')).to.have.a.property('category', 'standard');
+                expect(Parser.parseFormatCode('odf', 'ui', 'Standard')).to.have.a.property('category', 'standard');
                 // bug 46211: empty format code falls back to standard format
                 expect(Parser.parseFormatCode('ooxml', 'op', '')).to.have.a.property('category', 'standard');
                 expect(Parser.parseFormatCode('ooxml', 'ui', '')).to.have.a.property('category', 'standard');
@@ -424,7 +425,7 @@ define([
             it('should parse special ODF date tokens', function () {
                 expect(Parser.parseFormatCode('ooxml', 'op', 'QQ')).to.have.a.property('category', 'custom');
                 expect(Parser.parseFormatCode('ooxml', 'op', 'WW')).to.have.a.property('category', 'custom');
-                expect(Parser.parseFormatCode('ooxml', 'op', 'NN')).to.have.a.property('category', 'custom');
+                expect(Parser.parseFormatCode('ooxml', 'op', 'NN')).to.have.a.property('syntaxError', true);
                 expect(Parser.parseFormatCode('odf', 'op', 'QQ')).to.have.a.property('category', 'date');
                 expect(Parser.parseFormatCode('odf', 'op', 'WW')).to.have.a.property('category', 'date');
                 expect(Parser.parseFormatCode('odf', 'op', 'NN')).to.have.a.property('category', 'date');
@@ -521,7 +522,7 @@ define([
                 expect(timeFormat.hasEqualCategory(dateTimeFormat)).to.equal(false);
             });
             it('should treat date and time categories differently', function () {
-                expect(stdFormat.hasEqualCategory(dateFormat), { anyDateTime: true }).to.equal(false);
+                expect(stdFormat.hasEqualCategory(dateFormat, { anyDateTime: true })).to.equal(false);
                 expect(dateFormat.hasEqualCategory(timeFormat, { anyDateTime: true })).to.equal(true);
                 expect(timeFormat.hasEqualCategory(dateFormat, { anyDateTime: true })).to.equal(true);
                 expect(dateFormat.hasEqualCategory(dateTimeFormat, { anyDateTime: true })).to.equal(true);
