@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -46,6 +47,22 @@ define([
 
         // public methods -----------------------------------------------------
 
+        describe('method "getUid"', function () {
+            var obj1 = new BaseObject(), obj2 = new BaseObject();
+            it('should exist', function () {
+                expect(obj1).to.respondTo('getUid');
+            });
+            it('should return a UID', function () {
+                expect(obj1.getUid()).to.be.a('string');
+            });
+            it('should return the same UID for the same object', function () {
+                expect(obj1.getUid()).to.equal(obj1.getUid());
+            });
+            it('should return different UIDs for different objects', function () {
+                expect(obj1.getUid()).to.not.equal(obj2.getUid());
+            });
+        });
+
         describe('method "createAbortablePromise"', function () {
             var obj = new BaseObject();
             it('should exist', function () {
@@ -54,6 +71,8 @@ define([
             it('should create an abortable promise', function () {
                 var promise = obj.createAbortablePromise($.Deferred());
                 expect(promise).to.be.an('object');
+                expect(promise).to.respondTo('state');
+                expect(promise).to.respondTo('promise');
                 expect(promise).to.respondTo('abort');
                 expect(promise.state()).to.equal('pending');
                 promise.abort();
@@ -68,24 +87,24 @@ define([
                 expect(promise.state()).to.equal('resolved');
             });
             it('should invoke the callback on abort', function () {
-                var spy = sinon.spy(),
-                    promise = obj.createAbortablePromise($.Deferred(), spy);
+                var spy = sinon.spy();
+                var promise = obj.createAbortablePromise($.Deferred(), spy);
                 expect(spy.called).to.equal(false);
                 promise.abort();
                 expect(spy.calledOnce).to.equal(true);
-                expect(spy.calledOn(promise)).to.equal(true);
+                expect(spy.calledOn(obj)).to.equal(true);
                 expect(spy.calledWith('abort')).to.equal(true);
             });
             it('should abort the promise after a timeout', function () {
-                var promise = obj.createAbortablePromise($.Deferred(), $.noop, 10);
+                var promise = obj.createAbortablePromise($.Deferred(), null, 10);
                 expect(promise.state()).to.equal('pending');
                 clock.tick(11);
                 expect(promise.state()).to.equal('rejected');
             });
             it('should override promise.then() to return an abortable promise', function () {
-                var spy = sinon.spy(),
-                    promise1 = obj.createAbortablePromise($.Deferred(), spy).fail(spy),
-                    promise2 = promise1.then(null, spy, null, spy);
+                var spy = sinon.spy();
+                var promise1 = obj.createAbortablePromise($.Deferred(), spy).fail(spy);
+                var promise2 = promise1.then(null, spy, null, spy);
                 expect(promise1).to.not.equal(promise2);
                 expect(promise2).to.respondTo('abort');
                 promise2.abort(42);
@@ -113,7 +132,7 @@ define([
                 expect(promise.state()).to.equal('pending');
                 obj.destroy();
                 expect(promise.state()).to.equal('rejected');
-                expect(spy.calledWith('abort')).to.equal(true);
+                expect(spy.calledWith('destroy')).to.equal(true);
             });
         });
 
@@ -161,19 +180,35 @@ define([
             });
         });
 
-        describe('method "getUid"', function () {
-            var obj1 = new BaseObject(), obj2 = new BaseObject();
+        describe('method "createDeferredObject"', function () {
+            var obj = new BaseObject();
             it('should exist', function () {
-                expect(obj1).to.respondTo('getUid');
+                expect(obj).to.respondTo('createDeferredObject');
             });
-            it('should return a UID', function () {
-                expect(obj1.getUid()).to.be.a('string');
+            it('should create a pending deferred object', function () {
+                var def = obj.createDeferredObject();
+                expect(def).to.be.an('object');
+                expect(def).to.respondTo('state');
+                expect(def).to.respondTo('promise');
+                expect(def).to.respondTo('resolve');
+                expect(def).to.respondTo('reject');
+                expect(def.state()).to.equal('pending');
             });
-            it('should return the same UID for the same object', function () {
-                expect(obj1.getUid()).to.equal(obj1.getUid());
+            it('should reject the deferred object after a timeout', function () {
+                var spy = sinon.spy();
+                var def = obj.createDeferredObject({ timeout: 10 }).fail(spy);
+                expect(def.state()).to.equal('pending');
+                clock.tick(11);
+                expect(def.state()).to.equal('rejected');
+                expect(spy.calledWith('timeout')).to.equal(true);
             });
-            it('should return different UIDs for different objects', function () {
-                expect(obj1.getUid()).to.not.equal(obj2.getUid());
+            it('should reject the deferred object on destruction', function () {
+                var spy = sinon.spy();
+                var def = obj.createDeferredObject().fail(spy);
+                expect(def.state()).to.equal('pending');
+                obj.destroy();
+                expect(def.state()).to.equal('rejected');
+                expect(spy.calledWith('destroy')).to.equal(true);
             });
         });
 
@@ -350,8 +385,8 @@ define([
                 expect(obj).to.respondTo('waitForFailure');
             });
             it('should wait for promise\'s failure', function () {
-                var def1 = $.Deferred(), spy1 = sinon.spy(),
-                    def2 = $.Deferred(), spy2 = sinon.spy();
+                var def1 = $.Deferred(), spy1 = sinon.spy();
+                var def2 = $.Deferred(), spy2 = sinon.spy();
                 obj.waitForFailure(def1, spy1);
                 obj.waitForFailure(def2, spy2);
                 expect(spy1.called).to.equal(false);
@@ -369,8 +404,8 @@ define([
                 expect(obj).to.respondTo('waitForAny');
             });
             it('should wait for promise\'s success or failure', function () {
-                var def1 = $.Deferred(), spy1 = sinon.spy(),
-                    def2 = $.Deferred(), spy2 = sinon.spy();
+                var def1 = $.Deferred(), spy1 = sinon.spy();
+                var def2 = $.Deferred(), spy2 = sinon.spy();
                 obj.waitForAny(def1, spy1);
                 obj.waitForAny(def2, spy2);
                 expect(spy1.called).to.equal(false);
@@ -384,19 +419,16 @@ define([
 
         describe('method "destroy"', function () {
 
-            var obj = new BaseObject(),
-                src = $({}),
-                src2 = $({}),
-                def = $.Deferred(),
-                spy1 = sinon.spy(),
-                spy2 = sinon.spy(),
-                spy3 = sinon.spy();
-
-            src2.off = false;
+            var obj = new BaseObject();
+            var src1 = $({}), src2 = $({});
+            var def = $.Deferred();
+            var spy1 = sinon.spy();
+            var spy2 = sinon.spy();
+            var spy3 = sinon.spy();
 
             obj.registerDestructor(spy1);
             obj.registerDestructor(spy2);
-            obj.listenTo(src, 'test', spy3);
+            obj.listenTo(src1, 'test1', spy3);
             obj.listenTo(src2, 'test2', spy3);
             obj.waitForSuccess(def, spy3);
 
@@ -422,7 +454,7 @@ define([
                 expect(obj).not.to.respondTo('destroy');
             });
             it('should release event handlers', function () {
-                src.trigger('test');
+                src1.trigger('test1');
                 expect(spy3.called).to.equal(false);
             });
             it('should release promise handlers', function () {
