@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -61,6 +62,15 @@ define([
             expect(TimerMixin).to.be.a('function');
         });
 
+        // Scheduler must be empty, otherwise some tests may fail unexpectedly because of other
+        // running background timer loops. If this test fails, there may exist another unit test
+        // module whare an application has been created globally. Check that the function call
+        // AppHelper.createXYZApplication() is located locally inside the callback of the
+        // outermost "describe()" of the unit test.
+        it('should run with clean timer scheduler', function () {
+            expect(Scheduler.empty()).to.equal(true);
+        });
+
         // private helpers ----------------------------------------------------
 
         function TimerClass() {
@@ -384,7 +394,7 @@ define([
                 expect(obj).to.respondTo('repeatSliced');
             });
             it('should invoke callback in time slices and stop on Utils.BREAK', function () {
-                var spy = makeSpy();
+                var spy = makeSpy(null);
                 var timer = obj.repeatSliced(spy);
                 expect(spy.called).to.equal(false);
                 // tick once to trigger first slice; spy will run twice (150 each)
