@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -329,15 +330,15 @@ define([
             });
         });
 
-        describe('method "createCombinedIterator"', function () {
+        describe('method "createSerialIterator"', function () {
             it('should exist', function () {
-                expect(IteratorUtils).itself.to.respondTo('createCombinedIterator');
+                expect(IteratorUtils).itself.to.respondTo('createSerialIterator');
             });
-            it('should create a combined iterator', function () {
+            it('should create a serial iterator', function () {
                 var it1 = IteratorUtils.createArrayIterator([2, 3]);
                 var it2 = IteratorUtils.ALWAYS_DONE_ITERATOR;
                 var it3 = IteratorUtils.createArrayIterator([4, 5]);
-                var combIt = IteratorUtils.createCombinedIterator(it1, it2, it3);
+                var combIt = IteratorUtils.createSerialIterator(it1, it2, it3);
                 expect(combIt).to.respondTo('next');
                 expect(combIt.next()).to.deep.equal({ done: false, value: 2, index: 0 });
                 expect(combIt.next()).to.deep.equal({ done: false, value: 3, index: 1 });
