@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -23,21 +24,25 @@ window.chai.use(function (chai, utils) {
      * Adds a new property to Chai's message chain.
      *
      * @param {String} name
-     *  The name of the new property.
+     *  The name of the new property. May be a space-separated list of
+     *  different property names.
      *
      * @param {Function} handler
      *  The callback function invoked for the property. Will be called in the
      *  context of the assertion instance.
      */
     function addProperty(name, handler) {
-        utils.addProperty(chai.Assertion.prototype, name, handler);
+        name.split(/\s+/).forEach(function (property) {
+            utils.addProperty(chai.Assertion.prototype, property, handler);
+        });
     }
 
     /**
      * Adds a new method to Chai's message chain.
      *
      * @param {String} name
-     *  The name of the new method.
+     *  The name of the new method. May be a space-separated list of different
+     *  methods names.
      *
      * @param {Function} handler
      *  The callback function invoked for the method. Will be called in the
@@ -45,7 +50,9 @@ window.chai.use(function (chai, utils) {
      *  the method in the language chain of the assertion.
      */
     function addMethod(name, handler) {
-        utils.addMethod(chai.Assertion.prototype, name, handler);
+        name.split(/\s+/).forEach(function (method) {
+            utils.addMethod(chai.Assertion.prototype, method, handler);
+        });
     }
 
     /**
@@ -65,6 +72,51 @@ window.chai.use(function (chai, utils) {
 
     // properties =============================================================
 
+    /**
+     * A property asserting whether the actual value is a jQuery collection
+     * containing exactly one DOM node, regardless of its type.
+     *
+     * @example
+     *  expect($('<div>')).to.be.a.jqNode;
+     */
+    addProperty('jqNode', function () {
+        this.assert(
+            (this._obj instanceof $) && (this._obj.length === 1),
+            'expected #{this} to be a jQuery collection with a single DOM node',
+            'expected #{this} to not be a jQuery collection with a single DOM node'
+        );
+    });
+
+    /**
+     * A property asserting whether the actual value is a jQuery collection
+     * containing exactly one DOM element node.
+     *
+     * @example
+     *  expect($('<div>')).to.be.a.jqElementNode;
+     */
+    addProperty('jqElementNode', function () {
+        this.assert(
+            (this._obj instanceof $) && (this._obj.length === 1) && (this._obj[0].nodeType === 1),
+            'expected #{this} to be a jQuery collection with a single DOM element node',
+            'expected #{this} to not be a jQuery collection with a single DOM element node'
+        );
+    });
+
+    /**
+     * A property asserting whether the actual value is a jQuery collection
+     * containing exactly one DOM text node.
+     *
+     * @example
+     *  expect($('<div>text</div>').contents()).to.be.a.jqTextNode;
+     */
+    addProperty('jqTextNode', function () {
+        this.assert(
+            (this._obj instanceof $) && (this._obj.length === 1) && (this._obj[0].nodeType === 3),
+            'expected #{this} to be a jQuery collection with a single DOM text node',
+            'expected #{this} to not be a jQuery collection with a single DOM text node'
+        );
+    });
+
     /**
      * A property asserting whether the actual value is zero, or almost zero.
      * Precisely, returns whether the absolute value is less than or equal to
@@ -144,7 +196,7 @@ window.chai.use(function (chai, utils) {
      *  The expected string that will be compared with the result of passing
      *  the tested value to the String() constructor.
      */
-    addMethod('stringifyTo', function (expected) {
+    addMethod('stringifyTo stringifiesTo', function (expected) {
         var result = String(this._obj);
         this.assert(
             result === expected,
@@ -173,5 +225,20 @@ window.chai.use(function (chai, utils) {
         );
     });
 
+    // helpers ================================================================
+
+    /**
+     * Wrap the expect() function and check the parameter count. This helps to
+     * prevent typos in the unit tests that may hide failing tests.
+     */
+    window.expect = (function (expect) {
+        return function (result) {
+            if (arguments.length !== 1) {
+                throw new Error('expect() MUST be called with exactly one parameter');
+            }
+            return expect(result);
+        };
+    }(window.expect));
+
     // ========================================================================
 });
