@@ -9,6 +9,11 @@ require.config({
         return (/\/(tk|settings)\/.*_spec\.js$/i).test(file);
     }),
 
+    // global helper code for the tests to be loaded with RequireJS
+    paths: {
+        globals: '/base/spec/globals'
+    },
+
     // we have to kickoff jasmine, as it is asynchronous
     callback: window.__karma__.start
 });
